!
!+ Defines kind parameters
!
! $Id: mo_kind.f90 7362 2011-11-01 16:48:20Z andreas $
!
!==============================================================================
!> Define kind parameters
!>
MODULE mo_kind
!
! Description:
!   Define kind parameters.
!
! Current Code Owner: DWD, Andreas Rhodin
!    phone: +49 69 8062 2722
!    fax:   +49 69 8062 3721
!    email: andreas.rhodin@dwd.de
!
! History:
! Version      Date       Name
! ------------ ---------- ----
! V1_1         2008/11/05 Andreas Rhodin
!  First operational 3D-Var release
! V1_4         2009/03/26 Andreas Rhodin
!  No changes
! V1_7         2009/08/24 Andreas Rhodin
!  add directives for doxygen
! V1_10        2010/04/20 Michael Gertz
!  Adaptions for SVN
! V1_13        2011/11/01 Andreas Rhodin
!  changed 3dvar revision numbers (CVS->SVN)
!
! Code Description:
! Language: Fortran 95.
! Software Standards:
!
! Authors:
! Andreas Rhodin  MPIfM/DWD  1999  initial revision
!                            2007  changed for NEC SX
!------------------------------------------------------------------------------
   implicit none
   public

   !---------------------
   ! Real kind parameters
   !---------------------
   !
   !>  8 byte real kind parameter
   !
   integer, parameter :: dp = selected_real_kind(13)
   !
   !>  4 byte real kind parameter
   !
   integer, parameter :: sp = selected_real_kind(6)
   !
   !>  working precision used in the program
   !
   integer, parameter :: wp = dp

   !------------------------
   ! Integer kind parameters
   !------------------------
   !
   !>  8 byte integer kind parameter
   !
   integer, parameter :: i8 = selected_int_kind(14)  ! 8 byte integer
   !
   !>  4 byte integer kind parameter
   !
   integer, parameter :: i4 = selected_int_kind (9)  ! 4 byte integer
   !
   !>  2 byte integer kind parameter
   !
   integer, parameter :: i2 = selected_int_kind (4)  ! 2 byte integer
   !
   !>  1 byte integer kind parameter
   !
   integer, parameter :: i1 = selected_int_kind (2)  ! 1 byte integer

   !---------------------------------------------------------
   !> kind parameter for integer sufficient to hold a pointer
   !---------------------------------------------------------
#ifdef CP4
   integer, parameter :: cp = i4
#else
   integer, parameter :: cp = i8
#endif

end module mo_kind

!==============================================================================
