!+ Source module for the radar operators
!------------------------------------------------------------------------------

!!! Fix for lreadmeta_from_netcdf=.true.: Model crashed in case there were missing
!!!       records (obs_times) in those radar files which were not used to get the obs_times
!!!       (only one of 4 radar files for a station is used to get the obs_times!). 
!!!       Now such partly missing obs_times are eliminated, if
!!!       lcheck_inputrecords is set .true.

!!! NOTE: horizontal smoothing scheint viel ineffektiver zu sein als vertikal. Warum????

!!! NOTE: in the parallel version of output_radar_smth, each PE has 
!!!       to output the SAME radar ista
!!!       at each output timestep. At the moment there cannot be a change
!!!       in this ordering during the model run! Take care of this, if
!!!       some day an asynchroneous version is implemented.
!!!    REASON: the SAVE field n_sh for the first range bin encountering
!!!       beam shielding.

!!! NOTE: scheinbar lange Rechenzeiten in calc_dbz_vec() kommen daher, dass
!!!       in der von dort aufgerufenen radar_mie_lm_vec.f90 ein MPI-Austausch
!!!       bei der Bestimmung der Tmax fuer den Schmelzgrad stattfindet und
!!!       sich dort die PEs synchronisieren. Starke load imbalancen bei der
!!!       Radarpunktverteilung auf die PEs fuehren dann in Verbindung mit der
!!!       Schleifenabarbeitung der einzelnen Radarstationen in den calc_mod_...()
!!!       Routinen zu langen Wartezeiten innerhalb calc_dbz_vec(), die voll
!!!       als "Rechenzeit" gezaehlt werden.

!!! TODO: Mie-lookup tables parallelisieren: jeder PE erstellt nur einen Teil der
!!!       table, dann mti mpi_alltoallv() broadcasten. Wg. starker abh. der Konvergenz
!!!       der Mie-Reihen primr anhand von Temperatur und Schmelzgrad auf die
!!!       PEs aufteilen.

!!! TODO: concept for (reflectivity weighted) terminal velocity and distribution
!!!       of work among Yuefei, Dorit and me.

!!! TODO: replace local index calculations by sub2ind??() and ind2sub??()

!!! TODO: output_radar_smth() - replace nsmth by nobs where possible and
!!!       reduce allocated field sizes accordingly, also eliminate "IF (counter(irp) /= 0)"
!!!       if possible.



!!! Now output of el_loc and hl_loc only once at the beginning for const. beam propag.
!!!   to save time, memory and disk space!

!!! replaced maxrss()-Function from a lib from A. Rhodin to U. Blahaks own lib:
!!!  Compile with LIB = /e/uhome/ublahak/LM/LIBCFUNC/libcfunc_sx9.a

!!! Eliminated very large local array hfl(irp,2,2,ke) in calc_vert_weight_vec(),
!!!  which caused unnecessary huge memory consumption in case of const. beam propag.!

!!! Bugfixe: wrong "n" index in calls to el_loc_43() has been corrected,
!!!          now local elevations in file "ersim..." look good. Slight changes
!!!          of the results for radial wind for const. beam propag.

!!! Lokale Felder auf den PEs sofort deallokieren, wenn gatherv_values() gelaufen ist. Das
!!!    drfte den Speicherbedarf stark absenken.

!!! output3D_ascii() - put information on azimuts, ranges, elevations and radar position
!!!                    in file headers; also itype_refl, configuration flags and aliasing info.

!!! lextdbz only effective if itype_refl = 1 !

!!! Implemented beam shielding for constant beam propagation.
!!!   This is accomplished by using internally a special missing value
!!!   -988.88 for vr and z of radar bins below the orography, and then,
!!!   in output_radar() and output_radar_smth(), set all z and vr-values
!!!   to missing (-999.99) outwards of these shielded bins.
!!!   - output_radar() is straight forward (new subroutine elim_shielded(...))
!!!   - output_radar_smth() was a little bit tricky due to the
!!!     "vector-like" storage of multidimensional fields. Here, a new
!!!     index-field n_sh(naz,nel,niv,nih) was created, in which the
!!!     range-index n of the first occurence of a shielded bin is
!!!     stored for each ray, when output_radar_smth() is called the first
!!!     time. Later, all bins outwards of this n are treated as missing
!!!     in the integral averages which make up the beam smoothing.
!!!     For reflectivity, missing values are counted as zeros with full weight.
!!!     For radial velocity, missing values and their weights are discarded.

!!! (Un)comment the following precprocessor switch if you want (not want) to
!!!   have detailed ftrace (=profiling) output for obs_write_cdf_feedobs()
! #define FTRACE_RADAR

!!! new optional flags "obs_is_aliased" and "mod_is_aliased" for obs_write_cdf_feedobs()

!!! namelist parameters "llookup" und "itype_refl_glob" eingefuehrt

!!! Bugfix: Behandlung von fehlenden NetCDF-Radardatenfiles robuster gemacht

!!! itlrad von nnew -> nnow wg. Konsistenz mit src_output.f90

!!! calc_dbz_vec(): itl muss in die Entscheidung miteinbezogen werden, ob neu gerechnet wird
!!!                 oder das Speicherfeld benutzt wird. Sonst ggf. Inkonsistenzen
!!!                 zwischen GP werten und Polarkoordinatenwerten

!!! obs_write_cdf_feedobs: body-loop mit Indexliste, dann write_loop outer loop.
!!!                        Erst in write_report_radar_1
!!!                        ueber diese Indexliste loopen, wenn rvala/ivala gefuellt werden.
!!!        Gleichzeitig loop order irep/kk in rep_body aendern!

!!! Indexreihenfolge der 3D-Felder in output_radar und output_radar_smth geaendert,
!!!       dann bessere Vektorisierung: (range, azi, ele) -> (azi, range, ele)

!!! Bugfix: Unterschied mod und modulo!!! meist hatte ich mod verwendet, aber modulo gemeint!

!!! Einlesen von realen Radardaten und Uebernehmen der Metadaten aus den Files:
!!! Momentan: Wenn lreadmeta_from_netcdf = .true., dann werden die rs_meta und dbz-meta
!!! Eintraege sowie nradsta in der nameliste ignoriert. Die Metadaten von jedem Radar
!!! werden zunaechst mit einer Grundstruktur, die fuer alle Radare gleich ist, initialisiert,
!!! welche dann von get_meta_network_dwd() mit stationsspezifischen Parametern
!!! korrigiert wird. Anschliessend werden die Metadaten, die in den NetCDF-files sind,
!!! nochmals darueberkopiert.
!!!
!!! Funktionen/Subroutinen:
!!!             get_meta_proto_dwd()
!!!             get_meta_network_dwd()
!!!             read_meta_info_dwd()

!!! Zu machen: - alles was mit obs reading zu tun hat, in eigenes modul "src_radar_readobs.f90" ausgliedern!
!!!            - bei lreadmeta_from_netcdf: init D defaults in eine tmp-struktur mit 17 radargeraeten
!!!              diese knnen dann von der nameliste bermllert werden, wobei
!!!              die Zuordnung anhand der Stationsnummer erfolgt.
!!!            - Diese Metadaten initialisieren die zum file passende meta-struktur
!!!              die wiederum von den Angaben im file bermllert wird.
!!!            - el_arr sind die nominellen elevationen, die letztendlich verwendet werden , und el_arr_obs dient nur zum
!!!              cross-check nach dem Einlesen

!!! calc_dbz_vec() von src_output.f90 nach hier gezogen.

!!! ifdef TWOMOMSEIFERT implementiert

!!! Bugfix: distribute_sta_rfridx: IF-Bedingung in der Fehlerkontrolle

!!! Allocate / deallocate auf der NEC eher langsam. Wo irgend moeglich,
!!!   mit AUTOMATIC ARRAYS arbeiten. Allerdings ist das auf anderen
!!!   Systemen moeglicherweise nicht so gut wg. stack-Verbrauch.
!!! IDEE: Deswegen jeweils 2 Alternative Routinen einbauen und per namelistschalter
!!!   Die Art der Speicherallokierung auswaehlen.
!!! Dort wo sich allocate / deallocate nicht vermeiden laesst, die
!!!   Aufrufbloecke von verschiedenen Feldern in 1 Aufruf mit Komma-Liste
!!!   zusammenfassen.

!!! Bugfix: calc_geometry_smth: Indexberechnung bei el_arr()

!!! Grosser Speicherhunger bei lonline=.false. und lsmooth=.true.,
!!!   viel weniger Hunger bei lonline=.true. !!!
!!!  Liegt vermutlich daran, dass in calc_geometry_smth() viele
!!!   temporaere Felder mit voller Groesse nobsmax auf allen procs
!!!   allokiert werden. Da kann man vielleicht noch besser ausmisten.

!!! Reproduzierbarkeit hinsichtlich Prozessorzahl im Falle 
!!!   - lonline=.true.  und lsmooth=.true.   (calc_geometry_onsmth output_radar_smth calc_mod_reflectivity_onsmth
!!!   - lonline=.false. und lsmooth=.true.   (calc_geometry_smth   output_radar_smth calc_mod_reflectivity_smth
!!!   - lonline=.true.  und lsmooth=.false.  (calc_geometry_online output_radar      calc_mod_reflectivity_online
!!!   - lonline=.false. und lsmooth=.false.  (calc_geometry_vec    output_radar      calc_mod_reflectivity
!!! ABER NUR BEI v_r gegeben. Bei z_radar gibt es noch ein paar Pixel am Rand/Oberrand mit Unterschieden!
!!!
!!! --> LOESUNG: Das Problem lag daran, dass die Reflektivitaet nicht
!!!              auf den inneren boundlines berechnet wurde. Somit
!!!              liegen an Stellen, an denen die linke obere Ecke der
!!!              Modellgitterpunktsnacbarschaft fuer die Interpolation direkt
!!!              am Prozessorgebietsrand liegt, die "rechtsseitigen" Punkte
!!!              innerhalb der boundlines-Zone, und der Wert zum Interpolieren
!!!              ist dort auf Ausfall. Das fuerht natuerlich je nach Prozessorzahl
!!!              zu unterschiedlichen Ergebnissen.
!!!
!!! --> DESHALB: In die Interface-Routinen in radar_mie_lm_vec.f90 einen
!!!              optionalen Schalter "linc_boundlines" eingebaut, mit dem
!!!              man auswhlen kann, ob man die boundlines in die Reflektivitaets-
!!!              berechnung einbeziehen moechte oder nicht. default: NICHT!
!!!              Routinenaufrufe in src_output.f90 entsprechend angepasst.

!!! IF PROBLEMS WITH NAMELISTS OCCUR: COMPILE ON PLATFORMS OTHER THAN NEC,
!!! THEN THE IOMSG-MECHANISM (FORTRAN 2003) WILL GIVE YOU MUCH MORE DETAILED
!!! ERROR MESSAGES TO FIND ERRORS IN NAMELIST FILES. FOR THIS, YOU
!!! NEED FAIRLY NEW VERSIONS OF COMPILERS LIKE INTEL (>= 11.0) 
!!! OR GFORTRAN (> 4.3 ??). 
!!! IF THIS IS THE CASE, JUST UNCOMMENT THE FOLLOWING LINE AND
!!! THE IOMSG-MECHANISM WILL BE ACTIVE FOR THE READING OF NAMELIST
!!! "RADARSIM_PARAMS".
!!!
!#ifndef __SX__
!#define HAS_IOMSG
!#endif

!!! nbl_az is currently the same for all radars and is determined by
!!!  that radar which needs the most boundlines. Could this be made dynamic
!!!  some day, i.e., rs_grid(ista)%nbl_az ?

!!! CORRECT IMPLEMENTATION OF THE EFFECTIVE BEAM FUNCTION FOR SMOOTHING
!!! FOR THE CASE OF A RADAR WITH HORIZONTAL SCANNING ANTENNA.
!!!
!!! NEW FUNCTION:
!!!  - f4_eff_horzscan(ista,az0,el0,az,el)
!!!      computes the effective beam function at angle position(az,el) if the
!!!      beam center is at angle position (az0,el0) after the parameterization
!!!      of Blahak (JAOTECH 2008).
!!! 
!!! ALSO: implementation of Gauss-Legendre quadrature points which span
!!!  the range between the actual effective half width phi3_eff of the effective beam
!!!  function. This range depends now on the elevation of the beam center
!!!  as given in Blahak (2008).
!!!
!!! NEW FUNCTIONS FOR THIS:
!!!  - smth_az_horzscan(ista,ih,el0) : relative position of azim. smoothing point ih
!!!                                    to beam center az0
!!!  - smth_el_horzscan(ista,iv)     : relative position of elev. smoothing point iv
!!!                                    to beam center el0
!!!
!!!  so that the smoothing points can be computed simply by:
!!!
!!!    el_smth(iv) = el0 + smth_el_horzscan(ista,iv)
!!!    az_smth(ih) = az0 + smth_az_horzscan(ista,ih,el0)


!!! CHANGED obs_times from minutes to seconds. Obs times can now
!!! be given also values which do not fit exactly onto a model time step.
!!! In this case, the nearest model time step is used for output.


!!! CHANGED meaning of rs_meta(ista)%alt: now we have 2 variables:
!!!   - rs_meta(ista)%alt_agl_mod :  height AGL above the model orography
!!!   - rs_meta(ista)%alt_msl     :  height above MSL
!!! IF only rs_meta(ista)%alt_agl_mod is given in the namelist and
!!!  rs_meta(ista)%alt_msl < -9000.0 (default), then the radar height
!!!  rs_meta(ista)%alt_msl will be set to hsurf(iradar,jradar) + rs_meta(ista)%alt_agl_mod.
!!! IF rs_meta(ista)%alt_msl >= -9000.0, this value will be used
!!!  directly and takes precedence over the other. All subroutines
!!!  work with rs_meta(ista)%alt_msl.


!!! Nameliste RADARSIM_PARAMS eingefuehrt. Hier sind alle Parameter, die
!!! bisher in type rs_smth und read_grid_info untergebracht waren,
!!! enthalten, ausserdem die Parameter in dbz_data fuer jedes Radar einzeln.
!!! Der typ rs_smth wurde eliminiert und die Parameter
!!! in rs_meta uebernommen. Die smoothing-parameter koennen fuer jedes
!!! Radar einzeln anders gewaehlt werden, ebenso wie die Parameter fuer
!!! die dbz-Berechnung.
!!! Der type dbz_data ist jetzt ein Vektor dbz_data(nradsta_max), so
!!! dass, wie schon erwaehnt, man fuer jede Radarstation individuell 
!!! andere Reflektivitaetsparameter waehlen kann.
!!! Aus Gruenden der Rechenzeit ist es aber ratsam, entweder fuer alle
!!! Radare gleiche Parameter in dbz_data zu setzen oder die Radare
!!! zumindest in der Nameliste nach gleichen dbz_data zu gruppieren.
!!! Die Reflektivitaet wird naemlich auf dem Modellgitter innerhalb eines
!!! Zeitschrittes immer dann neu
!!! berechnet, wenn sich von einem Radar zum Nachfolgenden die Parameter
!!! in dbz_data(ista) geaendet haben, wenn also dbz_data(ista) /= dbz_data(ista-1).


!!! Idee von Yuefei oder Dorit (?): Reflektivitaet auf dem Modellgitter oder
!!! Azimutgitter nur dann berechnen, wenn auf dem jeweiligen Prozessor auch
!!! wirklich ein Abschnitt des Radargebietes liegt.


!!! Parallelisiere Ausgabe, implementiert bisher in output_radar():
!!!
!!! DO ista_par = 1, nradsta, num_compute  ! outer loop so that at each time each processor gets exactly one radar
!!!
!!!   NULLIFY the pointers radpos_all, ...
!!!
!!!   ! inner loop to distribute data among the processors
!!!   DO ista = ista_par, min(ista_par+npes-1,nradsta)
!!!     - send data from radar ista to processor ipe_rad=mod(ista-1,num_compute)
!!!     - if you are processor ipe_rad, receive the data of ista
!!!       and set output_my_radar=.true. and keep track of radar index ista (my_ista=ista)
!!!       and keep track of nobs of this radar (nobs = nobs_ista)
!!!   END DO
!!!
!!!   ! some (or each) processor(s) has/have now data from 1 station, now output in parallel:
!!!   IF (output_my_radar) then
!!!     output data from radar my_ista
!!!   END IF
!!!
!!! END DO
!!!
!!! Hierfuer: wenn bei gatherv_values() nur 1 Empfaenger, dann allokiere auch nur auf diesem PE den Zeiger,
!!!           und ansonsten keine aenderung des allokierungsstatus!

!!! In die Strahlgewichtsfunktion noch die korrekte \Delta\alpha / \theta3 einbauen,
!!! momentan ist hierfuer fest 1.0 (liefert konstante 1.461) genommen.

!!! Haeufig gebrauchte Codeschnipsel wie Indexumrechnungen oder die Kontrollausgaben
!!! bei output_radar / output_radar_smth in subroutinen auslagern (werden normalerweise
!!! ge-ilined, wenn sie nicht laenger als 50 Zeilen sind.)
!!!
!!! -> Kontrollausgaben sind erledigt
!!! -> Indexumrechnungen noch zu machen

!!! Parametereingabe ueber Nameliste (read_meta_info, read_smth_info, read_grid_info zusammenfassen)

!!! Bei Onlinestrahlausbreitung sind die Ergebnisse mit und ohne
!!! "smoothing" jetzt dieselben, unabhaengig von der Wahl der
!!! Anzahl der boundary lines "nbl_az". Bis auf die Stellen, an
!!! denen die Strahlen das Modellgebiet verlassen. Das liegt aber
!!! an der unterschiedlichen Behandlung von Randpixeln bei den beiden
!!! Methoden und ist nicht schlimm.

!!! neuer interner missing value fuer Punkte unterhalb oro (z.B. -988.88) 
!!!
!!! Momentan werden abgeschattete Punkte zu -999.99 und damit
!!! gleich wie die Radarpunkte ausserhalb Modellgebiet.
!!!
!!! Dann aber Problem in "calc_mod_reflectivity_onsmth":
!!! In der vorherigen Implementierung (Yuefei) wurden solche Punkte
!!! als 0-en mitgemittelt, was fuer die abgeschatteten Pixel korrekt ist.
!!! Allerdings passt das dann wieder nicht am Modellgebietsrand,
!!! da sollten die Punkte ausserhalb, die zu einem gemittelten 
!!! Radarpunktgebiet beitragen, einfach weggelassen werden.
!!! Ich habe mal die Behandlung von Ausfallwerten in "calc_mod_reflectivity_onsmth"
!!! so implementiert, dass diese einfach bei jeder Mittelung weggelassen
!!! werden. Auch nicht korrekt, aber Verwendung eines anderen
!!! "missing codes" fuer abgeschattete Pixel vorbereitet.
!!! 
!!! -> Yuefeis Methode ist erstmal das beste,
!!!    DENN DIE GEBIETSRAENDER SIND SOWIESO NICHT SO RELEVANT!

!!! hsurf als zusaetzliche Unterrandsschicht wg. Orographieabschattung 
!!!   in Azimutscheiben einbauen (calc_geometry_online, calc_geometry_onsmth, 
!!!   calc_vert_weight_online, calc_vert_weight_onsmth)

!!! output_radar_smth: reflectivity weighting muss mit linearem Z gemacht werden,
!!!   nicht mit DBZ! Habe das mal verbessert. z_radar_tmp, dbz_value, dbz_weight konnten eliminiert werden.

!!! output_radar, output_radar_smth: logik loutradwind / loutdbz ist programmtechnisch
!!!   etwas "durcheinander". U.u. fuehrt das zu unnoetiger Kommunikation.

!!! Neu: UEberpruefung, ob Radarstandort innerhalb Modellgebiet

!!! lfall ist noch nicht implementiert, nur der Schalter :-)

!!! lweightdbz = .true.: nur im Falle lsmooth=.true. wirksam!

!!! Fehler bei der UEberpruefung der Interpolations-Nachbarn auf Ausfallwerte korrigiert

!!! Missing values bei dbz_radar (in Radarkoordinaten):
!!! -999.99:  Ausserhalb Modellgebiet
!!! -99.99:   Das ist ein Null-Wert im linearen, d.h. Z = 0

!!! Missing values bei z_ext (z_ext ist in linearer Skalierung):
!!! -999.99:  Ausserhalb Modellgebiet

!!! Output momentan nur auf 1 PE. Wueschenswert: Bei mehreren Radarstationen
!!! gleichmaessige Verteilung auf die PEs.

!!! distribute_onlineinfos_xxx: derzeit nur Radare mit 360 azimuten moeglich. Es 
!!! sollte aber auch moeglich sein, dass jedes Radar individuell unterschiedliche
!!! beliebige Zahl von Azimuten hat.

!!! Auch an vielen anderen stellen ist die Azimutanzahl 1 bis 360 fest verdrahtet.
!!! Das sollte flexibler sein und sich nach der Definition in der Radar-Metadaten-Struktur 
!!! richten ... (teilweise verbessert)

!!! Momentan wird das Azimutscheibengitter, die Strahlausbreitung und die Interpolationen
!!! auf allen compute-PEs gerechnet, dieselben wie das restliche Modell.
!!! Erweiterung fuer die Zukunft: ASYNCHRONE Berechnung auf extra PEs bei Bedarf: 

!!! Manchmal fehlte die 1-proc-Variante bei den Verteilungsroutinen, z.B. bei distribute_onlineinfos_xxx(). Uli hat das mal ergaenzt (fehlt es noch wo ???).

!!! Das distribute_sta_rfridx() habe ich auf num_compute == 1 angepasst.

!!! nobs = Anzahl der Radarpunkte innerhalb Modellgebiet, egal ob dort z.B. Z > 0.
!!!   man koennte aber nur die von 0 verschiedenen Punkte verteilen, oder?
!!!   Allerdings muss man sich dann radpos_all fuer jede einzelne Variable gesondert
!!!   erstellen ...

!!! Konvention fuer vr geaendert: bisher positiv aufs radar zu, jetzt positiv vom radar weg.

!!! calc_geometry vektorisiert nun!!!

! UB>> The output timestep calculation in organize_radar is not 
!      a clean solution, since the timestep has to fit exactly
!      into a minute! It should rather choose the nearest timestep
!      of a certain desired output time, as it is done with the "normal"
!      model output time steps!

MODULE src_radar

  !------------------------------------------------------------------------------
  !
  ! Description: Radar forward operator module for calculation of simulated radar 
  !              quantities from a number of radar stations based on the COSMO
  !              model variables. Currently only radial velocity.
  !
  ! Subroutines:
  !
  !   * organize_radar (interface to the radar operator)
  !     
  !   * init_radar (first call only)
  !     - initialize module variables and open input and output files
  !
  !   * read_meta_info (first call only)
  !     - open netcdf files (one for each radar station)
  !     - read meta information (including measurement times)
  !     - distribute meta information to all PE's
  !   
  !   * calc_geometry (currently first call only)
  !     - compute the constant radar geometry using the 4/3 earth model of all
  !       radar stations with at least one measurement in the input files
  !     - assign a model grid cell to every radar point and store according indices
  !     - compute and store three interpolation weights (one for each spatial direction) 
  !       for each radar point
  !
  !   * read_radwind_obs(time) (not yet implemented)
  !     - read obs radial winds from all netcdf files (i.e. all stations) valid at a given time 
  !
  !   * calc_mod_radialwind 
  !     - for each radar point in local subdomain
  !        - interpolate u, v and w to the radar point (using the stored
  !          interpolation weights)
  !        - rotate horizontal wind vector to geographical reference system
  !        - project velocity vector to radar beam
  !       end for
  !
  !   * calc_innovations (currently for idealized cases only)
  !     - calculate innovations (obs-mod differences)
  !
  !   * output_radialwind
  !     - collect model radialwinds from all PE's to PE 0
  !     - output model radialwinds
  !
  !   * output3d_ascii_radar
  !     - output a 3D field of arbitrary size to an ASCII file in a simple format:
  !       1 header line, 1 line of field dimensions, long column of data (first index varies first).
  !       On the NEC SX, the ASCII file is however not directly written (due to very inefficient 
  !       formatted output) but a fortran binary file is produced,
  !       which has to be converted to ASCII by the program "bin2ascii_convrates3d" from Uli Blahak.
  !  
  !   * uvrot2uv_corr
  !     - original SR in utilities.f90, but there the input rlat / rlon have to
  !       be in degrees, whereas the model fields rlat / rlon are in radians.
  !       Therefore, to save computation time and also to be more accurate (the routine
  !       in utilities.f90 works with a nonaccurate local degrad), 
  !       a local version of uvrot2uv is introduced here with input rlat / rlon
  !       specified in radians.
  !  
  ! Current Code Owner: MeteoSwiss, Daniel Leuenberger
  !  phone:  +41  44 256 97 10
  !  fax:    +41  44 256 97 10
  !  email:  daniel.leuenberger@meteoswiss.ch
  !
  ! History:
  ! Version    Date       Name
  ! ---------- ---------- ----
  ! 4.12       2010/10/05 Daniel Leuenberger
  !  Initial version!
  ! 4.14       2010/11/03 Ulrich Blahak
  !  Changes related to vectorisation:
  !     - calc_geometry(): main loop does not vectorize in the present version,
  !       has to be rewritten in the future. However, changed two loops to
  !       fill raarr and azarr, since these were really screwed up
  !       by the NEC compiler.
  !     - calc_mod_radialwind(): completely rewritten the main loop due to
  !       bad vectorization properties; replaced fields uu, vv and ww by
  !       scalars uu111, uu211, etc., and manually inlined the code from external
  !       SR uvrot2uv_corr().
  !  Other changes:
  !     - read_meta_info():
  !          - added rs_meta(i)%az_offset, to enable the azimut vector not to begin
  !            with exact north (e.g., some radars begin to store their data
  !            beginning at 0.5 deg azimut);
  !          - changed units from km to m for rs_meta(i)%ra_inc 
  !            (this also fixed a bug in var. "azimuth" in calc_mod_radialwind);
  !     - new routine nullify_pointers() to correctly initialize the rs_data-structure
  !     - output_radialwind(): 
  !          - added correct initialization of pointers, 
  !            otherwise the check on their association status in gatherv_values()
  !            might fail (it failed on the SX9);
  !          - introduced "sorted" radar data field vrpolar(nra,naz,nel), which
  !            is the full radar data with missing values -999.99;
  !          - new output file and output format of ASCII-data: 
  !            1 header line, one line containing field dimensions, 1 long column of data
  !            (first index varies first); on the SX9, this is stored in a fortran
  !            binary file (using standard preprocessor switch __SX__) due to very 
  !            slow formatted output; convert later to the desired ASCII file with the
  !            fortran program "bin2ascii_convrates3d" from Ulrich Blahak;
  !          - the file "YURADWIND" now contains only one diagnostic line per radar file output.
  !     - local version uvrot2uv_corr() of the SR uvrot2uv() from utilities.f90 introduced
  !       (see above);
  !  Bug fixes: 
  !      - gatherv_values() in parallel_utilities:
  !          - POINTERS rvector_all / ivector_all must not be defined with INTENT(OUT),
  !            since this does not compile on the SX9 due to conflicting attributes.
  !      - calc_geometry(): replaced "int()" by "MAX( ... floor() ...,1)" to achieve 
  !        correct behaviour at the subdomain boundaries
  !      - moved call of organize_radar in lmorg further to the end of the time
  !        step loop, so that the boundary exchange happens before radar calculations.
  !        This is now the same treatment as with the syntetic sattelite pictures. 
  !
  ! Code Description:
  ! Language: Fortran 90.
  ! Software Standards: "European Standards for Writing and
  ! Documenting Exchangeable Fortran 90 Code".
  !==============================================================================
  !
  ! Declarations:
  !
  ! Modules used:

  USE data_parameters, ONLY :   &
       ireals,    & ! KIND-type parameter for real variables
       iintegers    ! KIND-type parameter for standard integer variables

  !------------------------------------------------------------------------------

  USE data_modelconfig, ONLY :   &
       ie,           & ! number of grid points in zonal direction
       je,           & ! number of grid points in meridional direction
       ke,           & ! number of grid points in vertical direction
       ie_tot,       &
       je_tot,       &
       ke_tot,       &
       istartpar,    & ! start index for computations in the parallel program
       iendpar,      & ! end index for computations in the parallel program
                                !   meridional direction
       jstartpar,    & ! start index for computations in the parallel program
       jendpar,      & ! end index for computations in the parallel program
       pollon,       & ! longitude of the rotated north pole (in degrees, E>0)
       pollat,       & ! latitude of the rotated north pole (in degrees, N>0)
       polgam,       & ! angle between the north poles of the systems
       dlon,         & ! grid point distance in zonal direction (in degrees)
       dlat,         & ! grid point distance in meridional direction (in degrees)
       startlon_tot, & ! transformed longitude of the lower left grid point
                                ! of the total domain (in degrees, E>0)
       startlat_tot, & ! transformed latitude of the lower left grid point
                                ! of the total domain (in degrees, N>0)
       startlon,     & ! transformed longitude of the lower left grid point
                       ! of this subdomain (in degrees, E>0)
       startlat,     & ! transformed latitude of the lower left grid point
                       ! of this subdomain (in degrees, N>0)
       degrad,       & ! factor for transforming degree to rad
       raddeg,       & ! factor for transforming rad to degree       
       dt,           & ! long time-step
       klv850          ! k index of the LM-mainlevel nearest to 850 HPa
  ! end of data_modelconfig
  !------------------------------------------------------------------------------

  USE data_constants  , ONLY :   &
       
                                ! 1. mathematical constants
                                ! -------------------------
       
       pi,           & ! circle constant
       
                                ! 2. physical constants and related variables
                                ! -------------------------------------------
       r_v,          & ! gas constant for water vapour
       r_earth,      & ! mean radius of the earth
       rho_w, rho_ice, K_w, K_ice, t0_melt

  !------------------------------------------------------------------------------

  USE data_fields, ONLY :   &
       rlat,         & ! geographical latitude                         ( rad )
       rlon,         & ! geographical longitude                        ( rad )
       hhl,          & ! geometrical height of half levels             ( m   )
       u,            &
       v,            &
       w,            &
       t,            & 
       pp,           &
       p0,           &
       rho,          &
       qv,           &
       qc,           & ! specific cloud water content
       qi,           & ! specific cloud ice content
       qr,           & ! specific rain content                         (kg/kg)
       qs,           & ! specific snow content                         (kg/kg)
       qg              ! specific graupel content                      (kg/kg)

#ifdef TWOMOMSEIFERT
  USE data_fields, ONLY :   &
       qh,           & ! specific hail content                         (kg/kg)
       qnc,          & ! number concentration cloud droplets           ( 1/kg)
       qni,          & ! number concentration cloud ice                ( 1/kg)
       qnr,          & ! number concentration raindrops                ( 1/kg)
       qns,          & ! number concentration snow                     ( 1/kg)
       qng,          & ! number concentration graupel                  ( 1/kg)
       qnh             ! number concentration hail                     ( 1/kg)
#endif

  !------------------------------------------------------------------------------

  USE data_runcontrol , ONLY :   &
       nvers,        & ! version number of experiment for documentation
       nuspecif,     & ! output unit for protocolling the namelist input
       yuspecif,     & ! file name
       nstop,        & ! last time step of the forecast
       ntstep,       & ! actual time step
       nnow,         & ! corresponds to ntstep
       nnew,         & ! corresponds to ntstep + 1
       itype_gscp,   & ! type of grid-scale precipitation physics
       lgsp,         & ! switch to include grid-scale precipitation
       ltime,        & ! switch on timing of the model run, YUTIMING
!!$       leps,         & ! switch ensemble mode on/off
       iepsmem         ! ID of the member in the ensemble (ID >= 0)

  !------------------------------------------------------------------------------

  USE data_parallel,      ONLY :  &
       num_compute,     & ! number of compute PEs
       nboundlines,     & ! number of boundary lines of the domain for which
                                ! no forecast is computed = overlapping boundary
                                ! lines of the subdomains
       my_cart_id,      & ! rank of this subdomain in the cartesian communicator
       my_world_id,     & ! rank of this subdomain in the global communicator
       isubpos,         & ! positions of the subdomains in the total domain. Given
                                ! are the i- and the j-indices of the lower left and the
                                ! upper right grid point in the order
                                ! i_ll, j_ll, i_ur, j_ur.
                                ! Only the interior of the domains are considered, not
                                ! the boundary lines.
       icomm_cart,      & ! communicator for the virtual cartesian topology
       icomm_world,     & ! communicator for all PEs
       imp_reals,       & ! determines the correct REAL type used in the model for MPI
       imp_integers,    & ! determines the correct INTEGER type used in the model for MPI
       imp_character,   & ! determines the correct CHARACTER type used in the model for MPI
       imp_logical,     & ! determines the correct LOGICAL type used in the model for MPI
       intbuf,          & ! Buffers for distributing Namelists
       logbuf,          & ! Buffers for distributing Namelists
       realbuf,         & ! Buffers for distributing Namelists
       charbuf
  !------------------------------------------------------------------------------

  USE data_io,            ONLY :  &
       root,            & ! pointer to the root of gribout namelists
       ydate_ini,       & ! start of the forecast yyyymmddhh (year,month,day,hour)
       yncglob_institution ,& ! originating center name
       yncglob_source      ,& ! program name and version
       dbzcalc_params

  !------------------------------------------------------------------------------

#ifdef NUDGING
  USE data_nudge_all, ONLY :   &
       nverend    ,& ! 0   : end of verification period in timesteps
       hversta    ,& ! 0.0 : start of verification period in 'model integ. hours'
       hverend       ! 0.0 : end of verification period in 'model integr. hours'
#endif

  !------------------------------------------------------------------------------

  USE utilities,          ONLY :  &
       phirot2phi,          & !
       rlarot2rla,          & !
       phi2phirot,          & !
       rla2rlarot,          & !
       linear_interpol,     & !
       diff_seconds,        &
       get_utc_date 

  !------------------------------------------------------------------------------

  USE time_utilities,           ONLY :  &
       nutiming, get_timings,           &
       i_radar_ini, i_radar_compgrid, i_radar_comm, i_radar_ongeom, &
       i_radar_comppolar, i_radar_out

  !------------------------------------------------------------------------------

  USE parallel_utilities,       ONLY :  &
       distribute_values,               &
       global_values,                   &
       gatherv_values,                  &
       gather_values,                   &
       def_mpi_dbzcalc_params_type
  !------------------------------------------------------------------------------

  USE data_radar,               ONLY :  &
       nel_max, nscanstrategies_max, nobstimes_max, ngpsm_max, nradsta_max,     &
       ndatakind, cndatakind, datakind, &
       radar_meta_type, radar_data_type, radar_grid_type, &
       def_mpi_radar_meta_type
  !------------------------------------------------------------------------------

  USE environment,              ONLY :  model_abort, &
       get_free_unit, release_unit
  !------------------------------------------------------------------------------
 
#ifdef NETCDF
  USE netcdf, ONLY :  &
       nf90_open, &
       nf90_noerr, &
       NF90_NOWRITE, &
       nf90_inquire, &
       nf90_inq_dimid, &
       nf90_inquire_dimension, &
       nf90_inq_varid , &
       nf90_get_var, &
       nf90_close, &
       nf90_get_att
#endif

  !==============================================================================

  IMPLICIT NONE

#ifdef HAS_MAXRSS
  INTERFACE
    FUNCTION maxrss ()
      INTEGER(kind=KIND(1)) :: maxrss
    END FUNCTION maxrss
  END INTERFACE
#endif

  ! array of radar station meta data (local PE)
  TYPE(radar_meta_type)                 :: rs_meta(nradsta_max)
  ! array of radar data (local PE)
  TYPE(radar_data_type), SAVE           :: rs_data(nradsta_max)
  ! array of auxiliary azimut grid data (local PE)
  TYPE(radar_grid_type), SAVE           :: rs_grid(nradsta_max)

  ! meta data for configuration of grid point reflectivity calculation
  ! for each radar
  TYPE(dbzcalc_params)                  :: dbz_meta(nradsta_max)

  ! Default meta data of the German radar network:
  INTEGER (KIND=iintegers), PARAMETER   :: nradsta_dwd = 22         ! (17 new + 5 old stations)
  TYPE(radar_meta_type)                 :: rs_meta_dwd_proto        ! proto type
  TYPE(radar_meta_type)                 :: rs_meta_dwd(nradsta_dwd) ! full infos for each radar
  TYPE(dbzcalc_params)                  :: dbz_meta_dwd(nradsta_dwd)

  ! Default meta data of the Swiss radar network:
  INTEGER (KIND=iintegers), PARAMETER   :: nradsta_swiss = 3
  TYPE(radar_meta_type)                 :: rs_meta_swiss_proto          ! proto type
  TYPE(radar_meta_type)                 :: rs_meta_swiss(nradsta_swiss) ! full infos for each radar
  TYPE(dbzcalc_params)                  :: dbz_meta_swiss(nradsta_swiss)
  
  INTEGER(kind=iintegers)         :: itype_refl_glob  ! global setting for itype_refl

  ! time level used in src_radar.f90 for the model fields u,v,w,T,p,qX,qnX
  INTEGER (KIND=iintegers)              :: itlrad
  ! number of radar stations
  INTEGER (KIND=iintegers)              :: nradsta
  ! year, month, day, hour, minute and second of model start (YYYYMMDDhhmmss):
  CHARACTER (len=14)                    :: zydate_ini_mod

  ! unit number of radar beam geometry control output file
  INTEGER (KIND=iintegers)              :: radgeomoutputunit (nradsta_max)
  ! unit number of simul. radar radial wind control output file
  INTEGER (KIND=iintegers)              :: radwindoutputunit (nradsta_max)
  ! unit number of observed radar radial wind control output file
  INTEGER (KIND=iintegers)              :: radwindobsoutputunit (nradsta_max)
  ! unit number of simul. radar reflectivity control output file
  INTEGER (KIND=iintegers)              :: radrefloutputunit (nradsta_max)
  ! unit number of observed radar reflectivity control output file
  INTEGER (KIND=iintegers)              :: radreflobsoutputunit (nradsta_max)
  ! unit number of simul. radar extinction control output file
  INTEGER (KIND=iintegers)              :: extrefloutputunit (nradsta_max)
  ! overlap for the auxiliary azimut-slice grid at the lower and upper azimut ends
  INTEGER (KIND=iintegers)              :: nbl_az 

  !.. switch to enable ASCII-output (default = .true.):
  !    (disabling just prevents the output-step in subroutine output3d_ascii(), 
  !       not the computations and the output in the diagnosis files!)
  LOGICAL                    :: lascii_output
  !.. switch to enable output of netcdf feedback files (only possible with -DNETCDF and -DNUDGING)
  LOGICAL                    :: lfdbk_output
  !.. enable debug info output:
  LOGICAL                    :: ldebug_radsim
  !.. enable calculation and output of radial wind for each radar:
  LOGICAL                    :: loutradwind
  !.. enable output of beam geometry (bin heights, local elevations) for each radar:
  LOGICAL                    :: lout_geom
  !.. enable calculation and output of reflectivity for each radar:
  LOGICAL                    :: loutdbz
  !.. enable calculation of extinction of reflectivity for each radar:
  LOGICAL                    :: lextdbz
  !.. enable the use of lookup tables for Mie-scattering:
  !    (default initialistion .TRUE., so that calc_dbz_vec() can be called also
  !     from other modules like src_output.f90 with a defined llookup_mie)
  LOGICAL                    :: llookup_mie = .TRUE.
  !.. enable to take the (attenuated) reflectivity as weight into 
  !     account WHILE caculating the radial wind for each radar:
  LOGICAL                    :: lweightdbz
  !.. enable to take the falling velocity of hydrometeors into account 
  !     while caculating the radial wind for each radar:
  LOGICAL                    :: lfall
  !.. enable to change the strategy for computing of radio propagation path:
  !     static 4/3-earth ("offline") or 
  !     dynamic ("online") depending on actual refractive index of air
  LOGICAL                    :: lonline, lsode
  !.. enable spatial smoothing (weighted spatial mean over measuring
  !     volume increasing with distance):
  LOGICAL                    :: lsmooth
  !.. meta data of radar station will be read from netCDF data files, overriding
  !   any radar meta data from the namelist:
  LOGICAL                    :: lreadmeta_from_netcdf
  !.. if lreadmeta_from_netcdf=.true., check the record numbers in files for
  !   vr, qv, z, qz for each station on correspondence in time. If not, 
  !   set record numbers for corresponding times for each data type file
  !   separately (VERY SLOW ON VECTOR MACHINES!)
  !   This might help, if some records are missing in an input file (e.g., for qv) and
  !   are present in another file (e.g., vr) for the same station.
  LOGICAL                    :: lcheck_inputrecords
  LOGICAL                    :: lequal_azi_alldatasets

  !.. Missing values for reading from NetCDF radar files:
  REAL (KIND=ireals), PARAMETER   :: missing_obs = -999.99_ireals
  REAL (KIND=ireals)              :: missing_vr
  REAL (KIND=ireals)              :: missing_qv
  REAL (KIND=ireals)              :: missing_z
  REAL (KIND=ireals)              :: missing_qz

  !.. Global default for namelist parameters for the dbz-calculation
  !   from radar_mie_lm_vec.f90:
  TYPE(dbzcalc_params), PARAMETER  :: dbz_namlst_d = dbzcalc_params ( &
       0.055_ireals   , & ! %lambda_radar         [m]
       273.16_ireals  , & ! %Tmeltbegin_s         [K]
       0.0_ireals     , & ! %meltdegTmin_s        [-]
       263.16_ireals  , & ! %Tmeltbegin_g         [K]
       0.2_ireals     , & ! %meltdegTmin_g        [-]
       263.16_ireals  , & ! %Tmeltbegin_h         [K]
       0.2_ireals     , & ! %meltdegTmin_h        [-]
       999999_iintegers,& ! %station_id           [6-digit number]
       3              , & ! %itype_refl [1, 2, 3, or 4]
       1              , & ! %igraupel_type        [1, 2, or 3]
       'masmas      ' , & ! %ctype_drysnow_mie    [12-char string]
       'mawsasmawsms' , & ! %ctype_wetsnow_mie    [12-char string]
       'mis         ' , & ! %ctype_drygraupel_mie [12-char string]
       'mawsms      ' , & ! %ctype_wetgraupel_mie [12-char string]
       'mis         ' , & ! %ctype_dryhail_mie    [12-char string]
       'mws         ' , & ! %ctype_wethail_mie    [12-char string]
       'mas         ' , & ! %ctype_drysnow_ray    [12-char string]
       'mawsms      ' , & ! %ctype_wetsnow_ray    [12-char string]
       'mis         ' , & ! %ctype_drygraupel_ray [12-char string]
       'mawsms      ' , & ! %ctype_wetgraupel_ray [12-char string]
       'mis         ' , & ! %ctype_dryhail_ray    [12-char string]
       'mawsms      '   & ! %ctype_wethail_ray    [12-char string]
       )

  !.. Data types for radar_meta- and dbzparams-structures for MPI-exchange:
  INTEGER(kind=iintegers) :: mpi_dbzcalc_params_typ, mpi_radar_meta_typ

  !.. Directory where NetCDF obs input resides (from namelist):
  CHARACTER(LEN=250)          :: ydirradarin 


  !==============================================================================
  ! Public and Private Subroutines

  !==============================================================================
  ! Module procedures
  !==============================================================================

CONTAINS

  !==============================================================================
  !+ Module procedure in src_radar for 
  !------------------------------------------------------------------------------

  SUBROUTINE template

    !------------------------------------------------------------------------------
    !
    ! Description:
    !
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'template'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

!!$ Subroutine code here ...

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE template

  SUBROUTINE init_smth_info
    !------------------------------------------------------------------------------
    !
    ! Description: Initializes some parameters needed for the 
    !              spatial smoothing (short:smth)  
    !              
    !
    ! Method:
    !
    ! Input: Some namelist parameters from namelist RADARSIM_PARAMS
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg
    INTEGER (KIND = iintegers)           :: i, ista

    ! Integration points: vertical and horizontal, which means elevation 
    !                     and azimuth in radar system     
    REAL (KIND = ireals), ALLOCATABLE    :: xabsc_v(:),xabsc_h(:)
    ! Weights of integration points
    REAL (KIND = ireals), ALLOCATABLE    :: weig_v(:) ,weig_h(:)

    CHARACTER(len=300) :: errstring



    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'init_smth_info'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! Here the meta data should be read in from the netcdf files on PE 0
    ! Currently it is simply taken from already readed namelist parameters:

    DO ista = 1, nradsta
      
      rs_meta(ista)%xabscsm_v = 0.0_ireals
      rs_meta(ista)%weigsm_v  = 0.0_ireals

      ALLOCATE(xabsc_v(rs_meta(ista)%ngpsm_v))
      ALLOCATE(weig_v(rs_meta(ista)%ngpsm_v))

      CALL gauleg(rs_meta(ista)%ngpsm_v,xabsc_v,weig_v)

      rs_meta(ista)%xabscsm_v(1:rs_meta(ista)%ngpsm_v) = xabsc_v
      rs_meta(ista)%weigsm_v(1:rs_meta(ista)%ngpsm_v)  = weig_v      

      IF (ldebug_radsim) &
           WRITE(*,*) ista, '  xabsc_v = ', (xabsc_v(i),i=1,rs_meta(ista)%ngpsm_v)


      rs_meta(ista)%xabscsm_h = 0.0_ireals
      rs_meta(ista)%weigsm_h  = 0.0_ireals

      ALLOCATE(xabsc_h(rs_meta(ista)%ngpsm_h))
      ALLOCATE(weig_h(rs_meta(ista)%ngpsm_h))

      CALL gauleg(rs_meta(ista)%ngpsm_h,xabsc_h,weig_h)

      rs_meta(ista)%xabscsm_h(1:rs_meta(ista)%ngpsm_h) = xabsc_h
      rs_meta(ista)%weigsm_h(1:rs_meta(ista)%ngpsm_h)  = weig_h

      IF (ldebug_radsim) &
           WRITE(*,*) ista, '  xabsc_h = ', (xabsc_h(i),i=1,rs_meta(ista)%ngpsm_h)

      DEALLOCATE(xabsc_v)
      DEALLOCATE(xabsc_h)
      DEALLOCATE(weig_v)
      DEALLOCATE(weig_h)

    END DO

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE init_smth_info

  SUBROUTINE init_grid_info

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    ! Local scalars:
    CHARACTER (LEN=32)                      yzroutine
    INTEGER (KIND = iintegers)           :: i,ista

    yzroutine(:) = ' '
    yzroutine = 'init_grid_info'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    DO ista = 1,nradsta

      ! .. The azimut slice grid's horizontal grid distance is
      !    determined as the smaller of the two horizontal model grid
      !    distances:
      rs_grid(ista)%al_inc      = MIN(dlon, dlat) * r_earth * degrad
      rs_grid(ista)%al_inc      = 1000.0
      rs_grid(ista)%nal         = CEILING(rs_meta(ista)%ra_inc * rs_meta(ista)%nra &
                                          / rs_grid(ista)%al_inc) + 1

    ! needed for index calculation when nbl_az > 0 
    ! (extra azimut slices at lower and upper azimut range for lsmooth = .TRUE. .AND. lonline = .true.
    ! in the auxiliary azimuth grid to facilitate interpolation to smoothing points inbetween)
      rs_grid(ista)%naz_nbl     = rs_meta(ista)%naz + 2*nbl_az

      ! Control output:
      IF (ldebug_radsim) THEN
        WRITE (*,'(a,i3,a,f12.2," m")') 'rs_grid(', ista, ')%al_inc  = ',rs_grid(ista)%al_inc
        WRITE (*,'(a,i3,a,i12)')        'rs_grid(', ista, ')%nal     = ',rs_grid(ista)%nal
        WRITE (*,'(a,i3,a,i12)')        'rs_grid(', ista, ')%naz_nbl = ',rs_grid(ista)%naz_nbl
      END IF

    END DO

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE init_grid_info



  !==============================================================================
  !+ Module procedure in src_radar for organizing the radar forward operator
  !------------------------------------------------------------------------------

  SUBROUTINE organize_radar

    !------------------------------------------------------------------------------
    !
    ! Description: Organizing routine for the radar forward operator. This routine
    !              is the interface to the radar operator
    !
    ! Method:      In first call: 
    !              - init_radar    : Initialyze Operator
    !              - read_meta_info: Read the meta information of the radar stations
    !                                from the observation files
    !              - nullify_pointers: allocate rs_data-structure and nullify 
    !                                POINTER components
    !              - calc_geometry : Calculate the radar beam geometry for all radar
    !                                stations
    !              In every call:
    !              - determine if an observation is available for the current time step
    !              - calc_mod_radialwind  : Calculates the model radial wind using the 
    !                                       current model wind field (u,v,w)
    !              - calc_mod_reflectivtiy: Calculates the radar reflectivitx using
    !                                       calc_dbz_vec (-> radar_mie_lm_vec)
    !              - output_radialwind    : Write model radial wind to output file
    !                                       (currently to an ascii file, later to the
    !                                       netcdf feedback file)
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 
    LOGICAL        ::  lcalc(nradsta_max)
    LOGICAL, SAVE  ::  lfirst_ini = .TRUE.
    LOGICAL, SAVE  ::  lfirst_cmp = .TRUE.
    LOGICAL, SAVE  ::  lfirst_output = .TRUE.
    INTEGER (KIND=iintegers)    :: ista,izerror,i
    REAL (kind=ireals) :: time_mod
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'organize_radar'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    ! .. Set the correct time level for the model variables to be used for
    !    the radar simulation: should be nnow consistent with src_output.f90!
    itlrad = nnow

    IF (lfirst_ini) THEN
      ! .. read namelist, do cross checks, distribute / initialize all 
      !    necessary parameters on all PEs
      !    including former read_meta_info(), read_smth_info() and read_grid_info():
      IF (my_cart_id == 0) PRINT *,my_cart_id," call init_radar"
      CALL init_radar

      lfirst_ini = .FALSE.

      IF (ltime) CALL get_timings (i_radar_ini, ntstep, dt, izerror)

    END IF

    lcalc = .FALSE.

    IF (loutradwind .OR. loutdbz) THEN

      ! Time in seconds since model start:
      time_mod = ntstep * dt

      ! determine if an observation is available for the current time step
      DO ista = 1, nradsta
        IF (ANY(rs_meta(ista)%obs_times - 0.5*dt < time_mod .AND. &
             time_mod <= rs_meta(ista)%obs_times + 0.5*dt)) THEN
          lcalc(ista) = .TRUE.
        END IF
      END DO

    END IF

    ! do nothing if nothing has to be done:
    IF (ANY(lcalc)) THEN

#ifdef HAS_MAXRSS
      WRITE (*,'(a,f10.1,a,i10,a,i5)') &
           'DIAG radar after entry: Memory maximum consumption at t =', time_mod, &
           ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

      IF (lonline) THEN

        IF (lfirst_cmp) THEN

          IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_grid"
          CALL calc_geometry_grid

          IF (ltime) CALL get_timings (i_radar_ini, ntstep, dt, izerror)

          IF (my_cart_id == 0) PRINT *,my_cart_id,"distribute heights and associated indices infos via azimuths"
          DO ista = 1,nradsta

            CALL distribute_onlineinfos_reals(rs_grid(ista)%hl_grd(:),&
                 rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                 1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%hl_azgrd,&
                 imp_reals,icomm_cart,num_compute)

            CALL distribute_onlineinfos_integers(rs_grid(ista)%ind_intp(:,2),&
                 rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                 1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%ind_azgrd,&
                 imp_integers,icomm_cart,num_compute)

          ENDDO

          lfirst_cmp = .FALSE.

          IF (ltime) CALL get_timings (i_radar_comm, ntstep, dt, izerror)

        END IF ! lfirst_cmp

#ifdef HAS_MAXRSS
      WRITE (*,'(a,f10.1,a,i10,a,i5)') &
           'DIAG radar after azgrid geometry: Memory maximum consumption at t =', time_mod, &
           ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

        IF (loutradwind .OR. loutdbz) THEN

          IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_sta_rfridx"
          CALL calc_sta_rfridx(lcalc,time_mod)

          IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_grd_rfridx"
          CALL calc_grd_rfridx(lcalc,time_mod)

          IF (loutradwind) THEN
            IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_grd_winduvw"
            CALL calc_grd_winduvw(lcalc,time_mod)        ! defines rs_data(:)%radwind_mod(:)
          END IF

          IF (loutdbz .OR. lweightdbz) THEN
            IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_grd_reflectivtiy"
            CALL calc_grd_reflectivity(lcalc,time_mod)      ! defines rs_data(:)%z_radar_mod(:)
          END IF

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after interpolation to azgrid: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)


          DO ista = 1,nradsta

            IF (.NOT.lcalc(ista)) CYCLE

            IF (loutdbz .OR. lweightdbz) THEN
              CALL distribute_onlineinfos_reals(rs_grid(ista)%z_radar_grd(:),&
                   rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                   1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%z_radar_azgrd,&
                   imp_reals,icomm_cart,num_compute)
              ! de:
              IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
                CALL distribute_onlineinfos_reals(rs_grid(ista)%z_ext_grd(:),&
                     rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                     1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%z_ext_azgrd,&
                     imp_reals,icomm_cart,num_compute)
              ENDIF
              ! de.
            ENDIF

            IF (loutradwind) THEN
              CALL distribute_onlineinfos_reals(rs_grid(ista)%u_grd(:),&
                   rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                   1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%u_azgrd,&
                   imp_reals,icomm_cart,num_compute)

              CALL distribute_onlineinfos_reals(rs_grid(ista)%v_grd(:),&
                   rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                   1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%v_azgrd,&
                   imp_reals,icomm_cart,num_compute)

              CALL distribute_onlineinfos_reals(rs_grid(ista)%w_grd(:),&
                   rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                   1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%w_azgrd,&
                   imp_reals,icomm_cart,num_compute)
            ENDIF

            CALL distribute_onlineinfos_reals(rs_grid(ista)%rfridx_grd(:),&
                 rs_grid(ista)%ind_intp(:,2),rs_grid(ista)%ngrd, &
                 1,rs_meta(ista)%naz,rs_grid(ista)%naz_nbl,rs_grid(ista)%rfridx_azgrd,&
                 imp_reals,icomm_cart,num_compute)

          ENDDO


          IF (my_cart_id == 0) PRINT *,my_cart_id," call  distribute_sta_rfridx"
          CALL distribute_sta_rfridx

          IF (ltime) CALL get_timings (i_radar_comm, ntstep, dt, izerror)


#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after distribute_onlineinfos: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (lsmooth) THEN
            IF (lsode) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_onsmthnew"
              CALL calc_geometry_onsmthnew(lcalc,time_mod)
            ELSE
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_onsmth"
              CALL calc_geometry_onsmth(lcalc,time_mod)
            ENDIF
          ELSE ! lsmooth = .false.
            IF (lsode) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_onlinenew"
              CALL calc_geometry_onlinenew(lcalc,time_mod)
            ELSE
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_online"
              CALL calc_geometry_online(lcalc,time_mod)
            ENDIF
          END IF ! lsmooth

          IF (ltime) CALL get_timings (i_radar_ongeom, ntstep, dt, izerror)


#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after online beam propagation: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (loutdbz .OR. lweightdbz) THEN
            IF (lsmooth) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_reflectivtiy_onsmth"
              CALL calc_mod_reflectivity_onsmth(lcalc,time_mod)
            ELSE ! lsmooth = .false. 
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_reflectivtiy_online"
              CALL calc_mod_reflectivity_online(lcalc,time_mod)
            END IF ! lsmooth
          ENDIF

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after online reflectivity: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (loutradwind) THEN
            IF (lsmooth) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_radialwind_onsmth"
              CALL calc_mod_radialwind_onsmth(lcalc,time_mod)
            ELSE ! lsmooth = .false.
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_radialwind_online"
              CALL calc_mod_radialwind_online(lcalc,time_mod)
            END IF ! lsmooth  
          ENDIF

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after online radial wind: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)

          IF (lfirst_output) THEN
            CALL opendiagfiles ( "replace", "rewind" )
            lfirst_output = .FALSE.
          ELSE
            CALL opendiagfiles ( "old", "append" )
          END IF

          IF (lsmooth) THEN
            IF (my_cart_id == 0) PRINT *,my_cart_id," call output_radar_smth"
            CALL output_radar_smth(lcalc,time_mod)
          ELSE ! lsmooth = .false.
            IF (my_cart_id == 0) PRINT *,my_cart_id," call output_radar"
            CALL output_radar(lcalc,time_mod)
          END IF ! lsmooth

          CALL closediagfiles ()

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after online output: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          ! clean up memory:
          DO ista = 1,nradsta

            IF (ASSOCIATED(rs_grid(ista)%u_grd))         DEALLOCATE(rs_grid(ista)%u_grd)
            IF (ASSOCIATED(rs_grid(ista)%v_grd))         DEALLOCATE(rs_grid(ista)%v_grd)
            IF (ASSOCIATED(rs_grid(ista)%w_grd))         DEALLOCATE(rs_grid(ista)%w_grd)
            IF (ASSOCIATED(rs_grid(ista)%z_radar_grd))   DEALLOCATE(rs_grid(ista)%z_radar_grd)
            IF (ASSOCIATED(rs_grid(ista)%z_ext_grd))     DEALLOCATE(rs_grid(ista)%z_ext_grd)
            IF (ASSOCIATED(rs_grid(ista)%rfridx_grd))    DEALLOCATE(rs_grid(ista)%rfridx_grd)
            IF (ASSOCIATED(rs_grid(ista)%u_azgrd))       DEALLOCATE(rs_grid(ista)%u_azgrd)
            IF (ASSOCIATED(rs_grid(ista)%v_azgrd))       DEALLOCATE(rs_grid(ista)%v_azgrd)
            IF (ASSOCIATED(rs_grid(ista)%w_azgrd))       DEALLOCATE(rs_grid(ista)%w_azgrd)
            IF (ASSOCIATED(rs_grid(ista)%z_radar_azgrd)) DEALLOCATE(rs_grid(ista)%z_radar_azgrd)
            IF (ASSOCIATED(rs_grid(ista)%z_ext_azgrd))   DEALLOCATE(rs_grid(ista)%z_ext_azgrd)
            IF (ASSOCIATED(rs_grid(ista)%rfridx_azgrd))  DEALLOCATE(rs_grid(ista)%rfridx_azgrd)
            IF (ASSOCIATED(rs_data(ista)%radwind_mod))      DEALLOCATE(rs_data(ista)%radwind_mod)
            IF (ASSOCIATED(rs_data(ista)%radwind_mod_smth)) DEALLOCATE(rs_data(ista)%radwind_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%z_radar_mod))      DEALLOCATE(rs_data(ista)%z_radar_mod)
            IF (ASSOCIATED(rs_data(ista)%z_radar_mod_smth)) DEALLOCATE(rs_data(ista)%z_radar_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%z_ext_mod))      DEALLOCATE(rs_data(ista)%z_ext_mod)
            IF (ASSOCIATED(rs_data(ista)%z_ext_mod_smth)) DEALLOCATE(rs_data(ista)%z_ext_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%w_intp))    DEALLOCATE(rs_data(ista)%w_intp)
            IF (ASSOCIATED(rs_data(ista)%w_intp_smth))    DEALLOCATE(rs_data(ista)%w_intp_smth)
            IF (ASSOCIATED(rs_data(ista)%ind_intp))  DEALLOCATE(rs_data(ista)%ind_intp)
            IF (ASSOCIATED(rs_data(ista)%ind_intp_smth))  DEALLOCATE(rs_data(ista)%ind_intp_smth)
            IF (ASSOCIATED(rs_data(ista)%hl_loc))  DEALLOCATE(rs_data(ista)%hl_loc)
            IF (ASSOCIATED(rs_data(ista)%el_loc))  DEALLOCATE(rs_data(ista)%el_loc)

          END DO

          IF (num_compute > 1) THEN
            IF (ldebug_radsim) THEN
              WRITE (*,*) 'Reached MPI_BARRIER at end of organize_radar on proc ', &
                   my_cart_id, ' obs_time = ', time_mod
            END IF
            CALL MPI_BARRIER(icomm_cart, izerror)
          END IF

          IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)


        ENDIF ! loutradwind .OR. loutdbz

      ELSE ! lonline=.false.

        IF (lfirst_cmp) THEN

          IF (loutradwind .OR. loutdbz) THEN

            If (lsmooth) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_smth"
              CALL calc_geometry_smth                  ! defines rs_data(:)%w_intp(:,:)
            ELSE
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_geometry_vec"
              CALL calc_geometry_vec                   ! defines rs_data(:)%w_intp(:,:)
            END IF
            !         rs_data(:)%ind_intp(:,:)
            !         rs_data(:)%nobs
          END IF

          lfirst_cmp = .FALSE.

          IF (ltime) CALL get_timings (i_radar_ini, ntstep, dt, izerror)

        END IF  ! lfirst_cmp

#ifdef HAS_MAXRSS
        WRITE (*,'(a,f10.1,a,i10,a,i5)') &
             'DIAG radar after geometry: Memory maximum consumption at t =', time_mod, &
             ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

        IF (loutradwind .OR. loutdbz) THEN

          IF (loutradwind) THEN
            If (lsmooth) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_radialwind_smth"
              CALL calc_mod_radialwind_smth(lcalc,time_mod)        ! defines rs_data(:)%radwind_mod(:)
            ELSE
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_radialwind"
              CALL calc_mod_radialwind(lcalc,time_mod)             ! defines rs_data(:)%radwind_mod(:)
            END IF
          END IF

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after radialwind: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)

          IF (loutdbz .OR. lweightdbz) THEN
            If (lsmooth) THEN
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_reflectivtiy_smth"
              CALL calc_mod_reflectivity_smth(lcalc,time_mod)      ! defines rs_data(:)%z_radar_mod(:)
            ELSE
              IF (my_cart_id == 0) PRINT *,my_cart_id," call calc_mod_reflectivtiy"
              CALL calc_mod_reflectivity(lcalc,time_mod)           ! defines rs_data(:)%z_radar_mod(:)
            END IF
          END IF

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after reflectivity: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)


          IF (lfirst_output) THEN
            CALL opendiagfiles ( "replace", "rewind" )
            lfirst_output = .FALSE.
          ELSE
            CALL opendiagfiles ( "old", "append" )
          END IF

          If (lsmooth) THEN
            IF (my_cart_id == 0) PRINT *,my_cart_id," call output_radar_smth"
            CALL output_radar_smth(lcalc,time_mod)
          ELSE
            IF (my_cart_id == 0) PRINT *,my_cart_id," call output_radar"
            CALL output_radar(lcalc,time_mod)
          END IF

          CALL closediagfiles ()

#ifdef HAS_MAXRSS
          WRITE (*,'(a,f10.1,a,i10,a,i5)') &
               'DIAG radar after output: Memory maximum consumption at t =', time_mod, &
               ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

          ! clean up memory:
          DO ista = 1,nradsta
            IF (ASSOCIATED(rs_data(ista)%radwind_mod_smth)) DEALLOCATE(rs_data(ista)%radwind_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%radwind_mod)) DEALLOCATE(rs_data(ista)%radwind_mod)
            IF (ASSOCIATED(rs_data(ista)%z_radar_mod_smth)) DEALLOCATE(rs_data(ista)%z_radar_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%z_radar_mod)) DEALLOCATE(rs_data(ista)%z_radar_mod)
            IF (ASSOCIATED(rs_data(ista)%z_ext_mod_smth)) DEALLOCATE(rs_data(ista)%z_ext_mod_smth)
            IF (ASSOCIATED(rs_data(ista)%z_ext_mod)) DEALLOCATE(rs_data(ista)%z_ext_mod)
          END DO

          IF (num_compute > 1) THEN
            IF (ldebug_radsim) THEN
              WRITE (*,*) 'Reached MPI_BARRIER at end of organize_radar on proc ', &
                   my_cart_id, ' obs_time (model) = ', time_mod
            END IF
            CALL MPI_BARRIER(icomm_cart, izerror)
          END IF

          IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)


        END IF  ! loutradwind .OR. loutdbz

      END IF ! lonline

    END IF ! lcalc


#ifdef HAS_MAXRSS
    WRITE (*,'(a,f10.1,a,i10,a,i5)') &
         'DIAG radar end: Memory maximum consumption at t =', time_mod, &
         ' s: ', maxrss(), ' MB on PE ', my_cart_id
#endif

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE organize_radar

  !==============================================================================
  !+ Module procedure in src_radar for the initialization of the radar operator
  !------------------------------------------------------------------------------

  SUBROUTINE init_radar

    !------------------------------------------------------------------------------
    !
    ! Description: Reads namelist RADARSIM_PARAMS, gets metadata from NetCDF, 
    !              initializes MODULE variables, opens control output files
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32)            :: yzroutine
    CHARACTER (LEN=80)            :: yzerrmsg 
    CHARACTER (LEN= 9)            :: yinput       ! Namelist INPUT file
    INTEGER (KIND = iintegers)    :: ista, nblaztmp(nradsta_max), ista_par, ipe_rad
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE init_radar
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'init_radar'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! Initial date and time of the forecast run in format "YYYYMMDDhhmmss"
!!$    zydate_ini_mod = ydate_ini // "0000" 
    zydate_ini_mod = ydate_ini

    IF (num_compute > 1) THEN
      ! .. Define the mpi type for the structure rs_meta:
      CALL def_mpi_radar_meta_type     (mpi_radar_meta_typ    )
      CALL def_mpi_dbzcalc_params_type (mpi_dbzcalc_params_typ)
    END IF

    ! Set default meta structure for German (DWD) radars:
    rs_meta_dwd_proto = get_meta_proto_dwd()
    ! Set default meta structure for Swiss (MeteoSwiss) radars:
    rs_meta_swiss_proto = get_meta_proto_swiss()

    ! Input the namelist variables for the radar simulator:
    ! and, if lreadmeta_from_netcdf = .true., get radar station metadata
    !  from radar netcdf-files. These metadata take precedence over the corresponding
    !  namelist parameters.
    !  (comprises all parameters from the former read_meta_info() and
    !   read_smth_info() )
    CALL input_radarnamelist

    ! Allocate data arrays:
!!$ not needed any more    ALLOCATE(rs_data(nradsta))
!!$ not needed any more   ALLOCATE(rs_grid(nradsta))

    ! Initialize the smoothing weigths for each radar (if needed):
    IF (lsmooth) THEN
      CALL init_smth_info()
    END IF

    ! Initialize number of boundlines in auxiliary azimut slice
    ! grid if necessary:
    IF (lsmooth .AND. lonline) THEN
      ! >= 1 line of overlap at the lower and upper azimut index ends for the 
      ! auxiliary azimut-slices-grid (must RESULT in more space than needed 
      ! by the horizontal averaging stencil)
      ! For simplicity, we take the maximum value needed by any
      ! of the radars. 
      ! MIGHT BE CHANGED TO INDIVIDUAL VALUES FOR EACH OF THE RADARS LATERON!
      nblaztmp = 0
      DO ista = 1, nradsta
        nblaztmp(ista) = CEILING( smth_az_horzscan(ista,rs_meta(ista)%ngpsm_h, &
             MAXVAL(rs_meta(ista)%el_arr)) / rs_meta(ista)%az_inc )
      END DO
      nbl_az = MAX(MAXVAL(nblaztmp), 1_iintegers)
    ELSE
      nbl_az = 0
    END IF

    IF (ldebug_radsim) THEN
      WRITE (*,*) TRIM(yzroutine)//' : nbl_az = ', nbl_az
    END IF

    ! Initialize the parameters for the azimut slice grid for each radar (if needed):
    !  (this needs the parameter nbl_az from above)
    IF (lonline) THEN
      CALL init_grid_info()
    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE init_radar


  SUBROUTINE opendiagfiles ( openstatus, openpos )

    !------------------------------------------------------------------------------
    !
    ! Description: Opens file units for diagnostic output files
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    CHARACTER (len=*), INTENT(in) :: openstatus   ! e.g., "replace" or "old"
    CHARACTER (len=*), INTENT(in) :: openpos      ! e.g., "rewind" or "append"

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    ! name of control output file for radar beam geometry (height, local elevation)
    CHARACTER (LEN=250)                   :: outfile_hr
    ! name of control output file for simul radar radial wind
    CHARACTER (LEN=250)                   :: outfile_vr
    ! name of control output file for obs. radar radial wind
    CHARACTER (LEN=250)                   :: outfile_vr_obs
    ! name of control output file for simul. radar reflectivity
    CHARACTER (LEN=250)                   :: outfile_zr
    ! name of control output file for obs. radar reflectivity
    CHARACTER (LEN=250)                   :: outfile_zr_obs
    ! name of control output file for radar extinction
    CHARACTER (LEN=250)                   :: outfile_ze

    CHARACTER (LEN=32)            :: yzroutine
    CHARACTER (LEN=80)            :: yzerrmsg 
    INTEGER (KIND = iintegers)    :: ista, ista_par, ipe_rad, ios

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE init_radar
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'opendiagfiles'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! .. Open the file units for the control output for each data set of
    !    each radar station:
    IF (.FALSE.) THEN
!!$ Left in the code, so that in future, one might go
!!$ back to output on node 0 only for whatever reason:
      ! .. Here, a parallel output is not implemented yet, so 
      !    all the files for the control output for each radar
      !    have to be opened on PE 0
      IF (my_cart_id == 0) THEN
        DO ista = 1, nradsta
          IF (lout_geom) THEN
            outfile_hr(:) = ' '
            WRITE (outfile_hr,'("YURADGEOM_ID-",i6.6)') rs_meta(ista)%station_id
            CALL get_free_unit(radgeomoutputunit(ista))
            OPEN(radgeomoutputunit(ista),file=TRIM(outfile_hr),iostat=ios, &
                 status=TRIM(openstatus), position=TRIM(openpos), action='write')
            CALL openerrmsg ( ios, TRIM(outfile_hr) )
          END IF
          IF (loutradwind) THEN
            outfile_vr(:) = ' '
            WRITE (outfile_vr,'("YURADWIND_ID-",i6.6)') rs_meta(ista)%station_id
            CALL get_free_unit(radwindoutputunit(ista))
            OPEN(radwindoutputunit(ista),file=TRIM(outfile_vr),iostat=ios, &
                 status=TRIM(openstatus), position=TRIM(openpos), action='write')
            CALL openerrmsg ( ios, TRIM(outfile_vr) )
            IF (lreadmeta_from_netcdf) THEN
              outfile_vr_obs(:) = ' '
              WRITE (outfile_vr_obs,'("YURADWINDOBS_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(radwindobsoutputunit(ista))
              OPEN(radwindobsoutputunit(ista),file=TRIM(outfile_vr_obs),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_vr_obs) )
            END IF
          END IF
          IF (loutdbz) THEN
            outfile_zr(:) = ' '
            WRITE (outfile_zr,'("YURADREFL_ID-",i6.6)') rs_meta(ista)%station_id
            CALL get_free_unit(radrefloutputunit(ista))
            OPEN(radrefloutputunit(ista),file=TRIM(outfile_zr),iostat=ios, &
                 status=TRIM(openstatus), position=TRIM(openpos), action='write')
            CALL openerrmsg ( ios, TRIM(outfile_zr) )
            IF (lreadmeta_from_netcdf) THEN
              outfile_zr_obs(:) = ' '
              WRITE (outfile_zr_obs,'("YURADREFLOBS_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(radreflobsoutputunit(ista))
              OPEN(radreflobsoutputunit(ista),file=TRIM(outfile_zr_obs),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_zr_obs) )
            END IF
            IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
              outfile_ze(:) = ' '
              WRITE (outfile_ze,'("YUEXTREFL_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(extrefloutputunit(ista))
              OPEN(extrefloutputunit(ista),file=TRIM(outfile_ze),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_ze) )
            END IF
          END IF
        END DO
      END IF
    ELSE
      ! .. Here, parallel output is implemented in a way that the radar
      !    station output is distributed among the compute PEs in a
      !    round-robin fashion:
      DO ista_par = 1, nradsta, num_compute
        DO ista = ista_par, MIN(ista_par+num_compute-1, nradsta)
          ipe_rad = MOD(ista-1, num_compute)
          IF (ipe_rad == my_cart_id) THEN
            IF (lout_geom) THEN
              outfile_hr(:) = ' '
              WRITE (outfile_hr,'("YURADGEOM_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(radgeomoutputunit(ista))
              OPEN(radgeomoutputunit(ista),file=TRIM(outfile_hr),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_hr) )
            END IF
            IF (loutradwind) THEN
              outfile_vr(:) = ' '
              WRITE (outfile_vr,'("YURADWIND_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(radwindoutputunit(ista))
              OPEN(radwindoutputunit(ista),file=TRIM(outfile_vr),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_vr) )
              IF (lreadmeta_from_netcdf) THEN
                outfile_vr_obs(:) = ' '
                WRITE (outfile_vr_obs,'("YURADWINDOBS_ID-",i6.6)') rs_meta(ista)%station_id
                CALL get_free_unit(radwindobsoutputunit(ista))
                OPEN(radwindobsoutputunit(ista),file=TRIM(outfile_vr_obs),iostat=ios, &
                     status=TRIM(openstatus), position=TRIM(openpos), action='write')
                CALL openerrmsg ( ios, TRIM(outfile_vr_obs) )
              END IF
            END IF
            IF (loutdbz) THEN
              outfile_zr(:) = ' '
              WRITE (outfile_zr,'("YURADREFL_ID-",i6.6)') rs_meta(ista)%station_id
              CALL get_free_unit(radrefloutputunit(ista))
              OPEN(radrefloutputunit(ista),file=TRIM(outfile_zr),iostat=ios, &
                   status=TRIM(openstatus), position=TRIM(openpos), action='write')
              CALL openerrmsg ( ios, TRIM(outfile_zr) )
              IF (lreadmeta_from_netcdf) THEN
                outfile_zr_obs(:) = ' '
                WRITE (outfile_zr_obs,'("YURADREFLOBS_ID-",i6.6)') rs_meta(ista)%station_id
                CALL get_free_unit(radreflobsoutputunit(ista))
                OPEN(radreflobsoutputunit(ista),file=TRIM(outfile_zr_obs),iostat=ios, &
                     status=TRIM(openstatus), position=TRIM(openpos), action='write')
                CALL openerrmsg ( ios, TRIM(outfile_zr_obs) )
              END IF
              IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
                outfile_ze(:) = ' '
                WRITE (outfile_ze,'("YUEXTREFL_ID-",i6.6)') rs_meta(ista)%station_id
                CALL get_free_unit(extrefloutputunit(ista))
                OPEN(extrefloutputunit(ista),file=TRIM(outfile_ze),iostat=ios, &
                     status=TRIM(openstatus), position=TRIM(openpos), action='write')
                CALL openerrmsg ( ios, TRIM(outfile_ze) )
              END IF
            END IF
          END IF
        END DO
      END DO
    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  CONTAINS

    SUBROUTINE openerrmsg ( ios, outfile )
      INTEGER, INTENT(in) :: ios
      CHARACTER (LEN=*)   :: outfile
      IF ( ios /= 0 ) THEN
        CALL model_abort (my_world_id, 20365, &
             'ERROR: problem in ' //TRIM(yzroutine)// &
             ': error opening output diagnosis file '//TRIM(outfile) , &
             'src_radar.f90, '//TRIM(yzroutine))
      END IF
    END SUBROUTINE openerrmsg

  END SUBROUTINE opendiagfiles

  SUBROUTINE closediagfiles ()

    !------------------------------------------------------------------------------
    !
    ! Description: Closes file units for diagnostic output files
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32)            :: yzroutine
    CHARACTER (LEN=80)            :: yzerrmsg 
    INTEGER (KIND = iintegers)    :: ista, ista_par, ipe_rad
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE init_radar
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'closediagfiles'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! .. Open the file units for the control output for each data set of
    !    each radar station:
    IF (.FALSE.) THEN
!!$ Left in the code, so that in future, one might go
!!$ back to output on node 0 only for whatever reason:
      ! .. Here, a parallel output is not implemented yet, so 
      !    all the files for the control output for each radar
      !    have to be opened on PE 0
      IF (my_cart_id == 0) THEN
        DO ista = 1, nradsta
          IF (lout_geom) THEN
            CLOSE(radgeomoutputunit(ista))
            CALL release_unit (radgeomoutputunit(ista))
          END IF
          IF (loutradwind) THEN
            CLOSE(radwindoutputunit(ista))
            CALL release_unit (radwindoutputunit(ista))
            IF (lreadmeta_from_netcdf) THEN
              CLOSE (radwindobsoutputunit(ista))
              CALL release_unit (radwindobsoutputunit(ista))
            END IF
          END IF
          IF (loutdbz) THEN
            CLOSE(radrefloutputunit(ista))
            CALL release_unit (radrefloutputunit(ista))
            IF (lreadmeta_from_netcdf) THEN
              CLOSE(radreflobsoutputunit(ista))
              CALL release_unit (radreflobsoutputunit(ista))
            END IF
            IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
              CLOSE(extrefloutputunit(ista))
              CALL release_unit (extrefloutputunit(ista))
            END IF
          END IF
        END DO
      END IF
    ELSE
      ! .. Here, parallel output is implemented in a way that the radar
      !    station output is distributed among the compute PEs in a
      !    round-robin fashion:
      DO ista_par = 1, nradsta, num_compute
        DO ista = ista_par, MIN(ista_par+num_compute-1, nradsta)
          ipe_rad = MOD(ista-1, num_compute)
          IF (ipe_rad == my_cart_id) THEN
            IF (lout_geom) THEN
              CLOSE(radgeomoutputunit(ista))
              CALL release_unit (radgeomoutputunit(ista))             
            END IF
            IF (loutradwind) THEN
              CLOSE(radwindoutputunit(ista))
              CALL release_unit (radwindoutputunit(ista))
              IF (lreadmeta_from_netcdf) THEN
                CLOSE(radwindobsoutputunit(ista))
                CALL release_unit (radwindobsoutputunit(ista))
              END IF
            END IF
            IF (loutdbz) THEN
              CLOSE(radrefloutputunit(ista))
              CALL release_unit (radrefloutputunit(ista))
              IF (lreadmeta_from_netcdf) THEN
                CLOSE(radreflobsoutputunit(ista))
                CALL release_unit (radreflobsoutputunit(ista))
              END IF
              IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
                CLOSE(extrefloutputunit(ista))
                CALL release_unit (extrefloutputunit(ista))
              END IF
            END IF
          END IF
        END DO
      END DO
    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE closediagfiles

  !==============================================================================
  !+ Module procedure in src_radar for the computation of radar beam geometry
  !------------------------------------------------------------------------------

  SUBROUTINE calc_geometry

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar beam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the 
    !              model winds to the radar points. Currently these interpolation
    !              weights and the interpolation indices are constant in time since 
    !              the radar geometry is also constant in time and this subroutine
    !              is only called in the first call of the operator. For a future
    !              version this routine can be called every time the operator is called.
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32)  :: yzroutine
    CHARACTER (LEN=80)  :: yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,ira,nobsmax,nobs,nobs_above_sfc,&
         i,j,k,m,n,o,offset_i,offset_j,nobs_below_sfc,nrp,nu,no,nur,nor
    REAL    (KIND = ireals)          :: &
                                ! UB>> removed initialization with 0.0 here, because wi, wj and wk then would get an implicit "SAVE" attribute!!!
         wi,& ! interpolation weight in i-direction
         wj,& ! interpolation weight in j-direction
         wk,& ! interpolation weight in k-direction
         rlon_min     ,& ! min rotated longitude in local subdomain
         rlon_max     ,& ! max rotated longitude in local subdomain
         rlat_min     ,& ! min rotated latitude in local subdomain
         rlat_max     ,& ! max rotated latitude in local subdomain
         rlon_r       ,& ! rotated longitude for a radar point
         rlat_r       ,&
         htop            ! top height of model domain
    REAL    (KIND = ireals), ALLOCATABLE :: &
         azarr(:)    ,& ! array of azimuths
         raarr(:)    ,& ! array of radial bins
         lat_r(:,:,:),& ! array of geographical latitudes for each radar point (az,ra,el)
         lon_r(:,:,:),& ! array of geographical longitudes for each radar point (az,ra,el)
         alt_r(:,:)  ,& ! array of altitudes above sea level for each radar point (ra,el)
         w_intp(:,:) ,& ! array of horizontal interpolation weights for each observation (first dimension)
         hl_loc(:), el_loc(:)
    ! and each spatial direction i,j,k (second dimension) 
    INTEGER (KIND = iintegers), ALLOCATABLE ::&
         ind_intp(:,:)  ! array of grid indices for each observation (first dimension)
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2,3,4: the observation indices in azimuthal, radial and elevation direction (m,n,o)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    htop = MAXVAL(hhl(:,:,1))

    ! loop over radar stations
    DO ista = 1,nradsta

      ! allocate and initialize local aux arrays
      nobsmax = rs_meta(ista)%nra * rs_meta(ista)%naz * rs_meta(ista)%nel
      ALLOCATE(w_intp(nobsmax,3))
      ALLOCATE(ind_intp(nobsmax,2))
      ALLOCATE(lat_r(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel))
      ALLOCATE(lon_r(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel))
      ALLOCATE(alt_r(rs_meta(ista)%nra,rs_meta(ista)%nel))
      ALLOCATE(hl_loc(nobsmax))
      ALLOCATE(el_loc(nobsmax))

!CDIR BEGIN COLLAPSE
      w_intp   = -1.0_ireals
      ind_intp = -1_iintegers
      lat_r    = 0.0_ireals
      lon_r    = 0.0_ireals
      alt_r    = -1.0_ireals
!CDIR END

      ! fill up range array
      ALLOCATE(raarr(rs_meta(ista)%nra))
      DO ira = 1,rs_meta(ista)%nra
        raarr(ira) = ira * rs_meta(ista)%ra_inc
      END DO
      ! UB<<

      ! fill up azimuth array
      ALLOCATE(azarr(rs_meta(ista)%naz))
      DO iaz = 1,rs_meta(ista)%naz
        azarr(iaz) = (iaz-1_iintegers) * rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        ! Folding into the range [0, 360]
        azarr(iaz) = MODULO(azarr(iaz),360.0_ireals)
      END DO
      ! UB<<

      ! calculate geographical coordinates (lat,lon,alt) of radar points
      CALL rad2geo_const(rs_meta(ista)%lat,       &
           rs_meta(ista)%lon,       &
           rs_meta(ista)%alt_msl,   &
           rs_meta(ista)%naz,       &
           rs_meta(ista)%nra,       &
           rs_meta(ista)%nel,       &
           raarr,                   &
           azarr,                   &
           rs_meta(ista)%el_arr(1:rs_meta(ista)%nel),&
           lat_r,lon_r,alt_r)

      ! calculate min and max of rotated lat and lon of subdomain
      ! use whole domain, i.e. inclusive boundary zone at the border 
      ! of the total domain
      offset_i = nboundlines
      offset_j = nboundlines

      ! rotated longitude of western boundary
      rlon_min = startlon_tot + (isubpos(my_cart_id,1)-1)*dlon
      !       if (istartpar == 1) then
      !         offset_i = 0
      !         rlon_min = rlon_min - nboundlines*dlon
      !       end if

      !       ! rotated longitude of eastern boundary
      rlon_max = startlon_tot + (isubpos(my_cart_id,3)-1)*dlon
      !       if (iendpar == ie) rlon_max = rlon_max + (nboundlines-1)*dlon
      ! 
      !       ! rotated latitude of southern boundary
      rlat_min = startlat_tot + (isubpos(my_cart_id,2)-1)*dlat
      !       if (jstartpar == 1) then
      !         offset_j = 0
      !         rlat_min = rlat_min - nboundlines*dlon
      !       end if

      !       ! rotated latitude of northern boundary
      rlat_max = startlat_tot + (isubpos(my_cart_id,4)-1)*dlat
      !       if (jendpar == je) rlat_max = rlat_max + (nboundlines-1)*dlat


      ! loop over all radar points
      nrp = 0
      nobs_above_sfc = 0     
      nobs_below_sfc = 0     
      DO o = 1, rs_meta(ista)%nel         ! loop over elevations
        DO n = 1, rs_meta(ista)%nra       ! loop over radii
          DO m = 1, rs_meta(ista)%naz     ! loop over azimuths

            nrp = nrp + 1

            ! UB>> there are vectorized routines rla2rlarot_vec and phi2phirot_vec!
            ! calculate rotated longitude and latitude of radar point
            rlon_r = rla2rlarot(lat_r(m,n,o),lon_r(m,n,o),pollat,pollon,polgam)
            rlat_r = phi2phirot(lat_r(m,n,o),lon_r(m,n,o),pollat,pollon)

            ! UB>> a "cycle" is vectorization obstructive!!!
            ! cycle if radar point is not in local subdomain
            IF ((rlat_r < rlat_min-0.5*dlat) .OR. &
                 (rlat_r > rlat_max+0.5*dlat) .OR. &
                 (rlon_r < rlon_min-0.5*dlon) .OR. &
                 (rlon_r > rlon_max+0.5*dlon) .OR. &
                 (alt_r(n,o) > htop) ) CYCLE

            ! calculate indices of model point southwest of radar point
            ! UB>> floor instead of int because of correct behaviour at the subdomain boundaries:
!!$            i = 1 + int((rlon_r - rlon_min)/dlon,iintegers) + offset_i
!!$            j = 1 + int((rlat_r - rlat_min)/dlat,iintegers) + offset_j
            i = MAX(1 + FLOOR((rlon_r - rlon_min)/dlon,iintegers) + offset_i, 1_iintegers)
            j = MAX(1 + FLOOR((rlat_r - rlat_min)/dlat,iintegers) + offset_j, 1_iintegers)
            ! UB<<
            ! compute interpolation weights in i and j direction
            wi = (rlon_r-(rlon_min + (i-offset_i-1)*dlon))/dlon
            wi = MIN(MAX(wi,0.0_ireals),1.0_ireals)
            wj = (rlat_r-(rlat_min + (j-offset_j-1)*dlat))/dlat
            wj = MIN(MAX(wj,0.0_ireals),1.0_ireals)


            ! calculate vertical index k above radar point and vertical interpolation weight wk
            ! UB>> vectorization obstructive!!!
            CALL calc_vert_weight(alt_r(n,o),hhl(i:i+1,j:j+1,1:ke+1),ke,wi,wj,k,wk)

            IF (k > 0) THEN
              ! if radar point above surface (is indicated by k > 0):

              nobs_above_sfc = nobs_above_sfc + 1
              
              ! store weights and indices of radar point
              w_intp(nobs_above_sfc,1) = wi
              w_intp(nobs_above_sfc,2) = wj
              w_intp(nobs_above_sfc,3) = wk
              
              ind_intp(nobs_above_sfc,1) = i + (j-1)*ie + (k-1)*ie*je
              ind_intp(nobs_above_sfc,2) = nrp
              ! (This is equivalent to:
              !   ind_intp(nobs_above_sfc,2) = m + (n-1)*rs_meta(ista)%naz + &
              !                          (o-1)*rs_meta(ista)%naz*rs_meta(ista)%nra
              ! )
              
              hl_loc(nobs_above_sfc) = alt_r(n,o)
              el_loc(nobs_above_sfc) = el_loc_43(raarr(n),rs_meta(ista)%el_arr(o),rs_meta(ista)%alt_msl)

            ELSE
              ! if radar point below surface (is indicated by k = -1):

              nobs_below_sfc  = nobs_below_sfc + 1

              ! in this case, write from the back of the vectors:
              nor             = nobsmax - nobs_below_sfc + 1

              w_intp(nor,:)   = -999.99_ireals
              ind_intp(nor,1) = -999_iintegers
              ind_intp(nor,2) = nrp
              hl_loc(nor)     = alt_r(n,o)
              el_loc(nor)     = -999.99_ireals

            END IF

          END DO
        END DO
      END DO

      rs_data(ista)%nobs_above_sfc  = nobs_above_sfc
      rs_data(ista)%nobs            = nobs_above_sfc + nobs_below_sfc

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp))   DEALLOCATE (rs_data(ista)%w_intp)
      IF (ASSOCIATED(rs_data(ista)%ind_intp)) DEALLOCATE (rs_data(ista)%ind_intp)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))   DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))   DEALLOCATE (rs_data(ista)%el_loc)
      ALLOCATE(rs_data(ista)%w_intp(nobs,3))
      ALLOCATE(rs_data(ista)%ind_intp(nobs,2))
      ALLOCATE(rs_data(ista)%hl_loc(nobs))
      ALLOCATE(rs_data(ista)%el_loc(nobs))

      IF (nobs_above_sfc > 0) THEN 
        ! copy values from auxiliary variables
        rs_data(ista)%w_intp(1:nobs_above_sfc,:)   = w_intp(1:nobs_above_sfc,:)
        rs_data(ista)%ind_intp(1:nobs_above_sfc,:) = ind_intp(1:nobs_above_sfc,:)
        rs_data(ista)%hl_loc(1:nobs_above_sfc)     = hl_loc(1:nobs_above_sfc)
        rs_data(ista)%el_loc(1:nobs_above_sfc)     = el_loc(1:nobs_above_sfc)
      END IF

      IF (nobs_below_sfc > 0) THEN 
        ! copy values from auxiliary variables
        nu = nobs_above_sfc+1
        no = nobs_above_sfc+nobs_below_sfc
        nur = nobsmax-nobs_below_sfc+1
        nor = nobsmax
        rs_data(ista)%w_intp(nu:no,:)   = w_intp(nor:nur:-1,:)
        rs_data(ista)%ind_intp(nu:no,:) = ind_intp(nor:nur:-1,:)
        rs_data(ista)%hl_loc(nu:no)     = hl_loc(nor:nur:-1)
        rs_data(ista)%el_loc(nu:no)     = el_loc(nor:nur:-1)
      END IF



      ! deallocate auxiliary fields
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(raarr)
      DEALLOCATE(azarr)
      DEALLOCATE(lat_r)
      DEALLOCATE(lon_r)
      DEALLOCATE(alt_r)
      DEALLOCATE(hl_loc)
      DEALLOCATE(el_loc)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id


  END SUBROUTINE calc_geometry


  ! ZY >> Vectorized Version for Subroutine calc_geometry added
  !==============================================================================
  !+ Module procedure in src_radar for the computation of radar beam geometry
  !------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_vec

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar beam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the 
    !              model data to the radar points. These interpolation
    !              weights and the interpolation indices are constant in time since 
    !              the radar geometry is also constant in time and this subroutine
    !              is only called in the first call of the operator.
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,ira,irp,nobsmax,nobs_above_sfc, &
         nrp,i,j,k,m,n,o,offset_i,offset_j,irploc, &
         nobs_below_sfc

    REAL    (KIND = ireals)          :: &
         wi,& ! interpolation weight in i-direction
         wj,& ! interpolation weight in j-direction
         wk,& ! interpolation weight in k-direction
         rlon_min     ,& ! min rotated longitude in local subdomain
         rlon_max     ,& ! max rotated longitude in local subdomain
         rlat_min     ,& ! min rotated latitude in local subdomain
         rlat_max     ,& ! max rotated latitude in local subdomain
         htop            ! top height of model domain

    REAL    (KIND = ireals), ALLOCATABLE :: &
         azarr(:)    ,& ! array of azimuths
         raarr(:)    ,& ! array of radial bins
         lat_r(:)    ,& ! array of geographical latitudes for each radar point (nrp)
         lon_r(:)    ,& ! array of geographical longitudes for each radar point (nrp)
         alt_r(:)    ,& ! array of altitudes above sea level for each radar point (nrp)
         alt_rtmp(:) ,& ! array of altitudes above sea level for temporary radar point (nrp)
         rlat_r(:)   ,& ! rotated latitude for each radar point in local subdomain
         rlon_r(:)   ,& ! rotated lonitude for each radar point in local subdomain
         w_intp(:,:) ,& ! array of horizontal interpolation weights for each observation (first dimension) and each spatial direction i,j,k (second dimension) 
         w_intptmp(:,:) ! array of horizontal interpolation weights for each temporary radar point

    INTEGER (KIND = iintegers), ALLOCATABLE ::&
         irp_tmp(:) , &
         ind_intptmp(:,:) 
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2: the observation indices in azimuthal, radial and elevation direction (irp)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_vec
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_vec'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    htop = MAXVAL(hhl(:,:,1))

    ! loop over radar stations
    DO ista = 1,nradsta

      ! allocate and initialize local aux arrays
      nobsmax = rs_meta(ista)%nra * rs_meta(ista)%naz * rs_meta(ista)%nel

      ALLOCATE(irp_tmp(nobsmax)) 
      ALLOCATE(lat_r(nobsmax))
      ALLOCATE(lon_r(nobsmax))
      ALLOCATE(alt_r(nobsmax))
      ALLOCATE(rlon_r(nobsmax))
      ALLOCATE(rlat_r(nobsmax))

!CDIR BEGIN COLLAPSE
      irp_tmp  = -1_iintegers
      lat_r    = 0.0_ireals
      lon_r    = 0.0_ireals
      alt_r    = -1.0_ireals
      rlon_r   = 0.0_ireals
      rlat_r   = 0.0_ireals
!CDIR END


      ! fill up range array
      ALLOCATE(raarr(rs_meta(ista)%nra))
      DO ira = 1,rs_meta(ista)%nra
        raarr(ira) = ira * rs_meta(ista)%ra_inc
      END DO

      ! fill up azimuth array
      ALLOCATE(azarr(rs_meta(ista)%naz))
      DO iaz = 1,rs_meta(ista)%naz
        azarr(iaz) = (iaz-1_iintegers) * rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        ! Folding into the range [0, 360] degrees
        azarr(iaz) = MODULO(azarr(iaz),360.0_ireals)
      END DO

      ! calculate geographical coordinates (lat,lon,alt) of radar points
      CALL rad2geo_const_vec(rs_meta(ista)%lat,       &
           rs_meta(ista)%lon,       &
           rs_meta(ista)%alt_msl,   &
           rs_meta(ista)%naz,       &
           rs_meta(ista)%nra,       &
           rs_meta(ista)%nel,       &
           raarr,                   &
           azarr,                   &
           rs_meta(ista)%el_arr(1:rs_meta(ista)%nel),&
           lat_r,lon_r,alt_r)

      ! calculate min and max of rotated lat and lon of subdomain
      ! use whole domain, i.e. inclusive boundary zone at the border 
      ! of the total domain
      offset_i = nboundlines
      offset_j = nboundlines

      ! rotated longitude of western boundary
      rlon_min = startlon_tot + (isubpos(my_cart_id,1)-1)*dlon

      ! rotated longitude of eastern boundary
      rlon_max = startlon_tot + (isubpos(my_cart_id,3)-1)*dlon

      ! rotated latitude of southern boundary
      rlat_min = startlat_tot + (isubpos(my_cart_id,2)-1)*dlat

      ! rotated latitude of northern boundary
      rlat_max = startlat_tot + (isubpos(my_cart_id,4)-1)*dlat

      ! UB>> there are vectorized routines rla2rlarot_vec and phi2phirot_vec!
      ! calculate rotated longitude and latitude of radar point
      DO irp = 1, nobsmax

        rlon_r(irp) = rla2rlarot(lat_r(irp),lon_r(irp),pollat,pollon,polgam)
        rlat_r(irp) = phi2phirot(lat_r(irp),lon_r(irp),pollat,pollon)

      ENDDO

      DEALLOCATE(lat_r)
      DEALLOCATE(lon_r)

      ! To gain the indices i,j of model grids southwest to radar points and 
      ! check if the radar point is in the local domain, based on lon i and lat j of radar points
      nrp = 0

      DO irp = 1, nobsmax

        IF ( (rlat_r(irp) >= rlat_min-0.5*dlat) .AND. &
             (rlat_r(irp) <= rlat_max+0.5*dlat) .AND. &
             (rlon_r(irp) >= rlon_min-0.5*dlon) .AND. &
             (rlon_r(irp) <= rlon_max+0.5*dlon) .AND. &
             (alt_r(irp)  <= htop) ) THEN

          nrp = nrp + 1

          irp_tmp(nrp) = irp

        END IF

      END DO

      ALLOCATE(ind_intptmp(nrp,4))
      ALLOCATE(w_intptmp(nrp,3))
      ALLOCATE(alt_rtmp(nrp))

!CDIR BEGIN COLLAPSE
      w_intptmp = -1.0_ireals
      ind_intptmp = -1_iintegers
      alt_rtmp = -1.0_ireals
!CDIR END


!CDIR NODEP,VOVERTAKE,VOB
      DO irp = 1, nrp

        irploc = irp_tmp(irp)

        i = MAX(1 + FLOOR((rlon_r(irploc) - rlon_min)/dlon,iintegers) + offset_i, 1_iintegers)
        j = MAX(1 + FLOOR((rlat_r(irploc) - rlat_min)/dlat,iintegers) + offset_j, 1_iintegers)

        ind_intptmp(irp,1) = irploc
        ind_intptmp(irp,2) = i
        ind_intptmp(irp,3) = j

        ! compute interpolation weights in i and j direction
        w_intptmp(irp,1) = MIN(MAX((rlon_r(irploc)-(rlon_min + (i-offset_i-1)*dlon))/dlon,0.0_ireals),1.0_ireals)
        w_intptmp(irp,2) = MIN(MAX((rlat_r(irploc)-(rlat_min + (j-offset_j-1)*dlat))/dlat,0.0_ireals),1.0_ireals)

        alt_rtmp(irp) = alt_r(irploc)

      ENDDO

      DEALLOCATE(irp_tmp)
      DEALLOCATE(alt_r)
      DEALLOCATE(rlat_r)
      DEALLOCATE(rlon_r)      

      ! To gain the indices k of model grids above radar points 
      CALL calc_vert_weight_vec(nrp,alt_rtmp(1:nrp),ind_intptmp(1:nrp,2),ind_intptmp(1:nrp,3),&
           w_intptmp(1:nrp,1),w_intptmp(1:nrp,2),ind_intptmp(1:nrp,4),w_intptmp(1:nrp,3))

      ! Check if the radar point is in the local domain, based on height k
      ! Obtain the final set of observable radar points above the surface in the local domain
      nobs_above_sfc = 0 
      DO irp = 1, nrp
        IF (ind_intptmp(irp,4) > 0) THEN
          nobs_above_sfc = nobs_above_sfc + 1
        END IF
      END DO

      ! Number of obs above surface:
      rs_data(ista)%nobs_above_sfc     = nobs_above_sfc
      ! Total number of obs (including points below surface):
      rs_data(ista)%nobs               = nrp

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp))   DEALLOCATE (rs_data(ista)%w_intp)
      IF (ASSOCIATED(rs_data(ista)%ind_intp)) DEALLOCATE (rs_data(ista)%ind_intp)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))   DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))   DEALLOCATE (rs_data(ista)%el_loc)
      ALLOCATE(rs_data(ista)%w_intp(nrp,3))
      ALLOCATE(rs_data(ista)%ind_intp(nrp,2))
      ALLOCATE(rs_data(ista)%hl_loc(nrp))
      ALLOCATE(rs_data(ista)%el_loc(nrp))

      ! First, sort radar points above surface into the weight fields:
      nobs_above_sfc = 0 
!CDIR VOVERTAKE,VOB
      DO irp = 1, nrp

        IF (ind_intptmp(irp,4) > 0) THEN

          nobs_above_sfc = nobs_above_sfc + 1

          rs_data(ista)%w_intp(nobs_above_sfc,1) = w_intptmp(irp,1)
          rs_data(ista)%w_intp(nobs_above_sfc,2) = w_intptmp(irp,2)
          rs_data(ista)%w_intp(nobs_above_sfc,3) = w_intptmp(irp,3)

          rs_data(ista)%ind_intp(nobs_above_sfc,1) = &
               ind_intptmp(irp,2) + (ind_intptmp(irp,3)-1)*ie + &
               (ind_intptmp(irp,4)-1)*ie*je 

          rs_data(ista)%ind_intp(nobs_above_sfc,2) = ind_intptmp(irp,1)
          rs_data(ista)%hl_loc(nobs_above_sfc) = alt_rtmp(irp)

          CALL ind2sub3D( ind_intptmp(irp,1), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                          m, n, o )

          rs_data(ista)%el_loc(nobs_above_sfc) = &
               el_loc_43 (raarr(n), rs_meta(ista)%el_arr(o), rs_meta(ista)%alt_msl)

        ENDIF

      ENDDO

      ! Then, keep track of the positions of the points below surface:
      !   (Here, later the missing value -988.88 will be set for radial wind and reflectivity)
      nobs_below_sfc = nobs_above_sfc
!CDIR VOVERTAKE,VOB
      DO irp = 1, nrp
      
        IF (ind_intptmp(irp,4) == -1) THEN
          nobs_below_sfc = nobs_below_sfc + 1
          rs_data(ista)%w_intp(nobs_below_sfc,1)   = -999.99_ireals
          rs_data(ista)%w_intp(nobs_below_sfc,2)   = -999.99_ireals
          rs_data(ista)%w_intp(nobs_below_sfc,3)   = -999.99_ireals
          rs_data(ista)%ind_intp(nobs_below_sfc,1) = -999_iintegers
          rs_data(ista)%ind_intp(nobs_below_sfc,2) = ind_intptmp(irp,1)
          rs_data(ista)%hl_loc(nobs_below_sfc)     = alt_rtmp(irp)          
          rs_data(ista)%el_loc(nobs_below_sfc)     = -988.88_ireals
        END IF

      END DO

      ! deallocate auxiliary fields
      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(raarr)
      DEALLOCATE(azarr)
      DEALLOCATE(alt_rtmp)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_vec


  ! ZY >> calc_geometry with spatial averaging added   
  !==============================================================================
  !+ Module procedure in src_radar for the computation of radar subbeams geometry
  !------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_smth

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar main- and subbeams geometry and the 
    !              interpolation weights and interpolation indices for the 
    !              interpolation to basis points of Gauss-Legendre Quadrature.
    !              These interpolation weights and the interpolation indices
    !              are constant in time since the radar geometry is also constant
    !              in time and this subroutine is only called in the first call of 
    !              the operator.
    !              
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers) :: ista,iaz,ira,irp,nobsmax,nrp,i,j,k,m,n,o, &
         offset_i,offset_j, &
         ismth,jsmth,ksmth,iv,ih,nsmth_above_sfc,nsmth_below_sfc,irploc
    REAL    (KIND = ireals)    ::                   &                              
         wi_smth          ,& ! interpolation weight in i-direction
         wj_smth          ,& ! interpolation weight in j-direction
         wk_smth          ,& ! interpolation weight in k-direction
         rlon_min         ,& ! min rotated longitude in local subdomain
         rlon_max         ,& ! max rotated longitude in local subdomain
         rlat_min         ,& ! min rotated latitude in local subdomain
         rlat_max         ,& ! max rotated latitude in local subdomain
         htop             ,& ! top height of model domain
         el_sta              ! elevation angle of sub-beam at radar station

    REAL    (KIND = ireals),      ALLOCATABLE    :: &
         azarr(:)         ,& ! array of azimuths
         raarr(:)         ,& ! array of radial bins
         lat_smth(:)      ,& ! array of geographical latitudes for each radar point (nrp)
         lon_smth(:)      ,& ! array of geographical longitudes for each radar point (nrp)
         alt_smth(:)      ,& ! array of altitudes above sea level for each radar point (nrp)
         alt_rtmp(:)      ,& ! array of altitudes above sea level for temporary radar point (nrp)
         rlat_smth(:)     ,& ! rotated latitude for each radar point in local subdomain
         rlon_smth(:)     ,& ! rotated lonitude for each radar point in local subdomain
         w_intptmp(:,:)      ! array of interpolation weights for each smoothing points (first dimension) and each spatial direction i,j,k (second dimension) 

    INTEGER (KIND = iintegers),   ALLOCATABLE ::    &
         irp_tmp(:) ,&
         ind_intptmp(:,:) !!$ ,&
!!$                                  ind_intp_smth(:,:)  ! array of grid indices for each observation (first dimension)
    ! array of indices in azimuthal, radial and elevation direction (second dimension) 

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_smth
    !-----------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_smth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    htop = MAXVAL(hhl(:,:,1))

    ! loop over radar stations
    DO ista = 1,nradsta

      ! allocate and initialize local aux arrays
      nobsmax = rs_meta(ista)%nra * rs_meta(ista)%naz * rs_meta(ista)%nel * rs_meta(ista)%ngpsm_v * rs_meta(ista)%ngpsm_h

      ALLOCATE(irp_tmp(nobsmax)) 
      ALLOCATE(lat_smth(nobsmax)) 
      ALLOCATE(lon_smth(nobsmax))
      ALLOCATE(alt_smth(nobsmax))
      ALLOCATE(rlon_smth(nobsmax))
      ALLOCATE(rlat_smth(nobsmax))

!CDIR BEGIN COLLAPSE
      irp_tmp    = -1_iintegers
      lat_smth   = 0.0_ireals
      lon_smth   = 0.0_ireals
      alt_smth   = -1.0_ireals
      rlon_smth  = 0.0_ireals
      rlat_smth  = 0.0_ireals
!CDIR END


      ! fill up range array
      ALLOCATE(raarr(rs_meta(ista)%nra))
      DO ira = 1,rs_meta(ista)%nra
        raarr(ira) = ira * rs_meta(ista)%ra_inc
      END DO

      ! fill up azimuth array
      ALLOCATE(azarr(rs_meta(ista)%naz))
      DO iaz = 1,rs_meta(ista)%naz
        azarr(iaz) = (iaz-1_iintegers) * rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        ! Folding into the range [0, 360] degrees
        azarr(iaz) = MODULO(azarr(iaz),360.0_ireals)
      END DO

      ! calculate geographical coordinates (lat,lon,alt) of radar points
      CALL rad2geo_const_smth(ista, rs_meta(ista)%lat,  &
           rs_meta(ista)%lon,       &
           rs_meta(ista)%alt_msl,   &
           rs_meta(ista)%naz,       &
           rs_meta(ista)%nra,       &
           rs_meta(ista)%nel,       &
           rs_meta(ista)%ngpsm_v,   &
           rs_meta(ista)%ngpsm_h,   &
           raarr,                   &
           azarr,                   &
           rs_meta(ista)%el_arr(1:rs_meta(ista)%nel),  &
           lat_smth,lon_smth,alt_smth)

      ! calculate min and max of rotated lat and lon of subdomain
      ! use whole domain, i.e. inclusive boundary zone at the border 
      ! of the total domain
      offset_i = nboundlines
      offset_j = nboundlines

      ! rotated longitude of western boundary
      rlon_min = startlon_tot + (isubpos(my_cart_id,1)-1)*dlon

      ! rotated longitude of eastern boundary
      rlon_max = startlon_tot + (isubpos(my_cart_id,3)-1)*dlon

      ! rotated latitude of southern boundary
      rlat_min = startlat_tot + (isubpos(my_cart_id,2)-1)*dlat

      ! rotated latitude of northern boundary
      rlat_max = startlat_tot + (isubpos(my_cart_id,4)-1)*dlat

      DO irp = 1, nobsmax

        rlon_smth(irp) = rla2rlarot(lat_smth(irp),lon_smth(irp),pollat,pollon,polgam)
        rlat_smth(irp) = phi2phirot(lat_smth(irp),lon_smth(irp),pollat,pollon)

      ENDDO

      DEALLOCATE(lat_smth)
      DEALLOCATE(lon_smth)

      ! To gain the indices i,j of model grids southwest to radar points and 
      ! check if the radar point is in the local domain, based on lon i and lat j of radar points
      nrp = 0

      DO irp = 1, nobsmax

        IF ( (rlat_smth(irp) >= rlat_min-0.5*dlat) .AND. &
             (rlat_smth(irp) <= rlat_max+0.5*dlat) .AND. &
             (rlon_smth(irp) >= rlon_min-0.5*dlon) .AND. &
             (rlon_smth(irp) <= rlon_max+0.5*dlon) .AND. &
             (alt_smth(irp)  <= htop) ) THEN

          nrp = nrp + 1

          irp_tmp(nrp) = irp

        END IF

      END DO

      ALLOCATE(ind_intptmp(nrp,4))
      ALLOCATE(w_intptmp(nrp,3))
      ALLOCATE(alt_rtmp(nrp))

!CDIR BEGIN COLLAPSE
      w_intptmp     = -1.0_ireals
      ind_intptmp   = -1_iintegers
      alt_rtmp      = -1.0_ireals
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
      DO irp = 1, nrp

        irploc = irp_tmp(irp)

        i = MAX(1 + FLOOR((rlon_smth(irploc) - rlon_min)/dlon,iintegers) + offset_i, 1_iintegers)
        j = MAX(1 + FLOOR((rlat_smth(irploc) - rlat_min)/dlat,iintegers) + offset_j, 1_iintegers)

        ind_intptmp(irp,1) = irploc
        ind_intptmp(irp,2) = i
        ind_intptmp(irp,3) = j

        ! compute interpolation weights in i and j direction
        w_intptmp(irp,1) = MIN(MAX((rlon_smth(irploc)-(rlon_min + (i-offset_i-1)*dlon))/dlon,0.0_ireals),1.0_ireals)
        w_intptmp(irp,2) = MIN(MAX((rlat_smth(irploc)-(rlat_min + (j-offset_j-1)*dlat))/dlat,0.0_ireals),1.0_ireals)

        alt_rtmp(irp) = alt_smth(irploc)

      ENDDO

      DEALLOCATE(irp_tmp)
      DEALLOCATE(alt_smth)
      DEALLOCATE(rlat_smth)
      DEALLOCATE(rlon_smth)      

      ! To gain the indices k of model grids above radar points 
      CALL calc_vert_weight_vec(nrp,alt_rtmp(1:nrp),ind_intptmp(1:nrp,2),ind_intptmp(1:nrp,3),&
           w_intptmp(1:nrp,1),w_intptmp(1:nrp,2),ind_intptmp(1:nrp,4),w_intptmp(1:nrp,3))

      ! Check if the radar point is in the local domain, based on height k
      ! Obtain the final set of observable radar points above the surface in the local domain
      nsmth_above_sfc = 0
      DO irp = 1, nrp
        IF (ind_intptmp(irp,4) > 0) THEN
          nsmth_above_sfc = nsmth_above_sfc + 1
        END IF
      END DO

      WRITE(*,*) 'calc_geometry_smth:  nsmth = ', nsmth_above_sfc

      ! Number of obs above surface:
      rs_data(ista)%nsmth_above_sfc     = nsmth_above_sfc
      ! Total number of obs (including points below surface):
      rs_data(ista)%nsmth               = nrp

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp_smth))   DEALLOCATE (rs_data(ista)%w_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%ind_intp_smth)) DEALLOCATE (rs_data(ista)%ind_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))        DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))        DEALLOCATE (rs_data(ista)%el_loc)
      ALLOCATE(rs_data(ista)%w_intp_smth(nrp,3))
      ALLOCATE(rs_data(ista)%ind_intp_smth(nrp,2))
      ALLOCATE(rs_data(ista)%hl_loc(nrp))
      ALLOCATE(rs_data(ista)%el_loc(nrp))

      ! First, sort radar points above surface into the weight fields:
      nsmth_above_sfc = 0
!CDIR VOVERTAKE,VOB
      DO irp = 1, nrp

        IF (ind_intptmp(irp,4) > 0) THEN

          nsmth_above_sfc = nsmth_above_sfc + 1

          rs_data(ista)%w_intp_smth(nsmth_above_sfc,1)   = w_intptmp(irp,1)
          rs_data(ista)%w_intp_smth(nsmth_above_sfc,2)   = w_intptmp(irp,2)
          rs_data(ista)%w_intp_smth(nsmth_above_sfc,3)   = w_intptmp(irp,3)
          rs_data(ista)%ind_intp_smth(nsmth_above_sfc,1) = &
               ind_intptmp(irp,2)+(ind_intptmp(irp,3)-1)*ie+(ind_intptmp(irp,4)-1)*ie*je
          rs_data(ista)%ind_intp_smth(nsmth_above_sfc,2) = ind_intptmp(irp,1)
          rs_data(ista)%hl_loc(nsmth_above_sfc)          = alt_rtmp(irp)

          CALL ind2sub5D( ind_intptmp(irp,1), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                          rs_meta(ista)%nel, rs_meta(ista)%ngpsm_v, &
                          m, n, o, iv, ih )

          el_sta = rs_meta(ista)%el_arr(o) + smth_el_horzscan(ista,iv)

          rs_data(ista)%el_loc(nsmth_above_sfc) = &
               el_loc_43 (raarr(n), el_sta, rs_meta(ista)%alt_msl)

        ENDIF

      ENDDO

      ! Then, keep track of the positions of the points below surface:
      !   (Here, later the missing value -988.88 will be set for radial wind and reflectivity)
      nsmth_below_sfc = nsmth_above_sfc
!CDIR VOVERTAKE,VOB
      DO irp = 1, nrp
      
        IF (ind_intptmp(irp,4) == -1) THEN
          nsmth_below_sfc = nsmth_below_sfc + 1
          rs_data(ista)%w_intp_smth(nsmth_below_sfc,1)   = -999.99_ireals
          rs_data(ista)%w_intp_smth(nsmth_below_sfc,2)   = -999.99_ireals
          rs_data(ista)%w_intp_smth(nsmth_below_sfc,3)   = -999.99_ireals
          rs_data(ista)%ind_intp_smth(nsmth_below_sfc,1) = -999_iintegers
          rs_data(ista)%ind_intp_smth(nsmth_below_sfc,2) = ind_intptmp(irp,1)
          rs_data(ista)%hl_loc(nsmth_below_sfc)          = alt_rtmp(irp)          
          rs_data(ista)%el_loc(nsmth_below_sfc) = 988.88_ireals
        END IF

      END DO

      ! deallocate auxiliary fields
      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(raarr)
      DEALLOCATE(azarr)
      DEALLOCATE(alt_rtmp)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_smth

  !=======================================================================================
  !+ Module procedure in src_radar for the computation of the geometry for auxiliary grids
  !---------------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_grid

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the geometry for auxiliary grids and the interpolation weights
    !              and interpolation indices for the interpolation of the model
    !              data to the auxiliary grids. These interpolation
    !              weights and the interpolation indices are constant in time since 
    !              the radar geometry is also constant in time and this subroutine
    !              is only called in the first call of the operator. 
    !              A halo region of nbl_az at the azimutal field margins is 
    !              taken into account (important for lsmooth=.true.).
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,ngrdmax,ngrd,i,j,k,m,n,o,offset_i,offset_j,iaz,ial,io,jo
    REAL    (KIND = ireals)          :: az               ,& ! azimuth 
                                        al               ,& ! arc length
                                        wi               ,& ! interpolation weight in azimth direction
                                        wj               ,& ! interpolation weight in arc length direction
                                        wk               ,& ! interpolation weight in vertical direction
                                        rlon_min         ,& ! min rotated longitude in local subdomain
                                        rlon_max         ,& ! max rotated longitude in local subdomain
                                        rlat_min         ,& ! min rotated latitude in local subdomain
                                        rlat_max         ,& ! max rotated latitude in local subdomain
                                        rlon_g           ,& ! rotated longitude for a auxiliary grid
                                        rlat_g           ,& ! rotated latitude for a auxiliary grid
                                        rlon_g0          ,& ! rotated longtitude of radar station
                                        rlat_g0          ,& ! rotated latitude of radare station
                                        hfl11,hfl21,hfl12,hfl22

    REAL    (KIND = ireals)          :: hfl(ie,je,ke)                         

    REAL    (KIND = ireals),            ALLOCATABLE    :: &
                                        azarr(:)         ,& ! array of azimuths
                                        alarr(:)         ,& ! array of arc length
                                        lat_g(:,:)       ,& ! array of geographical latitudes for each auxiliary grid (az,al)
                                        lon_g(:,:)       ,& ! array of geographical longitudes for each auxiliary grid (az,al)
                                        hl(:)            ,& ! array of geographical heights for each auxiliary grid  
                                        w_intp(:,:)         ! array of interpolation weights for each auxiliary grid 

    INTEGER (KIND = iintegers),         ALLOCATABLE     ::&
                                        ind_intp(:,:)       ! array of indices for each auxiliary grid (first dimension)
                                                            ! the second dimension contains of 
                                                            ! 1:     the continuous number of the model grid cell associated with the observation
                                                            ! 2:     the grid indices in azimuthal, arc length and vertical direction (m,n,k)
   
    !- End of header


    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_grid
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_grid'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! allocate and initialize local aux arrays
      ngrdmax = (rs_grid(ista)%nal+1) * (rs_grid(ista)%naz_nbl) *  ke 

      ALLOCATE(w_intp(ngrdmax,2))
      ALLOCATE(ind_intp(ngrdmax,2))
      ALLOCATE(lat_g(rs_grid(ista)%naz_nbl,rs_grid(ista)%nal+1))
      ALLOCATE(lon_g(rs_grid(ista)%naz_nbl,rs_grid(ista)%nal+1))

!CDIR BEGIN COLLAPSE
      w_intp   = -1.0_ireals
      ind_intp = -1_iintegers
      lat_g    = 0.0_ireals
      lon_g    = 0.0_ireals
!CDIR END

      ! fill up azimuth array
      ALLOCATE(azarr(rs_grid(ista)%naz_nbl))
      DO iaz = 1,rs_grid(ista)%naz_nbl
        azarr(iaz) = (iaz-nbl_az-1) * rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        ! Folding into the range [0, 360] degrees:
        azarr(iaz) = MODULO(azarr(iaz),360.0_ireals)
      END DO

      ! fill up arc length array
      ALLOCATE(alarr(rs_grid(ista)%nal+1))
      DO ial = 1,rs_grid(ista)%nal+1
        alarr(ial) = (ial-1)*rs_grid(ista)%al_inc
      END DO

      ! calculate geographical coordinates (lat,lon) of grid points
      call grd2geo(rs_meta(ista)%lat,       &
           rs_meta(ista)%lon,       &
           rs_grid(ista)%naz_nbl,   &
           rs_grid(ista)%nal+1,     &
           azarr,                   &
           alarr,                   &
           lat_g,lon_g)


      ! calculate min and max of rotated lat and lon of subdomain
      ! use whole domain, i.e. inclusive boundary zone at the border 
      ! of the total domain
      offset_i = nboundlines
      offset_j = nboundlines

      ! rotated longitude of western boundary
      rlon_min = startlon_tot + (isubpos(my_cart_id,1)-1)*dlon


      ! rotated longitude of eastern boundary
      rlon_max = startlon_tot + (isubpos(my_cart_id,3)-1)*dlon

      ! rotated latitude of southern boundary
      rlat_min = startlat_tot + (isubpos(my_cart_id,2)-1)*dlat


      ! rotated latitude of northern boundary
      rlat_max = startlat_tot + (isubpos(my_cart_id,4)-1)*dlat


      ! loop over all grid points
      ngrd = 0     

      ALLOCATE(hl(ngrdmax))
!CDIR COLLAPSE
      hl = -999.99_ireals

      DO n = 1, rs_grid(ista)%nal+1      ! loop over arc length
        DO m = 1, rs_grid(ista)%naz_nbl  ! loop over azimuths

          ! calculate rotated longitude and latitude of radar point
          rlon_g = rla2rlarot(lat_g(m,n),lon_g(m,n),pollat,pollon,polgam)
          rlat_g = phi2phirot(lat_g(m,n),lon_g(m,n),pollat,pollon)

          ! cycle if radar point is not in local subdomain
          IF ((rlat_g >= rlat_min-0.5*dlat) .AND. &
               (rlat_g <= rlat_max+0.5*dlat) .AND. &
               (rlon_g >= rlon_min-0.5*dlon) .AND. &
               (rlon_g <= rlon_max+0.5*dlon)) THEN

            ! calculate indices of model point southwest of auxiliary grid point
!!$ UB>> corrected:
            i = MAX(1 + FLOOR((rlon_g - rlon_min)/dlon,iintegers) + offset_i, 1_iintegers)
            j = MAX(1 + FLOOR((rlat_g - rlat_min)/dlat,iintegers) + offset_j, 1_iintegers)
!!$ UB<<
            
            io = MIN(i+1,ie)
            jo = MIN(j+1,je)

            ! compute interpolation weights in az and al direction
            wi = (rlon_g-(rlon_min + (i-offset_i-1)*dlon))/dlon
            wi = MIN(MAX(wi,0.0_ireals),1.0_ireals)
            wj = (rlat_g-(rlat_min + (j-offset_j-1)*dlat))/dlat
            wj = MIN(MAX(wj,0.0_ireals),1.0_ireals)

            DO k = ke,1,-1         ! loop over heights

      !      hfl(:,:,k) = 0.5*(hhl(:,:,k) + hhl(:,:,k+1))

              hfl11 = 0.5*(hhl(i,j,k)   + hhl(i,j,k+1))
              hfl21 = 0.5*(hhl(io,j,k)  + hhl(io,j,k+1))
              hfl12 = 0.5*(hhl(i,jo,k)  + hhl(i,jo,k+1))
              hfl22 = 0.5*(hhl(io,jo,k) + hhl(io,jo,k+1))
              
              ngrd = ngrd + 1
              
              hl(ngrd) = (hfl11*(1.0_ireals-wi) + hfl21*wi)*(1.0_ireals - wj) + &
                   (hfl12*(1.0_ireals-wi) + hfl22*wi)*wj
              
              ! store weights and indices of auxiliary grid point
              w_intp(ngrd,1) = wi
              w_intp(ngrd,2) = wj
              
              ind_intp(ngrd,1) = i + (j-1)*ie + (k-1)*ie*je
              ind_intp(ngrd,2) = m + (n-1)*rs_grid(ista)%naz_nbl + &
                   (k-1)*rs_grid(ista)%naz_nbl*(rs_grid(ista)%nal+1)
              
            END DO

          END IF

        END DO
      END DO


      rs_grid(ista)%ngrd     = ngrd

      WRITE(*,*)"radar station",ista
      WRITE(*,*)"ngrd,ngrdmax",ngrd,ngrdmax

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_grid(ista)%w_intp))   DEALLOCATE (rs_grid(ista)%w_intp)
      IF (ASSOCIATED(rs_grid(ista)%ind_intp)) DEALLOCATE (rs_grid(ista)%ind_intp)
      IF (ASSOCIATED(rs_grid(ista)%hl_grd))   DEALLOCATE (rs_grid(ista)%hl_grd)

      ALLOCATE(rs_grid(ista)%w_intp(ngrd,2))
      ALLOCATE(rs_grid(ista)%ind_intp(ngrd,2))
      ALLOCATE(rs_grid(ista)%hl_grd(ngrd))

      IF (ngrd > 0) THEN

        ! copy values from auxiliary variables
        rs_grid(ista)%w_intp   = w_intp(1:ngrd,:)
        rs_grid(ista)%ind_intp = ind_intp(1:ngrd,:)
        rs_grid(ista)%hl_grd   = hl(1:ngrd)

      END IF
      
      WRITE(*,*)"ngrd", rs_grid(ista)%ngrd 
      WRITE(*,*)"max w_intp",MAXVAL(rs_grid(ista)%w_intp)
      WRITE(*,*)"min w_intp",MinVAL(rs_grid(ista)%w_intp)
      WRITE(*,*)"max ind_intp",maxval(rs_grid(ista)%ind_intp)
      WRITE(*,*)"min ind_intp",MinVAL(rs_grid(ista)%ind_intp)
      WRITE(*,*)"max hl_grd",maxval(rs_grid(ista)%hl_grd)
      WRITE(*,*)"min hl_grd",MinVAL(rs_grid(ista)%hl_grd)

      ! deallocate auxiliary fields
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(hl)
      DEALLOCATE(azarr)
      DEALLOCATE(alarr)
      DEALLOCATE(lat_g)
      DEALLOCATE(lon_g)   

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_grid


  ! ZY >> Dynamical Version for Subroutine calc_geometry added
  !==============================================================================
  !+ Module procedure in src_radar for the computation of radar beam geometry
  !------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_online(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar beam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the 
    !              model data to the radar points.This routine will be called every time 
    !              when the operator is called.
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,igrd,nae,nobsmax,nobs,m,n,k,&
                                        ira,iae,iel,irp,nrp,nrp2,naz,mmax,mmin,ko,no,flag1
    INTEGER (KIND = iintegers)       :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)          :: el_sta,d1,d2,elsign,  &
         rfridx11, rfridx21, rfridx12, rfridx22,              &
         wl,wk


    REAL    (KIND = ireals), ALLOCATABLE    ::         &
         hl_azgrd(:,:,:)     ,&
         rfridx_azgrd(:,:,:) ,&
         hl(:,:)             ,&
         al(:,:)             ,&
         el(:,:)             ,&
         el_loc(:)           ,&
         rfridx(:,:)         ,&
         w_intp(:,:)         ,& ! array of horizontal interpolation weights for each observation (first dimension) and each spatial direction i,j,k (second dimension) 
         w_intptmp(:,:)      ,& ! array of horizontal interpolation weights for each temporary radar point
         w_intptmp2(:,:)     ,& 
         hl_tmp(:)           ,&
         hl_tmp2(:)          ,&
         hl_loc(:)         


    INTEGER (KIND = iintegers), ALLOCATABLE ::         &
         flag(:,:)           ,&
         azarr(:)            ,& 
         ind_intptmp(:,:)    ,&
         ind_intptmp2(:,:)   ,&
         ind_intp(:,:)  ! array of grid indices for each observation (first dimension)
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2: the observation indices in azimuthal, radial and elevation direction (irp)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_online
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_online'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    IF (nbl_az /= 0) THEN
      CALL model_abort (my_world_id, 20574, &
           'ERROR: problem in ' //TRIM(yzroutine)// &
           ': nbl_az > 0, which is not applicable here!', &
           'src_radar.f90, '//TRIM(yzroutine))
    END IF  

    ! loop over radar stations
    DO ista = 1,nradsta

      IF (.NOT.lcalc(ista)) CYCLE

      ! HERE NBL_AZ=0, SINCE NO HORIZONTAL INTERPOLATION WITHIN THE AZIMUT-SLICE-DATA!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      naz     = iend(my_cart_id) - istart(my_cart_id) + 1

      ! fill up azimuth array
      ALLOCATE(azarr(naz))
      DO iaz = 1,naz
        azarr(iaz) = istart(my_cart_id) + (iaz-1_iintegers)
      END DO

      ! allocate and initialize local aux arrays

      nobsmax = rs_meta(ista)%nra * naz * rs_meta(ista)%nel
      nae     = naz * rs_meta(ista)%nel

      ALLOCATE(hl_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(rfridx_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(hl(nae,rs_meta(ista)%nra))
      ALLOCATE(al(nae,rs_meta(ista)%nra))
      ALLOCATE(el(nae,rs_meta(ista)%nra))
      ALLOCATE(rfridx(nae,rs_meta(ista)%nra))
      ALLOCATE(w_intp(nobsmax,2))
      ALLOCATE(ind_intp(nobsmax,2))
      ALLOCATE(hl_loc(nobsmax))
      ALLOCATE(el_loc(nobsmax))
      ALLOCATE(flag(nae,0:rs_meta(ista)%nra))

!CDIR BEGIN COLLAPSE
      hl_azgrd = -999.99_ireals
      rfridx_azgrd = -999.99_ireals
      hl       = -999.99_ireals
      al       = 0.0_ireals
      el       = -99.0_ireals
      el_loc   = -99.0_ireals
      rfridx   = -999.99_ireals
      w_intp   = -1.0_ireals
      ind_intp = -1_iintegers
      flag(:,0)= 1_iintegers
      flag(:,1:rs_meta(ista)%nra) = 0_iintegers
!CDIR END

      nobs = 0_iintegers

!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1
        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        hl_azgrd(m,n,k) = rs_grid(ista)%hl_azgrd(igrd)

        rfridx_azgrd(m,n,k) = rs_grid(ista)%rfridx_azgrd(igrd)

      ENDDO

      WRITE(*,*) "max hl_azgrd(m,n,k)",MAXVAL(hl_azgrd)

      WRITE(*,*) "min hl_azgrd(m,n,k)",MINVAL(hl_azgrd)
      WRITE(*,*) "max rfridx_azgrd(m,n,k)",MAXVAL(rfridx_azgrd)
      WRITE(*,*) "min rfridx_azgrd(m,n,k)",MINVAL(rfridx_azgrd)

!!$ UB>> pulled outside the ira-loop to save time:
      ALLOCATE(w_intptmp(nae,2))
      ALLOCATE(ind_intptmp(nae,4))
      ALLOCATE(w_intptmp2(nae,2))
      ALLOCATE(ind_intptmp2(nae,4))
      ALLOCATE(hl_tmp(nae))
      ALLOCATE(hl_tmp2(nae))
!!$ UB<<

      DO ira = 1, rs_meta(ista)%nra

!CDIR BEGIN COLLAPSE
        w_intptmp = -1.0_ireals
        ind_intptmp = -1_iintegers
        w_intptmp2 = -1.0_ireals
        ind_intptmp2 = -1_iintegers
        hl_tmp = -999.99_ireals
        hl_tmp2 = -999.99_ireals
        nrp = 0_iintegers
        nrp2= 0_iintegers
!CDIR END

        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers) THEN

            IF (ira == 1) THEN
              
              el_sta = rs_meta(ista)%el_arr(INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1)  
              
              hl(iae,ira) = SQRT((r_earth +rs_meta(ista)%alt_msl)**2 + rs_meta(ista)%ra_inc**2 - &
                   2*rs_meta(ista)%ra_inc*(r_earth +rs_meta(ista)%alt_msl) * COS(el_sta*degrad + 0.5*pi)) - &
                   (r_earth) 
              
              d1 = SIN(el_sta*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))
              
              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)
              
              al(iae,ira) = r_earth*ASIN(d1)
              
              
            ELSE
              
              hl(iae,ira) = SQRT((r_earth + hl(iae,ira-1))**2 +  rs_meta(ista)%ra_inc**2 - &
                   2*rs_meta(ista)%ra_inc*(r_earth + hl(iae,ira-1)) * COS(el(iae,ira-1)*degrad + 0.5*pi)) - &
                   (r_earth)
              
              d1 = SIN(el(iae,ira-1)*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))
              
              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)
              
              al(iae,ira) = al(iae,ira-1) + r_earth*ASIN(d1)   
              
              
            ENDIF
            
          ENDIF   ! flag(iae,ira-1) > 0

        ENDDO ! Loop over nae

        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers .AND. &
               FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 <= rs_grid(ista)%nal) THEN

            nrp = nrp + 1
            
            iaz = MOD(iae-1,naz) + 1
            
            iel = INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1
            
            ind_intptmp(nrp,1) = azarr(iaz) + (ira - 1)*rs_meta(ista)%naz + &
                 (iel - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra ! save indices for az, el, ra
            
            ind_intptmp(nrp,2) = iaz      ! save local indices of az
            
            ind_intptmp(nrp,3) = FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 ! save indices of al
            
            w_intptmp(nrp,1) =  al(iae,ira)/rs_grid(ista)%al_inc - FLOOR(al(iae,ira)/rs_grid(ista)%al_inc)
            
            hl_tmp(nrp) =  hl(iae,ira)
            
          ENDIF
            
        ENDDO

        WRITE(*,*)"max  hl_tmp",maxval(hl_tmp)
        WRITE(*,*)"min  hl_tmp",minval(hl_tmp)
        WRITE(*,*)"max  hl_azgrd 2 ",maxval(hl_azgrd)
        WRITE(*,*)"min  hl_azgrd 2 ",minval(hl_azgrd)
     
        CALL calc_vert_weight_online(nrp,hl_tmp(1:nrp), &
             hl_azgrd,                                  &  ! hl_azgrd(istart_az:iend_az,:,:)
             azarr, naz,                       &  ! index of iaz in the aux. grid
             istart(my_cart_id), iend(my_cart_id),      &
             rs_grid(ista)%nal + 1,                     &
             ke,                                        &
             ind_intptmp(1:nrp,2),                      &  
             ind_intptmp(1:nrp,3),                      &
             w_intptmp(1:nrp,1),                        &
             ind_intptmp(1:nrp,4),                      &   
             w_intptmp(1:nrp,2))

        WRITE(*,*)"the value of nrp is ",nrp

        ! This Loop needed for a better vecorization of the next loop
        DO irp = 1, nrp

          IF (ind_intptmp(irp,4) > 0) THEN

            nrp2 = nrp2 + 1

            ind_intptmp2(nrp2,1) = ind_intptmp(irp,1)
            ind_intptmp2(nrp2,2) = ind_intptmp(irp,2) 
            ind_intptmp2(nrp2,3) = ind_intptmp(irp,3)
            ind_intptmp2(nrp2,4) = ind_intptmp(irp,4)

            w_intptmp2(nrp2,1)   = w_intptmp(irp,1)
            w_intptmp2(nrp2,2)   = w_intptmp(irp,2)

            hl_tmp2(nrp2)        = hl_tmp(irp) 

          ENDIF

        ENDDO

        WRITE(*,*) "nrp2 = ",nrp2

        DO irp = 1, nrp2

          nobs = nobs + 1

          w_intp(nobs,1) = w_intptmp2(irp,1)

          w_intp(nobs,2) = w_intptmp2(irp,2)

          ! save postion of arounding grid points: iaz,ial,ihl
          ind_intp(nobs,1) = azarr(ind_intptmp2(irp,2)) + (ind_intptmp2(irp,3)-1)*rs_meta(ista)%naz + &
               (ind_intptmp2(irp,4)-1)*(rs_meta(ista)%naz)*(rs_grid(ista)%nal+1)
          ! save position of radar point: iaz,ira,iel
          ind_intp(nobs,2) =  ind_intptmp2(irp,1)

          hl_loc(nobs) = hl_tmp2(irp)

          m = azarr(ind_intptmp2(irp,2))
          n = ind_intptmp2(irp,3)
          no= MIN(n+1,rs_grid(ista)%nal+1) 
          k = ind_intptmp2(irp,4)
          ko= MIN(k+1,ke)

          iaz = ind_intptmp2(irp,2)
          iel = INT(REAL(ind_intp(nobs,2)-1,ireals) / &
                (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          iae = iaz + (iel - 1)*naz

          flag(iae,ira) = 1_iintegers

          rfridx11 = rfridx_azgrd(m,n,k)
          rfridx21 = rfridx_azgrd(m,no,k)
          rfridx12 = rfridx_azgrd(m,n,ko)
          rfridx22 = rfridx_azgrd(m,no,ko)

          wl = w_intp(nobs,1)
          wk = w_intp(nobs,2)


!!$ Ausfallwertbehandlung bei den 4 Nachbarn:
!!$ 1) Alle 4 sind Ausfallwerte => rfridx(iae,ira) = Ausfallwert
!!$ 2) Bei weniger Ausfallwerten: Es wird versucht,
!!$    diese durch die horizontalen Nachbarn zu ersetzen bzw. bei
!!$    2 Ausfaellen in einer Schicht diese ganz herauszuschmeissen.
!!$
          IF (rfridx11 < -900.0_ireals .AND. rfridx21 >= -900.0_ireals) THEN
            rfridx11 = rfridx21
          ELSEIF (rfridx11 >= -900.0_ireals .AND. rfridx21 < -900.0_ireals) THEN
            rfridx21 = rfridx11
          ELSEif (rfridx11 < -900.0_ireals .AND. rfridx21 < -900.0_ireals) then
            wk = 1.0
          ELSE
            CONTINUE
          ENDIF


          IF (rfridx12 < -900.0_ireals .AND. rfridx22 >= -900.0_ireals) THEN
            rfridx12 = rfridx22
          ELSEIF (rfridx12 >= -900.0_ireals .AND. rfridx22 < -900.0_ireals) THEN
            rfridx22 = rfridx12
          ELSEIF (rfridx12 < -900.0_ireals .AND. rfridx22 < -900.0_ireals) THEN
            wk = 0.0
          ELSE
            CONTINUE
          ENDIF

          rfridx(iae,ira) = (rfridx11*(1.0_ireals-wl)+rfridx21*wl)*(1.0_ireals - wk) + (rfridx12*(1.0_ireals-wl)+rfridx22*wl)*wk

          IF (ira == 1) THEN

            el_sta = rs_meta(ista)%el_arr(INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1)

            elsign = SIGN(1.0_ireals,el_sta)

            d2 = (r_earth + rs_meta(ista)%alt_msl)/ &
                 (r_earth + hl(iae,ira))*rs_grid(ista)%rfridx_sta/rfridx(iae,ira)*COS(el_sta*degrad)

            IF(d2 > 1.0 .AND. rfridx(iae,ira) < rs_grid(ista)%rfridx_sta) THEN
              flag1 = 1
            ELSE 
              flag1 = 0
            ENDIF

            ! .. -el_sta = Approximate solution, only correct in the limit (rearth+h) -> oo
            el(iae,ira) = flag1    * (-el_sta) + &
                          (1-flag1)* elsign*ACOS(MIN(MAX(d2,-1.0_ireals),1.0_ireals))/degrad

          ELSE 

            elsign = SIGN(1.0_ireals,el(iae,ira-1))

            d2 = (r_earth + hl(iae,ira-1))/ &
                 (r_earth + hl(iae,ira))*rfridx(iae,ira-1)/rfridx(iae,ira)*COS(el(iae,ira-1)*degrad)

            IF(d2 > 1.0  .AND. rfridx(iae,ira) <  rfridx(iae,ira-1)) THEN
              flag1 = 1
            ELSE 
              flag1 = 0
            ENDIF
            
            ! .. -el() = Approximate solution, only correct in the limit (rearth+h) -> oo
            el(iae,ira) = flag1    * (-el(iae,ira-1)) + &
                          (1-flag1)* elsign*ACOS(MIN(MAX(d2,-1.0_ireals),1.0_ireals))/degrad

          ENDIF

!!$ UB>> reformulated into the above IF-clause for vectorization:
!!$          IF(d2 > 1.0 .AND. ira == 1) THEN
!!$
!!$            el(iae,ira) = -el_sta
!!$
!!$          ELSEIF (d2 > 1.0 .AND. ira > 1) THEN
!!$
!!$            el(iae,ira) =  -el(iae,ira-1)
!!$
!!$          ELSE 
!!$
!!$            d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)
!!$
!!$            el(iae,ira) = elsign*ACOS(d2)/degrad
!!$
!!$          ENDIF

          el_loc(nobs) =  el(iae,ira)

        ENDDO ! loop over nrp2

      ENDDO ! loop over nra

!!$ UB>> pulled outside ira-loop:
      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(hl_tmp)
      DEALLOCATE(w_intptmp2)
      DEALLOCATE(ind_intptmp2)
      DEALLOCATE(hl_tmp2)
!!$ UB<<

      rs_data(ista)%nobs     = nobs

      WRITE(*,*)"nobs = ",nobs
      WRITE(*,*)"max hl",MAXVAL(hl)
      WRITE(*,*)"min hl",MINVAL(hl)
      WRITE(*,*)"max el",MAXVAL(el)
      WRITE(*,*)"min el",MINVAL(el)

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp))   DEALLOCATE (rs_data(ista)%w_intp)
      IF (ASSOCIATED(rs_data(ista)%ind_intp)) DEALLOCATE (rs_data(ista)%ind_intp)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))   DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))   DEALLOCATE (rs_data(ista)%el_loc)

      ALLOCATE(rs_data(ista)%w_intp(nobs,2))
      ALLOCATE(rs_data(ista)%ind_intp(nobs,2))
      ALLOCATE(rs_data(ista)%hl_loc(nobs))
      ALLOCATE(rs_data(ista)%el_loc(nobs))

      IF (nobs > 0) THEN 

        ! copy values from auxiliary variables
        rs_data(ista)%w_intp   = w_intp(1:nobs,:)
        rs_data(ista)%ind_intp = ind_intp(1:nobs,:)
        rs_data(ista)%hl_loc   = hl_loc(1:nobs)
        rs_data(ista)%el_loc   = el_loc(1:nobs)

      END IF

      ! deallocate auxiliary fields
      DEALLOCATE(hl_azgrd)
      DEALLOCATE(rfridx_azgrd)
      DEALLOCATE(hl)
      DEALLOCATE(al)
      DEALLOCATE(el)
      DEALLOCATE(rfridx)
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(hl_loc)
      DEALLOCATE(el_loc)
      DEALLOCATE(flag)
      DEALLOCATE(azarr)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_online
  ! ZY << Vectorized Version for Subroutine calc_geometry added

  SUBROUTINE calc_geometry_onlinenew(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar beam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the 
    !              model data to the radar points.This routine will be called every time 
    !              when the operator is called.
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,igrd,nstep,nae,nobsmax,nobs,m,n,k,&
         ira,iae,iel,irp,nrp,nrp2,naz,mmax,mmin,ko,no,flag1
    INTEGER (KIND = iintegers)       :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)          :: el_sta,d1,d2,elsign,  &
         rfridx11, rfridx21, rfridx12, rfridx22,              &
         wl,wk


    REAL    (KIND = ireals), ALLOCATABLE    ::         &
         hl_azgrd(:,:,:)     ,&
         rfridx_azgrd(:,:,:) ,&
         hl(:,:)             ,&
         al(:,:)             ,&
         el(:,:)             ,&
         dhdr(:,:)           ,&
         el_loc(:)           ,&
         rfridx(:,:)         ,&
         w_intp(:,:)         ,& ! array of horizontal interpolation weights for each observation (first dimension) and each spatial direction i,j,k (second dimension) 
         w_intptmp(:,:)      ,& ! array of horizontal interpolation weights for each temporary radar point
         w_intptmp2(:,:)     ,& 
         hl_tmp(:)           ,&
         hl_tmp2(:)          ,&
         hl_loc(:)           ,&
         alt_stavec(:)       ,&
         dhdr_stavec(:)      ,&       
         rfridx_stavec(:)    

    INTEGER (KIND = iintegers), ALLOCATABLE ::         &
         flag(:,:)           ,&
         azarr(:)            ,& 
         ind_intptmp(:,:)    ,&
         ind_intptmp2(:,:)   ,&
         ind_intp(:,:)  ! array of grid indices for each observation (first dimension)
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2: the observation indices in azimuthal, radial and elevation direction (irp)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_onlinenew
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_onlinenew'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    IF (nbl_az /= 0) THEN
      CALL model_abort (my_world_id, 20574, &
           'ERROR: problem in ' //TRIM(yzroutine)// &
           ': nbl_az > 0, which is not applicable here!', &
           'src_radar.f90, '//TRIM(yzroutine))
    END IF

    ! loop over radar stations
    DO ista = 1,nradsta

      IF (.NOT.lcalc(ista)) CYCLE

      ! HERE NBL_AZ=0, SINCE NO HORIZONTAL INTERPOLATION WITHIN THE AZIMUT-SLICE-DATA!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      naz     = iend(my_cart_id) - istart(my_cart_id) + 1

      ! fill up azimuth array
      ALLOCATE(azarr(naz))
      DO iaz = 1,naz
        azarr(iaz) = istart(my_cart_id) + (iaz-1_iintegers)
      END DO

      ! allocate and initialize local aux arrays

      nobsmax = rs_meta(ista)%nra * naz * rs_meta(ista)%nel
      nae     = naz * rs_meta(ista)%nel
      nstep = 1_iintegers

      ALLOCATE(hl_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(rfridx_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(hl(nae,rs_meta(ista)%nra))
      ALLOCATE(al(nae,rs_meta(ista)%nra))
      ALLOCATE(el(nae,rs_meta(ista)%nra))
      ALLOCATE(dhdr(nae,rs_meta(ista)%nra))
      ALLOCATE(rfridx(nae,rs_meta(ista)%nra))
      ALLOCATE(w_intp(nobsmax,2))
      ALLOCATE(ind_intp(nobsmax,2))
      ALLOCATE(hl_loc(nobsmax))
      ALLOCATE(el_loc(nobsmax))
      ALLOCATE(flag(nae,0:rs_meta(ista)%nra))
      ALLOCATE(alt_stavec(nae))
      ALLOCATE(dhdr_stavec(nae))
      ALLOCATE(rfridx_stavec(nae))

!CDIR BEGIN COLLAPSE
      hl_azgrd     = -999.99_ireals
      rfridx_azgrd = -999.99_ireals
      hl           = -999.99_ireals
      al           = 0.0_ireals
      el           = -999.99_ireals
      dhdr         = -999.99_ireals
      el_loc       = -999.99_ireals
      rfridx       = -999.99_ireals
      !rfridx_loc   = -999.99_ireals
      !      rfridxgrad   = -999.99_ireals
      w_intp       = -1.0_ireals
      ind_intp     = -1_iintegers
      flag(:,0)    = 1_iintegers
      flag(:,1:rs_meta(ista)%nra) = 0_iintegers
!CDIR END

      alt_stavec        = rs_meta(ista)%alt_msl

      DO iae = 1, nae
        iel = INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1
        dhdr_stavec(iae) =  SIN(rs_meta(ista)%el_arr(iel)*degrad)
      ENDDO

      rfridx_stavec     = rs_grid(ista)%rfridx_sta

      WRITE(*,*)"radar station is",ista
      WRITE(*,*)"rfridx_stavec is",rfridx_stavec

      !      rfridxgrad_stavec = rs_grid(ista)%rfridxgrad_sta

      nobs = 0_iintegers

!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1

        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        hl_azgrd(m,n,k) = rs_grid(ista)%hl_azgrd(igrd)

        rfridx_azgrd(m,n,k) = rs_grid(ista)%rfridx_azgrd(igrd)

      ENDDO

      WRITE(*,*) "size(rs_grid(ista)%ind_azgrd",ista,SIZE(rs_grid(ista)%ind_azgrd)
      WRITE(*,*) "max hl_azgrd(m,n,k)",MAXVAL(hl_azgrd)
      WRITE(*,*) "min hl_azgrd(m,n,k)",MINVAL(hl_azgrd)
      WRITE(*,*) "max rfridx_azgrd(m,n,k)",MAXVAL(rfridx_azgrd)
      WRITE(*,*) "min rfridx_azgrd(m,n,k)",MINVAL(rfridx_azgrd)

!!$ UB>> pulled outside the ira-loop to save time:
      ALLOCATE(w_intptmp(nae,2))
      ALLOCATE(ind_intptmp(nae,4)) 
      ALLOCATE(w_intptmp2(nae,2))
      ALLOCATE(ind_intptmp2(nae,4))
      ALLOCATE(hl_tmp(nae))
      ALLOCATE(hl_tmp2(nae))
!!$ UB<<

      DO ira = 1, rs_meta(ista)%nra

!CDIR BEGIN COLLAPSE
        w_intptmp = -1.0_ireals
        ind_intptmp = -1_iintegers
        w_intptmp2 = -1.0_ireals
        ind_intptmp2 = -1_iintegers
        hl_tmp = -999.99_ireals
        hl_tmp2 = -999.99_ireals
        nrp = 0_iintegers
        nrp2= 0_iintegers
!CDIR END        

        IF (ira == 1) THEN

          CALL calc_height_rk4(nstep,nae,rs_meta(ista)%nra,alt_stavec,dhdr_stavec,rfridx_stavec, &
               rs_meta(ista)%ra_inc,flag(:,0),hl(:,ira),dhdr(:,ira))

        ELSE

          CALL calc_height_rk4(nstep,nae,rs_meta(ista)%nra,hl(:,ira-1),dhdr(:,ira-1),rfridx(:,ira-1),&
               rs_meta(ista)%ra_inc,flag(:,ira-1),hl(:,ira),dhdr(:,ira))

        ENDIF

        ! calc_height_rk4(nst,nae,nra,hl1,dhdr1,rfridx,rfridxgrad,ra_inc,flag,hl2,dhdr2)
        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers) THEN

            IF (ira == 1) THEN

              el_sta = rs_meta(ista)%el_arr(INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1)  

!!$              hl(iae,ira) = SQRT((r_earth +rs_meta(ista)%alt_msl)**2 + rs_meta(ista)%ra_inc**2 - &
!!$                   2*rs_meta(ista)%ra_inc*(r_earth +rs_meta(ista)%alt_msl) * COS(el_sta*degrad + 0.5*pi)) - &
!!$                   (r_earth) 

              el(iae,ira) = ASIN(dhdr(iae,ira))/degrad

              d1 = SIN(el_sta*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))

              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)

              al(iae,ira) = r_earth*ASIN(d1)


            ELSE

!!$              hl(iae,ira) = SQRT((r_earth + hl(iae,ira-1))**2 +  rs_meta(ista)%ra_inc**2 - &
!!$                   2*rs_meta(ista)%ra_inc*(r_earth + hl(iae,ira-1)) * COS(el(iae,ira-1)*degrad + 0.5*pi)) - &
!!$                   (r_earth)

              el(iae,ira-1) = ASIN(dhdr(iae,ira-1))/degrad

              el(iae,ira) = ASIN(dhdr(iae,ira))/degrad

              d1 = SIN(el(iae,ira-1)*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))

              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)

              al(iae,ira) = al(iae,ira-1) + r_earth*ASIN(d1)   


            ENDIF

          ENDIF   ! flag(iae,ira-1) > 0

        ENDDO ! Loop over nae

        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers .AND. &
               FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 <= rs_grid(ista)%nal) THEN

            nrp = nrp + 1

            iaz = MOD(iae-1,naz) + 1

            iel = INT(REAL(iae-1,ireals)/REAL(naz,ireals),iintegers) + 1

            ind_intptmp(nrp,1) = azarr(iaz) + (ira - 1)*rs_meta(ista)%naz + &
                 (iel - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra ! save indices for az, el, ra

            ind_intptmp(nrp,2) = iaz      ! save local indices of az

            ind_intptmp(nrp,3) = FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 ! save indices of al

            w_intptmp(nrp,1) =  al(iae,ira)/rs_grid(ista)%al_inc - FLOOR(al(iae,ira)/rs_grid(ista)%al_inc)

            hl_tmp(nrp) =  hl(iae,ira)

          ENDIF

        ENDDO

        IF (nrp > 0) THEN

          CALL calc_vert_weight_online(nrp,hl_tmp(1:nrp), &
               hl_azgrd,                                  &  ! hl_azgrd(istart_az:iend_az,:,:)
               azarr, naz,                       &  ! index of iaz in the aux. grid
               istart(my_cart_id), iend(my_cart_id),      &
               rs_grid(ista)%nal + 1,                     &
               ke,                                        &
               ind_intptmp(1:nrp,2),                      &  
               ind_intptmp(1:nrp,3),                      &
               w_intptmp(1:nrp,1),                        &
               ind_intptmp(1:nrp,4),                      &   
               w_intptmp(1:nrp,2))

          ! This Loop needed for a better vecorization of the next loop
          DO irp = 1, nrp

            IF (ind_intptmp(irp,4) > 0) THEN

              nrp2 = nrp2 + 1

              ind_intptmp2(nrp2,1) = ind_intptmp(irp,1)
              ind_intptmp2(nrp2,2) = ind_intptmp(irp,2) 
              ind_intptmp2(nrp2,3) = ind_intptmp(irp,3)
              ind_intptmp2(nrp2,4) = ind_intptmp(irp,4)

              w_intptmp2(nrp2,1)   = w_intptmp(irp,1)
              w_intptmp2(nrp2,2)   = w_intptmp(irp,2)

              hl_tmp2(nrp2)        = hl_tmp(irp) 

            ENDIF

          ENDDO


          WRITE(*,*) "nrp2 = ",nrp2

          IF (nrp2 > 0) THEN

            DO irp = 1, nrp2

              iaz = ind_intptmp2(irp,2)
              iel = INT(REAL(ind_intptmp2(irp,1)-1,ireals) / &
                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
              iae = iaz + (iel - 1)*naz

              IF (flag(iae,ira-1) == 0_iintegers) CYCLE

              flag(iae,ira) = 1_iintegers

              nobs = nobs + 1

              w_intp(nobs,1) = w_intptmp2(irp,1)

              w_intp(nobs,2) = w_intptmp2(irp,2)

              ! save postion of arounding grid points: iaz,ial,ihl
              ind_intp(nobs,1) = azarr(ind_intptmp2(irp,2)) + (ind_intptmp2(irp,3)-1)*rs_meta(ista)%naz + &
                   (ind_intptmp2(irp,4)-1)*(rs_meta(ista)%naz)*(rs_grid(ista)%nal+1)
              ! save position of radar point: iaz,ira,iel
              ind_intp(nobs,2) =  ind_intptmp2(irp,1)

              hl_loc(nobs) = hl_tmp2(irp)

              m = azarr(ind_intptmp2(irp,2))
              n = ind_intptmp2(irp,3)
              no= MIN(n+1,rs_grid(ista)%nal+1) 
              k = ind_intptmp2(irp,4)
              ko= MIN(k+1,ke)

!!$              iaz = ind_intptmp2(irp,2)
!!$              iel = INT(REAL(ind_intp(nobs,2)-1,ireals) / &
!!$                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
!!$              iae = iaz + (iel - 1)*naz
!!$
!!$              flag(iae,ira) = 1_iintegers

              rfridx11 = rfridx_azgrd(m,n,k)
              rfridx21 = rfridx_azgrd(m,no,k)
              rfridx12 = rfridx_azgrd(m,n,ko)
              rfridx22 = rfridx_azgrd(m,no,ko)

              wl = w_intp(nobs,1)
              wk = w_intp(nobs,2)


!!$ Ausfallwertbehandlung bei den 4 Nachbarn:
!!$ 1) Alle 4 sind Ausfallwerte => rfridx(iae,ira) = Ausfallwert
!!$ 2) Bei weniger Ausfallwerten: Es wird versucht,
!!$    diese durch die horizontalen Nachbarn zu ersetzen bzw. bei
!!$    2 Ausfaellen in einer Schicht diese ganz herauszuschmeissen.
!!$
              IF (rfridx11 < -900.0_ireals .AND. rfridx21 >= -900.0_ireals) THEN
                rfridx11 = rfridx21
              ELSEIF (rfridx11 >= -900.0_ireals .AND. rfridx21 < -900.0_ireals) THEN
                rfridx21 = rfridx11
              ELSEif (rfridx11 < -900.0_ireals .AND. rfridx21 < -900.0_ireals) then
                wk = 1.0
              ELSE
                CONTINUE
              ENDIF


              IF (rfridx12 < -900.0_ireals .AND. rfridx22 >= -900.0_ireals) THEN
                rfridx12 = rfridx22
              ELSEIF (rfridx12 >= -900.0_ireals .AND. rfridx22 < -900.0_ireals) THEN
                rfridx22 = rfridx12
              ELSEif (rfridx12 < -900.0_ireals .AND. rfridx22 < -900.0_ireals) then
                wk = 0.0
              ELSE
                CONTINUE
              ENDIF

              rfridx(iae,ira) = (rfridx11*(1.0_ireals-wl)+rfridx21*wl)*(1.0_ireals - wk) + (rfridx12*(1.0_ireals-wl)+rfridx22*wl)*wk

              el_loc(nobs) = el(iae,ira)

              ! rfridx_loc(nobs) = rfridx(iae,ira)

            ENDDO ! loop over nrp2

          ENDIF

        ENDIF

      ENDDO ! loop over nra

!!$ UB>> pulled outside ira-loop:
      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(hl_tmp)
      DEALLOCATE(w_intptmp2)
      DEALLOCATE(ind_intptmp2)
      DEALLOCATE(hl_tmp2)
!!$ UB<<

      !write(my_cart_id+700,'(A5,A6,3(A10,"(",A3")"),A5,A7,4A12,3A4,7A12,A10)') 'ista','nobs','az','m','ra','n','el','o','PE','alt_r','lon_r','lat_r','rlon_r','rlat_r','i','j','k','rlon_min','rlon(i,j)','rlat_min','rlat(i,j)','wi','wj','wk','nk'
      rs_data(ista)%nobs     = nobs

      WRITE(*,*)"nobs = ",nobs
      WRITE(*,*)"max hl",MAXVAL(hl)
      WRITE(*,*)"min hl",MINVAL(hl)
      WRITE(*,*)"max el",MAXVAL(el)
      WRITE(*,*)"min el",MINVAL(el)
      WRITE(*,*)"min rfridx",MINVAL(rfridx)

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp))   DEALLOCATE (rs_data(ista)%w_intp)
      IF (ASSOCIATED(rs_data(ista)%ind_intp)) DEALLOCATE (rs_data(ista)%ind_intp)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))   DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))   DEALLOCATE (rs_data(ista)%el_loc)

      ALLOCATE(rs_data(ista)%w_intp(nobs,2))
      ALLOCATE(rs_data(ista)%ind_intp(nobs,2))
      ALLOCATE(rs_data(ista)%hl_loc(nobs))
      ALLOCATE(rs_data(ista)%el_loc(nobs))

      IF ( nobs > 0 ) THEN

        ! copy values from auxiliary variables
        rs_data(ista)%w_intp   = w_intp(1:nobs,:)
        rs_data(ista)%ind_intp = ind_intp(1:nobs,:)
        rs_data(ista)%hl_loc   = hl_loc(1:nobs)
        rs_data(ista)%el_loc   = el_loc(1:nobs)

      END IF

      ! deallocate auxiliary fields
      DEALLOCATE(hl_azgrd)
      DEALLOCATE(rfridx_azgrd)
      DEALLOCATE(hl)
      DEALLOCATE(al)
      DEALLOCATE(el)
      DEALLOCATE(dhdr)
      DEALLOCATE(rfridx)
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(hl_loc)
      DEALLOCATE(el_loc)
      DEALLOCATE(flag)
      DEALLOCATE(azarr)
      DEALLOCATE(alt_stavec)
      DEALLOCATE(dhdr_stavec)
      DEALLOCATE (rfridx_stavec)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_onlinenew
  ! ZY << Vectorized Version for Subroutine calc_geometry added

  ! ZY >> Dynamical Version for Subroutine calc_geometry_smth added
  !=======================================================================================
  !+ Module procedure in src_radar for the computation of radar main- and subbeam geometry
  !---------------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_onsmth (lcalc,time_mod)

    !------------------------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar main- and subbeam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the auxiliary grids to the 
    !              smoothing points.This routine will be called every time when the operator is called
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !-------------------------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !-------------------------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,igrd,nae,nobsmax,nsmth,m,n,k,ira,iae,iel, &
                                        irp,nrp,nrp2,naz,mmax,mmin,mo,ko,no,iv,ih,flag1
    INTEGER (KIND = iintegers)       :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)          :: azstart,azend,el_sta,d1,d2,elsign,  &
         rfridx111,rfridx211,rfridx121,rfridx221,rfridx112,rfridx212,rfridx122,rfridx222, &
         wa,wl,wk


    REAL    (KIND = ireals), ALLOCATABLE :: &
         hl_azgrd(:,:,:)     ,&
         rfridx_azgrd(:,:,:) ,&
         hl(:,:)             ,&
         al(:,:)             ,&
         el(:,:)             ,&
         el_loc(:)           ,&
         rfridx(:,:)         ,&
         w_intp(:,:)         ,& ! array of horizontal interpolation weights for each observation (first dimension) and each spatial direction i,j,k (second dimension) 
         w_intptmp(:,:)      ,& ! array of horizontal interpolation weights for each temporary radar point
         w_intptmp2(:,:)     ,& 
         hl_tmp(:)           ,&
         hl_tmp2(:)          ,&
         hl_loc(:)           ,&
         azimuth_vec(:)      

    INTEGER (KIND = iintegers), ALLOCATABLE ::&
         flag(:,:)          ,&
         azarr_idx(:)       ,& 
         ind_intptmp(:,:)   ,&
         ind_intptmp2(:,:)  ,&
         ind_intp(:,:)  ! array of grid indices for each observation (first dimension)
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2: the observation indices in azimuthal, radial and elevation direction (irp)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_onsmth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_onsmth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      IF (.NOT.lcalc(ista)) CYCLE

      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      naz       = iend(my_cart_id) - istart(my_cart_id) + 1 - 2*nbl_az

      ! fill up azimuth array
      ALLOCATE(azarr_idx(naz))
      DO iaz = 1,naz
        azarr_idx(iaz) = istart(my_cart_id) + (iaz-1_iintegers)
      END DO

      ! allocate and initialize local aux arrays
      nobsmax = rs_meta(ista)%nra * naz * rs_meta(ista)%nel * rs_meta(ista)%ngpsm_v * rs_meta(ista)%ngpsm_h
      nae     = naz * rs_meta(ista)%nel * rs_meta(ista)%ngpsm_v * rs_meta(ista)%ngpsm_h 

!!$ UB>> Von "vollem" Azimut auf "Quasi-" Index (real) umgestellt, deswegen umformuliert:
      azstart = azarr_idx(1)   - nbl_az   ! die "+- nbl_az" sollen die Zwischenbereiche zwischen den PEs abdecken
      azend   = azarr_idx(naz) + nbl_az

      ALLOCATE(hl_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(rfridx_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(hl(nae,rs_meta(ista)%nra))
      ALLOCATE(al(nae,rs_meta(ista)%nra))
      ALLOCATE(el(nae,rs_meta(ista)%nra))
      ALLOCATE(rfridx(nae,rs_meta(ista)%nra))
      ALLOCATE(w_intp(nobsmax,3))
      ALLOCATE(ind_intp(nobsmax,2))
      ALLOCATE(hl_loc(nobsmax))
      ALLOCATE(el_loc(nobsmax))
      ALLOCATE(flag(nae,0:rs_meta(ista)%nra)) ! sofar is ALLOCATE(flag(nae,0:rs_meta(ista)%nra-1)), which is wrong. This mistake costs at least two weeks.  

      hl_azgrd = -999.99_ireals
      rfridx_azgrd = -999.99_ireals
      hl       = -999.99_ireals
      al       = 0.0_ireals
      el       = -99.0_ireals
      el_loc   = -99.0_ireals
      rfridx   = -999.99_ireals
      w_intp   = -1.0_ireals
      ind_intp = -1_iintegers
      flag(:,0)= 1_iintegers
      flag(:,1:rs_meta(ista)%nra) = 0_iintegers ! see above

      ! .. Helper vector for the azimuth in degrees:
      ALLOCATE(azimuth_vec(nae))
      DO iae = 1, nae

        iaz = MOD(iae-1,naz) + 1
        
        ih  = INT(REAL(iae-1,ireals)/ &
             (REAL(naz,ireals)*REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1
        
        ! elevation of the beam center at the radar station:
        el_sta = rs_meta(ista)%el_arr( MOD(INT(REAL(iae-1,ireals)/&
             REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1)

!!$ inlined code from smth_az_horzscan(ista,ih,el_sta):
!!$        phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
!!$             ( COS(el_sta*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
!!$             ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )
!!$
!!$        smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_h(ih)
!!$
!!$        azimuth_vec(iae)   = azarr_idx(iaz) + smthpoint / rs_meta(ista)%az_inc
           
        
        ! azimut of the smoothing point, depending on el_sta:
        azimuth_vec(iae)   = azarr_idx(iaz) + smth_az_horzscan(ista,ih,el_sta) / rs_meta(ista)%az_inc
        
      END DO

      nsmth = 0_iintegers

      DO igrd = 1, SIZE(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1
        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        hl_azgrd(m,n,k) = rs_grid(ista)%hl_azgrd(igrd)

        rfridx_azgrd(m,n,k) = rs_grid(ista)%rfridx_azgrd(igrd)

      ENDDO


      WRITE(*,*) "max hl_azgrd(m,n,k)",maxval(hl_azgrd)

      WRITE(*,*) "min hl_azgrd(m,n,k)",minval(hl_azgrd)
      WRITE(*,*) "max rfridx_azgrd(m,n,k)",maxval(rfridx_azgrd)
      WRITE(*,*) "min rfridx_azgrd(m,n,k)",minVAL(rfridx_azgrd)

      ALLOCATE(w_intptmp(nae,3))
      ALLOCATE(ind_intptmp(nae,4))
      ALLOCATE(w_intptmp2(nae,3))
      ALLOCATE(ind_intptmp2(nae,4))
      ALLOCATE(hl_tmp(nae))
      ALLOCATE(hl_tmp2(nae))

      DO ira = 1, rs_meta(ista)%nra

!!$ UB>> more efficient to move the allocation outside the loop:
!!$        ALLOCATE(w_intptmp(nae,3))
!!$        ALLOCATE(ind_intptmp(nae,4))
!!$        ALLOCATE(w_intptmp2(nae,3))
!!$        ALLOCATE(ind_intptmp2(nae,4))
!!$        ALLOCATE(hl_tmp(nae))
!!$        ALLOCATE(hl_tmp2(nae))

        w_intptmp = -1.0_ireals
        ind_intptmp = -1_iintegers
        w_intptmp2 = -1.0_ireals
        ind_intptmp2 = -1_iintegers
        hl_tmp = -999.99_ireals
        hl_tmp2 = -999.99_ireals
        nrp = 0_iintegers
        nrp2= 0_iintegers

        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers) THEN

            IF (ira == 1) THEN
              
              iv  = MOD(INT(REAL(iae-1,ireals)/ &
                   (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

!!$ inlined code from smth_el_horzscan(ista,iv):
!!$              theta3_eff = rs_meta(ista)%Theta3
!!$
!!$              smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_v(iv)
!!$
!!$              el_sta = rs_meta(ista)%el_arr( MOD(INT(REAL(iae-1,ireals)/&
!!$                     REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1) + &  
!!$                     smthpoint
              
              el_sta = rs_meta(ista)%el_arr( MOD(INT(REAL(iae-1,ireals)/&
                     REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1) + &  
                     smth_el_horzscan(ista,iv)
              
              hl(iae,ira) = SQRT((r_earth +rs_meta(ista)%alt_msl)**2 + rs_meta(ista)%ra_inc**2                     - &
                   2*rs_meta(ista)%ra_inc*(r_earth +rs_meta(ista)%alt_msl) * COS(el_sta*degrad + 0.5*pi)) - &
                   (r_earth) 
              
              d1 = SIN(el_sta*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))
              
              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)
              
              al(iae,ira) = (r_earth)*ASIN(d1)
              
              
            ELSE
              
              hl(iae,ira) = SQRT((r_earth + hl(iae,ira-1))**2 +  rs_meta(ista)%ra_inc**2       - &
                   2*rs_meta(ista)%ra_inc*(r_earth+hl(iae,ira-1))*COS(el(iae,ira-1)*degrad + 0.5*pi)) - &
                   (r_earth)

              d1 = SIN(el(iae,ira-1)*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))
              
              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)
              
              al(iae,ira) = al(iae,ira-1) + (r_earth)*ASIN(d1)   
              
            ENDIF

          ENDIF    ! flag(iae,ira-1) > 0

        ENDDO ! Loop over nae

        DO iae = 1, nae

          IF ( flag(iae,ira-1) > 0_iintegers .AND. &
               FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 <= rs_grid(ista)%nal .AND. &
               azstart <= azimuth_vec(iae) .AND. azimuth_vec(iae) <= azend ) THEN
            
            nrp = nrp + 1
            
            iaz = MOD(iae-1,naz) + 1
        
            iel = MOD(INT(REAL(iae-1,ireals)/ &
                 REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1
            
            ih  = INT(REAL(iae-1,ireals)/ &
                 (REAL(naz,ireals)*REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

            iv  = MOD(INT(REAL(iae-1,ireals)/ &
                 (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1
            
            ! Azimut index without nbl_az:
            ind_intptmp(nrp,1) = azarr_idx(iaz) + (ira - 1)*rs_meta(ista)%naz + &
                 (iel - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra + &
                 (iv - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra*rs_meta(ista)%nel +                 &
                 (ih - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra*rs_meta(ista)%nel*rs_meta(ista)%ngpsm_v
            
            ind_intptmp(nrp,2) = FLOOR(azimuth_vec(iae)) + nbl_az    ! save index of az of the left neighbouring 
            ! azimut slice in the auxiliary grid, including nbl_az
            
            ind_intptmp(nrp,3) = FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 ! save indices of al
            
            w_intptmp(nrp,1) = azimuth_vec(iae) - FLOOR(azimuth_vec(iae))
            
            w_intptmp(nrp,2) = al(iae,ira)/rs_grid(ista)%al_inc - FLOOR(al(iae,ira)/rs_grid(ista)%al_inc)
            
            hl_tmp(nrp) =  hl(iae,ira)
            
          ENDIF

        ENDDO

        WRITE(*,*)"max  hl_tmp",maxval(hl_tmp)
        WRITE(*,*)"min  hl_tmp",minval(hl_tmp)

        IF (nrp > 0) THEN

          CALL calc_vert_weight_onsmth(nrp,hl_tmp(1:nrp), &
               hl_azgrd,                                  &
               istart(my_cart_id),                        &
               iend(my_cart_id),                          &
               rs_grid(ista)%nal+1,                       &      
               ke,                                        &
               ind_intptmp(1:nrp,2),                      &  
               ind_intptmp(1:nrp,3),                      &
               w_intptmp(1:nrp,1),                        &
               w_intptmp(1:nrp,2),                        &
               ind_intptmp(1:nrp,4),                      &   
               w_intptmp(1:nrp,3))


          WRITE(*,*)"the value of nrp ist",nrp

          ! This Loop needed for a better vecorization of the next loop
          DO irp = 1, nrp

            IF (ind_intptmp(irp,4) > 0) THEN

              nrp2 = nrp2 + 1

              ind_intptmp2(nrp2,1) = ind_intptmp(irp,1)
              ind_intptmp2(nrp2,2) = ind_intptmp(irp,2) 
              ind_intptmp2(nrp2,3) = ind_intptmp(irp,3)
              ind_intptmp2(nrp2,4) = ind_intptmp(irp,4)

              w_intptmp2(nrp2,1)   = w_intptmp(irp,1)
              w_intptmp2(nrp2,2)   = w_intptmp(irp,2)
              w_intptmp2(nrp2,3)   = w_intptmp(irp,3)

              hl_tmp2(nrp2)        = hl_tmp(irp) 

            ENDIF

          ENDDO

          WRITE(*,*) "nrp2",nrp2

          IF (nrp2 > 0) THEN

            DO irp = 1, nrp2

              nsmth = nsmth + 1

              w_intp(nsmth,1) = w_intptmp2(irp,1)

              w_intp(nsmth,2) = w_intptmp2(irp,2)

              w_intp(nsmth,3) = w_intptmp2(irp,3)

              ! save postion of arounding grid points: iaz,ial,ihl
              ind_intp(nsmth,1) = ind_intptmp2(irp,2) + (ind_intptmp2(irp,3)-1)*rs_grid(ista)%naz_nbl + &
                   (ind_intptmp2(irp,4)-1)*(rs_grid(ista)%naz_nbl)*(rs_grid(ista)%nal+1)
              ! save position of radar point: iaz,ira,iel
              ind_intp(nsmth,2) =  ind_intptmp2(irp,1)

              hl_loc(nsmth) = hl_tmp2(irp)

              ! determine indices for interpolation in az, al, hl direction for current radar point
              ! (Indices relative to azimute-slice-grid, i.e., shifted by nbl_az)
              m = ind_intptmp2(irp,2)
              mo= MIN(m+1,iend(my_cart_id))
              n = ind_intptmp2(irp,3)
              no= MIN(n+1,rs_grid(ista)%nal+1) 
              k = ind_intptmp2(irp,4)
              ko= MIN(k+1,ke)

              iaz = MOD(MOD(ind_intp(nsmth,2)-1,rs_meta(ista)%naz)+1-1,naz) + 1   

              iel = MOD(INT(REAL(ind_intp(nsmth,2)-1,ireals) / &
                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers),rs_meta(ista)%nel) + 1

              iv  = MOD(INT(REAL(ind_intp(nsmth,2)-1,ireals)/ &
                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
                   REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

              ih  = INT(REAL(ind_intp(nsmth,2)-1,ireals)/(REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
                   REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

              iae = iaz + (iel-1)*naz + (iv-1)*naz*rs_meta(ista)%nel + (ih-1)*naz*rs_meta(ista)%nel*rs_meta(ista)%ngpsm_v

              flag(iae,ira) = 1_iintegers

              ! iae = MOD(ind_intp(nsmth,1)-1,rs_meta(ista)%naz*rs_meta(ista)%nel) + 1  ! campared with line 2694
              rfridx111 = rfridx_azgrd(m,n,k)
              rfridx211 = rfridx_azgrd(mo,n,k)
              rfridx121 = rfridx_azgrd(m,no,k)
              rfridx221 = rfridx_azgrd(mo,no,k)
              rfridx112 = rfridx_azgrd(m,n,ko)
              rfridx212 = rfridx_azgrd(mo,n,ko)
              rfridx122 = rfridx_azgrd(m,no,ko)
              rfridx222 = rfridx_azgrd(mo,no,ko)

              wa = w_intp(nsmth,1)
              wl = w_intp(nsmth,2)
              wk = w_intp(nsmth,3)

              IF (rfridx111 < -900.0_ireals .AND. rfridx211 >= -900.0_ireals) THEN
                rfridx111 = rfridx211
              ELSEIF (rfridx111 >= -900.0_ireals .AND. rfridx211 < -900.0_ireals) THEN
                rfridx211 = rfridx111
              ELSEIF (rfridx111 < -900.0_ireals .AND. rfridx211 < -900.0_ireals) THEN
                wl = 1.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx121 < -900.0_ireals .AND. rfridx221 >= -900.0_ireals) THEN
                rfridx121 = rfridx221
              ELSEIF (rfridx121 >= -900.0_ireals .AND. rfridx221 < -900.0_ireals) THEN
                rfridx221 = rfridx121
              ELSEIF (rfridx121 < -900.0_ireals .AND. rfridx221 < -900.0_ireals) THEN
                wl = 0.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx112 < -900.0_ireals .AND. rfridx212 >= -900.0_ireals) THEN
                rfridx112 = rfridx212
              ELSEIF (rfridx112 >= -900.0_ireals .AND. rfridx212 < -900.0_ireals) THEN
                rfridx212 = rfridx112
              ELSEIF (rfridx112 < -900.0_ireals .AND. rfridx212 < -900.0_ireals) THEN
                wl = 1.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx122 < -900.0_ireals .AND. rfridx222 >= -900.0_ireals) THEN
                rfridx122 = rfridx222
              ELSEIF (rfridx122 >= -900.0_ireals .AND. rfridx222 < -900.0_ireals) THEN
                rfridx222 = rfridx122
              ELSEIF (rfridx122 < -900.0_ireals .AND. rfridx222 < -900.0_ireals) THEN
                wl = 0.0
              ELSE
                CONTINUE
              ENDIF

              rfridx(iae,ira) = ((rfridx111*(1.0_ireals-wa)+rfridx211*wa)*(1.0_ireals - wl)   + &
                   (rfridx121*(1.0_ireals-wa)+rfridx221*wa)*wl)*(1.0_ireals-wk) + &
                   ((rfridx112*(1.0_ireals-wa)+rfridx212*wa)*(1.0_ireals - wl)   + &
                   (rfridx122*(1.0_ireals-wa)+rfridx222*wa)*wl)*wk

              IF (ira == 1) THEN

!!$ inlined code from smth_el_horzscan:
!!$                theta3_eff = rs_meta(ista)%Theta3
!!$
!!$                smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                     rs_meta(ista)%xabscsm_v(iv)
!!$
!!$                el_sta = rs_meta(ista)%el_arr(iel) + smthpoint
                
                el_sta = rs_meta(ista)%el_arr(iel) + smth_el_horzscan(ista,iv)

                elsign = SIGN(1.0_ireals,el_sta)

                d2 = (r_earth + rs_meta(ista)%alt_msl)/ &
                     (r_earth + hl(iae,ira))*rs_grid(ista)%rfridx_sta/rfridx(iae,ira)*COS(el_sta*degrad)

                IF(d2 > 1.0 .AND. rfridx(iae,ira) < rs_grid(ista)%rfridx_sta) THEN
                  flag1 = 1
                ELSE 
                  flag1 = 0
                ENDIF

                ! .. -el_sta = Approximate solution, only correct in the limit (rearth+h) -> oo
                el(iae,ira) = flag1    * (-el_sta) + &
                              (1-flag1)* elsign*ACOS(MIN(MAX(d2,-1.0_ireals),1.0_ireals))/degrad

              ELSE ! ira > 1

                elsign = SIGN(1.0_ireals,el(iae,ira-1))

                d2 = (r_earth + hl(iae,ira-1))/ &
                     (r_earth + hl(iae,ira))*rfridx(iae,ira-1)/rfridx(iae,ira)*COS(el(iae,ira-1)*degrad)

                IF(d2 > 1.0 .AND. rfridx(iae,ira) < rfridx(iae,ira-1)) THEN
                  flag1 = 1
                ELSE 
                  flag1 = 0
                ENDIF

                  ! .. -el() = Approximate solution, only correct in the limit (rearth+h) -> oo
                el(iae,ira) = flag1    * (-el(iae,ira-1)) + &
                              (1-flag1)* elsign*ACOS(MIN(MAX(d2,-1.0_ireals),1.0_ireals))/degrad

              ENDIF

!!$ UB>> reformulated into the above IF-clause for vectorization:
!!$              IF(d2 > 1.0 .AND. ira == 1) THEN
!!$
!!$                el(iae,ira) = -el_sta
!!$                
!!$              ELSEIF (d2 > 1.0 .AND. ira > 1) THEN
!!$                
!!$                el(iae,ira) =  -el(iae,ira-1)
!!$                
!!$              ELSE 
!!$                
!!$                d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)
!!$                
!!$                el(iae,ira) = elsign*ACOS(d2)/degrad
!!$                
!!$              ENDIF
              
              
              el_loc(nsmth) =  el(iae,ira)
              
            ENDDO ! loop over nrp2

          END IF  ! if nrp2 > 0

        END IF  ! if nrp > 0


!!$        DEALLOCATE(w_intptmp)
!!$        DEALLOCATE(ind_intptmp)
!!$        DEALLOCATE(hl_tmp)
!!$        DEALLOCATE(w_intptmp2)
!!$        DEALLOCATE(ind_intptmp2)
!!$        DEALLOCATE(hl_tmp2)

      ENDDO ! loop over nra

      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(hl_tmp)
      DEALLOCATE(w_intptmp2)
      DEALLOCATE(ind_intptmp2)
      DEALLOCATE(hl_tmp2)


      rs_data(ista)%nsmth     = nsmth

      WRITE(*,*)"nsmth",nsmth
      WRITE(*,*)"max hl",MAXVAL(hl)
      WRITE(*,*)"min hl",MINVAL(hl)
      WRITE(*,*)"max el",MAXVAL(el)
      WRITE(*,*)"min el",MINVAL(el)

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp_smth))   DEALLOCATE (rs_data(ista)%w_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%ind_intp_smth)) DEALLOCATE (rs_data(ista)%ind_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))        DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))        DEALLOCATE (rs_data(ista)%el_loc)

      ALLOCATE(rs_data(ista)%w_intp_smth(nsmth,3))
      ALLOCATE(rs_data(ista)%ind_intp_smth(nsmth,2))
      ALLOCATE(rs_data(ista)%hl_loc(nsmth))
      ALLOCATE(rs_data(ista)%el_loc(nsmth))

      IF (nsmth > 0) THEN 

        ! copy values from auxiliary variables
        rs_data(ista)%w_intp_smth   = w_intp(1:nsmth,:)
        rs_data(ista)%ind_intp_smth = ind_intp(1:nsmth,:)
        rs_data(ista)%hl_loc        = hl_loc(1:nsmth)
        rs_data(ista)%el_loc        = el_loc(1:nsmth)

      END IF

      ! deallocate auxiliary fields
      DEALLOCATE(hl_azgrd)
      DEALLOCATE(rfridx_azgrd)
      DEALLOCATE(hl)
      DEALLOCATE(al)
      DEALLOCATE(el)
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(hl_loc)
      DEALLOCATE(el_loc)
      DEALLOCATE(flag)
      DEALLOCATE(rfridx)
      DEALLOCATE(azarr_idx)
      DEALLOCATE(azimuth_vec)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_onsmth
  ! ZY << Dynamical Version for Subroutine calc_geometry_smth added

  
  ! ZY >> Dynamical Version for Subroutine calc_geometry_smth added
  !=======================================================================================
  !+ Module procedure in src_radar for the computation of radar main- and subbeam geometry
  !---------------------------------------------------------------------------------------

  SUBROUTINE calc_geometry_onsmthnew (lcalc,time_mod)

    !------------------------------------------------------------------------------------------------
    !
    ! Description: Calculates the radar main- and subbeam geometry and the interpolation weights
    !              and interpolation indices for the interpolation of the auxiliary grids to the 
    !              smoothing points.This routine will be called every time when the operator is called
    !              
    ! Method:
    !
    ! Input files:
    !
    ! Output files:
    !
    !-------------------------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !-------------------------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,iaz,igrd,nstep,nae,nobsmax,nsmth,m,n,k,ira,iae,iel, &
         irp,nrp,nrp2,naz,mmax,mmin,mo,ko,no,iv,ih,flag1
    INTEGER (KIND = iintegers)       :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)          :: azstart,azend,el_sta,d1,d2,elsign,  &
         rfridx111,rfridx211,rfridx121,rfridx221,rfridx112,rfridx212,rfridx122,rfridx222, &
         wa,wl,wk


    REAL    (KIND = ireals), ALLOCATABLE :: &
         hl_azgrd(:,:,:)     ,&
         rfridx_azgrd(:,:,:) ,&
         hl(:,:)             ,&
         al(:,:)             ,&
         el(:,:)             ,&
         dhdr(:,:)           ,&
         el_loc(:)           ,&
         rfridx(:,:)         ,&
                                !rfridx_loc(:)         ,&
                                !         rfridxgrad(:,:)     ,&
         w_intp(:,:)         ,& ! array of horizontal interpolation weights for each observation (first dimension) and each spatial direction i,j,k (second dimension) 
         w_intptmp(:,:)      ,& ! array of horizontal interpolation weights for each temporary radar point
         w_intptmp2(:,:)     ,& 
         hl_tmp(:)           ,&
         hl_tmp2(:)          ,&
         hl_loc(:)           ,&
         alt_stavec(:)       ,&
         dhdr_stavec(:)      ,&
         rfridx_stavec(:)    ,&
                                !         rfridxgrad_stavec(:),&
         azimuth_vec(:)                  


    INTEGER (KIND = iintegers), ALLOCATABLE ::&
         flag(:,:)          ,&
         azarr_idx(:)       ,& 
         ind_intptmp(:,:)   ,&
         ind_intptmp2(:,:)  ,&
         ind_intp(:,:)  ! array of grid indices for each observation (first dimension)
    ! the second dimension contains of 
    ! 1:     the continuous number of the model grid cell associated with the observation
    ! 2: the observation indices in azimuthal, radial and elevation direction (irp)
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_geometry_onsmthnew
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_geometry_onsmthnew'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

!!$    IF (nbl_az /= 0) THEN
!!$      CALL model_abort (my_world_id, 20574, &
!!$           'ERROR: problem in ' //TRIM(yzroutine)// &
!!$           ': nbl_az > 0, which is not applicable here!', &
!!$           'src_radar.f90, '//TRIM(yzroutine))
!!$    END IF

    ! loop over radar stations
    DO ista = 1,nradsta

      IF (.NOT.lcalc(ista)) CYCLE

      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      naz       = iend(my_cart_id) - istart(my_cart_id) + 1 - 2*nbl_az

      ! fill up azimuth array
      ALLOCATE(azarr_idx(naz))
      DO iaz = 1,naz
        azarr_idx(iaz) = istart(my_cart_id) + (iaz-1_iintegers)
      END DO

      ! allocate and initialize local aux arrays
      nobsmax = rs_meta(ista)%nra * naz * rs_meta(ista)%nel * rs_meta(ista)%ngpsm_v * rs_meta(ista)%ngpsm_h
      nae     = naz * rs_meta(ista)%nel * rs_meta(ista)%ngpsm_v * rs_meta(ista)%ngpsm_h 
      nstep   = 1_iintegers

!!$ UB>> Von "vollem" Azimut auf "Quasi-" Index (real) umgestellt, deswegen umformuliert:
      azstart = azarr_idx(1)   - nbl_az   ! die "+- nbl_az" sollen die Zwischenbereiche zwischen den PEs abdecken
      azend   = azarr_idx(naz) + nbl_az

      ALLOCATE(hl_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(rfridx_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(hl(nae,rs_meta(ista)%nra))
      ALLOCATE(al(nae,rs_meta(ista)%nra))
      ALLOCATE(el(nae,rs_meta(ista)%nra))
      ALLOCATE(dhdr(nae,rs_meta(ista)%nra))
      ALLOCATE(rfridx(nae,rs_meta(ista)%nra))
      ALLOCATE(w_intp(nobsmax,3))
      ALLOCATE(ind_intp(nobsmax,2))
      ALLOCATE(hl_loc(nobsmax))
      ALLOCATE(el_loc(nobsmax))
      ALLOCATE(flag(nae,0:rs_meta(ista)%nra))
      ALLOCATE(alt_stavec(nae)) 
      ALLOCATE(dhdr_stavec(nae))
      ALLOCATE(rfridx_stavec(nae))

      hl_azgrd = -999.99_ireals
      rfridx_azgrd = -999.99_ireals
      hl       = -999.99_ireals
      al       = 0.0_ireals
      el       = -999.99_ireals
      dhdr     = -999.99_ireals
      el_loc   = -999.99_ireals
      rfridx   = -999.99_ireals
      !rfridx_loc = -999.99_ireals
      !      rfridxgrad = -999.99_ireals
      w_intp   = -1.0_ireals
      ind_intp = -1_iintegers
      flag(:,0)= 1_iintegers
      flag(:,1:rs_meta(ista)%nra) = 0_iintegers ! see above

      alt_stavec        = rs_meta(ista)%alt_msl

      ! .. Helper vector for the azimuth in degrees:
      ALLOCATE(azimuth_vec(nae))
      DO iae = 1, nae

        iaz = MOD(iae-1,naz) + 1

        iel = MOD(INT(REAL(iae-1,ireals)/&
             REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1

        iv  = MOD(INT(REAL(iae-1,ireals)/ &
             (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

        ih  = INT(REAL(iae-1,ireals)/ &
             (REAL(naz,ireals)*REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

!!$ code inlined from smth_el_horzscan:
!!$        theta3_eff = rs_meta(ista)%Theta3
!!$
!!$        smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$             rs_meta(ista)%xabscsm_v(iv)
!!$
!!$        el_sta = rs_meta(ista)%el_arr(iel) + smthpoint

        ! elevation of the beam center at the radar station:
        el_sta = rs_meta(ista)%el_arr(iel)+ smth_el_horzscan(ista,iv)

        dhdr_stavec(iae) = SIN(el_sta*degrad) 

        el_sta = rs_meta(ista)%el_arr(iel)

!!$ code inlined from smth_az_horzscan;
!!$        phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
!!$             ( COS(el_sta*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
!!$             ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )
!!$
!!$        smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
!!$             rs_meta(ista)%xabscsm_h(ih)
!!$
!!$        azimuth_vec(iae)   = azarr_idx(iaz) + smthpoint / rs_meta(ista)%az_inc

        ! azimut of the smoothing point, depending on el_sta:
        azimuth_vec(iae)   = azarr_idx(iaz) + smth_az_horzscan(ista,ih,el_sta) / rs_meta(ista)%az_inc

      END DO

!!$      DO iae = 1, nae
!!$ 
!!$        iv  = MOD(INT(REAL(iae-1,ireals)/ &
!!$             (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1
!!$
!!$        iel = MOD(INT(REAL(iae-1,ireals)/&
!!$              REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1
!!$        dhdr_stavec(iae) =  SIN((rs_meta(ista)%el_arr(iel)+ smth_el_horzscan(ista,iv))*degrad)
!!$      
!!$      ENDDO
!!$

      rfridx_stavec     = rs_grid(ista)%rfridx_sta

      nsmth = 0_iintegers

      DO igrd = 1, SIZE(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1

        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        hl_azgrd(m,n,k) = rs_grid(ista)%hl_azgrd(igrd)

        rfridx_azgrd(m,n,k) = rs_grid(ista)%rfridx_azgrd(igrd)

      ENDDO


      WRITE(*,*) "max hl_azgrd(m,n,k)",maxval(hl_azgrd)
      WRITE(*,*) "min hl_azgrd(m,n,k)",minval(hl_azgrd)
      WRITE(*,*) "max rfridx_azgrd(m,n,k)",maxval(rfridx_azgrd)
      WRITE(*,*) "min rfridx_azgrd(m,n,k)",minVAL(rfridx_azgrd)


      ALLOCATE(w_intptmp(nae,3))
      ALLOCATE(ind_intptmp(nae,4))
      ALLOCATE(w_intptmp2(nae,3))
      ALLOCATE(ind_intptmp2(nae,4))
      ALLOCATE(hl_tmp(nae))
      ALLOCATE(hl_tmp2(nae))

      DO ira = 1, rs_meta(ista)%nra

!!$ UB>> more efficient to move the allocation outside the loop:
!!$        ALLOCATE(w_intptmp(nae,3))
!!$        ALLOCATE(ind_intptmp(nae,4))
!!$        ALLOCATE(w_intptmp2(nae,3))
!!$        ALLOCATE(ind_intptmp2(nae,4))
!!$        ALLOCATE(hl_tmp(nae))
!!$        ALLOCATE(hl_tmp2(nae))

        w_intptmp = -1.0_ireals
        ind_intptmp = -1_iintegers
        w_intptmp2 = -1.0_ireals
        ind_intptmp2 = -1_iintegers
        hl_tmp = -999.99_ireals
        hl_tmp2 = -999.99_ireals
        nrp = 0_iintegers
        nrp2= 0_iintegers

        IF (ira == 1) THEN

          CALL calc_height_rk4(nstep,nae,rs_meta(ista)%nra,alt_stavec,dhdr_stavec,rfridx_stavec,&
               rs_meta(ista)%ra_inc,flag(:,0),hl(:,ira),dhdr(:,ira))

        ELSE

          CALL calc_height_rk4(nstep,nae,rs_meta(ista)%nra,hl(:,ira-1),dhdr(:,ira-1),rfridx(:,ira-1),&
               rs_meta(ista)%ra_inc,flag(:,ira-1),hl(:,ira),dhdr(:,ira))

        ENDIF

!!$        WRITE(*,*) 'flag(1,ira)',flag(1,ira-1)
!!$        WRITE (*,*) 'dhdr(1,ira)',dhdr(1,ira)


        DO iae = 1, nae

          IF (flag(iae,ira-1) > 0_iintegers) THEN

            IF (ira == 1) THEN

              iv  = MOD(INT(REAL(iae-1,ireals)/ &
                   (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

!!$ code inlined from smth_el_horzscan:
!!$              theta3_eff = rs_meta(ista)%Theta3
!!$
!!$              smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_v(iv)
!!$
!!$              el_sta = rs_meta(ista)%el_arr( MOD(INT(REAL(iae-1,ireals)/&
!!$                   REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1) + &  
!!$                   smthpoint

              el_sta = rs_meta(ista)%el_arr( MOD(INT(REAL(iae-1,ireals)/&
                     REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1) + &  
                     smth_el_horzscan(ista,iv)

              !IF (dhdr(iae,ira) > 1.0_ireals .OR. dhdr(iae,ira) < -1.0_ireals) WRITE (*,*) 'dhdr1 is wrong'

              el(iae,ira) = ASIN(dhdr(iae,ira))/degrad

              d1 = SIN(el_sta*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))

              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)

              al(iae,ira) = (r_earth)*ASIN(d1)


            ELSE

              !IF (dhdr(iae,ira) > 1.0_ireals .OR. dhdr(iae,ira) < -1.0_ireals)  WRITE (*,*) 'dhdr2 is wrong'

              !IF (dhdr(iae,ira-1) > 1.0_ireals .OR. dhdr(iae,ira-1) < -1.0_ireals) WRITE (*,*) 'dhdr3 is wrong',dhdr(iae,ira-1),iae

              el(iae,ira-1) = ASIN(dhdr(iae,ira-1))/degrad

              el(iae,ira) = ASIN(dhdr(iae,ira))/degrad

              d1 = SIN(el(iae,ira-1)*degrad + 0.5*pi) * rs_meta(ista)%ra_inc/(r_earth + hl(iae,ira))

              d1 = MIN(MAX(d1,-1.0_ireals),1.0_ireals)

              al(iae,ira) = al(iae,ira-1) + (r_earth)*ASIN(d1)   

            ENDIF

          ENDIF    ! flag(iae,ira-1) > 0

        ENDDO ! Loop over nae

        DO iae = 1, nae

          IF ( flag(iae,ira-1) > 0_iintegers .AND. &
               FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 <= rs_grid(ista)%nal .AND. &
               REAL(azstart,ireals) <= azimuth_vec(iae) .AND. azimuth_vec(iae) <= REAL(azend,ireals)) THEN

            nrp = nrp + 1

            iaz = MOD(iae-1,naz) + 1

            iel = MOD(INT(REAL(iae-1,ireals)/ &
                 REAL(naz,ireals),iintegers),rs_meta(ista)%nel) + 1

            ih  = INT(REAL(iae-1,ireals)/ &
                 (REAL(naz,ireals)*REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

            iv  = MOD(INT(REAL(iae-1,ireals)/ &
                 (REAL(naz,ireals)* REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

            ! Azimut index without nbl_az:
            ind_intptmp(nrp,1) = azarr_idx(iaz) + (ira - 1)*rs_meta(ista)%naz + &
                 (iel - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra + &
                 (iv - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra*rs_meta(ista)%nel +                 &
                 (ih - 1)*rs_meta(ista)%naz*rs_meta(ista)%nra*rs_meta(ista)%nel*rs_meta(ista)%ngpsm_v

            ind_intptmp(nrp,2) = FLOOR(azimuth_vec(iae)) + nbl_az    ! save index of az of the left neighbouring 
            ! azimut slice in the auxiliary grid, including nbl_az

            ind_intptmp(nrp,3) = FLOOR(al(iae,ira)/rs_grid(ista)%al_inc) + 1 ! save indices of al

            w_intptmp(nrp,1) = azimuth_vec(iae) - FLOOR(azimuth_vec(iae))

            w_intptmp(nrp,2) = al(iae,ira)/rs_grid(ista)%al_inc - FLOOR(al(iae,ira)/rs_grid(ista)%al_inc)

            hl_tmp(nrp) =  hl(iae,ira)

            IF (hl_tmp(nrp) < 0.0_ireals) WRITE(*,*)'hl_tmp is wrong'

          ENDIF

        ENDDO

!!$        WRITE(*,*)"ira",ira
!!$        WRITE(*,*)"max  hl_tmp",maxval(hl_tmp)
!!$        WRITE(*,*)"min  hl_tmp",minval(hl_tmp)
!!$        WRITE(*,*)"max  dhdr",MAXVAL(dhdr(:,ira))
!!$        WRITE(*,*)"min  dhdr",minval(dhdr(:,ira))
!!$        WRITE(*,*)"max  el",MAXVAL(el(:,ira))
!!$        WRITE(*,*)"min  el",MINVAL(el(:,ira))
!!$        WRITE(*,*)"max  al",MAXVAL(al(:,ira))
!!$        WRITE(*,*)"min  al",minval(al(:,ira))
!!$        WRITE(*,*)"the value of nrp ist",nrp

        IF (nrp > 0) THEN

          CALL calc_vert_weight_onsmth(nrp,hl_tmp(1:nrp), &
               hl_azgrd,                                  &
               istart(my_cart_id),                        &
               iend(my_cart_id),                          &
               rs_grid(ista)%nal+1,                       &      
               ke,                                        &
               ind_intptmp(1:nrp,2),                      &  
               ind_intptmp(1:nrp,3),                      &
               w_intptmp(1:nrp,1),                        &
               w_intptmp(1:nrp,2),                        &
               ind_intptmp(1:nrp,4),                      &   
               w_intptmp(1:nrp,3))

          ! This Loop needed for a better vecorization of the next loop
          DO irp = 1, nrp

            IF (ind_intptmp(irp,4) > 0) THEN

              nrp2 = nrp2 + 1

              ind_intptmp2(nrp2,1) = ind_intptmp(irp,1)
              ind_intptmp2(nrp2,2) = ind_intptmp(irp,2) 
              ind_intptmp2(nrp2,3) = ind_intptmp(irp,3)
              ind_intptmp2(nrp2,4) = ind_intptmp(irp,4)

              w_intptmp2(nrp2,1)   = w_intptmp(irp,1)
              w_intptmp2(nrp2,2)   = w_intptmp(irp,2)
              w_intptmp2(nrp2,3)   = w_intptmp(irp,3)

              hl_tmp2(nrp2)        = hl_tmp(irp) 

            ENDIF

          ENDDO

!!$          WRITE(*,*) "nrp2",nrp2

          IF (nrp2 > 0) THEN

            DO irp = 1, nrp2

              iaz = MOD(MOD(ind_intptmp2(irp,1)-1,rs_meta(ista)%naz)+1-1,naz) + 1   

              iel = MOD(INT(REAL(ind_intptmp2(irp,1)-1,ireals) / &
                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers),rs_meta(ista)%nel) + 1

              iv  = MOD(INT(REAL(ind_intptmp2(irp,1)-1,ireals)/ &
                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
                   REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1

              ih  = INT(REAL(ind_intptmp2(irp,1)-1,ireals)/(REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
                   REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

              iae = iaz + (iel-1)*naz + (iv-1)*naz*rs_meta(ista)%nel + (ih-1)*naz*rs_meta(ista)%nel*rs_meta(ista)%ngpsm_v

              IF (flag(iae,ira-1) == 0_iintegers) CYCLE

              flag(iae,ira) = 1_iintegers

              nsmth = nsmth + 1

              w_intp(nsmth,1) = w_intptmp2(irp,1)

              w_intp(nsmth,2) = w_intptmp2(irp,2)

              w_intp(nsmth,3) = w_intptmp2(irp,3)

              ! save postion of arounding grid points: iaz,ial,ihl
              ind_intp(nsmth,1) = ind_intptmp2(irp,2) + (ind_intptmp2(irp,3)-1)*rs_grid(ista)%naz_nbl + &
                   (ind_intptmp2(irp,4)-1)*(rs_grid(ista)%naz_nbl)*(rs_grid(ista)%nal+1)
              ! save position of radar point: iaz,ira,iel
              ind_intp(nsmth,2) =  ind_intptmp2(irp,1)

              hl_loc(nsmth) = hl_tmp2(irp)

              ! determine indices for interpolation in az, al, hl direction for current radar point
              ! (Indices relative to azimute-slice-grid, i.e., shifted by nbl_az)
              m = ind_intptmp2(irp,2)
              mo= MIN(m+1,iend(my_cart_id))
              n = ind_intptmp2(irp,3)
              no= MIN(n+1,rs_grid(ista)%nal+1) 
              k = ind_intptmp2(irp,4)
              ko= MIN(k+1,ke)

!!$              iaz = MOD(MOD(ind_intp(nsmth,2)-1,rs_meta(ista)%naz)+1-1,naz) + 1   
!!$
!!$              iel = MOD(INT(REAL(ind_intp(nsmth,2)-1,ireals) / &
!!$                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers),rs_meta(ista)%nel) + 1
!!$
!!$              iv  = MOD(INT(REAL(ind_intp(nsmth,2)-1,ireals)/ &
!!$                   (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
!!$                   REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v) + 1
!!$
!!$              ih  = INT(REAL(ind_intp(nsmth,2)-1,ireals)/(REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
!!$                   REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1
!!$
!!$              iae = iaz + (iel-1)*naz + (iv-1)*naz*rs_meta(ista)%nel + (ih-1)*naz*rs_meta(ista)%nel*rs_meta(ista)%ngpsm_v
!!$
!!$              flag(iae,ira) = 1_iintegers

              ! iae = MOD(ind_intp(nsmth,1)-1,rs_meta(ista)%naz*rs_meta(ista)%nel) + 1  ! campared with line 2694
              rfridx111 = rfridx_azgrd(m,n,k)
              rfridx211 = rfridx_azgrd(mo,n,k)
              rfridx121 = rfridx_azgrd(m,no,k)
              rfridx221 = rfridx_azgrd(mo,no,k)
              rfridx112 = rfridx_azgrd(m,n,ko)
              rfridx212 = rfridx_azgrd(mo,n,ko)
              rfridx122 = rfridx_azgrd(m,no,ko)
              rfridx222 = rfridx_azgrd(mo,no,ko)

              wa = w_intp(nsmth,1)
              wl = w_intp(nsmth,2)
              wk = w_intp(nsmth,3)

              IF (rfridx111 < -900.0_ireals .AND. rfridx211 >= -900.0_ireals) THEN
                rfridx111 = rfridx211
              ELSEIF (rfridx111 >= -900.0_ireals .AND. rfridx211 < -900.0_ireals) THEN
                rfridx211 = rfridx111
              ELSEIF (rfridx111 < -900.0_ireals .AND. rfridx211 < -900.0_ireals) THEN
                wl = 1.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx121 < -900.0_ireals .AND. rfridx221 >= -900.0_ireals) THEN
                rfridx121 = rfridx221
              ELSEIF (rfridx121 >= -900.0_ireals .AND. rfridx221 < -900.0_ireals) THEN
                rfridx221 = rfridx121
              ELSEIF (rfridx121 < -900.0_ireals .AND. rfridx221 < -900.0_ireals) THEN
                wl = 0.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx112 < -900.0_ireals .AND. rfridx212 >= -900.0_ireals) THEN
                rfridx112 = rfridx212
              ELSEIF (rfridx112 >= -900.0_ireals .AND. rfridx212 < -900.0_ireals) THEN
                rfridx212 = rfridx112
              ELSEIF (rfridx112 < -900.0_ireals .AND. rfridx212 < -900.0_ireals) THEN
                wl = 1.0
              ELSE
                CONTINUE
              ENDIF

              IF (rfridx122 < -900.0_ireals .AND. rfridx222 >= -900.0_ireals) THEN
                rfridx122 = rfridx222
              ELSEIF (rfridx122 >= -900.0_ireals .AND. rfridx222 < -900.0_ireals) THEN
                rfridx222 = rfridx122
              ELSEIF (rfridx122 < -900.0_ireals .AND. rfridx222 < -900.0_ireals) THEN
                wl = 0.0
              ELSE
                CONTINUE
              ENDIF

              rfridx(iae,ira) = ((rfridx111*(1.0_ireals-wa)+rfridx211*wa)*(1.0_ireals - wl)   + &
                   (rfridx121*(1.0_ireals-wa)+rfridx221*wa)*wl)*(1.0_ireals-wk) + &
                   ((rfridx112*(1.0_ireals-wa)+rfridx212*wa)*(1.0_ireals - wl)   + &
                   (rfridx122*(1.0_ireals-wa)+rfridx222*wa)*wl)*wk


              el_loc(nsmth) =  el(iae,ira)

              !              rfridx_loc(nsmth) =  rfridx(iae,ira)

            ENDDO ! loop over nrp2

          END IF  ! if nrp2 > 0

        END IF  ! if nrp > 0


!!$        DEALLOCATE(w_intptmp)
!!$        DEALLOCATE(ind_intptmp)
!!$        DEALLOCATE(hl_tmp)
!!$        DEALLOCATE(w_intptmp2)
!!$        DEALLOCATE(ind_intptmp2)
!!$        DEALLOCATE(hl_tmp2)

      ENDDO ! loop over nra

      DEALLOCATE(w_intptmp)
      DEALLOCATE(ind_intptmp)
      DEALLOCATE(hl_tmp)
      DEALLOCATE(w_intptmp2)
      DEALLOCATE(ind_intptmp2)
      DEALLOCATE(hl_tmp2)


      rs_data(ista)%nsmth     = nsmth

      WRITE(*,*)"nsmth",nsmth
      WRITE(*,*)"max hl",MAXVAL(hl)
      WRITE(*,*)"min hl",MINVAL(hl)
      WRITE(*,*)"max el",MAXVAL(el)
      WRITE(*,*)"min el",MINVAL(el)
      WRITE(*,*)"min rfridx",MINVAL(rfridx)

      ! allocate arrays of interpolation coefficients and indices of current radar station
      !  (for safety: deallocate first, if associated)
      IF (ASSOCIATED(rs_data(ista)%w_intp_smth))   DEALLOCATE (rs_data(ista)%w_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%ind_intp_smth)) DEALLOCATE (rs_data(ista)%ind_intp_smth)
      IF (ASSOCIATED(rs_data(ista)%hl_loc))        DEALLOCATE (rs_data(ista)%hl_loc)
      IF (ASSOCIATED(rs_data(ista)%el_loc))        DEALLOCATE (rs_data(ista)%el_loc)

      ALLOCATE(rs_data(ista)%w_intp_smth(nsmth,3))
      ALLOCATE(rs_data(ista)%ind_intp_smth(nsmth,2))
      ALLOCATE(rs_data(ista)%hl_loc(nsmth))
      ALLOCATE(rs_data(ista)%el_loc(nsmth))

      IF (nsmth > 0) THEN 

        ! copy values from auxiliary variables
        rs_data(ista)%w_intp_smth   = w_intp(1:nsmth,:)
        rs_data(ista)%ind_intp_smth = ind_intp(1:nsmth,:)
        rs_data(ista)%hl_loc        = hl_loc(1:nsmth)
        rs_data(ista)%el_loc        = el_loc(1:nsmth)

      END IF

      ! deallocate auxiliary fields
      DEALLOCATE(hl_azgrd)
      DEALLOCATE(rfridx_azgrd)
      DEALLOCATE(hl)
      DEALLOCATE(al)
      DEALLOCATE(el)
      DEALLOCATE(dhdr)
      DEALLOCATE(w_intp)
      DEALLOCATE(ind_intp)
      DEALLOCATE(hl_loc)
      DEALLOCATE(el_loc)
      DEALLOCATE(flag)
      DEALLOCATE(rfridx)
      DEALLOCATE(azarr_idx)
      DEALLOCATE(azimuth_vec)
      DEALLOCATE(alt_stavec)
      DEALLOCATE(dhdr_stavec)
      DEALLOCATE(rfridx_stavec)

    END DO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_geometry_onsmthnew
  ! ZY << Dynamical Version for Subroutine calc_geometry_smth added


  !==============================================================================
  !+ Module procedure in src_radar for the computation of the model radial winds
  !------------------------------------------------------------------------------
  SUBROUTINE calc_mod_radialwind(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radial winds for each 
    !              radar station by 
    !              - bilinear interpolation of u,v and w to radar points
    !              - projection onto radar beam
    !
    ! Method:      Following Jaervinen et al., 2009, Tellus
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                :: ista,iaz,ira,nobsmax,nobs,i,j,k,m,n,o,offset_i,offset_j,iobs,nk,np,ii,jj,kk, &
                                                 iu, io, ju, jo, ku, ko
    REAL    (KIND = ireals)                   ::                             &  
                                               ! UB>> removed initialization with 0.0 here, because wi, wj and wk then would get an implicit "SAVE" attribute!!!
                                                 wi                         ,& ! interpolation weight in i-direction
                                                 wj                         ,& ! interpolation weight in j-direction
                                                 wk                         ,& ! interpolation weight in k-direction
                                                 uu111, uu211, uu121, uu221 ,& 
                                                 uu112, uu212, uu122, uu222 ,& 
                                                 vv111, vv211, vv121, vv221, & 
                                                 vv112, vv212, vv122, vv222, & 
                                                 ww111, ww211, ww121, ww221, & 
                                                 ww112, ww212, ww122, ww222, &
                                                 urot_rp,vrot_rp,u_rp,v_rp,w_rp,range,azimuth,elevation,alpha,&
                                                 zsinpol,zcospol,zlonp,zlat,zarg1,zarg2,znorm,rlattmp,rlontmp
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_radialwind
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'calc_mod_radialwind'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! allocate array of model radial winds
      ALLOCATE(rs_data(ista)%radwind_mod(rs_data(ista)%nobs))
      
      ! Set data points below surface to -988.88 (back side of the vectors):
      DO iobs = rs_data(ista)%nobs_above_sfc+1, rs_data(ista)%nobs
        rs_data(ista)%radwind_mod(iobs) = -988.88
      END DO

      ! Loop over observation points above surface (front side of the vectors):
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs_above_sfc

        ! for each radar point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp(iobs,1)
    
        ! for each radar point determine the continuous number np of radar points
        np = rs_data(ista)%ind_intp(iobs,2)

        ! determine indices in azimuthal radial and elevation direction for current radar point
        m  = MOD(np-1,rs_meta(ista)%naz) + 1
        n  = MOD( INT(REAL(np-1,ireals) / REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
        o  = INT( REAL(np-1,ireals) / &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals) ), iintegers ) + 1

        ! determine model grid point south-west and above of radar grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1

        ! determine interpolation weights
        wi = rs_data(ista)%w_intp(iobs,1)
        wj = rs_data(ista)%w_intp(iobs,2)
        wk = rs_data(ista)%w_intp(iobs,3)

        ! UB>> reorganization to enable vectorization:

        ! interpolate u,v and w to the 8 surrounding mass points and then trilinearly to the radar point

        iu = MAX(i-1,1)
        io = MIN(i+1,ie)
        ju = MAX(j-1,1)
        jo = MIN(j+1,je)
        ko = MIN(k+1,ke)

        uu111 = 0.5_ireals*(u(i ,j ,k ,itlrad) + u(iu,j ,k ,itlrad))
        uu211 = 0.5_ireals*(u(io,j ,k ,itlrad) + u(i ,j ,k ,itlrad))
        uu121 = 0.5_ireals*(u(i ,jo,k ,itlrad) + u(iu,jo,k ,itlrad))
        uu221 = 0.5_ireals*(u(io,jo,k ,itlrad) + u(i ,jo,k ,itlrad))
        uu112 = 0.5_ireals*(u(i ,j ,ko,itlrad) + u(iu,j ,ko,itlrad))
        uu212 = 0.5_ireals*(u(io,j ,ko,itlrad) + u(i ,j ,ko,itlrad))
        uu122 = 0.5_ireals*(u(i ,jo,ko,itlrad) + u(iu,jo,ko,itlrad))
        uu222 = 0.5_ireals*(u(io,jo,ko,itlrad) + u(i ,jo,ko,itlrad))

        urot_rp = ((uu111*(1.0_ireals-wi) + uu211*wi)*(1.0_ireals-wj) + &
                   (uu121*(1.0_ireals-wi) + uu221*wi)*            wj)*(1.0_ireals-wk) + &
                  ((uu112*(1.0_ireals-wi) + uu212*wi)*(1.0_ireals-wj) + &
                   (uu122*(1.0_ireals-wi) + uu222*wi)*            wj)*wk

        vv111 = 0.5_ireals*(v(i ,j ,k ,itlrad) + v(i ,ju,k ,itlrad))
        vv211 = 0.5_ireals*(v(io,j ,k ,itlrad) + v(io,ju,k ,itlrad))
        vv121 = 0.5_ireals*(v(i ,jo,k ,itlrad) + v(i ,j ,k ,itlrad))
        vv221 = 0.5_ireals*(v(io,jo,k ,itlrad) + v(io,j ,k ,itlrad))
        vv112 = 0.5_ireals*(v(i ,j ,ko,itlrad) + v(i ,ju,ko,itlrad))
        vv212 = 0.5_ireals*(v(io,j ,ko,itlrad) + v(io,ju,ko,itlrad))
        vv122 = 0.5_ireals*(v(i ,jo,ko,itlrad) + v(i ,j ,ko,itlrad))
        vv222 = 0.5_ireals*(v(io,jo,ko,itlrad) + v(io,j ,ko,itlrad))

        vrot_rp = ((vv111*(1.0_ireals-wi) + vv211*wi)*(1.0_ireals-wj) + &
                   (vv121*(1.0_ireals-wi) + vv221*wi)*            wj)*(1.0_ireals-wk) + &
                  ((vv112*(1.0_ireals-wi) + vv212*wi)*(1.0_ireals-wj) + &
                   (vv122*(1.0_ireals-wi) + vv222*wi)*            wj)*wk

        ko = MIN(k+1,ke+1)
        ku = MIN(k+2,ke+1)

        ww111 = 0.5_ireals*(w(i ,j ,ko,itlrad) + w(i ,j ,k ,itlrad))
        ww211 = 0.5_ireals*(w(io,j ,ko,itlrad) + w(io,j ,k ,itlrad))
        ww121 = 0.5_ireals*(w(i ,jo,ko,itlrad) + w(i ,jo,k ,itlrad))
        ww221 = 0.5_ireals*(w(io,jo,ko,itlrad) + w(io,jo,k ,itlrad))
        ww112 = 0.5_ireals*(w(i ,j ,ku,itlrad) + w(i ,j ,ko,itlrad))
        ww212 = 0.5_ireals*(w(io,j ,ku,itlrad) + w(io,j ,ko,itlrad))
        ww122 = 0.5_ireals*(w(i ,jo,ku,itlrad) + w(i ,jo,ko,itlrad))
        ww222 = 0.5_ireals*(w(io,jo,ku,itlrad) + w(io,jo,ko,itlrad))

        w_rp    = ((ww111*(1.0_ireals-wi) + ww211*wi)*(1.0_ireals-wj) + &
                   (ww121*(1.0_ireals-wi) + ww221*wi)*            wj)*(1.0_ireals-wk) + &
                  ((ww112*(1.0_ireals-wi) + ww212*wi)*(1.0_ireals-wj) + &
                   (ww122*(1.0_ireals-wi) + ww222*wi)*            wj)*wk


        ! calculate horizontal model wind in geographical reference system from that in the rotated 
        ! system; 
        ! Hereby estimate the geographical position of the radar point by the nearest 
        ! model grid point to the south-west and above, to save the memory fort
        ! the geographical position in the rs_data - structure:

        ! UB>>==========================================================================
        ! UB>> replaced by the actual formulas for better vectorization, if automatic inlining fails:

!!$        CALL uvrot2uv_corr (urot_rp, vrot_rp, rlat(i,j), rlon(i,j), &
!!$          pollat, pollon, u_rp, v_rp)

        zsinpol = SIN(pollat * degrad)
        zcospol = COS(pollat * degrad)
        zlonp   = (pollon*degrad-rlon(i,j))
        zlat    =                rlat(i,j)

        zarg1   = zcospol*SIN(zlonp)
        zarg2   = zsinpol*COS(zlat) - zcospol*SIN(zlat)*COS(zlonp)
        znorm   = 1.0/SQRT(zarg1**2 + zarg2**2)

        ! Convert the u- and v-components
        u_rp    =   urot_rp*zarg2*znorm + vrot_rp*zarg1*znorm
        v_rp    = - urot_rp*zarg1*znorm + vrot_rp*zarg2*znorm

        ! UB<<==========================================================================

        ! calculate range, azimuth and elevation of radar point
        range     = n*rs_meta(ista)%ra_inc
        azimuth   = (m-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        elevation = rs_meta(ista)%el_arr(o)

        ! calculate correction angle due to curvature of earth (see Jaervinen et al., 2009)
!!$        alpha = elevation*degrad + ATAN(range*COS(elevation*degrad) / &
!!$               (range*SIN(elevation*degrad) + 4.0_ireals/3.0_ireals*r_earth + rs_meta(ista)%alt_msl))
!!$ replaced by rs_data(ista)%el_loc, the exact local elevation angle:
        alpha =  rs_data(ista)%el_loc(iobs)*degrad

        ! calculate model radial wind at radar point
        !! UB> changed sign convention: positive is away from the radar!
        !!        rs_data(ista)%radwind_mod(iobs) = - (u_rp*SIN(azimuth*degrad) + v_rp*COS(azimuth*degrad)) * &
        !!             cos(elevation*degrad + alpha) - w_rp*sin(elevation*degrad + alpha)

        rs_data(ista)%radwind_mod(iobs) = (u_rp*SIN(azimuth*degrad) + v_rp*COS(azimuth*degrad)) * &
                                           COS(alpha) + w_rp*SIN(alpha)

        !write(my_cart_id+700,'(2I6,8I6,7F12.3') rs_meta(ista)%station_id,int(ntstep * dt / 60.0,iintegers), &
        !    iobs,nk,m,n,o,i,j,k,wi,wj,wk,u_rp,v_rp,w_rp,rs_data(ista)%radwind_mod(iobs)


      END DO    ! loop over radar points

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_mod_radialwind



  ! ZY >>  calc_mod_radialwind_smth with spatial smoothing added

  !============================================================================================
  !+ Module procedure in src_radar for the computation of the model radial winds with smoothing
  !--------------------------------------------------------------------------------------------
  SUBROUTINE calc_mod_radialwind_smth(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radial winds for each 
    !              radar station by 
    !              - trilinear interpolation of u,v and w to smoothing points
    !              - projection onto radar main- or subbeam
    !              - smoothing with Gauss-Legendre Quadraure
    ! Method:      Following Jaervinen et al., 2009, Tellus
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                :: ista,i,j,k,m,n,o,offset_i,offset_j,nk,np,ii,jj,kk,iu,io,ju,jo,ku,ko,iv,ih,ismth
    REAL    (KIND = ireals)                   :: wi_smth, & ! 
                                                 wj_smth, & ! 
                                                 wk_smth, & ! 
                                                 ! u, v, and w of the 8 surrounding model grid points for each radar point;
                                                 uu111, uu211, uu121, uu221, & 
                                                 uu112, uu212, uu122, uu222, & 
                                                 vv111, vv211, vv121, vv221, & 
                                                 vv112, vv212, vv122, vv222, & 
                                                 ww111, ww211, ww121, ww221, & 
                                                 ww112, ww212, ww122, ww222, &                                    
                                                 urot_rp,vrot_rp,u_rp,v_rp,w_rp,range,azimuth,elevation,alpha, &
                                                 zsinpol,zcospol,zlonp,zlat,zarg1,zarg2,znorm,rlattmp,rlontmp
    !- End of header
    !==============================================================================


    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_radialwind_smth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine = 'calc_mod_radialwind_smth'

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ALLOCATE(rs_data(ista)%radwind_mod_smth(rs_data(ista)%nsmth))

      ! Set data points below surface to -988.88 (back side of the vectors):
      DO ismth = rs_data(ista)%nsmth_above_sfc+1, rs_data(ista)%nsmth
        rs_data(ista)%radwind_mod_smth(ismth) = -988.88
      END DO

      ! loop over observation points
!CDIR NODEP,VOVERTAKE,VOB
      DO ismth = 1, rs_data(ista)%nsmth_above_sfc

        ! for each smoothing point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp_smth(ismth,1)

        ! for each radar point determine the continuous number np of radar points
        np = rs_data(ista)%ind_intp_smth(ismth,2)

        m  = MOD(np-1,rs_meta(ista)%naz) + 1

        n  = MOD(INT(REAL(np-1,ireals)/REAL(rs_meta(ista)%naz,ireals),iintegers),rs_meta(ista)%nra) + 1

        o  = MOD(INT(REAL(np-1,ireals)/ &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers),rs_meta(ista)%nel) + 1

        iv = MOD(INT(REAL(np-1,ireals)/ &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
             REAL(rs_meta(ista)%nel,ireals)),iintegers),rs_meta(ista)%ngpsm_v)+1

        ih = INT(REAL(np-1,ireals)/(REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
             REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1

        ! determine model grid point south-west and above of grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/REAL(ie,ireals)/REAL(je,ireals),iintegers) + 1

        ! determine interpolation weights
        wi_smth = rs_data(ista)%w_intp_smth(ismth,1)
        wj_smth = rs_data(ista)%w_intp_smth(ismth,2)
        wk_smth = rs_data(ista)%w_intp_smth(ismth,3)

        ! interpolate u,v and w to the 8 surrounding mass points and then trilinearly to the radar point

        iu = MAX(i-1,1)
        io = MIN(i+1,ie)
        ju = MAX(j-1,1)
        jo = MIN(j+1,je)
        ko = MIN(k+1,ke)

        uu111 = 0.5_ireals*(u(i ,j ,k ,itlrad) + u(iu,j ,k ,itlrad))
        uu211 = 0.5_ireals*(u(io,j ,k ,itlrad) + u(i ,j ,k ,itlrad))
        uu121 = 0.5_ireals*(u(i ,jo,k ,itlrad) + u(iu,jo,k ,itlrad))
        uu221 = 0.5_ireals*(u(io,jo,k ,itlrad) + u(i ,jo,k ,itlrad))
        uu112 = 0.5_ireals*(u(i ,j ,ko,itlrad) + u(iu,j ,ko,itlrad))
        uu212 = 0.5_ireals*(u(io,j ,ko,itlrad) + u(i ,j ,ko,itlrad))
        uu122 = 0.5_ireals*(u(i ,jo,ko,itlrad) + u(iu,jo,ko,itlrad))
        uu222 = 0.5_ireals*(u(io,jo,ko,itlrad) + u(i ,jo,ko,itlrad))

        urot_rp = ((uu111*(1.0_ireals-wi_smth) + uu211*wi_smth)*(1.0_ireals-wj_smth) + &
                   (uu121*(1.0_ireals-wi_smth) + uu221*wi_smth)*            wj_smth)*(1.0_ireals-wk_smth) + &
                  ((uu112*(1.0_ireals-wi_smth) + uu212*wi_smth)*(1.0_ireals-wj_smth) + &
                   (uu122*(1.0_ireals-wi_smth) + uu222*wi_smth)*            wj_smth)*wk_smth

        vv111 = 0.5_ireals*(v(i ,j ,k ,itlrad) + v(i ,ju,k ,itlrad))
        vv211 = 0.5_ireals*(v(io,j ,k ,itlrad) + v(io,ju,k ,itlrad))
        vv121 = 0.5_ireals*(v(i ,jo,k ,itlrad) + v(i ,j ,k ,itlrad))
        vv221 = 0.5_ireals*(v(io,jo,k ,itlrad) + v(io,j ,k ,itlrad))
        vv112 = 0.5_ireals*(v(i ,j ,ko,itlrad) + v(i ,ju,ko,itlrad))
        vv212 = 0.5_ireals*(v(io,j ,ko,itlrad) + v(io,ju,ko,itlrad))
        vv122 = 0.5_ireals*(v(i ,jo,ko,itlrad) + v(i ,j ,ko,itlrad))
        vv222 = 0.5_ireals*(v(io,jo,ko,itlrad) + v(io,j ,ko,itlrad))

        vrot_rp = ((vv111*(1.0_ireals-wi_smth) + vv211*wi_smth)*(1.0_ireals-wj_smth) + &
                   (vv121*(1.0_ireals-wi_smth) + vv221*wi_smth)*            wj_smth)*(1.0_ireals-wk_smth) + &
                  ((vv112*(1.0_ireals-wi_smth) + vv212*wi_smth)*(1.0_ireals-wj_smth) + &
                   (vv122*(1.0_ireals-wi_smth) + vv222*wi_smth)*            wj_smth)*wk_smth

        ko = MIN(k+1,ke+1)
        ku = MIN(k+2,ke+1)

        ww111 = 0.5_ireals*(w(i ,j ,ko,itlrad) + w(i ,j ,k ,itlrad))
        ww211 = 0.5_ireals*(w(io,j ,ko,itlrad) + w(io,j ,k ,itlrad))
        ww121 = 0.5_ireals*(w(i ,jo,ko,itlrad) + w(i ,jo,k ,itlrad))
        ww221 = 0.5_ireals*(w(io,jo,ko,itlrad) + w(io,jo,k ,itlrad))
        ww112 = 0.5_ireals*(w(i ,j ,ku,itlrad) + w(i ,j ,ko,itlrad))
        ww212 = 0.5_ireals*(w(io,j ,ku,itlrad) + w(io,j ,ko,itlrad))
        ww122 = 0.5_ireals*(w(i ,jo,ku,itlrad) + w(i ,jo,ko,itlrad))
        ww222 = 0.5_ireals*(w(io,jo,ku,itlrad) + w(io,jo,ko,itlrad))

        w_rp    = ((ww111*(1.0_ireals-wi_smth) + ww211*wi_smth)*(1.0_ireals-wj_smth) + &
                   (ww121*(1.0_ireals-wi_smth) + ww221*wi_smth)*            wj_smth)*(1.0_ireals-wk_smth) + &
                  ((ww112*(1.0_ireals-wi_smth) + ww212*wi_smth)*(1.0_ireals-wj_smth) + &
                   (ww122*(1.0_ireals-wi_smth) + ww222*wi_smth)*            wj_smth)*wk_smth


        ! calculate horizontal model wind in geographical reference system from that in the rotated 
        ! system; 
        ! Hereby estimate the geographical position of the radar point by the nearest 
        ! model grid point to the south-west and above, to save the memory fort
        ! the geographical position in the rs_data - structure:

        ! UB>>==========================================================================
        ! UB>> replaced by the actual formulas for better vectorization, if automatic inlining fails:

!!$        CALL uvrot2uv_corr (urot_rp, vrot_rp, rlat(i,j), rlon(i,j), &
!!$          pollat, pollon, u_rp, v_rp)

        zsinpol = SIN(pollat * degrad)
        zcospol = COS(pollat * degrad)
        zlonp   = (pollon*degrad-rlon(i,j))
        zlat    =                rlat(i,j)

        zarg1   = zcospol*SIN(zlonp)
        zarg2   = zsinpol*COS(zlat) - zcospol*SIN(zlat)*COS(zlonp)
        znorm   = 1.0/SQRT(zarg1**2 + zarg2**2)

        ! Convert the u- and v-components
        u_rp    =   urot_rp*zarg2*znorm + vrot_rp*zarg1*znorm
        v_rp    = - urot_rp*zarg1*znorm + vrot_rp*zarg2*znorm

        ! UB<<==========================================================================

        ! calculate range, azimuth and elevation of smoothing point
        range     = n*rs_meta(ista)%ra_inc

!!$ inlined code from smth_el_horzscan
!!$        theta3_eff = rs_meta(ista)%Theta3
!!$
!!$        smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                     rs_meta(ista)%xabscsm_v(iv)
!!$
!!$        elevation = rs_meta(ista)%el_arr(o) + smthpoint

        elevation = rs_meta(ista)%el_arr(o) + smth_el_horzscan(ista,iv)


!!$ inlined code from smth_az_horzscan:
!!$        phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
!!$             ( COS(rs_meta(ista)%el_arr(o)*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
!!$             ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )
!!$
!!$        smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_h(ih)
!!$
!!$        azimuth   = (m-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start + smthpoint
                    
        azimuth   = (m-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start + &
                    smth_az_horzscan(ista,ih,rs_meta(ista)%el_arr(o))


        ! calculate correction angle due to curvature of earth (see Jaervinen et al., 2009)
!!$        alpha = elevation*degrad + ATAN(range*COS(elevation*degrad) / &
!!$               (range*SIN(elevation*degrad) + 4.0_ireals/3.0_ireals*r_earth + rs_meta(ista)%alt_msl))
!!$ replaced by rs_data(ista)%el_loc, the exact local elevation angle:
        alpha =  rs_data(ista)%el_loc(ismth)*degrad


        ! calculate model radial wind at smoothing point
        rs_data(ista)%radwind_mod_smth(ismth) = (u_rp*SIN(azimuth*degrad) + v_rp*COS(azimuth*degrad)) * &
             COS(alpha) + w_rp*SIN(alpha)


      END DO    ! loop over radar smoothing points

    END DO   ! loop over radar stations

  END SUBROUTINE calc_mod_radialwind_smth

  ! ZY <<  calc_mod_radialwind_smth with spatial averaging added


  !==============================================================================
  !+ Module procedure in src_radar for the computation of the model radial winds
  !  under consideration of dynamical propagation path
  !------------------------------------------------------------------------------
  SUBROUTINE calc_mod_radialwind_online(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radial winds for each 
    !              radar station by 
    !              - bilinear interpolation of u,v and w to radar points
    !              - projection onto radar beam
    !
    ! Method:      Following Jaervinen et al., 2009, Tellus
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ista,igrd,iaz,ira,iel,nobsmax,nobs,i,j,k,m,n,o,offset_i,offset_j,iobs,nk,np,no,ko
    INTEGER (KIND = iintegers)       :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)                   ::                     &                              
                                                 wl                 ,& ! interpolation weight in i-direction
                                                 wk                 ,& ! interpolation weight in j-direction
                                                 u11, u21, u12, u22 ,& 
                                                 v11, v21, v12, v22 ,& 
                                                 w11, w21, w12, w22 ,& 
                                                 u,v,w,azimuth,alpha

    REAL    (KIND = ireals), ALLOCATABLE      :: u_azgrd(:,:,:),v_azgrd(:,:,:),w_azgrd(:,:,:)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_radialwind_online
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

!!$===============================
!!$ correct ONLY for nbl_az = 0 
!!$===============================

    yzroutine(:) = ' '
    yzroutine = 'calc_mod_radialwind_online'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! 1 line of overlap at the lower azimut index end!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      ALLOCATE(u_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(v_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(w_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))

!!$ UB>> Initialize with standard missing value (= point outside model domain):
      u_azgrd = -999.99_ireals
      v_azgrd = -999.99_ireals
      w_azgrd = -999.99_ireals

      !sort the collected smoothing points data into 3d filed according to sorted azimuth, arc length, height.
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1
        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        u_azgrd(m,n,k) = rs_grid(ista)%u_azgrd(igrd)

        v_azgrd(m,n,k) = rs_grid(ista)%v_azgrd(igrd)

        w_azgrd(m,n,k) = rs_grid(ista)%w_azgrd(igrd)

      ENDDO

      ! allocate array of model radial winds
      ALLOCATE(rs_data(ista)%radwind_mod(rs_data(ista)%nobs))

      ! loop over observation points
      ! UB>> loop rewritten due to vectorisation:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs

        ! for each radar point determine the continuous number nk of the grid cube 
        ! surrounded by the 4 nearest auxiliary grid points
        nk = rs_data(ista)%ind_intp(iobs,1)

        ! for each radar point determine the continuous number np of radar points
        np = rs_data(ista)%ind_intp(iobs,2)
        
        ! determine indices in azimuthal radial and elevation direction for current radar point
        iaz  = MOD(np-1,rs_meta(ista)%naz) + 1
        ira  = MOD( INT(REAL(np-1,ireals) / REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
        iel  = INT( REAL(np-1,ireals) / &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals) ), iintegers ) + 1

        ! determine indices for interpolation grids in atimuthal, arc length, vertical direction for current radar point
        m  = MOD(nk-1,rs_meta(ista)%naz) + 1 + nbl_az
        n  = MOD(INT(REAL(nk-1,ireals) / &
             REAL(rs_meta(ista)%naz,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(nk-1,ireals) / &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        ! determine interpolation weights
        wl = rs_data(ista)%w_intp(iobs,1)
        wk = rs_data(ista)%w_intp(iobs,2)

        no= MIN(n+1,rs_grid(ista)%nal+1) 
        ko= MIN(k+1,ke)

        u11 = u_azgrd(m,n,k)
        u21 = u_azgrd(m,no,k)
        u12 = u_azgrd(m,n,ko)
        u22 = u_azgrd(m,no,ko)

        v11 = v_azgrd(m,n,k)
        v21 = v_azgrd(m,no,k)
        v12 = v_azgrd(m,n,ko)
        v22 = v_azgrd(m,no,ko)

        w11 = w_azgrd(m,n,k)
        w21 = w_azgrd(m,no,k)
        w12 = w_azgrd(m,n,ko)
        w22 = w_azgrd(m,no,ko)

        ! If the value on a grid point is missing, it will be replaced by value from the horizontal symmetric grid point;
        ! If both value are missing, neglect these two points while intepolation
        IF (u11 < -900.0_ireals .AND. u21 >= -900.0_ireals) THEN
          u11 = u21
          v11 = v21
          w11 = w21
        ELSEIF (u11 >= -900.0_ireals .AND. u21 < -900.0_ireals) THEN
          u21 = u11
          v21 = v11
          w21 = w11
        ELSEif (u11 < -900.0_ireals .AND. u21 < -900.0_ireals) then
          wk = 1.0
        ELSE
          CONTINUE
        ENDIF

        IF (u12 < -900.0_ireals .AND. u22 >= -900.0_ireals) THEN
          u12 = u22
          v12 = v22
          w12 = w22
        ELSEIF (u12 >= -900.0_ireals .AND. u22 < -900.0_ireals) THEN
          u22 = u12
          v22 = v12
          w22 = w12
        ELSEif (u12 < -900.0_ireals .AND. u22 < -900.0_ireals) then
          wk = 0.0
        ELSE
          CONTINUE
        ENDIF

        u = (u11*(1.0_ireals-wl)+u21*wl)*(1.0_ireals - wk) + (u12*(1.0_ireals-wl)+u22*wl)*wk

        v = (v11*(1.0_ireals-wl)+v21*wl)*(1.0_ireals - wk) + (v12*(1.0_ireals-wl)+v22*wl)*wk

        w = (w11*(1.0_ireals-wl)+w21*wl)*(1.0_ireals - wk) + (w12*(1.0_ireals-wl)+w22*wl)*wk


        ! UB<<==========================================================================

        ! calculate azimuth of radar point
        azimuth   = (iaz-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start
        azimuth   = MODULO(azimuth,360.0_ireals)

        ! calculate correction angle due to curvature of earth (see Jaervinen et al., 2009)
!!$        alpha = ATAN(range*COS(elevation*degrad) / &
!!$             (range*SIN(elevation*degrad) + 4.0_ireals/3.0_ireals*r_earth + rs_meta(ista)%alt_msl))

        alpha = rs_data(ista)%el_loc(iobs)*degrad

        ! calculate model radial wind at radar point
        rs_data(ista)%radwind_mod(iobs) = &
             (u*COS(alpha)*SIN(azimuth*degrad) + v*COS(azimuth*degrad)) * COS(alpha) + w*SIN(alpha)

        !write(my_cart_id+700,'(2I6,8I6,7F12.3') rs_meta(ista)%station_id,int(ntstep * dt / 60.0,iintegers), &
        !    iobs,nk,m,n,o,i,j,k,wi,wj,wk,u_rp,v_rp,w_rp,rs_data(ista)%radwind_mod(iobs)

      END DO    ! loop over radar points

      IF (rs_data(ista)%nobs > 0) THEN
        WRITE(*,*)"max of radarwind_mod",MAXVAL(rs_data(ista)%radwind_mod)
        WRITE(*,*)"min of radarwind_mod",MINVAL(rs_data(ista)%radwind_mod)
      END IF

      DEALLOCATE(u_azgrd)
      DEALLOCATE(v_azgrd)
      DEALLOCATE(w_azgrd)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_mod_radialwind_online



  !=================================================================================================
  !+ Module procedure in src_radar for the computation of the model radial winds at smoothing points
  !  under consideration of dynamical propagation path
  !-------------------------------------------------------------------------------------------------
  SUBROUTINE calc_mod_radialwind_onsmth(lcalc,time_mod)

    !-----------------------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radial winds on smoothing points for each 
    !              radar station by 
    !              - trilinear interpolation of u,v and w to smoothing points
    !              - projection onto radar main- or subbeam
    !
    ! Method:      Following Jaervinen et al., 2009, Tellus
    !
    !-----------------------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)              :: ista,igrd,iaz,ira,iel, &
                                               nobsmax,k,m,n,offset_i,offset_j,ismth, &
                                               nk,np,mo,no,ko,ih
    INTEGER (KIND = iintegers)              :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)                 ::                                                &  
                                               wa                                           , &                                           
                                               wl                                           , & ! interpolation weight in i-direction
                                               wk                                           , & ! interpolation weight in j-direction
                                               u111, u211, u121, u221,u112, u212, u122, u222, & 
                                               v111, v211, v121, v221,v112, v212, v122, v222, & 
                                               w111, w211, w121, w221,w112, w212, w122, w222, & 
                                               u,v,w,range,azimuth,elevation,alpha
    REAL    (KIND = ireals), ALLOCATABLE     ::u_azgrd(:,:,:),v_azgrd(:,:,:),w_azgrd(:,:,:)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_radialwind_onsmth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'calc_mod_radialwind_onsmth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! 1 line of overlap at the lower azimut index end!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      ALLOCATE(u_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(v_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
      ALLOCATE(w_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))

!!$ UB>> Initialize with standard missing value (= point outside model domain):
      u_azgrd = -999.99_ireals
      v_azgrd = -999.99_ireals
      w_azgrd = -999.99_ireals

      !sort the collected smoothing points data into 3d filed according to sorted azimuth, arc length, height.
!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current smoothing point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1

        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        u_azgrd(m,n,k) = rs_grid(ista)%u_azgrd(igrd)

        v_azgrd(m,n,k) = rs_grid(ista)%v_azgrd(igrd)

        w_azgrd(m,n,k) = rs_grid(ista)%w_azgrd(igrd)

      ENDDO

      ! allocate array of model radial winds
      ALLOCATE(rs_data(ista)%radwind_mod_smth(rs_data(ista)%nsmth))

      !if (rs_data(ista)%nsmth > 0) then
      !   write(my_cart_id+700,'(2A6,8A6,7A12') "WMO","time","ismth","nk","m","n","o","i","j","k","wi","wj","wk","u_rp","v_rp","w_rp","radwind_mod"     
      !end if

      ! loop over observation points
      ! UB>> loop rewritten due to vectorisation:
!CDIR NODEP,VOVERTAKE,VOB
      DO ismth = 1, rs_data(ista)%nsmth

        ! for each smoothing point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest auxiliary grid points
        nk = rs_data(ista)%ind_intp_smth(ismth,1)

        ! for each smoothing point determine the continuous number np of smoothing points
        np = rs_data(ista)%ind_intp_smth(ismth,2)

         

        ! determine indices for interpolation grids in atimuthal, arc length, vertical direction for current smoothing point
        m  = MOD(nk-1,rs_grid(ista)%naz_nbl) + 1
        n  = MOD(INT(REAL(nk-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(nk-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        ! determine interpolation weights
        wa = rs_data(ista)%w_intp_smth(ismth,1)
        wl = rs_data(ista)%w_intp_smth(ismth,2)
        wk = rs_data(ista)%w_intp_smth(ismth,3)

        mo = MIN(m+1,iend(my_cart_id))
        no = MIN(n+1,rs_grid(ista)%nal+1) 
        ko = MIN(k+1,ke)

        u111 = u_azgrd(m,n,k)
        u211 = u_azgrd(mo,n,k)
        u121 = u_azgrd(m,no,k)
        u221 = u_azgrd(mo,no,k)
        u112 = u_azgrd(m,n,ko)
        u212 = u_azgrd(mo,n,ko)
        u122 = u_azgrd(m,no,ko)
        u222 = u_azgrd(mo,no,ko)

        v111 = v_azgrd(m,n,k)
        v211 = v_azgrd(mo,n,k)
        v121 = v_azgrd(m,no,k)
        v221 = v_azgrd(mo,no,k)
        v112 = v_azgrd(m,n,ko)
        v212 = v_azgrd(mo,n,ko)
        v122 = v_azgrd(m,no,ko)
        v222 = v_azgrd(mo,no,ko)

        w111 = w_azgrd(m,n,k)
        w211 = w_azgrd(mo,n,k)
        w121 = w_azgrd(m,no,k)
        w221 = w_azgrd(mo,no,k)
        w112 = w_azgrd(m,n,ko)
        w212 = w_azgrd(mo,n,ko)
        w122 = w_azgrd(m,no,ko)
        w222 = w_azgrd(mo,no,ko)

        ! If the value on a grid point is missing, it will be replaced by value from the horizontal symmetric grid point;
        ! If both value are missing, neglect these two points while interpolation
        IF (u111 < -900.0_ireals .AND. u211 >= -900.0_ireals) THEN
          u111 = u211
          v111 = v211
          w111 = w211
        ELSEIF (u111 >= -900.0_ireals .AND. u211 < -900.0_ireals) THEN
          u211 = u111
          v211 = v111
          w211 = w111
        ELSEif (u111 < -900.0_ireals .AND. u211 < -900.0_ireals) then
          wl = 1.0
        ELSE
          CONTINUE
        ENDIF

        IF (u121 < -900.0_ireals .AND. u221 >= -900.0_ireals) THEN
          u121 = u221
          v121 = v221
          w121 = w221
        ELSEIF (u121 >= -900.0_ireals .AND. u221 < -900.0_ireals) THEN
          u221 = u121
          v221 = v121
          w221 = w121
        ELSEif (u121 < -900.0_ireals .AND. u221 < -900.0_ireals) then
          wl = 0.0
        ELSE
          CONTINUE
        ENDIF

        IF (u112 < -900.0_ireals .AND. u212 >= -900.0_ireals) THEN
          u112 = u212
          v112 = v212
          w112 = w212
        ELSEIF (u112 >= -900.0_ireals .AND. u212 < -900.0_ireals) THEN
          u212 = u112
          v212 = v112
          w212 = w112
        ELSEif (u112 < -900.0_ireals .AND. u212 < -900.0_ireals) then
          wl = 1.0
        ELSE
          CONTINUE
        ENDIF

        IF (u122 < -900.0_ireals .AND. u222 >= -900.0_ireals) THEN
          u122 = u222
          v122 = v222  
          w122 = w222
        ELSEIF (u122 >= -900.0_ireals .AND. u222 < -900.0_ireals) THEN
          u222 = u122
          v222 = v122
          w222 = w122
        ELSEif (u122 < -900.0_ireals .AND. u222 < -900.0_ireals) then
          wl = 0.0
        ELSE
          CONTINUE
        ENDIF

!!$ do not interpolate if one of the model grid points is invalid:
!!$     (could completely replace the above IF-clauses)
        IF (u111 < -900.0_ireals .OR. u211 <  -900.0_ireals .OR. &
            u121 < -900.0_ireals .OR. u221 <  -900.0_ireals .OR. &
            u112 < -900.0_ireals .OR. u212 <  -900.0_ireals .OR. &
            u122 < -900.0_ireals .OR. u222 <  -900.0_ireals .OR. &
            v111 < -900.0_ireals .OR. v211 <  -900.0_ireals .OR. &
            v121 < -900.0_ireals .OR. v221 <  -900.0_ireals .OR. &
            v112 < -900.0_ireals .OR. v212 <  -900.0_ireals .OR. &
            v122 < -900.0_ireals .OR. v222 <  -900.0_ireals .OR. &
            w111 < -900.0_ireals .OR. w211 <  -900.0_ireals .OR. &
            w121 < -900.0_ireals .OR. w221 <  -900.0_ireals .OR. &
            w112 < -900.0_ireals .OR. w212 <  -900.0_ireals .OR. &
            w122 < -900.0_ireals .OR. w222 <  -900.0_ireals ) THEN
         
          rs_data(ista)%radwind_mod_smth(ismth) =   -999.99_ireals

          CYCLE

        ENDIF

        u = ((u111*(1.0_ireals-wa)+u211*wa)*(1.0_ireals - wl)   + &
             (u121*(1.0_ireals-wa)+u221*wa)*wl)*(1.0_ireals-wk) + &
             ((u112*(1.0_ireals-wa)+u212*wa)*(1.0_ireals - wl)  + &
             (u122*(1.0_ireals-wa)+u222*wa)*wl)*wk


        v = ((v111*(1.0_ireals-wa)+v211*wa)*(1.0_ireals - wl)   + &
             (v121*(1.0_ireals-wa)+v221*wa)*wl)*(1.0_ireals-wk) + &
             ((v112*(1.0_ireals-wa)+v212*wa)*(1.0_ireals - wl)  + &
             (v122*(1.0_ireals-wa)+v222*wa)*wl)*wk


        w = ((w111*(1.0_ireals-wa)+w211*wa)*(1.0_ireals - wl)   + &
             (w121*(1.0_ireals-wa)+w221*wa)*wl)*(1.0_ireals-wk) + &
             ((w112*(1.0_ireals-wa)+w212*wa)*(1.0_ireals - wl)  + &
             (w122*(1.0_ireals-wa)+w222*wa)*wl)*wk

        alpha = rs_data(ista)%el_loc(ismth)*degrad


        ih  = INT(REAL(np-1,ireals)/(REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)* &
             REAL(rs_meta(ista)%nel,ireals)*REAL(rs_meta(ista)%ngpsm_v,ireals)),iintegers) + 1
        iaz  = MOD(np-1,rs_meta(ista)%naz) + 1

        iel  = MOD(INT(REAL(np-1,ireals)/ &
               (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_meta(ista)%nra,ireals)),iintegers),rs_meta(ista)%nel) + 1

!!$ inlined code from smth_az_horzscan:
!!$        phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
!!$             ( COS(rs_meta(ista)%el_arr(iel)*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
!!$             ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )
!!$
!!$        smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_h(ih)
!!$
!!$        azimuth  = (iaz-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start + smthpoint
!!$                   

        azimuth  = (iaz-1)*rs_meta(ista)%az_inc + rs_meta(ista)%az_start + &
                   smth_az_horzscan(ista,ih,rs_meta(ista)%el_arr(iel))

!!$ UB>> unnoetig, weil nur unter SIN() und COS() gebraucht ...
        azimuth  = MODULO(azimuth, 360.0_ireals)

        rs_data(ista)%radwind_mod_smth(ismth) = &
             (u*COS(alpha)*SIN(azimuth*degrad)+v*COS(azimuth*degrad))*COS(alpha) + w*SIN(alpha)
       
      END DO    ! loop over radar points

      IF (rs_data(ista)%nsmth > 0) THEN
        WRITE(*,*)"max of radwind_mod_smth: ",MAXVAL(rs_data(ista)%radwind_mod_smth)
        WRITE(*,*)"min of radwind_mod_smth: ",MINVAL(rs_data(ista)%radwind_mod_smth)
      END IF

      DEALLOCATE(u_azgrd)
      DEALLOCATE(v_azgrd)
      DEALLOCATE(w_azgrd)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_mod_radialwind_onsmth


  !================================================================================================
  !+ Module procedure in src_radar for the computation of the model u,v,w winds at auxiliary grids
  !------------------------------------------------------------------------------------------------
  SUBROUTINE calc_grd_winduvw(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model u,v,w winds for each 
    !              radar station by 
    !              - bilinear interpolation of u,v and w to grid points
    !            
    !
    ! 
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                :: ista,iaz,ira,nobsmax,ngrd,i,j,k,m,n,o,offset_i,offset_j,igrd,nk,np,ii,jj,kk, &
         iu, io, ju, jo, ku, ko
    REAL    (KIND = ireals)          ::          wi,                             & ! interpolation weight in i-direction
         wj,                             & ! interpolation weight in j-direction
         wk,                             & ! interpolation weight in k-direction
         uu11, uu21, uu12, uu22,         & 
         vv11, vv21, vv12, vv22,         & 
         ww11, ww21, ww12, ww22,         & 
         urot_rp,vrot_rp,u_rp,v_rp,w_rp, &
         zsinpol,zcospol,zlonp,zlat,zarg1,zarg2,znorm,rlattmp,rlontmp
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_grd_winduvw
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'calc_grd_winduvw'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      IF (rs_grid(ista)%ngrd .GE. 0) THEN

        ! allocate array of model radial winds
        ALLOCATE(rs_grid(ista)%u_grd(rs_grid(ista)%ngrd))
        ALLOCATE(rs_grid(ista)%v_grd(rs_grid(ista)%ngrd))
        ALLOCATE(rs_grid(ista)%w_grd(rs_grid(ista)%ngrd))

        ! rs_grid(ista)%radwind_grd(rs_grid(ista)%ngrd) = 0.0_ireals

        !if (rs_data(ista)%nobs > 0) then
        !   write(my_cart_id+700,'(2A6,8A6,7A12') "WMO","time","iobs","nk","m","n","o","i","j","k","wi","wj","wk","u_rp","v_rp","w_rp","radwind_mod"     
        !end if

        ! loop over observation points
        ! UB>> loop rewritten due to vectorisation:
       
!CDIR NODEP,VOVERTAKE,VOB
        DO igrd = 1, rs_grid(ista)%ngrd

          ! for each grid point determine the continuous number nk of the grid cube 
          ! surrounded by the 8 nearest model grid points
          nk = rs_grid(ista)%ind_intp(igrd,1)
          
          ! for each grid point determine the continuous number np of grid points
          np = rs_grid(ista)%ind_intp(igrd,2)
          
          
          ! determine indices in azimuthal, arc length and vertical direction for current grid point
!!$          m  = MOD(np-1,rs_grid(ista)%naz_nbl) + 1
!!$          n  = MOD( INT(REAL(np-1,ireals) / REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1 ) + 1
!!$          o  = INT( REAL(np-1,ireals) / &
!!$               (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals) ), iintegers ) + 1

          ! determine model grid point south-west and above of grid point
          i = MOD(nk-1,ie) + 1
          j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
          k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1

          ! determine interpolation weights
          wi = rs_grid(ista)%w_intp(igrd,1)
          wj = rs_grid(ista)%w_intp(igrd,2)

          ! interpolate u,v and w to the 8 surrounding mass points and then trilinearly to the radar point
          iu = MAX(i-1,1)
          io = MIN(i+1,ie)
          ju = MAX(j-1,1)
          jo = MIN(j+1,je)

          uu11 = 0.5_ireals*(u(i ,j ,k ,itlrad) + u(iu,j ,k ,itlrad))
          uu21 = 0.5_ireals*(u(io,j ,k ,itlrad) + u(i ,j ,k ,itlrad))
          uu12 = 0.5_ireals*(u(i ,jo,k ,itlrad) + u(iu,jo,k ,itlrad))
          uu22 = 0.5_ireals*(u(io,jo,k ,itlrad) + u(i ,jo,k ,itlrad))

          urot_rp = (uu11*(1.0_ireals-wi) + uu21*wi)*(1.0_ireals-wj) + &
               (uu12*(1.0_ireals-wi) + uu22*wi)*            wj

          vv11 = 0.5_ireals*(v(i ,j ,k ,itlrad) + v(i ,ju,k ,itlrad))
          vv21 = 0.5_ireals*(v(io,j ,k ,itlrad) + v(io,ju,k ,itlrad))
          vv12 = 0.5_ireals*(v(i ,jo,k ,itlrad) + v(i ,j ,k ,itlrad))
          vv22 = 0.5_ireals*(v(io,jo,k ,itlrad) + v(io,j ,k ,itlrad))

          vrot_rp = (vv11*(1.0_ireals-wi) + vv21*wi)*(1.0_ireals-wj) + &
               (vv12*(1.0_ireals-wi) + vv22*wi)*            wj

          ! UB>> neu:
          ko = MIN(k+1,ke+1)
          !        ku = MIN(k+2,ke+1)

          ww11 = 0.5_ireals*(w(i ,j ,ko,itlrad) + w(i ,j ,k ,itlrad))
          ww21 = 0.5_ireals*(w(io,j ,ko,itlrad) + w(io,j ,k ,itlrad))
          ww12 = 0.5_ireals*(w(i ,jo,ko,itlrad) + w(i ,jo,k ,itlrad))
          ww22 = 0.5_ireals*(w(io,jo,ko,itlrad) + w(io,jo,k ,itlrad))

          ! UB>> neu:
          rs_grid(ista)%w_grd(igrd)    = (ww11*(1.0_ireals-wi) + ww21*wi)*(1.0_ireals-wj) + &
               (ww12*(1.0_ireals-wi) + ww22*wi)*            wj


          ! calculate horizontal model wind in geographical reference system from that in the rotated 
          ! system; 
          ! Hereby estimate the geographical position of the radar point by the nearest 
          ! model grid point to the south-west and above, to save the memory fort
          ! the geographical position in the rs_data - structure:

          ! UB>>==========================================================================
          ! UB>> replaced by the actual formulas for better vectorization, if automatic inlining fails:

!!$        CALL uvrot2uv_corr (urot_rp, vrot_rp, rlat(i,j), rlon(i,j), &
!!$          pollat, pollon, u_rp, v_rp)

          zsinpol = SIN(pollat * degrad)
          zcospol = COS(pollat * degrad)
          zlonp   = (pollon*degrad-rlon(i,j))
          zlat    =                rlat(i,j)

          zarg1   = zcospol*SIN(zlonp)
          zarg2   = zsinpol*COS(zlat) - zcospol*SIN(zlat)*COS(zlonp)
          znorm   = 1.0/SQRT(zarg1**2 + zarg2**2)

          ! Convert the u- and v-components
          rs_grid(ista)%u_grd(igrd)   =   urot_rp*zarg2*znorm + vrot_rp*zarg1*znorm
          rs_grid(ista)%v_grd(igrd)   = - urot_rp*zarg1*znorm + vrot_rp*zarg2*znorm


          ! UB<<==========================================================================



        END DO    ! loop over radar points
        
      END IF

      IF (rs_grid(ista)%ngrd > 0) THEN
        WRITE(*,*)"max of u_grd",MAXVAL(rs_grid(ista)%u_grd)
        WRITE(*,*)"min of u_grd",MINVAL(rs_grid(ista)%u_grd)

        WRITE(*,*)"max of v_grd",MAXVAL(rs_grid(ista)%v_grd)
        WRITE(*,*)"min of v_grd",MINVAL(rs_grid(ista)%v_grd)

        WRITE(*,*)"max of w_grd",MAXVAL(rs_grid(ista)%w_grd)
        WRITE(*,*)"min of w_grd",MINVAL(rs_grid(ista)%w_grd)
      END IF


    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_grd_winduvw


  !==============================================================================
  !+ Module procedure in src_radar for the computation of the radar reflectivity
  !------------------------------------------------------------------------------
  SUBROUTINE calc_mod_reflectivity(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the radar reflectivity for each 
    !              radar station. Output values are in linear space, not logarithmic (dBZ)!
    !
    ! Method:
    !
    !------------------------------------------------------------------------------
    !

    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                 :: izerror,                             &
                                                  ista,iobs,nk,np,m,n,o,i,j,k,io,jo,ko
    REAL    (KIND = ireals)                    ::                                      &
                                                  z_radar(ie,je,ke),                   &
                                                  z_ext(ie,je,ke),                     &
                                                  wi,wj,wk,                            & ! interpolation weight in i,j,k-direction
                                                  zz111, zz211, zz121, zz221,          & 
                                                  zz112, zz212, zz122, zz222,     &
                                                  ee111, ee211, ee121, ee221,     & 
                                                  ee112, ee212, ee122, ee222

    !- End of header
    !==============================================================================


    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_reflectivity
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_mod_reflectivity'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! calculate reflectivity on the model grid for this radar station:
      IF (ldebug_radsim) WRITE (*,*)  'calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista, ' ...'
      z_radar = -99.99_ireals
      z_ext = 0.0_ireals
      CALL calc_dbz_vec(itlrad, dbz_meta(ista), z_radar=z_radar, z_ext=z_ext)
      ! convert dBZ to linear unit mm^6/m^3:
      WHERE (z_radar >= -90.0_ireals)
        z_radar = 10.0_ireals**(0.1_ireals*z_radar)
      ELSEWHERE
        z_radar = 0.0_ireals
      END WHERE
      IF (ltime) CALL get_timings (i_radar_compgrid, ntstep, dt, izerror)
      IF (ldebug_radsim) WRITE (*,*)  'done with calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista

      ! allocate array of model reflectivities:
      ALLOCATE(rs_data(ista)%z_radar_mod(rs_data(ista)%nobs))
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(rs_data(ista)%z_ext_mod(rs_data(ista)%nobs))
      END IF

      ! Set data points below surface to -988.88:
      DO iobs = rs_data(ista)%nobs_above_sfc+1, rs_data(ista)%nobs
        rs_data(ista)%z_radar_mod(iobs) = -988.88
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          rs_data(ista)%z_ext_mod(iobs)   = -988.88
        END IF
      END DO

      ! Loop over observation points above SFC:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs_above_sfc

        ! for each radar point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp(iobs,1)

        ! determine model grid point south-west and above of radar grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1

        ! determine interpolation weights
        wi = rs_data(ista)%w_intp(iobs,1)
        wj = rs_data(ista)%w_intp(iobs,2)
        wk = rs_data(ista)%w_intp(iobs,3)

        ! interpolate Z (mm^6/m^3) of the 8 surrounding mass points trilinearly to the radar point
        io = MIN(i+1,ie)
        jo = MIN(j+1,je)
        ko = MIN(k+1,ke)

        zz111 = z_radar(i ,j ,k )
        zz211 = z_radar(io,j ,k )
        zz121 = z_radar(i ,jo,k )
        zz221 = z_radar(io,jo,k )
        zz112 = z_radar(i ,j ,ko)
        zz212 = z_radar(io,j ,ko)
        zz122 = z_radar(i ,jo,ko)
        zz222 = z_radar(io,jo,ko)

        rs_data(ista)%z_radar_mod(iobs) = ((zz111*(1.0_ireals-wi) + zz211*wi)*(1.0_ireals-wj) + &
             (zz121*(1.0_ireals-wi) + zz221*wi)*wj)*(1.0_ireals-wk) + &
             ((zz112*(1.0_ireals-wi) + zz212*wi)*(1.0_ireals-wj) + &
             (zz122*(1.0_ireals-wi) + zz222*wi)*wj)*wk

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN

          ee111 = z_ext(i ,j ,k )
        !  if (z_ext(i,j,k) /= 0.0_ireals) write(*,*) 'z_ext1 = ',z_ext(i ,j ,k )
          ee211 = z_ext(io,j ,k )
          ee121 = z_ext(i ,jo,k )
          ee221 = z_ext(io,jo,k )
          ee112 = z_ext(i ,j ,ko)
          ee212 = z_ext(io,j ,ko)
          ee122 = z_ext(i ,jo,ko)
          ee222 = z_ext(io,jo,ko)

          rs_data(ista)%z_ext_mod(iobs) = &
               ((ee111*(1.0_ireals-wi) + ee211*wi)*    (1.0_ireals-wj) + &
                (ee121*(1.0_ireals-wi) + ee221*wi)*wj)*(1.0_ireals-wk) + &
               ((ee112*(1.0_ireals-wi) + ee212*wi)*    (1.0_ireals-wj) + &
                (ee122*(1.0_ireals-wi) + ee222*wi)*wj)*wk

        END IF

      END DO    ! loop over radar points

      IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id    

  END SUBROUTINE calc_mod_reflectivity


  SUBROUTINE calc_mod_reflectivity_smth(lcalc,time_mod)

    !--------------------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the radar reflectivity at smoothing points for each
    !              radar station. Output values are in linear space, not logarithmic (dBZ)!
    !
    ! Method:
    !
    !--------------------------------------------------------------------------------------------
    !

    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg


    INTEGER (KIND = iintegers)                 :: ista,i,j,k,m,n,o,offset_i,offset_j,izerror,&
         nk,np,ii,jj,kk,iu,io,ju,jo,ku,ko,iv,ih,ismth
    REAL    (KIND = ireals)                    :: wi_smth,                        & !
         wj_smth,                        & !
         wk_smth                           !
    REAL    (KIND = ireals)                    ::                                 &
         z_radar(ie,je,ke),              &
         z_ext(ie,je,ke),                &
         zz111, zz211, zz121, zz221,     &
         zz112, zz212, zz122, zz222,     &
         ee111, ee211, ee121, ee221,     & 
         ee112, ee212, ee122, ee222

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_reflectivity_smth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine = 'calc_mod_reflectivity_smth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! calculate reflectivity on the model grid for this radar station:
      IF (ldebug_radsim) WRITE (*,*)  'calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista, ' ...'
      z_radar = -99.99_ireals
      z_ext = 0.0_ireals
      CALL calc_dbz_vec(itlrad, dbz_meta(ista), z_radar=z_radar, z_ext=z_ext)
      ! convert dBZ to linear unit mm^6/m^3:
      WHERE (z_radar >= -90.0_ireals)
        z_radar = 10.0_ireals**(0.1_ireals*z_radar)
      ELSEWHERE
        z_radar = 0.0_ireals
      END WHERE
      IF (ltime) CALL get_timings (i_radar_compgrid, ntstep, dt, izerror)
      IF (ldebug_radsim) WRITE (*,*)  'done with calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista

      ! allocate array of model reflectivities:
      ALLOCATE(rs_data(ista)%z_radar_mod_smth(rs_data(ista)%nsmth))
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(rs_data(ista)%z_ext_mod_smth(rs_data(ista)%nsmth)) 
      ENDIF

      ! Set data points below surface to -988.88 (back side of the vectors):
      DO ismth = rs_data(ista)%nsmth_above_sfc+1, rs_data(ista)%nsmth
        rs_data(ista)%z_radar_mod_smth(ismth) = -988.88
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          rs_data(ista)%z_ext_mod_smth(ismth)   = -988.88
        END IF
      END DO

      ! loop over all smoothing points
!CDIR NODEP,VOVERTAKE,VOB
      DO ismth = 1, rs_data(ista)%nsmth_above_sfc

        ! for each smoothing point determine the continuous number nk of the grid cube
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp_smth(ismth,1)

        ! determine model grid point south-west and above of radar grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1

        ! determine interpolation weights
        wi_smth = rs_data(ista)%w_intp_smth(ismth,1)
        wj_smth = rs_data(ista)%w_intp_smth(ismth,2)
        wk_smth = rs_data(ista)%w_intp_smth(ismth,3)

        ! interpolate Z (mm^6/m^3) of the 8 surrounding mass points trilinearly to the radar point
        io = MIN(i+1,ie)
        jo = MIN(j+1,je)
        ko = MIN(k+1,ke)

        zz111 = z_radar(i ,j ,k )
        zz211 = z_radar(io,j ,k )
        zz121 = z_radar(i ,jo,k )
        zz221 = z_radar(io,jo,k )
        zz112 = z_radar(i ,j ,ko)
        zz212 = z_radar(io,j ,ko)
        zz122 = z_radar(i ,jo,ko)
        zz222 = z_radar(io,jo,ko)

        rs_data(ista)%z_radar_mod_smth(ismth) = ((zz111*(1.0_ireals-wi_smth) + zz211*wi_smth)*(1.0_ireals-wj_smth) + &
             (zz121*(1.0_ireals-wi_smth) + zz221*wi_smth)*wj_smth)*(1.0_ireals-wk_smth) + &
             ((zz112*(1.0_ireals-wi_smth) + zz212*wi_smth)*(1.0_ireals-wj_smth) + &
             (zz122*(1.0_ireals-wi_smth) + zz222*wi_smth)*wj_smth)*wk_smth

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN

          ee111 = z_ext(i ,j ,k )
          ee211 = z_ext(io,j ,k )
          ee121 = z_ext(i ,jo,k )
          ee221 = z_ext(io,jo,k )
          ee112 = z_ext(i ,j ,ko)
          ee212 = z_ext(io,j ,ko)
          ee122 = z_ext(i ,jo,ko)
          ee222 = z_ext(io,jo,ko)

          rs_data(ista)%z_ext_mod_smth(ismth) = &
               ((ee111*(1.0_ireals-wi_smth) + ee211*wi_smth)*         (1.0_ireals-wj_smth) + &
               (ee121*(1.0_ireals-wi_smth) + ee221*wi_smth)*wj_smth)*(1.0_ireals-wk_smth) + &
               ((ee112*(1.0_ireals-wi_smth) + ee212*wi_smth)*         (1.0_ireals-wj_smth) + &
               (ee122*(1.0_ireals-wi_smth) + ee222*wi_smth)*wj_smth)*wk_smth
        END IF

      END DO    ! loop over radar points

      IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with calc_mod_reflectivity_smth() on proc ', my_cart_id

  END SUBROUTINE calc_mod_reflectivity_smth


  !===================================================================================
  !+ Module procedure in src_radar for the computation of the model radar reflectivity
  !  under consideration of dynamical propagation path
  !-----------------------------------------------------------------------------------
  SUBROUTINE calc_mod_reflectivity_online(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radial reflectivity for each 
    !              radar station by 
    !              - bilinear interpolation of u,v and w to radar points
    !              - projection onto radar beam
    !
    ! Input and output values are in linear space, not logarithmic (dBZ)!
    !
    ! Method:      Following Jaervinen et al., 2009, Tellus
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                :: ista,igrd,nobsmax,nobs,i,j,k,m,n,o,offset_i,offset_j,iobs,nk,np,no,ko
    INTEGER (KIND = iintegers)                :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)                   ::                    &  
                                                 wl                ,& ! interpolation weight in i-direction
                                                 wk                ,& ! interpolation weight in j-direction
                                                 z11, z21, z12, z22,&
                                                 ! de:
                                                 e11, e21, e12, e22
                                                 ! de.

    ! de: add z_ext_azgrd(:,:,:)
    REAL    (KIND = ireals), ALLOCATABLE      ::  z_radar_azgrd(:,:,:), z_ext_azgrd(:,:,:)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_reflectivity_online
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'calc_mod_reflectivity_online'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! 1 line of overlap at the lower azimut index end!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      ALLOCATE(z_radar_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
!!$ UB>> Initialize with standard missing value (= point outside model domain):
      z_radar_azgrd = -999.99_ireals
      ! de:
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(z_ext_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
!!$ UB>> Initialize with standard missing value (= point outside model domain):
        z_ext_azgrd = -999.99_ireals
      END IF
      ! de.
  
      !sort the collected smoothing points data into 3d field according to sorted azimuth, arc length, height.
!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1

        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        z_radar_azgrd(m,n,k) = rs_grid(ista)%z_radar_azgrd(igrd)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          z_ext_azgrd(m,n,k) = rs_grid(ista)%z_ext_azgrd(igrd)
        END IF

      ENDDO

      ! allocate array of model reflectivity & extinction
      ALLOCATE(rs_data(ista)%z_radar_mod(rs_data(ista)%nobs))
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(rs_data(ista)%z_ext_mod(rs_data(ista)%nobs))
      END IF

      ! loop over observation points
      ! UB>> loop rewritten due to vectorisation:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs

        ! for each radar point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp(iobs,1)

        ! for each radar point determine the continuous number np of radar points
        np = rs_data(ista)%ind_intp(iobs,2)

        ! determine indices for interpolation grids in atimuthal, arc length, vertical direction for current radar point
        m  = MOD(nk-1,rs_meta(ista)%naz) + 1 + nbl_az
        n  = MOD(INT(REAL(nk-1,ireals) / &
             REAL(rs_meta(ista)%naz,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(nk-1,ireals) / &
             (REAL(rs_meta(ista)%naz,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        ! determine interpolation weights
        wl = rs_data(ista)%w_intp(iobs,1)
        wk = rs_data(ista)%w_intp(iobs,2)

        no= MIN(n+1,rs_grid(ista)%nal+1) 
        ko= MIN(k+1,ke)

        z11 = z_radar_azgrd(m,n,k)
        z21 = z_radar_azgrd(m,no,k)
        z12 = z_radar_azgrd(m,n,ko)
        z22 = z_radar_azgrd(m,no,ko)

        ! If the value on a grid point is missing, it will be replaced by value from the horizontal symmetric grid point;
        ! If both value are missing, neglect these two points while intepolation
        IF (z11 < -900.0_ireals .AND. z21 >= -900.0_ireals)     THEN
          z11 = z21
        ELSEIF (z11 >= -900.0_ireals .AND. z21 < -900.0_ireals) THEN
          z21 = z11
        ELSEIF (z11 < -900.0_ireals .AND. z21 < -900.0_ireals) THEN
          wk = 1.0
        ELSE
          CONTINUE
        ENDIF


        IF (z12 < -900.0_ireals .AND. z22 >= -900.0_ireals)     THEN
          z12 = z22
        ELSEIF (z12 >= -900.0_ireals .AND. z22 < -900.0_ireals) THEN
          z22 = z12
        ELSEIF (z12 < -900.0_ireals .AND. z22 < -900.0_ireals) THEN
          wk = 0.0
        ELSE
          CONTINUE
        ENDIF

        rs_data(ista)%z_radar_mod(iobs) = (z11*(1.0_ireals-wl)+z21*wl)*(1.0_ireals - wk) + (z12*(1.0_ireals-wl)+z22*wl)*wk

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          e11 = z_ext_azgrd(m,n,k)
          e21 = z_ext_azgrd(m,no,k)
          e12 = z_ext_azgrd(m,n,ko)
          e22 = z_ext_azgrd(m,no,ko)

          ! If the value on a grid point is missing, it will be replaced by value from the horizontal symmetric grid point;
          ! If both value are missing, neglect these two points while intepolation
          IF (e11 < -900.0_ireals .AND. e21 >= -900.0_ireals)     THEN
            e11 = e21
          ELSEIF (e11 >= -900.0_ireals .AND. e21 < -900.0_ireals) THEN
            e21 = e11
          ELSEIF (e11 < -900.0_ireals .AND. e21 < -900.0_ireals) THEN
            wk = 1.0
          ELSE
            CONTINUE
          ENDIF


          IF (e12 < -900.0_ireals .AND. e22 >= -900.0_ireals)     THEN
            e12 = e22
          ELSEIF (e12 >= -900.0_ireals .AND. e22 < -900.0_ireals) THEN
            e22 = e12
          ELSEIF (e12 < -900.0_ireals .AND. e22 < -900.0_ireals) THEN
            wk = 0.0
          ELSE
            CONTINUE
          ENDIF

          rs_data(ista)%z_ext_mod(iobs) = (e11*(1.0_ireals-wl)+e21*wl)*(1.0_ireals - wk) + &
                                          (e12*(1.0_ireals-wl)+e22*wl)*wk

        END IF

      END DO    ! loop over radar points
      
      IF (rs_data(ista)%nobs > 0) THEN
        WRITE(*,*)"max of z_radar_mod",MAXVAL(rs_data(ista)%z_radar_mod)
        WRITE(*,*)"min of z_radar_mod",MINVAL(rs_data(ista)%z_radar_mod)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          WRITE(*,*)"max of z_ext_mod",MAXVAL(rs_data(ista)%z_ext_mod)
          WRITE(*,*)"min of z_ext_mod",MINVAL(rs_data(ista)%z_ext_mod)
        END IF
      END IF
    
      DEALLOCATE(z_radar_azgrd)
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) DEALLOCATE(z_ext_azgrd)
 
    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_mod_reflectivity_online


  !=======================================================================================================
  !+ Module procedure in src_radar for the computation of the model radar reflectivity at smoothing points
  !  under consideration of dynamical propagation path
  !-------------------------------------------------------------------------------------------------------
  SUBROUTINE calc_mod_reflectivity_onsmth(lcalc,time_mod)

    !---------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the model radar reflectivity for each 
    !              radar station by 
    !              - trilinear interpolation of radar reflectivity to smoothing points.
    ! Input and output values are in linear space, not logarithmic (dBZ)!
    !
    !---------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                :: istart(0:num_compute-1),iend(0:num_compute-1)

    INTEGER (KIND = iintegers)                :: ista,igrd,nobsmax,ismth,i,j,k,m,n,o,offset_i,offset_j,iobs,nk,mo,no,ko
    REAL    (KIND = ireals)                   ::      &  
         wa  ,& ! interpolation weight in i-direction
         wl  ,& ! interpolation weight in j-direction
         wk  ,& 
         z111, z211, z121, z221, z112, z212, z122, z222, &
         ! de:
         e111, e211, e121, e221, e112, e212, e122, e222
         ! de.

    ! de: add z_ext_azgrd(:,:,:)
    REAL    (KIND = ireals), ALLOCATABLE      :: z_radar_azgrd(:,:,:),z_ext_azgrd(:,:,:)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_mod_reflectivity_onsmth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'calc_mod_reflectivity_onsmth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! 1 line of overlap at the lower azimut index end!
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)

      ALLOCATE(z_radar_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
!!$ UB>> Initialize with standard missing value (= point outside model domain):
      z_radar_azgrd = -999.99_ireals

      ! de:
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(z_ext_azgrd(istart(my_cart_id):iend(my_cart_id),rs_grid(ista)%nal+1,ke))
!!$ UB>> Initialize with standard missing value (= point outside model domain):
        z_ext_azgrd = -999.99_ireals
      END IF
      ! de.

      !sort the collected smoothing points data into 3d filed according to sorted azimuth, arc length, heigh
!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, size(rs_grid(ista)%ind_azgrd)

        ! determine indices in az, al, hl direction for current grid point
        m  = MOD(rs_grid(ista)%ind_azgrd(igrd)-1,rs_grid(ista)%naz_nbl) + 1

        n  = MOD(INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(rs_grid(ista)%ind_azgrd(igrd)-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        z_radar_azgrd(m,n,k) = rs_grid(ista)%z_radar_azgrd(igrd)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          z_ext_azgrd(m,n,k) = rs_grid(ista)%z_ext_azgrd(igrd)
        END IF

      ENDDO

      ! allocate array of model radial winds
      ALLOCATE(rs_data(ista)%z_radar_mod_smth(rs_data(ista)%nsmth))
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(rs_data(ista)%z_ext_mod_smth(rs_data(ista)%nsmth))
      END IF

      ! loop over observation points
      ! UB>> loop rewritten due to vectorisation:
!CDIR NODEP,VOVERTAKE,VOB
      DO ismth = 1, rs_data(ista)%nsmth

        ! for each radar point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_data(ista)%ind_intp_smth(ismth,1)

        m  = MOD(nk-1,rs_grid(ista)%naz_nbl) + 1
        n  = MOD(INT(REAL(nk-1,ireals) / &
             REAL(rs_grid(ista)%naz_nbl,ireals),iintegers), rs_grid(ista)%nal+1) + 1
        k  = INT(REAL(nk-1,ireals) / &
             (REAL(rs_grid(ista)%naz_nbl,ireals)*REAL(rs_grid(ista)%nal+1,ireals)),iintegers) + 1

        mo= MIN(m+1,iend(my_cart_id))
        no= MIN(n+1,rs_grid(ista)%nal+1) 
        ko= MIN(k+1,ke)

        ! If the value on a grid point is missing -999.99 (i.e., is outside the model domain), 
        ! it will be replaced by VALUE from the horizontal symmetric grid point;
        ! If both values are missing, neglect these two points while interpolation
        z111 = z_radar_azgrd(m,n,k)
        z211 = z_radar_azgrd(mo,n,k)
        z121 = z_radar_azgrd(m,no,k)
        z221 = z_radar_azgrd(mo,no,k)
        z112 = z_radar_azgrd(m,n,ko)
        z212 = z_radar_azgrd(mo,n,ko)
        z122 = z_radar_azgrd(m,no,ko)
        z222 = z_radar_azgrd(mo,no,ko)

        wa = rs_data(ista)%w_intp_smth(ismth,1)
        wl = rs_data(ista)%w_intp_smth(ismth,2)
        wk = rs_data(ista)%w_intp_smth(ismth,3)

        IF (z111 < -900.0_ireals .AND. z211 >= -900.0_ireals)     THEN
          z111 = z211
        ELSEIF (z111 >= -900.0_ireals .AND. z211 < -900.0_ireals) THEN
          z211 = z111
        ELSEIF (z111 < -900.0_ireals .AND. z211 < -900.0_ireals) THEN
          wl = 1.0
        ELSE
          CONTINUE
        ENDIF

        IF (z121 < -900.0_ireals .AND. z221 >= -900.0_ireals)     THEN
          z121 = z221
        ELSEIF (z121 >= -900.0_ireals .AND. z221 < -900.0_ireals) THEN
          z221 = z121
        ELSEIF (z121 < -900.0_ireals .AND. z221 < -900.0_ireals) THEN
          wl = 0.0
        ELSE
          CONTINUE
        ENDIF

        IF (z112 < -900.0_ireals .AND. z212 >= -900.0_ireals)     THEN
          z112 = z212
        ELSEIF (z112 >= -900.0_ireals .AND. z212 < -900.0_ireals) THEN
          z212 = z112
        ELSEIF (z112 < -900.0_ireals .AND. z212 < -900.0_ireals) THEN
          wl = 1.0
        ELSE
          CONTINUE
        ENDIF

        IF (z122 < -900.0_ireals .AND. z222 >= -900.0_ireals)     THEN
          z122 = z222
        ELSEIF (z122 >= -900.0_ireals .AND. z222 < -900.0_ireals) THEN
          z222 = z122
        ELSEIF (z122 < -900.0_ireals .AND. z222 < -900.0_ireals) THEN
          wl = 0.0
        ELSE
          CONTINUE
        ENDIF

        IF (z111 < -900.0_ireals .OR. z211 <  -900.0_ireals .OR. &
            z121 < -900.0_ireals .OR. z221 <  -900.0_ireals .OR. &
            z112 < -900.0_ireals .OR. z212 <  -900.0_ireals .OR. &
            z122 < -900.0_ireals .OR. z222 <  -900.0_ireals) THEN
         
          rs_data(ista)%z_radar_mod_smth(ismth) =   -999.99_ireals

          CYCLE

        ENDIF

        rs_data(ista)%z_radar_mod_smth(ismth) = ((z111*(1.0_ireals-wa)+z211*wa)*(1.0_ireals - wl)   + &
                                                 (z121*(1.0_ireals-wa)+z221*wa)*wl)*(1.0_ireals-wk) + &
                                                ((z112*(1.0_ireals-wa)+z212*wa)*(1.0_ireals - wl)   + &
                                                 (z122*(1.0_ireals-wa)+z222*wa)*wl)*wk

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN

          ! If the value on a grid point is missing, it will be replaced by value from the horizontal symmetric grid point;
          ! If both value are missing, neglect these two points while intepolation
          e111 = z_ext_azgrd(m,n,k)
          e211 = z_ext_azgrd(mo,n,k)
          e121 = z_ext_azgrd(m,no,k)
          e221 = z_ext_azgrd(mo,no,k)
          e112 = z_ext_azgrd(m,n,ko)
          e212 = z_ext_azgrd(mo,n,ko)
          e122 = z_ext_azgrd(m,no,ko)
          e222 = z_ext_azgrd(mo,no,ko)

!!$ UB Missing values umgestellt auf -999.99 (outside model domain), sonst
!!$    ists am Rand mit den "normalen" 0en unsauber...
!!$ Vermutlich sind die folgenden exxx dieselben wie die zxxx oben...

          IF (e111 < -900.0_ireals .AND. e211 >= -900.0_ireals)     THEN
            e111 = e211
          ELSEIF (e111 >= -900.0_ireals .AND. e211 < -900.0_ireals) THEN
            e211 = e111
          ELSEIF (e111 < -900.0_ireals .AND. e211 < -900.0_ireals) THEN
            wl = 1.0
          Else
            CONTINUE
          ENDIF

          IF (e121 < -900.0_ireals .AND. e221 >= -900.0_ireals)     THEN
            e121 = e221
          ELSEIF (e121 >= -900.0_ireals .AND. e221 < -900.0_ireals) THEN
            e221 = e121
          ELSEIF (e121 < -900.0_ireals .AND. e221 < -900.0_ireals) THEN
            wl = 0.0
          ELSE
            CONTINUE
          ENDIF

          IF (e112 < -900.0_ireals .AND. e212 >= -900.0_ireals)     THEN
            e112 = e212
          ELSEIF (e112 >= -900.0_ireals .AND. e212 < -900.0_ireals) THEN
            e212 = e112
          ELSEIF (e112 < -900.0_ireals .AND. e212 < -900.0_ireals) THEN
            wl = 1.0
          ELSE
            CONTINUE
          ENDIF

          IF (e122 < -900.0_ireals .AND. e222 >= -900.0_ireals)     THEN
            e122 = e222
          ELSEIF (e122 >= -900.0_ireals .AND. e222 < -900.0_ireals) THEN
            e222 = e122
          ELSEIF (e122 < -900.0_ireals .AND. e222 < -900.0_ireals) THEN
            wl = 0.0
          ELSE
            CONTINUE
          ENDIF

          rs_data(ista)%z_ext_mod_smth(ismth) = ((e111*(1.0_ireals-wa)+e211*wa)*(1.0_ireals - wl)   + &
                                                 (e121*(1.0_ireals-wa)+e221*wa)*wl)*(1.0_ireals-wk) + &
                                                ((e112*(1.0_ireals-wa)+e212*wa)*(1.0_ireals - wl)   + &
                                                 (e122*(1.0_ireals-wa)+e222*wa)*wl)*wk
        END IF ! lextdbz

      END DO    ! loop over radar points

      IF (rs_data(ista)%nsmth > 0) THEN
        WRITE(*,*)"max of z_radar_mod",MAXVAL(rs_data(ista)%z_radar_mod_smth)
        WRITE(*,*)"min of z_radar_mod",MINVAL(rs_data(ista)%z_radar_mod_smth)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          WRITE(*,*)"max of z_ext_mod",MAXVAL(rs_data(ista)%z_ext_mod_smth)
          WRITE(*,*)"min of z_ext_mod",MINVAL(rs_data(ista)%z_ext_mod_smth)
        END IF
      END IF

      DEALLOCATE(z_radar_azgrd)
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) DEALLOCATE(z_ext_azgrd)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_mod_reflectivity_onsmth


  !================================================================================================
  !+ Module procedure in src_radar for the computation of the radar reflectivity at auxiliary grids
  !------------------------------------------------------------------------------------------------
  SUBROUTINE calc_grd_reflectivity(lcalc,time_mod)

    !-------------------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the radar reflectivity at auxiliary grids for each 
    !              radar station. Output values are in linear space, not logarithmic (dBZ)!
    !
    ! Method:
    !
    !-------------------------------------------------------------------------------------------
    !

    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                 :: ista,igrd,nk,np,izerror,m,n,o,&
         i,j,k,io,jo,ko,flag
    REAL    (KIND = ireals)                    :: z_radar(ie,je,ke),              &
         z_ext(ie,je,ke),                &
         wi,wj,wk,                       & ! interpolation weight in i,j,k-direction
         zz11, zz21, zz12, zz22,         &
         ee11, ee21, ee12, ee22

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_grd_reflectivity
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_grd_reflectivity'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! calculate reflectivity on the model grid for this radar station:
      IF (ldebug_radsim) WRITE (*,*)  'calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista, ' ...'
      z_radar = -99.99_ireals
      z_ext = 0.0_ireals
      CALL calc_dbz_vec(itlrad, dbz_meta(ista), z_radar=z_radar, z_ext=z_ext)
      ! convert dBZ to linear unit mm^6/m^3:
      WHERE (z_radar >= -90.0_ireals)
        z_radar = 10.0_ireals**(0.1_ireals*z_radar)
      ELSEWHERE
        z_radar = 0.0_ireals
      END WHERE
      IF (ltime) CALL get_timings (i_radar_compgrid, ntstep, dt, izerror)
      IF (ldebug_radsim) WRITE (*,*)  'done with calc_dbz_vec() on proc ', my_cart_id, ' for station ', ista

      ! allocate array of reflectivities at auxiliary grids:
      ALLOCATE(rs_grid(ista)%z_radar_grd(rs_grid(ista)%ngrd))
      IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
        ALLOCATE(rs_grid(ista)%z_ext_grd(rs_grid(ista)%ngrd))
      END IF

      ! loop over observation points
!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, rs_grid(ista)%ngrd

        ! for each grid point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_grid(ista)%ind_intp(igrd,1)

        ! ZY >> 
        ! for each grid point determine the continuous number np of grid points
        np = rs_grid(ista)%ind_intp(igrd,2)

        ! ZY <<

        ! determine model grid point south-west and above of radar grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1
        
        ! determine interpolation weights
        wi = rs_grid(ista)%w_intp(igrd,1)
        wj = rs_grid(ista)%w_intp(igrd,2)
        
        ! interpolate Z (mm^6/m^3) of the 8 surrounding mass points trilinearly to the radar point
        io = MIN(i+1,ie)
        jo = MIN(j+1,je)
        
        zz11 = z_radar(i ,j ,k )
        zz21 = z_radar(io,j ,k )
        zz12 = z_radar(i ,jo,k )
        zz22 = z_radar(io,jo,k )
        
        rs_grid(ista)%z_radar_grd(igrd) =  (zz11*(1.0_ireals-wi) + zz21*wi)*(1.0_ireals-wj) + &
             (zz12*(1.0_ireals-wi) + zz22*wi)*wj
        
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          ee11 = z_ext(i ,j ,k )
          ee21 = z_ext(io,j ,k )
          ee12 = z_ext(i ,jo,k )
          ee22 = z_ext(io,jo,k )
          
          rs_grid(ista)%z_ext_grd(igrd) =  (ee11*(1.0_ireals-wi) + ee21*wi)*(1.0_ireals-wj) + &
               (ee12*(1.0_ireals-wi) + ee22*wi)*wj
        END IF
        
      END DO    ! loop over radar points
      
      IF (rs_grid(ista)%ngrd > 0) THEN
        WRITE(*,*)"max of z_radar_grd",MAXVAL(rs_grid(ista)%z_radar_grd)
        WRITE(*,*)"min of z_radar_grd",MINVAL(rs_grid(ista)%z_radar_grd)

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          WRITE(*,*)"max of z_ext_grd",MAXVAL(rs_grid(ista)%z_ext_grd)
          WRITE(*,*)"min of z_ext_grd",MINVAL(rs_grid(ista)%z_ext_grd)
        END IF
      END IF

      IF (ltime) CALL get_timings (i_radar_comppolar, ntstep, dt, izerror)

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id    

  END SUBROUTINE calc_grd_reflectivity


  !================================================================================================
  !+ Module procedure in src_radar for the computation of the refraction indices at auxiliary grids
  !------------------------------------------------------------------------------------------------
  SUBROUTINE calc_grd_rfridx(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the refraction indices for each 
    !              radar station.
    !
    ! Method:
    !
    !------------------------------------------------------------------------------
    !

    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)                 :: ista,igrd,nk,np,m,n,o,i,j,k,io,jo,ko,ku
    REAL    (KIND = ireals)                    :: z_radar(ie,je,ke),                      &
         wi,wj,wk,                               & ! interpolation weight in i,j,k-direction
         tt11, tt21, tt12, tt22,                 &
         pp11, pp21, pp12, pp22,                 &
         ee11, ee21, ee12, ee22,                 &
         t_gp, p_gp, e_gp,                       &
         rfridx_grd,rfridx_up,rfridx_low,        &
         hfl_up,hfl_low,hfl11,hfl12,hfl21,hfl22 
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_grd_rfridx
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_grd_rfridx'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! loop over radar stations
    DO ista = 1,nradsta

      ! decide if current radar station shall be output at this time step
      IF (.NOT.lcalc(ista)) CYCLE

      ! allocate array of refraction indices at auxiliary grids :
      ALLOCATE(rs_grid(ista)%rfridx_grd(rs_grid(ista)%ngrd))

      ! loop over observation points
!CDIR NODEP,VOVERTAKE,VOB
      DO igrd = 1, rs_grid(ista)%ngrd

        ! for each grid point determine the continuous number nk of the grid cube 
        ! surrounded by the 8 nearest model grid points
        nk = rs_grid(ista)%ind_intp(igrd,1)

        ! for each grid point determine the continuous number np of grid points
        np = rs_grid(ista)%ind_intp(igrd,2)

        ! determine model grid point south-west and above of radar grid point
        i = MOD(nk-1,ie) + 1
        j = MOD(INT(REAL(nk-1,ireals)/REAL(ie,ireals),iintegers),je) + 1
        k = INT(REAL(nk-1,ireals)/(REAL(ie,ireals)*REAL(je,ireals)),iintegers) + 1

        ! determine interpolation weights
        wi = rs_grid(ista)%w_intp(igrd,1)
        wj = rs_grid(ista)%w_intp(igrd,2)
        
        ! interpolate Z (mm^6/m^3) of the 8 surrounding mass points trilinearly to the radar point
        io = MIN(i+1,ie)
        jo = MIN(j+1,je)
        ko = MIN(k+1,ke)
        ku = MAX(1,k-1)

        tt11 = t(i ,j ,k ,itlrad)
        tt21 = t(io,j ,k ,itlrad)
        tt12 = t(i ,jo,k ,itlrad)
        tt22 = t(io,jo,k ,itlrad)
        
        pp11 = pp(i ,j ,k,itlrad) + p0(i ,j ,k)
        pp21 = pp(io,j ,k,itlrad) + p0(io,j ,k)
        pp12 = pp(i ,jo,k,itlrad) + p0(i ,jo,k)
        pp22 = pp(io,jo,k,itlrad) + p0(io,jo,k)
        
        ee11 = rho(i ,j ,k) * qv(i ,j ,k,itlrad) * r_v * t(i ,j ,k,itlrad)
        ee21 = rho(io,j ,k) * qv(io,j ,k,itlrad) * r_v * t(io,j ,k,itlrad)
        ee12 = rho(i ,jo,k) * qv(i ,jo,k,itlrad) * r_v * t(i ,jo,k,itlrad)
        ee22 = rho(io,jo,k) * qv(io,jo,k,itlrad) * r_v * t(io,jo,k,itlrad)
        
        t_gp =  (tt11*(1.0_ireals-wi) + tt21*wi)*(1.0_ireals-wj) + &
                (tt12*(1.0_ireals-wi) + tt22*wi)*wj

        p_gp =  (pp11*(1.0_ireals-wi) + pp21*wi)*(1.0_ireals-wj) + &
                (pp12*(1.0_ireals-wi) + pp22*wi)*wj

        e_gp =  (ee11*(1.0_ireals-wi) + ee21*wi)*(1.0_ireals-wj) + &
                (ee12*(1.0_ireals-wi) + ee22*wi)*wj

        rfridx_grd = 1.0 + (77.6/100.0*p_gp/t_gp - 6.0/100.0*e_gp/t_gp + &
                     3.75E+03*e_gp/(t_gp**2))*1d-6


        IF (lsode) THEN
          !for onlinenew
          
          tt11 = t(i ,j ,ko ,itlrad)
          tt21 = t(io,j ,ko ,itlrad)
          tt12 = t(i ,jo,ko ,itlrad)
          tt22 = t(io,jo,ko ,itlrad)

          pp11 = pp(i ,j ,ko,itlrad) + p0(i ,j ,ko)
          pp21 = pp(io,j ,ko,itlrad) + p0(io,j ,ko)
          pp12 = pp(i ,jo,ko,itlrad) + p0(i ,jo,ko)
          pp22 = pp(io,jo,ko,itlrad) + p0(io,jo,ko)

          ee11 = rho(i ,j ,ko) * qv(i ,j ,ko,itlrad) * r_v * t(i ,j ,ko,itlrad)
          ee21 = rho(io,j ,ko) * qv(io,j ,ko,itlrad) * r_v * t(io,j ,ko,itlrad)
          ee12 = rho(i ,jo,ko) * qv(i ,jo,ko,itlrad) * r_v * t(i ,jo,ko,itlrad)
          ee22 = rho(io,jo,ko) * qv(io,jo,ko,itlrad) * r_v * t(io,jo,ko,itlrad)

          t_gp =  (tt11*(1.0_ireals-wi) + tt21*wi)*(1.0_ireals-wj) + &
               (tt12*(1.0_ireals-wi) + tt22*wi)*wj

          p_gp =  (pp11*(1.0_ireals-wi) + pp21*wi)*(1.0_ireals-wj) + &
               (pp12*(1.0_ireals-wi) + pp22*wi)*wj

          e_gp =  (ee11*(1.0_ireals-wi) + ee21*wi)*(1.0_ireals-wj) + &
               (ee12*(1.0_ireals-wi) + ee22*wi)*wj


          rfridx_low = 1.0 + (77.6/100.0*p_gp/t_gp - 6.0/100.0*e_gp/t_gp + &
               3.75E+03*e_gp/(t_gp**2))*1d-6

          tt11 = t(i ,j ,ku ,itlrad)
          tt21 = t(io,j ,ku ,itlrad)
          tt12 = t(i ,jo,ku ,itlrad)
          tt22 = t(io,jo,ku ,itlrad)

          pp11 = pp(i ,j ,ku,itlrad) + p0(i ,j ,ku)
          pp21 = pp(io,j ,ku,itlrad) + p0(io,j ,ku)
          pp12 = pp(i ,jo,ku,itlrad) + p0(i ,jo,ku)
          pp22 = pp(io,jo,ku,itlrad) + p0(io,jo,ku)

          ee11 = rho(i ,j ,ku) * qv(i ,j ,ku,itlrad) * r_v * t(i ,j ,ku,itlrad)
          ee21 = rho(io,j ,ku) * qv(io,j ,ku,itlrad) * r_v * t(io,j ,ku,itlrad)
          ee12 = rho(i ,jo,ku) * qv(i ,jo,ku,itlrad) * r_v * t(i ,jo,ku,itlrad)
          ee22 = rho(io,jo,ku) * qv(io,jo,ku,itlrad) * r_v * t(io,jo,ku,itlrad)

          t_gp =  (tt11*(1.0_ireals-wi) + tt21*wi)*(1.0_ireals-wj) + &
               (tt12*(1.0_ireals-wi) + tt22*wi)*wj

          p_gp =  (pp11*(1.0_ireals-wi) + pp21*wi)*(1.0_ireals-wj) + &
               (pp12*(1.0_ireals-wi) + pp22*wi)*wj

          e_gp =  (ee11*(1.0_ireals-wi) + ee21*wi)*(1.0_ireals-wj) + &
               (ee12*(1.0_ireals-wi) + ee22*wi)*wj


          rfridx_up = 1.0 + (77.6/100.0*p_gp/t_gp - 6.0/100.0*e_gp/t_gp + &
               3.75E+03*e_gp/(t_gp**2))*1e-6

          hfl11 = 0.5*(hhl(i,j,ko)   + hhl(i,j,ko+1))
          hfl21 = 0.5*(hhl(io,j,ko)  + hhl(io,j,ko+1))
          hfl12 = 0.5*(hhl(i,jo,ko)  + hhl(i,jo,ko+1))
          hfl22 = 0.5*(hhl(io,jo,ko) + hhl(io,jo,ko+1))

          hfl_low = (hfl11*(1.0_ireals-wi) + hfl21*wi)*(1.0_ireals - wj) + &
               (hfl12*(1.0_ireals-wi) + hfl22*wi)*wj

          hfl11 = 0.5*(hhl(i,j,ku)   + hhl(i,j,ku+1))
          hfl21 = 0.5*(hhl(io,j,ku)  + hhl(io,j,ku+1))
          hfl12 = 0.5*(hhl(i,jo,ku)  + hhl(i,jo,ku+1))
          hfl22 = 0.5*(hhl(io,jo,ku) + hhl(io,jo,ku+1))

          hfl_up = (hfl11*(1.0_ireals-wi) + hfl21*wi)*(1.0_ireals - wj) + &
               (hfl12*(1.0_ireals-wi) + hfl22*wi)*wj

          ! for lsode
          rs_grid(ista)%rfridx_grd(igrd) = 1.0/rfridx_grd * ((rfridx_low - rfridx_up)/(hfl_low - hfl_up))

        ELSE
        
          ! for online
          rs_grid(ista)%rfridx_grd(igrd) = rfridx_grd

        END IF

      END DO    ! loop over radar points

      IF (rs_grid(ista)%ngrd > 0) THEN
        WRITE(*,*) "maxrfridx",MAXVAL(rs_grid(ista)%rfridx_grd)
        WRITE(*,*) "minrfridx",MINVAL(rs_grid(ista)%rfridx_grd)
      END IF

    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id    

  END SUBROUTINE calc_grd_rfridx


  !==============================================================================================
  !+ Module procedure in src_radar for the computation of the refraction indices at radar station
  !----------------------------------------------------------------------------------------------
  SUBROUTINE calc_sta_rfridx(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine calculates the refraction indices for each 
    !              radar station.
    !
    ! Method:
    !
    !------------------------------------------------------------------------------
    !

    ! Scalar arguments with intent(in):
    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) :: yzroutine
    CHARACTER (LEN=80) :: yzerrmsg 
    CHARACTER (LEN=8)  :: ci

    INTEGER (KIND = iintegers)                 :: ista,igrd,nk,np,m,n,o,i,j,k,io,jo,ko,ku,offset_i,offset_j,ierr

    REAL    (KIND = ireals)                    :: rlon_min,rlon_max,rlat_min,rlat_max,rlon_g0,rlat_g0,    &
         wi,wj,wk,                                               & ! interpolation weight in i,j,k-direction
         tt111, tt211, tt121, tt221, tt112, tt212, tt122, tt222, &
         pp111, pp211, pp121, pp221, pp112, pp212, pp122, pp222, &  
         ee111, ee211, ee121, ee221, ee112, ee212, ee122, ee222, &
         hfl11, hfl21, hfl12, hfl22,hfl_low,hfl_up,              &
         t_sta, p_sta, e_sta,                                    &
         rfridx_sta,rfridx_low,rfridx_up 

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE calc_sta_rfridx
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'calc_sta_rfridx'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    DO ista = 1,nradsta
      rs_grid(ista)%rfridx_sta = 999.99_ireals
    ENDDO

    ! loop over radar stations
    DO ista = 1,nradsta

      IF (.NOT.lcalc(ista)) CYCLE

      ! calculate min and max of rotated lat and lon of subdomain
      ! use whole domain, i.e. inclusive boundary zone at the border 
      ! of the total domain
      offset_i = nboundlines
      offset_j = nboundlines

      ! rotated longitude of western boundary
      rlon_min = startlon_tot + (isubpos(my_cart_id,1)-1)*dlon


      ! rotated longitude of eastern boundary
      rlon_max = startlon_tot + (isubpos(my_cart_id,3)-1)*dlon

      ! rotated latitude of southern boundary
      rlat_min = startlat_tot + (isubpos(my_cart_id,2)-1)*dlat


      ! rotated latitude of northern boundary
      rlat_max = startlat_tot + (isubpos(my_cart_id,4)-1)*dlat


      rlon_g0 = rla2rlarot(rs_meta(ista)%lat,rs_meta(ista)%lon,pollat,pollon,polgam)

      rlat_g0 = phi2phirot(rs_meta(ista)%lat,rs_meta(ista)%lon,pollat,pollon)


      ! cycle if radar station is not in local subdomain
      IF ((rlat_g0 >= rlat_min-0.5*dlat) .AND. &
           (rlat_g0 <= rlat_max+0.5*dlat) .AND. &
           (rlon_g0 >= rlon_min-0.5*dlon) .AND. &
           (rlon_g0 <= rlon_max+0.5*dlon)) THEN
        
        ! calculate indices of model point southwest of radar station
!!$        i = 1 + INT((rlon_g0 - rlon_min)/dlon,iintegers) + offset_i
!!$        j = 1 + INT((rlat_g0 - rlat_min)/dlat,iintegers) + offset_j
        i = MAX(1 + FLOOR((rlon_g0 - rlon_min)/dlon,iintegers) + offset_i, 1_iintegers)
        j = MAX(1 + FLOOR((rlat_g0 - rlat_min)/dlat,iintegers) + offset_j, 1_iintegers)

        ! compute interpolation weights in i and j direction
        wi = (rlon_g0-(rlon_min + (i-offset_i-1)*dlon))/dlon
        wi = MIN(MAX(wi,0.0_ireals),1.0_ireals)
        wj = (rlat_g0-(rlat_min + (j-offset_j-1)*dlat))/dlat
        wj = MIN(MAX(wj,0.0_ireals),1.0_ireals)

        ! calculate vertical index k above radar station and vertical interpolation weight wk
        CALL calc_vert_weight(rs_meta(ista)%alt_msl,hhl(i:i+1,j:j+1,1:ke+1),ke,wi,wj,k,wk)  

        IF (k >= 1) THEN

          ! interpolate Z (mm^6/m^3) of the 8 surrounding mass points trilinearly to the radar point
          io = MIN(i+1,ie)
          jo = MIN(j+1,je)
          ko = MIN(k+1,ke)

          tt111 = t(i ,j ,k ,itlrad) 
          tt211 = t(io,j ,k ,itlrad)
          tt121 = t(i ,jo,k ,itlrad)
          tt221 = t(io,jo,k ,itlrad)
          tt112 = t(i ,j ,ko,itlrad)
          tt212 = t(io,j ,ko,itlrad)
          tt122 = t(i ,jo,ko,itlrad)
          tt222 = t(io,jo,ko,itlrad)

          pp111 = pp(i ,j ,k ,itlrad) + p0(i ,j ,k ) 
          pp211 = pp(io,j ,k ,itlrad) + p0(io,j ,k )
          pp121 = pp(i ,jo,k ,itlrad) + p0(i ,jo,k )
          pp221 = pp(io,jo,k ,itlrad) + p0(io,jo,k )
          pp112 = pp(i ,j ,ko,itlrad)+ p0(i ,j ,ko)
          pp212 = pp(io,j ,ko,itlrad)+ p0(io,j ,ko)
          pp122 = pp(i ,jo,ko,itlrad)+ p0(i ,jo,ko)
          pp222 = pp(io,jo,ko,itlrad)+ p0(io,jo,ko)

          ee111 = rho(i ,j ,k ) * qv(i ,j ,k ,itlrad) * r_v * t(i ,j ,k ,itlrad)
          ee211 = rho(io,j ,k ) * qv(io,j ,k ,itlrad) * r_v * t(io,j ,k ,itlrad)
          ee121 = rho(i ,jo,k ) * qv(i ,jo,k ,itlrad) * r_v * t(i ,jo,k ,itlrad)
          ee221 = rho(io,jo,k ) * qv(io,jo,k ,itlrad) * r_v * t(io,jo,k ,itlrad)
          ee112 = rho(i ,j ,ko) * qv(i ,j ,ko,itlrad) * r_v * t(i ,j ,ko,itlrad)
          ee212 = rho(io,j ,ko) * qv(io,j ,ko,itlrad) * r_v * t(io,j ,ko,itlrad)
          ee122 = rho(i ,jo,ko) * qv(i ,jo,ko,itlrad) * r_v * t(i ,jo,ko,itlrad)
          ee222 = rho(io,jo,ko) * qv(io,jo,ko,itlrad) * r_v * t(io,jo,ko,itlrad)


          t_sta = ((tt111*(1.0_ireals-wi) + tt211*wi)*(1.0_ireals-wj) + &
               (tt121*(1.0_ireals-wi) + tt221*wi)*            wj)*(1.0_ireals-wk) + &
               ((tt112*(1.0_ireals-wi) + tt212*wi)*(1.0_ireals-wj) + &
               (tt122*(1.0_ireals-wi) + tt222*wi)*            wj)*wk


          p_sta = ((pp111*(1.0_ireals-wi) + pp211*wi)*(1.0_ireals-wj) + &
               (pp121*(1.0_ireals-wi) + pp221*wi)*            wj)*(1.0_ireals-wk) + &
               ((pp112*(1.0_ireals-wi) + pp212*wi)*(1.0_ireals-wj) + &
               (pp122*(1.0_ireals-wi) + pp222*wi)*            wj)*wk


          e_sta = ((ee111*(1.0_ireals-wi) + ee211*wi)*(1.0_ireals-wj) + &
               (ee121*(1.0_ireals-wi) + ee221*wi)*            wj)*(1.0_ireals-wk) + &
               ((ee112*(1.0_ireals-wi) + ee212*wi)*(1.0_ireals-wj) + &
               (ee122*(1.0_ireals-wi) + ee222*wi)*            wj)*wk


          rfridx_sta = 1.0 + (77.6/100.0*p_sta/t_sta - 6.0/100.0*e_sta/t_sta + &
               3.75E+03*e_sta/(t_sta**2))*1d-6


          IF (lsode) THEN

            t_sta = (tt111*(1.0_ireals-wi) + tt211*wi)*(1.0_ireals-wj) + &
                 (tt121*(1.0_ireals-wi) + tt221*wi)*            wj

            p_sta = (pp111*(1.0_ireals-wi) + pp211*wi)*(1.0_ireals-wj) + &
                 (pp121*(1.0_ireals-wi) + pp221*wi)*            wj

            e_sta = (ee111*(1.0_ireals-wi) + ee211*wi)*(1.0_ireals-wj) + &
                 (ee121*(1.0_ireals-wi) + ee221*wi)*            wj

            rfridx_up = 1.0 + (77.6/100.0*p_sta/t_sta - 6.0/100.0*e_sta/t_sta + &
                 3.75E+03*e_sta/(t_sta**2))*1d-6


            t_sta = (tt112*(1.0_ireals-wi) + tt212*wi)*(1.0_ireals-wj) + &
                 (tt122*(1.0_ireals-wi) + tt222*wi)*            wj

            p_sta = (pp112*(1.0_ireals-wi) + pp212*wi)*(1.0_ireals-wj) + &
                 (pp122*(1.0_ireals-wi) + pp222*wi)*            wj

            e_sta = (ee112*(1.0_ireals-wi) + ee212*wi)*(1.0_ireals-wj) + &
                 (ee122*(1.0_ireals-wi) + ee222*wi)*            wj

            rfridx_low = 1.0 + (77.6/100.0*p_sta/t_sta - 6.0/100.0*e_sta/t_sta + &
                 3.75e3*e_sta/(t_sta**2))*1d-6


            hfl11 = 0.5*(hhl(i,j,ko)   + hhl(i,j,ko+1))
            hfl21 = 0.5*(hhl(io,j,ko)  + hhl(io,j,ko+1))
            hfl12 = 0.5*(hhl(i,jo,ko)  + hhl(i,jo,ko+1))
            hfl22 = 0.5*(hhl(io,jo,ko) + hhl(io,jo,ko+1))

            hfl_low = (hfl11*(1.0_ireals-wi) + hfl21*wi)*(1.0_ireals - wj) + &
                 (hfl12*(1.0_ireals-wi) + hfl22*wi)*wj

            hfl11 = 0.5*(hhl(i,j,k)   + hhl(i,j,k+1))
            hfl21 = 0.5*(hhl(io,j,k)  + hhl(io,j,k+1))
            hfl12 = 0.5*(hhl(i,jo,k)  + hhl(i,jo,k+1))
            hfl22 = 0.5*(hhl(io,jo,k) + hhl(io,jo,k+1))

            hfl_up = (hfl11*(1.0_ireals-wi) + hfl21*wi)*(1.0_ireals - wj) + &
                 (hfl12*(1.0_ireals-wi) + hfl22*wi)*wj


            ! for lsode (SR ..._onlinenew)
            rs_grid(ista)%rfridx_sta =  1.0/rfridx_sta * ((rfridx_low -  rfridx_up)/(hfl_low - hfl_up))

          ELSE

            ! for online
            rs_grid(ista)%rfridx_sta =  rfridx_sta

          ENDIF
         
        ENDIF

        WRITE(*,*) "ISTA ", ista,":  rfridx = ",rs_grid(ista)%rfridx_sta
        IF (rs_grid(ista)%rfridx_sta < -900.0_ireals) THEN
          ci(:) = ' '
          WRITE (ci,'(i8)') ista
          CALL model_abort (my_world_id, 20739, &
               'ERROR: problem in ' //TRIM(yzroutine)// &
               ': rfridx_sta for radar station ' //TRIM(ADJUSTL(ci))//&
               ', station height probably below model surface!', &
               TRIM(yzroutine)//',calculation of refractive index at radar stations')
        END IF
        
      ENDIF
      
    END DO   ! loop over radar stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id    

  END SUBROUTINE calc_sta_rfridx


  SUBROUTINE distribute_sta_rfridx

    !----------------------------------------------------------------------------------
    ! Description: This subroutine distributes the refraction indices at radar stations 
    !              to all processors
    !              
    !----------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 
    CHARACTER (LEN=8)  ci

    INTEGER (KIND = iintegers)       :: ierr,ista,i

    REAL (KIND = ireals)             :: rfridx_sta(nradsta), recvbuf(nradsta*num_compute)  

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE distribute_sta_rfridx
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'distribute_sta_rfridx'

    IF (ldebug_radsim) WRITE (*,*)  TRIM(yzroutine), ' on proc ', my_cart_id

    DO ista = 1, nradsta 

      rfridx_sta(ista) = rs_grid(ista)%rfridx_sta

    ENDDO

    recvbuf = 999.99_ireals

!!$ UB>>
    IF (num_compute > 1) THEN
!!$ UB<<

      CALL mpi_gather(rfridx_sta,nradsta,imp_reals,recvbuf,nradsta,imp_reals,0,icomm_cart,ierr)

      IF (my_cart_id == 0) THEN

        DO i = 1, nradsta*num_compute

          IF(recvbuf(i) .NE. 999.99_ireals) THEN

            IF (MOD(i,nradsta) == 0) THEN 

!!$ UB>>
              IF (rs_grid(nradsta)%rfridx_sta < 900.0_ireals .AND. &
                   ABS(rs_grid(nradsta)%rfridx_sta-recvbuf(i)) > 1e-12_ireals) THEN
                ! In that case, there must be some error in the 
                ! assignment of the radar stations to station indices.
                ci(:) = ' '
                WRITE (ci,'(i8)') nradsta
                CALL model_abort (my_world_id, 20572, &
                     'ERROR: problem in ' //TRIM(yzroutine)// &
                     ': possible problem with assignment of radar station ' //TRIM(ADJUSTL(ci)), &
                     TRIM(yzroutine)//', distribution of refractive index at radar stations')
              END IF
!!$ UB<<
              rs_grid(nradsta)%rfridx_sta = recvbuf(i)

            ELSE

!!$ UB>>
              IF (rs_grid(MOD(i,nradsta))%rfridx_sta < 900.0_ireals .AND. &
                   ABS(rs_grid(MOD(i,nradsta))%rfridx_sta-recvbuf(i)) > 1e-12_ireals) THEN
                ! In that case, there must be some error in the 
                ! assignment of the radar stations to station indices.
                ci(:) = ' '
                WRITE (ci, '(i8)') nradsta
                CALL model_abort (my_world_id, 20573, &
                     'ERROR: problem in ' //TRIM(yzroutine)// &
                     ': possible problem with assignment of radar station ' //TRIM(ADJUSTL(ci)), &
                     TRIM(yzroutine)//', distribution of refractive index at radar stations')
              END IF
!!$ UB<<
              rs_grid(MOD(i,nradsta))%rfridx_sta = recvbuf(i)

            ENDIF

          ENDIF

        ENDDO

      ENDIF

!!$ UB>>
    ENDIF
!!$ UB<<

    IF(num_compute > 1) THEN

      IF(my_cart_id == 0) THEN

        DO ista = 1, nradsta
          realbuf(ista) = rs_grid(ista)%rfridx_sta
        ENDDO

      ENDIF

      CALL distribute_values(realbuf,nradsta,0,imp_reals,icomm_cart,ierr)

      IF(my_cart_id /= 0) THEN

        DO ista = 1, nradsta
          rs_grid(ista)%rfridx_sta = realbuf(ista)
        ENDDO

      ENDIF

    ENDIF


  END SUBROUTINE distribute_sta_rfridx


  SUBROUTINE distribute_onlineinfos_new

!!$=====================================
!!$ NOT USED AT THE MOMENT !!!
!!$=====================================

    !------------------------------------------------------------------------------
    ! Description: This subroutine calculates the innovation (i.e. observed radial 
    !              wind minus model radial wind). Currently, only for idealized
    !              experiments where the observations are analytically specified 
    !              
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers)       :: ierr,ista,irank,igrd,ngrd,np,m,count,num,dim

    INTEGER (KIND = iintegers)       :: iiscnt,iircnt,                                &
         iisend(num_compute),iirecv(num_compute),      &
         iscnt(0:num_compute-1),ircnt(0:num_compute-1),&
         isdsp(0:num_compute-1),irdsp(0:num_compute-1),&
         istart(0:num_compute-1),iend(0:num_compute-1),&
         ipos_all(num_compute)

    REAL (KIND = ireals), ALLOCATABLE:: z_tmp(:,:), isend_tmp(:), isend(:), irecv(:)   

    REAL (KIND = ireals), POINTER    :: z_radar_grd_all(:)                                        

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE distribute_onlineinfos_new
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'distribute_onlineinfos_new'

    IF (ldebug_radsim) WRITE (*,*)  TRIM(yzroutine), ' on proc ', my_cart_id

    WRITE(*,*)"pos1"

    WRITE(*,*)"num_compute",num_compute

    DO ista = 1,nradsta

      ! to estimate the interval of azimuths for each processor, istart saves minimum, iend maximum
      CALL para_range(1,rs_meta(ista)%naz,num_compute,nbl_az,istart,iend)   

      NULLIFY(z_radar_grd_all)

      CALL gatherv_values(rs_grid(ista)%z_radar_grd, z_radar_grd_all, ipos_all, ngrd, &
           num_compute, imp_reals, 0, icomm_cart, yzerrmsg, ierr)

      IF (my_cart_id == 0) THEN

        ALLOCATE(z_tmp(0:num_compute-1,ngrd))
        ALLOCATE(isend_tmp(ngrd))

        z_tmp     = 0.0_ireals
        isend_tmp = 0.0_ireals

        count = 0_iintegers   

        WRITE(*,*)"pos2"

        DO irank = 0, num_compute-1

          num = 0_iintegers 

          dim = 0_iintegers

!CDIR NODEP,VOVERTAKE,VOB
          DO igrd = 1, ngrd

            ! for each grid point determine the continuous number np of grid points
            np = rs_grid(ista)%ind_intp(igrd,2)

            ! determine indices in azimuth for current grid point
            m  = MOD(np-1,rs_grid(ista)%naz_nbl) + 1

            ! check if the current azimuth should be sent to irank-processor 
            IF (istart(irank) <= m .AND. m <= iend(irank)) THEN

              num = num + 1
              z_tmp(irank,num) = rs_grid(ista)%z_radar_grd(igrd)

            ENDIF

          ENDDO ! loop over ngrd

          WRITE(*,*)"pos3"

          iscnt(irank) = num

          isdsp(irank) = count

          count = count + iscnt(irank)

          WRITE(*,*)"pos4"

          if (num > 0) then

            isend_tmp(dim+1:dim+num) =  z_tmp(irank,1:num)

          endif

          dim = dim + num

          WRITE(*,*)"pos5"

        ENDDO ! loop over num_compute

        ALLOCATE(isend(SUM(iscnt)))

        ! isend saves the data, which should be sent to processors from 0 to num_compute - 1
        isend(:) = isend_tmp(1:SUM(iscnt))

        ircnt(:) = iscnt

        intbuf(:)= ircnt

      ENDIF ! my_cart_id == 0

      CALL distribute_values(intbuf,num_compute,0,imp_integers,icomm_cart,ierr)

      IF (my_cart_id /= 0) THEN

        ircnt(:) = intbuf

      ENDIF

      ALLOCATE(irecv(ircnt(my_cart_id)))

      call mpi_scatterv(isend,iscnt,isdsp,imp_reals,irecv,ircnt(my_cart_id),imp_reals,0,icomm_cart,ierr)

      WRITE(*,*)"pos9"

      IF (ALLOCATED(z_tmp))     DEALLOCATE(z_tmp)
      IF (ALLOCATED(isend_tmp)) DEALLOCATE(isend_tmp)
      IF (ALLOCATED(isend))     DEALLOCATE(isend)
      IF (ALLOCATED(irecv))     DEALLOCATE(irecv)

      IF (ASSOCIATED(z_radar_grd_all)) DEALLOCATE(z_radar_grd_all)

    ENDDO ! loop over stations

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END  SUBROUTINE distribute_onlineinfos_new


  SUBROUTINE distribute_onlineinfos_reals(rvector_loc,ipos_loc,size_loc, &
       iaz_start,iaz_end,naz_nbl,rvector_az,idatatype,icomm,npes)

!!$=========================================
!!$ UB: added support for num_compute == 1
!!$=========================================

    !-----------------------------------------------------------------------------------------------------
    !
    ! Description: This subroutine collects the data for a variable (in type real) from all processors and 
    !              sends them back to processors according to the azimuths of data FOR ONE RADAR STATION!
    !
    ! Method:      mpi_alltoall and mpi_alltoallv      
    !
    !-----------------------------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !-----------------------------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers),INTENT(IN) :: size_loc,                         & ! size of vector
                                             idatatype,                        & ! data type of vector
                                             icomm,                            & ! MPI-communicator
                                             npes,                             & ! number of PEs  
                                             naz_nbl,                          & ! number of azimuts in total azimut-slice-grid (incl. 2*nbl_az)
                                             iaz_start,                        & ! the start index of azimuth
                                             iaz_end                             ! the final index of azimuth

    INTEGER (KIND = iintegers),INTENT(IN) :: ipos_loc(size_loc)   

    REAL (KIND = ireals),      INTENT(IN) :: rvector_loc(size_loc)

    REAL (KIND = ireals),      POINTER    :: rvector_az(:)                       ! MUST BE INITIALIZED BEFORE INPUT! e.g., nullify(rvector_az)

    INTEGER (KIND = iintegers)            :: ierr,ista,irank,igrd,ngrd,np,m,count1,count2,dim

    INTEGER (KIND = iintegers)            :: iiscnt,iircnt,                     &
                                             iisend(npes),iirecv(npes),         &
                                             iscnt(0:npes-1),ircnt(0:npes-1),   &
                                             isdsp(0:npes-1),irdsp(0:npes-1),   &
                                             istart(0:npes-1),iend(0:npes-1)  ! ,   &
!!$                                             flag(size_loc)
!!$    REAL (KIND = ireals),      ALLOCATABLE:: z_tmp(:,:), isend_tmp(:), isend(:), irecv(:)
    REAL (KIND = ireals),      ALLOCATABLE:: z_tmp(:,:), isend(:), irecv(:)


    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE distribute_onlineinfos_reals
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'distribute_onlineinfos_reals'

    IF (ldebug_radsim) WRITE (*,*)  TRIM(yzroutine), ' on proc ', my_cart_id

    ! to estimate the interval of azimuths for each processor (assuming that each radar has
    ! the same number of azimuts:
    CALL para_range(iaz_start,iaz_end,npes,nbl_az,istart,iend)
  
    IF(ASSOCIATED(rvector_az)) DEALLOCATE(rvector_az)
   
     iscnt(0:npes-1)= 0_iintegers 
     ircnt(0:npes-1)= 0_iintegers 
     isdsp(0:npes-1)= 0_iintegers 
     irdsp(0:npes-1)= 0_iintegers 


    IF (num_compute > 1) THEN

      ALLOCATE(z_tmp(0:npes-1,size_loc))
!!$      ALLOCATE(isend_tmp(size_loc))

      z_tmp     = -999.99_ireals
!!$      isend_tmp = 0.0_ireals

      count1 = 0_iintegers   
      count2 = 0_iintegers
      dim    = 0_iintegers
!!$      flag   = 0_iintegers

      DO irank = 0, npes-1

        ngrd = 0_iintegers 

!CDIR NODEP,VOVERTAKE,VOB
        DO igrd = 1, size_loc

!!$ flag unnoetig?
!!$          IF (flag(igrd) == 0_iintegers) THEN

            ! for each grid point determine the continuous number np of grid points
            np = ipos_loc(igrd)
            
            ! determine indices in azimuth for current grid point in total azimut-slice-grid
            m  = MOD(np-1,naz_nbl) + 1

            ! check if the current azimuth should be sent to irank-processor 
            IF (istart(irank) <= m .AND. m <= iend(irank)) THEN

              ngrd = ngrd + 1
              z_tmp(irank,ngrd) = rvector_loc(igrd)

            ENDIF

!!$          ENDIF

        ENDDO ! loop over ngrd

        iscnt(irank) = ngrd
        
        isdsp(irank) = count1

        count1 = count1 + iscnt(irank)

!!$        IF (ngrd > 0) THEN
!!$
!!$          isend_tmp(dim+1:dim+ngrd) =  z_tmp(irank,1:ngrd)
!!$
!!$        ENDIF
!!$
!!$        dim = dim + ngrd

      ENDDO ! loop over npes

      ALLOCATE(isend(SUM(iscnt)))
      isend = -999.99_ireals

!!$ UB>>      
!!$      ALLOCATE(isend_tmp(SUM(iscnt)))

      dim    = 0_iintegers
      DO irank = 0, npes-1
        ngrd = iscnt(irank)
        IF (ngrd > 0) THEN
          ! isend saves the data, which should be sent to processors from 0 to npes - 1
          isend(dim+1:dim+ngrd) =  z_tmp(irank,1:ngrd)
        ENDIF
        dim = dim + ngrd
      END DO
!!$ UB<< 

      ! isend saves the data, which should be sent to processors from 0 to npes - 1
!!$      isend(:) = isend_tmp(1:SUM(iscnt))

      ! to estimate ircnt
      iisend = iscnt
      iirecv = 0_iintegers
      iiscnt = 1_iintegers
      iircnt = 1_iintegers
  
      !distribute the number of data that each processor may obtain
      CALL mpi_alltoall(iisend,1,imp_integers,iirecv,1,imp_integers,icomm_cart,ierr) 
      
      ircnt(0:npes-1) = iirecv(1:npes)

      ! to estimate irdsp
      DO irank = 0, npes-1
        
        irdsp(irank) = count2
        count2 = count2 + ircnt(irank)
        
      ENDDO

      ALLOCATE(irecv(SUM(ircnt)))
      irecv = -999.99_ireals
      
      !distribute the data to processors
      CALL mpi_alltoallv(isend,iscnt,isdsp,imp_reals,irecv,ircnt,irdsp,imp_reals,icomm_cart,ierr)   

      
      ALLOCATE(rvector_az(SUM(ircnt)))
      
      rvector_az(:) = irecv
      
      DEALLOCATE(z_tmp)
!!$      DEALLOCATE(isend_tmp)
      DEALLOCATE(isend)
      DEALLOCATE(irecv)

    ELSE     ! num_compute == 1

      ALLOCATE(rvector_az(size_loc))
      
      rvector_az(:) = rvector_loc(:)
      
    END IF   ! num_compute > 1


    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE distribute_onlineinfos_reals


  SUBROUTINE distribute_onlineinfos_integers(ivector_loc,ipos_loc,size_loc,iaz_start, &
       iaz_end,naz_nbl,ivector_az,idatatype,icomm,npes)

    !------------------------------------------------------------------------------------------------------- 
    !
    ! Description: This subroutine collects the data of a variable (in type integer) from all processors and 
    !              sends them back to processors according to the azimuths of data  FOR ONE RADAR STATION!
    !
    ! Method:      mpi_alltoall and mpi_alltoallv       
    !
    !-------------------------------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !-------------------------------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers),INTENT(IN) ::     size_loc,                         & ! size of vector
                                                 idatatype,                        & ! data type of vector
                                                 icomm,                            & ! MPI-communicator
                                                 npes,                             & ! number of PEs  
                                                 naz_nbl,                          & ! number of azimuths in total azimut-slice-grid (incl. 2*nbl_az)
                                                 iaz_start,                        & ! the start index of azimuth
                                                 iaz_end                             ! the final index of azimuth

    INTEGER (KIND = iintegers),INTENT(IN) ::     ipos_loc(size_loc)   

    INTEGER (KIND = iintegers),INTENT(IN) ::     ivector_loc(size_loc)

    INTEGER (KIND = iintegers),   POINTER ::     ivector_az(:)                       ! MUST BE INITIALIZED BEFORE INPUT! e.g., nullify(ivector_az)

    INTEGER (KIND = iintegers)            ::     ierr,ista,irank,igrd,ngrd,np,m,count1,count2,dim

    INTEGER (KIND = iintegers)            ::     iiscnt,iircnt,                    &
                                                 iisend(npes),iirecv(npes),        &
                                                 iscnt(0:npes-1),ircnt(0:npes-1),  &
                                                 isdsp(0:npes-1),irdsp(0:npes-1),  &
                                                 istart(0:npes-1),iend(0:npes-1)   ! ,  &
!!$                                                 flag(size_loc)

!!$    INTEGER (KIND = iintegers),ALLOCATABLE::     z_tmp(:,:), isend_tmp(:), isend(:), irecv(:)
    INTEGER (KIND = iintegers),ALLOCATABLE::     z_tmp(:,:), isend(:), irecv(:)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE distribute_onlineinfos_integers
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'distribute_onlineinfos_integers'

    IF (ldebug_radsim) WRITE (*,*)  TRIM(yzroutine), ' on proc ', my_cart_id

    ! to estimate the interval of azimuths for each processor, istart saves minimum, iend maximum
    CALL para_range(iaz_start,iaz_end,npes,nbl_az,istart,iend)

    IF(ASSOCIATED(ivector_az)) DEALLOCATE(ivector_az)

     iscnt(0:npes-1)= 0_iintegers 
     ircnt(0:npes-1)= 0_iintegers 
     isdsp(0:npes-1)= 0_iintegers 
     irdsp(0:npes-1)= 0_iintegers 


    IF (num_compute > 1) THEN

      ALLOCATE(z_tmp(0:npes-1,size_loc))
!!$      ALLOCATE(isend_tmp(size_loc))

      z_tmp     = 0_iintegers
!!$      isend_tmp = 0.0_ireals

      ierr   = 0
      count1 = 0_iintegers   
      count2 = 0_iintegers
!!$      flag   = 0_iintegers
      
      DO irank = 0, npes-1
        
        ngrd = 0_iintegers 
        
!CDIR NODEP,VOVERTAKE,VOB
        DO igrd = 1, size_loc
          
!!$ flag unnoetig?
!!$          IF (flag(igrd) == 0_iintegers) THEN
            
            ! for each grid point determine the continuous number np of grid points
            np = ipos_loc(igrd)
            
            ! determine indices in azimuth for current grid point in total azimut-slice-grid:
            m  = MOD(np-1,naz_nbl) + 1
            
            ! check if the current azimuth should be sent to irank-processor 
            IF (istart(irank) <= m .AND. m <= iend(irank)) THEN
              
!!$ UB>>              flag(igrd)        = 1_iintegers   ! Mehrfachversand darf nicht mehr verhindert werden
              ngrd              = ngrd + 1
              z_tmp(irank,ngrd) = ivector_loc(igrd)
              
            ENDIF
            
!!$          ENDIF
          
        ENDDO ! loop over ngrd
        
        iscnt(irank) = ngrd
        
        isdsp(irank) = count1
        
        count1 = count1 + iscnt(irank)
        
!!$        IF (ngrd > 0) THEN
!!$          
!!$          isend_tmp(dim+1:dim+ngrd) =  z_tmp(irank,1:ngrd)
!!$          
!!$        ENDIF
!!$        
!!$        dim = dim + ngrd
        
      ENDDO ! loop over npes

      ALLOCATE(isend(SUM(iscnt)))
      isend = 0_iintegers

!!$ UB>>      
!!$      ALLOCATE(isend_tmp(SUM(iscnt)))

      dim    = 0_iintegers
      DO irank = 0, npes-1
        ngrd = iscnt(irank)
        IF (ngrd > 0) THEN
          ! isend saves the data, which should be sent to processors from 0 to npes - 1
          isend(dim+1:dim+ngrd) =  z_tmp(irank,1:ngrd)
        ENDIF
        dim = dim + ngrd
      END DO
!!$ UB<< 


      ! isend saves the data, which should be sent to processors from 0 to npes - 1
!!$      isend(:) = isend_tmp(1:SUM(iscnt))
      
      ! to estimate ircnt
      iisend = iscnt
      
      iirecv = 0_iintegers
      iiscnt = 1_iintegers
      iircnt = 1_iintegers
      
      !distribute the number of data that each processor may obtain
      CALL mpi_alltoall(iisend,1,imp_integers,iirecv,1,imp_integers,icomm_cart,ierr) 
      
      IF (ierr /= 0) THEN
        WRITE(*,*) 'Error in MPI_ALLTOALL'
      ENDIF
      
      ircnt(0:npes-1) = iirecv(1:npes)
      
      ! to estimate irdsp
      DO irank = 0, npes-1
        
        irdsp(irank) = count2
        count2 = count2 + ircnt(irank)
        
      ENDDO

      ALLOCATE(irecv(SUM(ircnt)))
      irecv = 0_iintegers

      !distribute the data to processors
      CALL mpi_alltoallv(isend,iscnt,isdsp,imp_integers,irecv,ircnt,irdsp,imp_integers,icomm_cart,ierr)  
            
      ALLOCATE(ivector_az(SUM(ircnt)))

      ivector_az(:) = irecv

      DEALLOCATE(z_tmp)
!!$      DEALLOCATE(isend_tmp)
      DEALLOCATE(isend)
      DEALLOCATE(irecv)

    ELSE     ! num_compute == 1

      ALLOCATE(ivector_az(size_loc))
      
      ivector_az(:) = ivector_loc(:)
      
    END IF   ! num_compute > 1

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END  SUBROUTINE distribute_onlineinfos_integers


  !------------------------------------------------------------------------------

  SUBROUTINE sub2ind3D( m, n, o, nm, nn, il )

    IMPLICIT NONE

    !------------------------------------------------------------------------------
    !
    ! Description: Convert indices m, n, o of a 3D field f(1:nm,1:nn,1:no)
    !              to a linear running index il starting at 1.
    !              nm, nn, no are the field dimensions.
    !
    !              il is defined as
    !              
    !        il = m + (n-1)*nm + (o-1)*nm*nn
    !
    !              and the subroutine ind2sub3D() reverses the calculation.
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER(kind=iintegers), INTENT(in)  :: m, n, o, nm, nn
    INTEGER(kind=iintegers), INTENT(out) :: il

    il = m + (n-1)*nm + (o-1)*nm*nn
    
  END SUBROUTINE sub2ind3D

  SUBROUTINE ind2sub3D( il, nm, nn, m, n, o )

    IMPLICIT NONE

    !------------------------------------------------------------------------------
    !
    ! Description: Convert linear running index il to 3D field indices
    !              m, n, o, given the first 2 field sizes
    !              nm, nn of a field f(1:nm,1:nn,1:no).
    !
    !              It is assumed that il is defined as
    !              
    !        il = m + (n-1)*nm + (o-1)*nm*nn
    !
    !              and this subroutine inverts this calculation.
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER(kind=iintegers), INTENT(in)  :: il, nm, nn
    INTEGER(kind=iintegers), INTENT(out) :: m, n, o

    m = MOD( (il-1)              , nm) + 1
    n = MOD( (il-1) / nm         , nn) + 1
    o =      (il-1) / (nm*nn)          + 1


  END SUBROUTINE ind2sub3D

  SUBROUTINE sub2ind5D( m, n, o, p, q, nm, nn, no, np, il )

    IMPLICIT NONE

    !------------------------------------------------------------------------------
    !
    ! Description: Convert indices m, n, o, p, q of a 
    !              5D field f(1:nm,1:nn,1:no,1:np,1:nq)
    !              to a linear running index il starting at 1.
    !              nm, nn, no, np, nq are the field dimensions.
    !
    !              il is defined as
    !              
    !        il = m + (n-1)*nm + (o-1)*nm*nn + (p-1)*nm*nn*no + (q-1)*nm*nn*no*np
    !
    !              and the subroutine ind2sub5D() reverses the calculation.
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER(kind=iintegers), INTENT(in)  :: m, n, o, p, q, nm, nn, no, np
    INTEGER(kind=iintegers), INTENT(out) :: il

    il = m + (n-1)*nm + (o-1)*nm*nn + (p-1)*nm*nn*no + (q-1)*nm*nn*no*np
    
  END SUBROUTINE sub2ind5D

  SUBROUTINE ind2sub5D( il, nm, nn, no, np, m, n, o, p, q )

    IMPLICIT NONE

    !------------------------------------------------------------------------------
    !
    ! Description: Convert linear running index il to 5D field indices
    !              m, n, o, p, q, given the first 4 field sizes
    !              nm, nn, no, np of a field f(1:nm,1:nn,1:no,1:np,1:nq).
    !
    !              It is assumed that il is defined as
    !              
    !        il = m + (n-1)*nm + (o-1)*nm*nn + (p-1)*nm*nn*no + (q-1)*nm*nn*no*np
    !
    !              and this subroutine inverts this calculation.
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER(kind=iintegers), INTENT(in)  :: il, nm, nn, no, np
    INTEGER(kind=iintegers), INTENT(out) :: m, n, o, p, q

    m = MOD( (il-1)              , nm) + 1
    n = MOD( (il-1) / nm         , nn) + 1
    o = MOD( (il-1) / (nm*nn)    , no) + 1
    p = MOD( (il-1) / (nm*nn*no) , np) + 1
    q =      (il-1) / (nm*nn*no*np) + 1


  END SUBROUTINE ind2sub5D


  !------------------------------------------------------------------------------
  !------------------------------------------------------------------------------


  SUBROUTINE output_radar(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: Gathers the radar data on the radar grid from each radar
    !              from all PEs to a single output PE per radar and writes
    !              the results to disc. Currently this is done in 
    !              ascii files (or bin files on the NEC),
    !              later it will be done to a netcdf feedback file
    !
    !              THIS PROCEDURE IS FOR SIMULATED RADAR DATA WITHOUT SPATIAL SMOOTHING!
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) :: yzroutine
    CHARACTER (LEN=80) :: yzerrmsg 

    INTEGER (KIND = iintegers)              :: ista,m,n,o,mpierror,iobs,nobs,i,j,k, &
         ista_par, my_ista, ipe_rad, nobs_ista, izerror

    REAL    (KIND = ireals)                 :: range,azimuth,elevation, &
         maxext, minext, maxref, minref, &
         maxwind, minwind, ext_coeff
    REAL    (KIND = ireals),    POINTER     :: &
         radwind_mod_all(:),           & ! model radial wind for all radar points of a radar station
         z_radar_mod_all(:),           & ! radar reflectivity for all radar points of a radar station
         z_ext_mod_all(:),             & ! extinction of radar reflectivity ''
         hl_all(:),                    & ! height of radar bin MSL
         el_all(:)                       ! local elevation of radar bin

    INTEGER (KIND = iintegers), POINTER     :: radpos_all(:)                   ! radar points indices of a radar station

    INTEGER (KIND = iintegers), ALLOCATABLE :: &
         m_all(:),       & ! azimuthal indices for all radar points of a radar station in simul
         n_all(:),       & ! radial    indices for all radar points of a radar station in simul
         o_all(:)          ! elevation indices for all radar points of a radar station in simul

    INTEGER (KIND = iintegers)              :: ipos_all(num_compute)

    REAL(kind=ireals),          ALLOCATABLE :: vrpolar(:,:,:),zrpolar(:,:,:),&
         zepolar(:,:,:),zepolar_tot(:,:,:), &
         hrpolar(:,:,:),erpolar(:,:,:)


    CHARACTER(len=100) :: fileprefix

    ! Flag for parallel output of each radar on different PEs. This
    ! flag indicates whether this PE has some radar data to output.
    LOGICAL :: output_my_radar

    ! Flag if geometry files (hrsim, ersim) have been written to a file:
    LOGICAL, SAVE :: geom_written(nradsta_max) = .FALSE., &
                     geom_all_written = .FALSE.

    ! Buffer for MPI_ALLREDUCE:
    LOGICAL :: lsendbuf(nradsta_max)


    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE output_radar
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'output_radar'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    IF (.NOT. (loutradwind .OR. loutdbz)) THEN
      WRITE (*,*) 'MESSAGE: '//TRIM(yzroutine)// &
           'No output of simulated radar data since loutradwind = loutdbz = .FALSE.'
      RETURN
    END IF

    ipos_all = 0_iintegers

    ! Distribute the radar data of different radars to all output PEs.
    ! Here we assume that all compute PEs are used for output, therefore
    ! the number of output PEs equals num_compute and num_compute is the
    ! chunk size for the following outer loop:

    NULLIFY(radwind_mod_all)
    NULLIFY(z_radar_mod_all)
    NULLIFY(z_ext_mod_all)
    NULLIFY(radpos_all)
    NULLIFY(hl_all)
    NULLIFY(el_all)

    IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)

    ! loop over num_compute-sized chunks of radar stations:
    chunkloop: DO ista_par = 1, nradsta, num_compute

      ! .. Distinction between single proc and parallel runs:
      IF (num_compute > 1) THEN

        output_my_radar = .FALSE.
        nobs = -999
        
        istaloop: DO ista = ista_par, MIN(ista_par+num_compute-1, nradsta)

          IF (.NOT.lcalc(ista)) CYCLE istaloop

          ! determine the number of the PE for output of the radar with no. ista:
          ipe_rad = MOD(ista-1, num_compute)

          ! .. Gather the values for this radar on the PE with no. ipe_rad:

          IF ( (lout_geom .AND. (lonline .OR. .NOT.geom_written(ista))) .OR. lreadmeta_from_netcdf) THEN
 
           ! Gather height of radar bin above MSL:
            CALL gatherv_values(rs_data(ista)%hl_loc, hl_all, ipos_all, nobs_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

            ! Gather local elevation angle:
            CALL gatherv_values(rs_data(ista)%el_loc, el_all, ipos_all, nobs_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

          END IF

          IF(loutradwind) THEN

            ! Gather radial winds:
            CALL gatherv_values(rs_data(ista)%radwind_mod, radwind_mod_all, ipos_all, nobs_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

          END IF

          IF(loutdbz .OR. lweightdbz) THEN

            ! Gather radar reflectivity:
            CALL gatherv_values(rs_data(ista)%z_radar_mod, z_radar_mod_all, ipos_all, nobs_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

            IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
              ! Gather extinction coefficients:
              CALL gatherv_values(rs_data(ista)%z_ext_mod, z_ext_mod_all, ipos_all, nobs_ista, &
                   num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

            END IF

          END IF

          CALL gatherv_values(rs_data(ista)%ind_intp(:,2), radpos_all, ipos_all, nobs_ista, &
               num_compute, imp_integers, ipe_rad, icomm_cart, yzerrmsg, mpierror)

          ! keep track of which radar is output on which processor:
          IF (my_cart_id == ipe_rad) THEN

            IF (ldebug_radsim) THEN
              WRITE (*,'(a,i3,a,i4,a,i4)') TRIM(yzroutine)//': distribution of stations over PEs: ista = ', &
                   ista, ' ipe_rad = ', ipe_rad, ' my_cart_id = ', my_cart_id
            END IF

            my_ista = ista
            output_my_radar = lcalc(ista)
            nobs = nobs_ista

          END IF

        END DO istaloop

        IF (ltime) CALL get_timings (i_radar_comm, ntstep, dt, izerror)

      ELSE   ! num_compute == 1

        ! In diesem Fall sind die lokalen und globalen ungeordneten
        ! Radardatenvektoren dieselben und es soll kein extra globaler
        ! zusaetzlicher Speicher allokiert werden. Deswegen hier eine
        ! simple POINTER-Zuweisung:

        IF (.NOT.lcalc(ista_par)) CYCLE chunkloop

        ipe_rad = 0
        my_ista = ista_par
        output_my_radar = .TRUE.

        nobs = SIZE(rs_data(my_ista)%ind_intp,1)

        IF (ASSOCIATED(radwind_mod_all))   NULLIFY(radwind_mod_all)
        IF (ASSOCIATED(z_radar_mod_all))   NULLIFY(z_radar_mod_all)
        IF (ASSOCIATED(z_ext_mod_all))     NULLIFY(z_ext_mod_all)
        IF (ASSOCIATED(radpos_all))        NULLIFY(radpos_all) 
        IF (ASSOCIATED(hl_all))            NULLIFY(hl_all) 
        IF (ASSOCIATED(el_all))            NULLIFY(el_all) 

        radwind_mod_all => rs_data(my_ista)%radwind_mod
        z_radar_mod_all => rs_data(my_ista)%z_radar_mod
        z_ext_mod_all   => rs_data(my_ista)%z_ext_mod
        radpos_all      => rs_data(my_ista)%ind_intp(:,2)
        hl_all          => rs_data(my_ista)%hl_loc
        el_all          => rs_data(my_ista)%el_loc

      END IF ! num_compute > 1

      IF (output_my_radar) THEN 

        ista = my_ista

        IF (ldebug_radsim) THEN
          WRITE (*,'(a,i3,a,i4)') TRIM(yzroutine)//': output of radar station ', &
               ista, ' on proc ', my_cart_id
        END IF

        ! .. Allocate fields for 3D radar data:
!!$        ALLOCATE(vrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), &
!!$                 zrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), &
!!$                 hrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel))
        ALLOCATE(vrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), &
                 zrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel))
        ! .. Initialize with standard missing value (= point outside model domain):
!CDIR BEGIN COLLAPSE
        vrpolar = -999.99_ireals
        zrpolar = -999.99_ireals
!CDIR END

        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          ALLOCATE(zepolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), &
                   zepolar_tot(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel))
!CDIR BEGIN COLLAPSE
          zepolar = -999.99_ireals
          zepolar_tot = 0.0_ireals
!CDIR END
        END IF

        ! .. Allocate index fields for re-copying radar data vectors to 3D data sets:
        ALLOCATE(m_all(nobs), n_all(nobs), o_all(nobs))

!CDIR BEGIN COLLAPSE
        m_all = -1_iintegers
        n_all = -1_iintegers
        o_all = -1_iintegers
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, nobs
          m_all(iobs)  = MOD( radpos_all(iobs)-1, rs_meta(ista)%naz ) + 1

          n_all(iobs)  = MOD( INT(REAL(radpos_all(iobs)-1,ireals) / &
               REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
          o_all(iobs)  = INT(REAL(radpos_all(iobs)-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
               *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
        END DO

        IF ( ANY( n_all > rs_meta(ista)%nra .OR. n_all < 1_iintegers .OR. &
                  m_all > rs_meta(ista)%naz .OR. m_all < 1_iintegers .OR. &
                  o_all > rs_meta(ista)%nel .OR. o_all < 1_iintegers ) ) THEN
          WRITE (*,*) TRIM(yzroutine)//' ERROR: SO NE SCH***!!!'
        END IF


        IF ( (lout_geom .AND. (lonline .OR. .NOT.geom_written(ista))) .OR. lreadmeta_from_netcdf ) THEN

          ALLOCATE(hrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), &
               erpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel))
          ! .. Initialize with standard missing value (= point outside model domain):
!CDIR BEGIN COLLAPSE
          hrpolar = -999.99_ireals
          erpolar = -999.99_ireals
!CDIR END

          DO iobs = 1, nobs
!!$            hrpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = hl_all(iobs)
!!$            erpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = el_all(iobs)
            hrpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = hl_all(iobs)
            erpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = el_all(iobs)
          END DO

          IF ( lout_geom .AND. (lonline .OR. .NOT.geom_written(ista)) ) THEN

            IF (.NOT. lonline) THEN
              ! Zero out shielded pixels in case of 4/3 earth model. For online ray propagation, this is not necessary
              !   because the ray tracing ends on impact on orography!
              CALL elim_shielded(erpolar, rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, -999.99_ireals)
            END IF

            !.. Output the sorted polar data set into a standard file format: 
            !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
            !   - simple ASCII on all other systems
            fileprefix(:) = ' '
            WRITE (fileprefix, '("hrsim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 hrpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. radar bin height above MSL', 'm', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)
            
            CALL control_output(radgeomoutputunit(ista), time_mod, rs_meta(ista), "hl_polar [m]", &
                 hrpolar, (hrpolar > -900.0_ireals), -999.99_ireals, nobs)
            
            
            fileprefix(:) = ' '
            WRITE (fileprefix, '("ersim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 erpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. local elevation angle', 'deg', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)
            
            CALL control_output(radgeomoutputunit(ista), time_mod, rs_meta(ista), "el_polar [m]", &
                 erpolar, (erpolar > -900.0_ireals), -999.99_ireals, nobs)

          END IF

          ! Set flag that geometry for this radar has been written to a file:
          geom_written(ista) = .TRUE.

        END IF

        IF (loutradwind) THEN

          !.. Sort the collected radar points into the 3D field according
          !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
          DO iobs = 1, nobs
!!$            vrpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = radwind_mod_all(iobs)
            vrpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = radwind_mod_all(iobs)
          END DO

          IF (.NOT. lonline) THEN
            ! Zero out shielded pixels in case of 4/3 earth model. For online ray propagation, this is not necessary
            !   because the ray tracing ends on impact on orography!
            CALL elim_shielded(vrpolar, rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, -999.99_ireals)
          END IF

          !.. Output the sorted polar data set into a standard file format: 
          !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
          !   - simple ASCII on all other systems
          fileprefix(:) = ' '
          WRITE (fileprefix, '("vrsim_id-",i6.6)') rs_meta(ista)%station_id
          CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
               vrpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. radial velocity, no aliasing', 'm/s', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

          CALL control_output(radwindoutputunit(ista), time_mod, rs_meta(ista), "V_r [m/s]", &
               vrpolar, (vrpolar > -900.0_ireals), -999.99_ireals, nobs)

        END IF ! loutradwind


        IF (loutdbz) THEN

          !.. Sort the collected radar points into the 3D field according
          !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
          DO iobs = 1, nobs
            ! Convert reflectivity from linear to dBZ values:
            IF (z_radar_mod_all(iobs) >= 1e-9_ireals) THEN
!!$              zrpolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = 10.0_ireals * LOG10(z_radar_mod_all(iobs))
              zrpolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = 10.0_ireals * LOG10(z_radar_mod_all(iobs))
            ELSEIF (z_radar_mod_all(iobs) >= -900.0_ireals) THEN
!!$              zrpolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = -99.99_ireals
              zrpolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = -99.99_ireals
            ELSEIF (z_radar_mod_all(iobs) >= -990.0_ireals) THEN
              ! Points below the surface:
!!$              zrpolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = z_radar_mod_all(iobs)
              zrpolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = z_radar_mod_all(iobs)
            END IF
            ! andernfalls -999.99 ...
          END DO

          IF (.NOT. lonline) THEN
            ! Zero out shielded pixels in case of 4/3 earth model. For online ray propagation, this is not necessary
            !   because the ray tracing ends on impact on orography!
            CALL elim_shielded(zrpolar, rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, -999.99_ireals)
          END IF

          IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN

!CDIR NODEP,VOVERTAKE,VOB
            DO iobs = 1, nobs
!!$              zepolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = z_ext_mod_all(iobs)
              zepolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = z_ext_mod_all(iobs)
            END DO

            IF (.NOT. lonline) THEN
              ! Zero out shielded pixels in case of 4/3 earth model. For online ray propagation, this is not necessary
              !   because the ray tracing ends on impact on orography!
              CALL elim_shielded(zepolar, rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, -999.99_ireals)
            END IF

            DO i = 1, rs_meta(ista)%nel
              DO j = 1, rs_meta(ista)%nra
                DO k = 1, rs_meta(ista)%naz
                  ! Clip missing values -999.99 resp. -988.88 to 0.0:
                  ext_coeff = MAX(zepolar(k,j,i), 0.0_ireals)
                  ! Sum up total extinction:
                  IF (j == 1) THEN
                    zepolar_tot(k,j,i) = ext_coeff * rs_meta(ista)%ra_inc
                  ELSE 
                    zepolar_tot(k,j,i) = zepolar_tot(k,j-1,i) + ext_coeff * rs_meta(ista)%ra_inc
                  END IF
                  zrpolar(k,j,i) = zrpolar(k,j,i) - 20.0/LOG(10.0)*zepolar_tot(k,j,i)
                END DO
              END DO
            END DO

            ! Convert units:
            zepolar_tot = 20.0/LOG(10.0)*zepolar_tot ! unit is now dB

            ! Set correct missing values for both zepolar and zepolar_tot:
            WHERE (zepolar >= -900.0_ireals)
              zepolar = 20.0/LOG(10.0)*zepolar*1000.0 ! unit is now dB/km
            ELSEWHERE
              zepolar_tot = -999.99_ireals
            END WHERE

            ! Output to file(s):
            fileprefix(:) = ' '
            WRITE (fileprefix, '("zepsim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 zepolar, TRIM(ADJUSTL(fileprefix)), 'Twoway attenuation coefficient for reflectivity', 'dB/km', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

            CALL control_output(extrefloutputunit(ista), time_mod, rs_meta(ista), "k_2 [dB/km]", &
                 zepolar, (zepolar > -900.0_ireals), -999.99_ireals, nobs)

            fileprefix(:) = ' '
            WRITE (fileprefix, '("zetsim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 zepolar_tot, TRIM(ADJUSTL(fileprefix)), 'Path integrated attenuation for reflectivity', 'dB', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

            maxext = MAXVAL(zepolar_tot)
            minext = MINVAL(zepolar_tot)
            WRITE(extrefloutputunit(ista),'(a,5x,es12.5,5x,es12.5)') "PIA [dB] MAX/MIN", maxext, minext

          END IF ! lextdbz
          ! de.

          ! Set correct 0-value (-99.99) and missing value (-999.99) for zrpolar:
!CDIR BEGIN COLLAPSE
          WHERE (zrpolar >= -900.0_ireals .AND. zrpolar < -90_ireals)
            zrpolar = -99.99_ireals
          END WHERE
          WHERE (zrpolar < -900.0_ireals)
            zrpolar = -999.99_ireals
          END WHERE
!CDIR END

          !.. Output the sorted polar data set into a standard file format: 
          !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
          !   - simple ASCII on all other systems
          fileprefix(:) = ' '
          WRITE (fileprefix, '("zrsim_id-",i6.6)') rs_meta(ista)%station_id
          CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
               zrpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. radar reflectivity', 'dBz', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

          CALL control_output(radrefloutputunit(ista), time_mod, rs_meta(ista), "Z [dBZ]", &
               zrpolar, (zrpolar > -900.0_ireals), -999.99_ireals, nobs)

        END IF ! loutdbz


#ifdef NETCDF
        IF (lreadmeta_from_netcdf) THEN

          CALL output_radar_dwd_obs (ista, time_mod, vrpolar, zrpolar, hrpolar)

        END IF
#endif

        DEALLOCATE(vrpolar, zrpolar, m_all, n_all, o_all)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          DEALLOCATE(zepolar, zepolar_tot)
        END IF
        IF (ALLOCATED(hrpolar)) THEN
          DEALLOCATE(hrpolar, erpolar)
        END IF

      END IF ! output_my_radar = .true.

      IF (num_compute > 1) THEN

        ! .. In this case, the memory has been allocated to the pointer
        !    itself by gatherv_values(). Therefore deallocate it.
        IF (ASSOCIATED(radwind_mod_all)) DEALLOCATE(radwind_mod_all)
        IF (ASSOCIATED(z_radar_mod_all)) DEALLOCATE(z_radar_mod_all)
        IF (ASSOCIATED(z_ext_mod_all))   DEALLOCATE(z_ext_mod_all)
        IF (ASSOCIATED(radpos_all))      DEALLOCATE(radpos_all)
        IF (ASSOCIATED(hl_all))          DEALLOCATE(hl_all)
        IF (ASSOCIATED(el_all))          DEALLOCATE(el_all)

      ELSE

        ! .. In this case, the pointers simply point to another
        !    pointers, to whom the memory has been allocated. Therefore,
        !    simply break the connection by NULLIFYING. The memory
        !    of the original pointers will be deallocated at the end
        !    of organize_radar().
        IF (ASSOCIATED(radwind_mod_all)) NULLIFY(radwind_mod_all)
        IF (ASSOCIATED(z_radar_mod_all)) NULLIFY(z_radar_mod_all)
        IF (ASSOCIATED(z_ext_mod_all))   NULLIFY(z_ext_mod_all)
        IF (ASSOCIATED(radpos_all))      NULLIFY(radpos_all)
        IF (ASSOCIATED(hl_all))          NULLIFY(hl_all)
        IF (ASSOCIATED(el_all))          NULLIFY(el_all)

      END IF

      IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)

    END DO chunkloop ! loop over (num_compute packages of) stations

    !----------------------------------------------------------------
    ! .. Distribute the info, for which stations the feedback files
    !    have been created by any of the processors:

    IF (num_compute > 1 .AND. lreadmeta_from_netcdf) THEN

      lsendbuf(:) = .FALSE.
      DO ista=1,nradsta
        lsendbuf(ista) = rs_meta(ista)%lfdbkfile_exist
      END DO

      CALL global_values (lsendbuf(1:nradsta), nradsta, 'OR', imp_logical, icomm_cart,    &
                          -1_iintegers, yzerrmsg, mpierror)
      DO ista=1,nradsta
        rs_meta(ista)%lfdbkfile_exist = lsendbuf(ista)
      END DO

    END IF

    !----------------------------------------------------------------
    ! .. Distribute the info, for which stations the geometry files
    !    have been written by any of the processors:

    IF (num_compute > 1 .AND. lout_geom .AND. .NOT.lonline .AND. .NOT.geom_all_written) THEN

      CALL global_values (geom_written(1:nradsta), nradsta, 'OR', imp_logical, icomm_cart,    &
                          -1_iintegers, yzerrmsg, mpierror)

    END IF

    geom_all_written = ALL(geom_written(1:nradsta))

    !----------------------------------------------------------------

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id        

  END SUBROUTINE output_radar


  ! ZY >> output_radar_smth with spatial averaging added
  !==============================================================================
  !+ Module procedure in src_radar for the output
  !------------------------------------------------------------------------------
  SUBROUTINE output_radar_smth(lcalc,time_mod)

    !------------------------------------------------------------------------------
    !
    ! Description: Gathers the data at smoothing points from each PE on PE 0 and writes
    !              results to disc. Currently this is done in an ascii file,
    !              later it will be done to a netcdf feedback file
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    LOGICAL                              :: lcalc(nradsta_max)
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start


    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32)  :: yzroutine
    CHARACTER (LEN=100) :: format_out
    CHARACTER (LEN=80)  :: yzerrmsg 

    INTEGER (KIND = iintegers)          :: ista,mpierror,iobs,nobs,i,j,k,iaz,nsmth,nrp,ismth,irp,iv,ih,tmp, &
         ista_par, my_ista, ipe_rad, nsmth_ista, izerror, m, n, o, iaerr, izs
    INTEGER (KIND = iintegers)          :: istart(0:num_compute-1),iend(0:num_compute-1)
    REAL    (KIND = ireals)             :: range,azimuth,elevation,el,az,el_tmp,az_tmp,ext_coeff, &
         maxext,minext,maxref,minref,maxwind,minwind

    REAL    (KIND = ireals),    POINTER :: radwind_mod_all_smth(:),z_radar_mod_all_smth(:),z_ext_mod_all_smth(:),&
         hl_loc_all_smth(:),el_loc_all_smth(:),pchk_sh(:)

    INTEGER (KIND = iintegers), POINTER :: radpos_all_smth(:)                  ! radar points indices of a radar station                      

    INTEGER (KIND = iintegers)          :: ipos_all(num_compute), iminloc(1), imaxloc(1)

    REAL(kind=ireals),       ALLOCATABLE :: hrpolar(:,:,:),hl_loc_smth(:,:,:),hl_loc(:),hl_all(:),intgrl_hl(:)

    REAL(kind=ireals),       ALLOCATABLE :: erpolar(:,:,:),el_loc_smth(:,:,:),el_loc(:),el_all(:),intgrl_el(:)

    REAL(kind=ireals),       ALLOCATABLE :: vrpolar(:,:,:),radwind_mod_all(:),&
         radwind_mod_smth(:,:,:),intgrl_wind(:)

    REAL(kind=ireals),       ALLOCATABLE :: zrpolar(:,:,:),z_radar_mod_all(:),z_radar_mod_smth(:,:,:),intgrl_z(:)

    REAL(kind=ireals),       ALLOCATABLE :: zepolar(:,:,:),zepolar_tot(:,:,:),z_ext_mod_all(:)

    REAL(kind=ireals),       ALLOCATABLE :: z_radar_mod_nmovh(:,:,:,:,:), &
         z_ext_mod_nmovh(:,:,:,:,:), z_ext_mod_nmovh_tot(:,:)

    REAL(kind=ireals),       ALLOCATABLE :: intgrl_pf(:),azarr(:),pf_value(:,:,:),cos_value(:,:,:)

    INTEGER(KIND=iintegers), ALLOCATABLE :: iv_all(:), ih_all(:), m_all(:), n_all(:), o_all(:), &
         flag_smth(:,:,:), counter(:), radpos(:), radpos_all(:)

    INTEGER(KIND=iintegers), ALLOCATABLE, SAVE :: n_sh(:,:,:,:)

    CHARACTER(len=100)                  :: fileprefix

    ! Flag for parallel output of each radar on different PEs. This
    ! flag indicates whether this PE has some radar data to output.
    LOGICAL :: output_my_radar

    ! Flag if geometry files (hrsim, ersim) have been written to a file:
    LOGICAL, SAVE :: geom_written(nradsta_max) = .FALSE., &
                     geom_all_written = .FALSE.

    ! Buffer for MPI_ALLREDUCE:
    LOGICAL :: lsendbuf(nradsta_max)

    ! For checking the radar points below sfc in the first call:
    LOGICAL, SAVE :: firstcall_offline = .TRUE.

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE output_radar_smth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'output_radar_smth'
    iaerr = 0
    izs = 0

    IF (.NOT. (loutradwind .OR. loutdbz)) THEN
      WRITE (*,*) 'MESSAGE: '//TRIM(yzroutine)// &
           'No output of simulated radar data since loutradwind = loutdbz = .FALSE.'
      RETURN
    END IF

    ipos_all = 0_iintegers

    ! Distribute the radar data of different radars to all output PEs.
    ! Here we assume that all compute PEs are used for output, therefore
    ! the number of output PEs equals num_compute and num_compute is the
    ! chunk size for the following outer loop:

    NULLIFY(radpos_all_smth)
    NULLIFY(hl_loc_all_smth)
    NULLIFY(el_loc_all_smth)
    NULLIFY(radwind_mod_all_smth)
    NULLIFY(z_radar_mod_all_smth)
    NULLIFY(z_ext_mod_all_smth)

    IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)

    ! loop over num_compute-sized chunks of radar stations:
    chunkloop: DO ista_par = 1, nradsta, num_compute

      ! .. Distinction between single proc and parallel runs:
      IF (num_compute > 1) THEN

        output_my_radar = .FALSE.
        nsmth           = -999

        istaloop: DO ista = ista_par, MIN(ista_par+num_compute-1, nradsta)

          IF (.NOT.lcalc(ista)) CYCLE istaloop  

          ! determine the number of the PE for output of the radar with no. ista:
          ipe_rad = MOD(ista-1, num_compute)

          ! .. Gather the values for this radar on the PE with no. ipe_rad:

          IF ( (lout_geom .AND. (lonline .OR. .NOT.geom_written(ista))) .OR. lreadmeta_from_netcdf) THEN

            ! Gather local ray height (for testing output purposes):
            CALL gatherv_values(rs_data(ista)%hl_loc, hl_loc_all_smth, ipos_all, nsmth_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

            ! Gather local elevation (for testing output purposes):
            CALL gatherv_values(rs_data(ista)%el_loc, el_loc_all_smth, ipos_all, nsmth_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)

          END IF


          IF(loutradwind) THEN

            ! Gather radial winds
            CALL gatherv_values(rs_data(ista)%radwind_mod_smth, radwind_mod_all_smth, ipos_all, nsmth_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)
            IF (ASSOCIATED(rs_data(ista)%radwind_mod_smth)) DEALLOCATE(rs_data(ista)%radwind_mod_smth)

          END IF

          IF(loutdbz .OR. lweightdbz) THEN
            ! Gather reflectivities
            CALL gatherv_values(rs_data(ista)%z_radar_mod_smth, z_radar_mod_all_smth, ipos_all, nsmth_ista, &
                 num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)
            IF (ASSOCIATED(rs_data(ista)%z_radar_mod_smth)) DEALLOCATE(rs_data(ista)%z_radar_mod_smth)

            IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
              ! Gather extinction coefficients
              CALL gatherv_values(rs_data(ista)%z_ext_mod_smth, z_ext_mod_all_smth, ipos_all, nsmth_ista, &
                   num_compute, imp_reals, ipe_rad, icomm_cart, yzerrmsg, mpierror)
              IF (ASSOCIATED(rs_data(ista)%z_ext_mod_smth)) DEALLOCATE(rs_data(ista)%z_ext_mod_smth)

            ENDIF
          ENDIF

          ! Gather linear spatial Index:
          CALL gatherv_values(rs_data(ista)%ind_intp_smth(:,2), radpos_all_smth, ipos_all, nsmth_ista, &
               num_compute, imp_integers, ipe_rad, icomm_cart, yzerrmsg, mpierror)

          ! keep track of which radar is output on which processor:
          IF (my_cart_id == ipe_rad) THEN

            IF (ldebug_radsim) THEN
              WRITE (*,'(a,i3,a,i4,a,i4)') TRIM(yzroutine)//': distribution of stations over PEs: ista = ', &
                   ista, ' ipe_rad = ', ipe_rad, ' my_cart_id = ', my_cart_id
            END IF

            my_ista = ista
            output_my_radar = lcalc(ista)
            nsmth = nsmth_ista

          END IF

        END DO istaloop

        IF (ltime) CALL get_timings (i_radar_comm, ntstep, dt, izerror)

      ELSE   ! num_compute == 1

        ! In diesem Fall sind die lokalen und globalen ungeordneten
        ! Radardatenvektoren dieselben und es soll kein extra globaler
        ! zusaetzlicher Speicher allokiert werden. Deswegen hier eine
        ! simple POINTER-Zuweisung:

        IF (.NOT.lcalc(ista_par)) CYCLE chunkloop

        ipe_rad = 0
        my_ista = ista_par
        output_my_radar = .TRUE.

        nsmth = SIZE(rs_data(ista)%ind_intp_smth,1)

        IF (ASSOCIATED(radpos_all_smth))        NULLIFY(radpos_all_smth)
        IF (ASSOCIATED(hl_loc_all_smth))        NULLIFY(hl_loc_all_smth)
        IF (ASSOCIATED(el_loc_all_smth))        NULLIFY(el_loc_all_smth)
        IF (ASSOCIATED(radwind_mod_all_smth))   NULLIFY(radwind_mod_all_smth)
        IF (ASSOCIATED(z_radar_mod_all_smth))   NULLIFY(z_radar_mod_all_smth)
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          IF (ASSOCIATED(z_ext_mod_all_smth))   NULLIFY(z_ext_mod_all_smth)
        END IF

        radpos_all_smth      => rs_data(my_ista)%ind_intp_smth(:,2)
        hl_loc_all_smth      => rs_data(my_ista)%hl_loc
        el_loc_all_smth      => rs_data(my_ista)%el_loc
        radwind_mod_all_smth => rs_data(my_ista)%radwind_mod_smth
        z_radar_mod_all_smth => rs_data(my_ista)%z_radar_mod_smth
        IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN
          z_ext_mod_all_smth => rs_data(my_ista)%z_ext_mod_smth
        END IF

      END IF ! num_compute > 1

      IF (output_my_radar) THEN 

        ista = my_ista

        IF (ldebug_radsim) THEN
          WRITE (*,'(a,i3,a,i4)') TRIM(yzroutine)//': output of radar station ', &
               ista, ' on proc ', my_cart_id
        END IF

        ALLOCATE(radpos(nsmth), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(iv_all(nsmth), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(ih_all(nsmth), stat=izs); iaerr = iaerr + ABS(izs)

        radpos = 0_iintegers
        iv_all = 0_iintegers
        ih_all = 0_iintegers

!CDIR NODEP,VOVERTAKE,VOB
        DO ismth = 1, nsmth

          irp = radpos_all_smth(ismth)

          CALL ind2sub5D( irp, rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, rs_meta(ista)%ngpsm_v, &
                               m, n, o, iv_all(ismth), ih_all(ismth) )

          CALL sub2ind3D( m, n, o, rs_meta(ista)%naz, rs_meta(ista)%nra, &
                          radpos(ismth))

        ENDDO

        nrp  = MAXVAL(radpos)

        WRITE(*,*) 'nrp = ', nrp, '  nsmth = ', nsmth

        ! Create a flag matrix indicating if the radar point
        ! is within the model domain, i.e., > -999.99:
        ALLOCATE(flag_smth(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
        flag_smth = 0_iintegers

        IF (.NOT. lonline .AND. firstcall_offline) THEN

          ! Prepare checking field for shielded pixels depending on configuration:
          ! NOTE: either loutradwind or loutdbz is .true. otherwise output_radar_smth() is not called!
          NULLIFY (pchk_sh)
          IF (loutradwind) THEN
            pchk_sh => radwind_mod_all_smth
          ELSEIF (loutdbz) THEN
            pchk_sh => z_radar_mod_all_smth
          END IF

          ALLOCATE(z_radar_mod_nmovh(rs_meta(ista)%naz,rs_meta(ista)%nra, &
               rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)

          ! n_sh(:,:,:,:) = Range index for beginning of beam shielding:
          ALLOCATE(n_sh(rs_meta(ista)%naz, &
               rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
          n_sh = rs_meta(ista)%nra + 1

          ! Determine first occurence of beam shielding along each radar ray
          ! and store range index in n_sh(:,:,:,:):
!CDIR NODEP
          DO ismth = 1, nsmth
            CALL ind2sub3D( radpos(ismth), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                            m, n, o )
            z_radar_mod_nmovh(m,n,o,iv_all(ismth),ih_all(ismth)) = &
                 pchk_sh(ismth)
          END DO

!CDIR NODEP
          DO ih = 1, rs_meta(ista)%ngpsm_h
            DO iv = 1, rs_meta(ista)%ngpsm_v
              DO i = 1, rs_meta(ista)%nel
                DO j = 1, rs_meta(ista)%nra
                  DO k = 1, rs_meta(ista)%naz

                    IF ( z_radar_mod_nmovh(k,j,i,iv,ih) > -990_ireals .AND. &
                         z_radar_mod_nmovh(k,j,i,iv,ih) < -980_ireals .AND. &
                         j < n_sh(k,i,iv,ih) ) THEN

                      n_sh(k,i,iv,ih) = j

                    END IF

                  END DO
                END DO
              END DO
            END DO
          END DO

          NULLIFY (pchk_sh)
          DEALLOCATE (z_radar_mod_nmovh)

          firstcall_offline = .FALSE.

        END IF

        IF (lonline) THEN

          ! Shielded pixels are not contained in the data vectors because
          !   the ray tracing ends on impact on orography!

!CDIR NODEP
          DO ismth = 1, nsmth

            flag_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = &
                 flag_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) + 1

          ENDDO

        ELSE

          ! Flag out shielded pixels in case of 4/3 earth model. For online ray propagation, this is not necessary
          !   because the ray tracing ends on impact on orography!
          
!CDIR NODEP
          DO ismth = 1, nsmth

            CALL ind2sub3D( radpos(ismth), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                            m, n, o )

            IF (n < n_sh(m,o,iv_all(ismth),ih_all(ismth))) THEN

!!! first index is sorted according to azimut, range, and elevation!
              flag_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = &
                   flag_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) + 1

            END IF

          ENDDO

        END IF

        IF (ANY(flag_smth > 1)) THEN

          WRITE (*,*) 'WARNING: More than one data value for some smth-points!'

        END IF

        ALLOCATE(radpos_all(nrp), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(counter(nrp), stat=izs)   ; iaerr = iaerr + ABS(izs)

        radpos_all = 0_iintegers
        counter  = 0_iintegers

        DO ih = 1, rs_meta(ista)%ngpsm_h
          DO iv = 1, rs_meta(ista)%ngpsm_v
            DO irp = 1, nrp

              IF(flag_smth(irp,iv,ih) /= 0) THEN

                counter(irp) = counter(irp) + 1

              ENDIF

            ENDDO
          ENDDO
        ENDDO

        nobs = 0_iintegers 

        DO irp = 1, nrp

          IF (counter(irp) > 0) THEN

            nobs = nobs + 1

!!! nobs are sorted according to azimut, range, and elevation!
            radpos_all(nobs) = irp

          ENDIF

        ENDDO

        ALLOCATE(m_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(n_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(o_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)

        m_all = -1_iintegers
        n_all = -1_iintegers
        o_all = -1_iintegers

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, nobs

          irp = radpos_all(iobs)

          CALL ind2sub3D( irp, rs_meta(ista)%naz, rs_meta(ista)%nra, &
                          m_all(iobs), n_all(iobs), o_all(iobs) )

        END DO

        IF ( ANY( n_all > rs_meta(ista)%nra .OR. n_all < 1_iintegers .OR. &
                  m_all > rs_meta(ista)%naz .OR. m_all < 1_iintegers .OR. &
                  o_all > rs_meta(ista)%nel .OR. o_all < 1_iintegers ) ) THEN
          WRITE (*,*) TRIM(yzroutine)//' ERROR: SO NE SCH***!!!'
        END IF


!!$==============================================================================================
!!$==============================================================================================
!!$
!!$ !!!!!!!!!!!!!!!!!!!!!!!!!!!! Compute and output heights and local elevations !!!!!!!!!!!!!!!!

                    
        IF ( (lout_geom .AND. (lonline .OR. .NOT.geom_written(ista))) .OR. lreadmeta_from_netcdf ) THEN

          ALLOCATE(hl_loc_smth(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(el_loc_smth(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(hl_loc(nrp), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(el_loc(nrp), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(intgrl_el(nrp), intgrl_hl(nrp), stat=izs); iaerr = iaerr + ABS(izs)

          hl_loc_smth = -999.99_ireals
          el_loc_smth = -999.99_ireals
          hl_loc      = 0.0_ireals
          el_loc      = 0.0_ireals
          intgrl_el = 0.0_ireals
          intgrl_hl = 0.0_ireals
          
          DO ismth = 1, nsmth

            hl_loc_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) =  hl_loc_all_smth(ismth)
            el_loc_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) =  el_loc_all_smth(ismth)
            
          ENDDO
          
          DO ih = 1, rs_meta(ista)%ngpsm_h
            DO iv = 1, rs_meta(ista)%ngpsm_v
              DO irp = 1, nrp
                
                IF (hl_loc_smth(irp,iv,ih) > -900.0_ireals) THEN

                  hl_loc(irp) = hl_loc(irp) +  &
                       rs_meta(ista)%weigsm_v(iv) * rs_meta(ista)%weigsm_h(ih) * &
                       hl_loc_smth(irp,iv,ih)
                  
                  intgrl_hl(irp) = intgrl_hl(irp) + &
                       rs_meta(ista)%weigsm_v(iv) * rs_meta(ista)%weigsm_h(ih)
                  
                END IF

                IF (flag_smth(irp,iv,ih) > 0 .AND. el_loc_smth(irp,iv,ih) > -900.0_ireals) THEN

                  el_loc(irp) = el_loc(irp) + &
                       rs_meta(ista)%weigsm_v(iv) * rs_meta(ista)%weigsm_h(ih) * &
                       el_loc_smth(irp,iv,ih)

                  intgrl_el(irp) = intgrl_el(irp) + &
                       rs_meta(ista)%weigsm_v(iv) * rs_meta(ista)%weigsm_h(ih)
                  
                ENDIF
                
              ENDDO
            ENDDO
          ENDDO
          
          
          ALLOCATE(hl_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(el_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)

!CDIR NODEP,VOVERTAKE,VOB
          DO iobs = 1, nobs
            
            irp = radpos_all(iobs)

            IF (intgrl_hl(irp) >= 1e-20_ireals) THEN
              hl_all(iobs) = hl_loc(irp) / intgrl_hl(irp)
            ELSE
              hl_all(iobs) = -999.99_ireals
            END IF

            IF (counter(irp) > 0 .AND. intgrl_el(irp) >= 1e-20_ireals) THEN
              el_all(iobs) = el_loc(irp) / intgrl_el(irp)
            ELSE
              el_all(iobs) = -999.99_ireals
            END IF
            
          ENDDO


!!$          ALLOCATE(hrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
!!$          ALLOCATE(erpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(hrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(erpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
          hrpolar = -999.99_ireals
          erpolar = -999.99_ireals

            !.. Sort the collected radar points into the 3D field according
            !   to sorted range, azimut and elevation:
          DO iobs = 1, nobs
!!$            hrpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = hl_all(iobs)
            hrpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = hl_all(iobs)
!!$            erpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = el_all(iobs)
            erpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = el_all(iobs)
          END DO

          IF ( lout_geom .AND. (lonline .OR. .NOT.geom_written(ista)) ) THEN

            !.. Output the sorted polar data set into a standard file format:
            !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
            
            !   - simple ASCII on all other systems
            fileprefix(:) = ' '
            WRITE (fileprefix, '("hrsim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 hrpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. radar bin height above MSL', 'm', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)
            
            CALL control_output(radgeomoutputunit(ista), time_mod, rs_meta(ista), "hl_polar [m]", &
                 hrpolar, (hrpolar > -900.0_ireals), -999.99_ireals, nobs)
            
            
            !.. Output the sorted polar data set into a standard file format:
            !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
            
            !   - simple ASCII on all other systems
            fileprefix(:) = ' '
            WRITE (fileprefix, '("ersim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 erpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. local elevation angle', 'deg', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)
            
            CALL control_output(radgeomoutputunit(ista), time_mod, rs_meta(ista), "el_polar [m]", &
                 erpolar, (erpolar > -900.0_ireals), -999.99_ireals, nobs)
          
            ! Set flag that geometry for this radar has been written to a file:
            geom_written(ista) = .TRUE.

          END IF
          
        END IF  ! calculate hl_all, el_all, output hrpolar, erpolar

!!$ !!!!!!!!!!!!!!!!! End of computations and output of heights and local elevations !!!!!!!!!!!!
!!$
!!$==============================================================================================
!!$==============================================================================================

        ! Allocate fields for sum of integration weights, beam function and functional determinant
        ! of the coordinate trafo kartesian -> spherical:
        ALLOCATE(intgrl_pf(nrp), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(pf_value(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(cos_value(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(azarr(rs_meta(ista)%naz), stat=izs); iaerr = iaerr + ABS(izs)

        intgrl_pf = 0.0_ireals
        pf_value  = 0.0_ireals
        cos_value = 0.0_ireals
        azarr     = 0.0_ireals

        ! fill up azimuth array

        DO iaz = 1,rs_meta(ista)%naz
          azarr(iaz) = (iaz-1_iintegers) * rs_meta(ista)%az_inc + rs_meta(ista)%az_start
          ! Folding into the range [0, 360] degrees:
          azarr(iaz) = MODULO(azarr(iaz),360.0_ireals)
        END DO

        DO ismth = 1, nsmth

          irp = radpos(ismth)

          IF (counter(irp) /= 0) THEN

            el  = rs_meta(ista)%el_arr( (irp-1)/(rs_meta(ista)%naz*rs_meta(ista)%nra)+1 )

            az  = azarr(MOD(irp-1, rs_meta(ista)%naz ) + 1)

            el_tmp =  el + smth_el_horzscan(ista,iv_all(ismth))

            az_tmp =  az + smth_az_horzscan(ista,ih_all(ismth),el)

            pf_value(irp,iv_all(ismth),ih_all(ismth)) = &
                 f4_eff_horzscan(ista,az,el,az_tmp,el_tmp)

            cos_value(irp,iv_all(ismth),ih_all(ismth)) = COS(el_tmp*degrad)

          ENDIF

        ENDDO

        DO ih = 1, rs_meta(ista)%ngpsm_h
          DO iv = 1, rs_meta(ista)%ngpsm_v
            DO irp = 1, nrp

              ! Integral over beam weighting function including missing points.
              ! This makes sense for reflectivity calculations, where this integral
              ! is the denominator. In this way, missing values (e.g., shielded values)
              ! enter the beam-function averaged value as zeros with full weight.

              ! Sum up all values when at least one of them is not a missing value:
              IF (counter(irp) > 0) THEN

                intgrl_pf(irp) = intgrl_pf(irp) + &
                     rs_meta(ista)%weigsm_v(iv)*rs_meta(ista)%weigsm_h(ih)*pf_value(irp,iv,ih)*cos_value(irp,iv,ih)

              END IF

            ENDDO
          ENDDO
        ENDDO


        IF (loutdbz .OR. lweightdbz) THEN

          ! z_radar_mod_smth should hold the linear value of reflectivity with index order
          ! (radpos, phi_points, theta_points):
          ALLOCATE(z_radar_mod_smth(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
          z_radar_mod_smth = -999.99_ireals


          ! "z_radar_mod_all_smth" ist linear (nicht dBZ!), also Daempfung logarithmisch abziehen:

          IF (lextdbz .AND. dbz_meta(ista)%itype_refl == 1) THEN

!!$            ALLOCATE(z_radar_mod_nmovh(rs_meta(ista)%nra,rs_meta(ista)%naz, &
!!$                 rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h)); iaerr = iaerr + ABS(izs)
!!$            ALLOCATE(z_ext_mod_nmovh  (rs_meta(ista)%nra,rs_meta(ista)%naz, &
!!$                 rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h)); iaerr = iaerr + ABS(izs)
!!$            ALLOCATE(z_ext_mod_nmovh_tot(rs_meta(ista)%nra,rs_meta(ista)%naz)); iaerr = iaerr + ABS(izs)
            ALLOCATE(z_radar_mod_nmovh(rs_meta(ista)%naz,rs_meta(ista)%nra, &
                 rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
            ALLOCATE(z_ext_mod_nmovh  (rs_meta(ista)%naz,rs_meta(ista)%nra, &
                 rs_meta(ista)%nel,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)
            ALLOCATE(z_ext_mod_nmovh_tot(rs_meta(ista)%naz,rs_meta(ista)%nra), stat=izs); iaerr = iaerr + ABS(izs)
!!$ UB>> Initialize with standard missing value (= point outside model domain):
            z_radar_mod_nmovh = -999.99_ireals
            z_ext_mod_nmovh = -999.99_ireals

            DO ismth = 1, nsmth

              CALL ind2sub3D( radpos(ismth), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                              m, n, o )

!!$              z_radar_mod_nmovh(n(ismth),m(ismth),o(ismth),iv_all(ismth),ih_all(ismth)) = &
!!$                   z_radar_mod_all_smth(ismth)
!!$              z_ext_mod_nmovh(n(ismth),m(ismth),o(ismth),iv_all(ismth),ih_all(ismth)) =  &
!!$                   z_ext_mod_all_smth(ismth)
              z_radar_mod_nmovh(m,n,o,iv_all(ismth),ih_all(ismth)) = &
                   z_radar_mod_all_smth(ismth)
              z_ext_mod_nmovh(m,n,o,iv_all(ismth),ih_all(ismth)) =  &
                   z_ext_mod_all_smth(ismth)
            END DO

            DO ih = 1, rs_meta(ista)%ngpsm_h
              DO iv = 1, rs_meta(ista)%ngpsm_v
                DO i = 1, rs_meta(ista)%nel
                  z_ext_mod_nmovh_tot(:,1) = 0.0_ireals
                  DO j = 1, rs_meta(ista)%nra
                    DO k = 1, rs_meta(ista)%naz
                      ext_coeff = MAX(z_ext_mod_nmovh(k,j,i,iv,ih), 0.0_ireals)
!!$                      IF (j == 1) THEN
!!$                        z_ext_mod_nmovh_tot(k,j) = ext_coeff*rs_meta(ista)%ra_inc
!!$                      ELSE
                      z_ext_mod_nmovh_tot(k,j) = z_ext_mod_nmovh_tot(k,MAX(j-1,1_iintegers)) + &
                           ext_coeff*rs_meta(ista)%ra_inc
!!$                      END IF
                      ! Note: z_radar_mod_nmovh is in linear units, so correct for extinction in linear space:
                      IF (z_radar_mod_nmovh(k,j,i,iv,ih) >= 0.0_ireals) THEN
                        ! preserving missing values < 0 !
                        z_radar_mod_nmovh(k,j,i,iv,ih) = z_radar_mod_nmovh(k,j,i,iv,ih) * &
                             EXP(-2.0_ireals * z_ext_mod_nmovh_tot(k,j))
                      END IF
                    END DO
                  END DO
                END DO
              END DO
            END DO

!CDIR NODEP
            DO ismth = 1, nsmth

              CALL ind2sub3D( radpos(ismth), rs_meta(ista)%naz, rs_meta(ista)%nra, &
                              m, n, o )

              ! still linear reflectivity value:
!!$              z_radar_mod_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = &
!!$                   z_radar_mod_nmovh(n(ismth),m(ismth),o(ismth),iv_all(ismth),ih_all(ismth))
              z_radar_mod_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = &
                   z_radar_mod_nmovh(m,n,o,iv_all(ismth),ih_all(ismth))

            END DO

          ELSE  ! .not. lextdbz

!CDIR NODEP
            DO ismth = 1, nsmth
              
              z_radar_mod_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = &
                   z_radar_mod_all_smth(ismth)
              
            ENDDO

          END IF


          IF (lweightdbz .OR. loutdbz) THEN

            ! .. 2D-integral over (ze_radar/l_ext^2)*f4*cos(theta) dtheta dphi:
            !   ( NOTE: the integral weights for Gauss-Legendre are already
            !     pre-multiplied with the total norm. integration range [-1;1],
            !     but the transformation factor (b-a)/2 to the "true" ranges, 
            !     which are, e.g.,
            !     rs_meta_d(1)%smth_interv_fact*[-theta3/2;+theta3/2]
            !     i.e., 
            !     rs_meta_d(1)%smth_interv_fact * theta3, are missing here,
            !     since the integrals only appear later as quotients,
            !     so that a constant factor cancels out. )
            !
            ALLOCATE(intgrl_z(nrp), stat=izs); iaerr = iaerr + ABS(izs)
            intgrl_z  = 0.0_ireals

            DO ih = 1, rs_meta(ista)%ngpsm_h
              DO iv = 1, rs_meta(ista)%ngpsm_v
                DO irp = 1, nrp

                  IF (counter(irp) > 0) THEN

                    IF (flag_smth(irp,iv,ih) > 0 .AND. z_radar_mod_smth(irp,iv,ih) > 0.0_ireals) THEN
                      intgrl_z(irp) = intgrl_z(irp) + &
                           rs_meta(ista)%weigsm_v(iv)*rs_meta(ista)%weigsm_h(ih)*z_radar_mod_smth(irp,iv,ih)* &
                           pf_value(irp,iv,ih)*cos_value(irp,iv,ih)
                    END IF

                  END IF

                ENDDO
              ENDDO
            ENDDO

          ENDIF ! lweightdbz .OR. loutdbz


!!$          ALLOCATE(zrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
          ALLOCATE(zrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
          zrpolar = -999.99_ireals

          IF (loutdbz) THEN 

            ALLOCATE(z_radar_mod_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)

!CDIR NODEP,VOVERTAKE,VOB
            DO iobs = 1, nobs

              irp = radpos_all(iobs)

              ! still linear reflectivity values:
              IF (counter(irp) > 0) THEN
                z_radar_mod_all(iobs) = intgrl_z(irp) / intgrl_pf(irp)
              ELSE
                z_radar_mod_all(iobs) = -999.99_ireals
              END IF

            ENDDO

            !.. Sort the collected radar points into the 3D field according
            !   to sorted range, azimut and elevation:
!CDIR NODEP
            DO iobs = 1, nobs
              IF (z_radar_mod_all(iobs) >= 1e-9_ireals) THEN
!!$                zrpolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = &
                zrpolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = &
                     10.0_ireals * LOG10(z_radar_mod_all(iobs))
              ELSEIF (z_radar_mod_all(iobs) >= -900.0_ireals) THEN
!!$                zrpolar( n_all(iobs),m_all(iobs),o_all(iobs) ) = -99.99_ireals
                zrpolar( m_all(iobs),n_all(iobs),o_all(iobs) ) = -99.99_ireals
              END IF
            END DO

          ! Set correct 0-value (-99.99) and missing value (-999.99) for zrpolar:
!CDIR BEGIN COLLAPSE
          WHERE (zrpolar >= -900.0_ireals .AND. zrpolar < -90_ireals)
            zrpolar = -99.99_ireals
          END WHERE
          WHERE (zrpolar < -900.0_ireals)
            zrpolar = -999.99_ireals
          END WHERE
!CDIR END

            !.. Output the sorted polar data set into a standard file format:
            !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak

            !   - simple ASCII on all other systems
            fileprefix(:) = ' '
            WRITE (fileprefix, '("zrsim_id-",i6.6)') rs_meta(ista)%station_id
            CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
                 zrpolar, TRIM(ADJUSTL(fileprefix)), 'Simul. radar reflectivity', 'dBz', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

            CALL control_output(radrefloutputunit(ista), time_mod, rs_meta(ista), "Z [dBZ]", &
                 zrpolar, (zrpolar > -900.0_ireals), -999.99_ireals, nobs)

          END IF ! loutdbz

        ENDIF ! loutdbz or lweightdbz


!!$        ALLOCATE(vrpolar(rs_meta(ista)%nra,rs_meta(ista)%naz,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
        ALLOCATE(vrpolar(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), stat=izs); iaerr = iaerr + ABS(izs)
        vrpolar = -999.99_ireals

        IF (loutradwind) THEN

          ALLOCATE(intgrl_wind(nrp)); iaerr = iaerr + ABS(izs)
          ALLOCATE(radwind_mod_smth(nrp,rs_meta(ista)%ngpsm_v,rs_meta(ista)%ngpsm_h), stat=izs); iaerr = iaerr + ABS(izs)

          intgrl_wind      = 0.0_ireals
          radwind_mod_smth = -999.99_ireals

          ! Re-initialize intgrl_pf for re-calculation for radwind, disregarding missing values::
          intgrl_pf        = 0.0_ireals

          WRITE(*,*) " max of radwind_mod_all_smth  is:",MAXVAL(radwind_mod_all_smth)
          WRITE(*,*) " min of radwind_mod_all_smth is:",MINVAL(radwind_mod_all_smth)

          DO ismth = 1, nsmth

             radwind_mod_smth(radpos(ismth),iv_all(ismth),ih_all(ismth)) = radwind_mod_all_smth(ismth)

          ENDDO

          WRITE(*,*) " max of radwind_mod_smth is:",MAXVAL(radwind_mod_smth)
          WRITE(*,*) " min of radwind_mod_smth is:",MINVAL(radwind_mod_smth)

          IF (lweightdbz) THEN

            DO ih = 1, rs_meta(ista)%ngpsm_h
              DO iv = 1, rs_meta(ista)%ngpsm_v
                DO irp = 1, nrp

                  IF (counter(irp) > 0) THEN

                    IF ( flag_smth(irp,iv,ih) > 0 .AND. z_radar_mod_smth(irp,iv,ih) > 0.0_ireals .AND. &
                         radwind_mod_smth(irp,iv,ih) > -900.0_ireals ) THEN

                      intgrl_wind(irp) = intgrl_wind(irp) + &
                           rs_meta(ista)%weigsm_v(iv)*rs_meta(ista)%weigsm_h(ih)*radwind_mod_smth(irp,iv,ih)* &
                           pf_value(irp,iv,ih)*cos_value(irp,iv,ih)*z_radar_mod_smth(irp,iv,ih)

                    END IF

                  END IF

                ENDDO
              ENDDO
            ENDDO

          ELSE   ! .not. lweightdbz

            DO ih = 1, rs_meta(ista)%ngpsm_h
              DO iv = 1, rs_meta(ista)%ngpsm_v
                DO irp = 1, nrp

                  IF (counter(irp) > 0) THEN

                    IF ( flag_smth(irp,iv,ih) > 0 .AND. radwind_mod_smth(irp,iv,ih) > -900.0_ireals ) THEN

                      intgrl_wind(irp) = intgrl_wind(irp) + &
                           rs_meta(ista)%weigsm_v(iv)*rs_meta(ista)%weigsm_h(ih)*radwind_mod_smth(irp,iv,ih)* &
                           pf_value(irp,iv,ih)*cos_value(irp,iv,ih)

                      ! Re-calculate intgrl_pf. This time, weights for missing values are not counted,
                      ! which makes sense for radial wind:
                      intgrl_pf(irp) = intgrl_pf(irp) + &
                           rs_meta(ista)%weigsm_v(iv)*rs_meta(ista)%weigsm_h(ih)*pf_value(irp,iv,ih)*cos_value(irp,iv,ih)

                    END IF

                  END IF

                ENDDO
              ENDDO
            ENDDO

          END IF

          ALLOCATE(radwind_mod_all(nobs), stat=izs); iaerr = iaerr + ABS(izs)

          IF (lweightdbz) THEN 

!CDIR NODEP,VOVERTAKE,VOB
            DO iobs = 1, nobs

              irp = radpos_all(iobs)

              IF( intgrl_z(irp) < 1.0e-9_ireals .OR. counter(irp) == 0 ) THEN

                radwind_mod_all(iobs) = -999.99_ireals

              ELSE

                radwind_mod_all(iobs) =  intgrl_wind(irp) / intgrl_z(irp)

              ENDIF

            ENDDO

          ELSE ! lweightdbz

!CDIR NODEP,VOVERTAKE,VOB
            DO iobs = 1, nobs

              irp = radpos_all(iobs)

              IF( counter(irp) > 0 .AND. intgrl_pf(irp) >= 1e-20_ireals) THEN

                radwind_mod_all(iobs) = intgrl_wind(irp) / intgrl_pf(irp)

              ELSE

                radwind_mod_all(iobs) = -999.99_ireals

              END IF

            ENDDO

          ENDIF  ! lweightdbz


          !.. Sort the collected radar points into the 3D field according
          !   to sorted range, azimut and elevation:
          DO iobs = 1, nobs
!!$            vrpolar( n_all(iobs),&
!!$                     m_all(iobs),&
!!$                     o_all(iobs) ) = radwind_mod_all(iobs)
            vrpolar( m_all(iobs),&
                     n_all(iobs),&
                     o_all(iobs) ) = radwind_mod_all(iobs)
          END DO

          !.. Output the sorted polar data set into a standard file format: 
          !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
          !   - simple ASCII on all other systems
          fileprefix(:) = ' '
          WRITE (fileprefix, '("vrsim_id-",i6.6)') rs_meta(ista)%station_id
          CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
               vrpolar, TRIM(ADJUSTL(fileprefix)), &
               'Simul. radial velocity, no aliasing', 'm/s', 'polar', &
               rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.FALSE.)

          CALL control_output(radwindoutputunit(ista), time_mod, rs_meta(ista), "V_r [m/s]", &
               vrpolar, (vrpolar > -900.0_ireals), -999.99_ireals, nobs)

        END IF ! loutradwind

        
        !.. Trap allocation errors:
        IF (iaerr /= 0) THEN
          CALL model_abort (my_world_id, 39999, &
               'ERROR: allocation error in ' //TRIM(yzroutine)// &
               ', probably not enough memory! Decrease number of smoothing points! ', &
               TRIM(yzroutine)//', distribution of refractive index at radar stations')
        END IF

#ifdef NETCDF
        IF (lreadmeta_from_netcdf) THEN

          CALL output_radar_dwd_obs (ista, time_mod, vrpolar, zrpolar, hrpolar)

        END IF
#endif

        DEALLOCATE( radpos,                                         &
                    iv_all, ih_all, flag_smth, intgrl_pf, pf_value, &
                    cos_value, azarr, counter, radpos_all,          &
                    m_all, n_all, o_all )

        DEALLOCATE( vrpolar, zrpolar )

        IF(ALLOCATED(intgrl_z))         DEALLOCATE(intgrl_z)
        IF(ALLOCATED(z_radar_mod_smth)) DEALLOCATE(z_radar_mod_smth)
        IF(ALLOCATED(z_radar_mod_all))  DEALLOCATE(z_radar_mod_all)

        IF(ALLOCATED(intgrl_wind))      DEALLOCATE(intgrl_wind)
        IF(ALLOCATED(radwind_mod_smth)) DEALLOCATE(radwind_mod_smth)
        IF(ALLOCATED(radwind_mod_all))  DEALLOCATE(radwind_mod_all)

        IF(ALLOCATED(hrpolar))          DEALLOCATE(hrpolar)
        IF(ALLOCATED(hl_loc_smth))      DEALLOCATE(hl_loc_smth)
        IF(ALLOCATED(hl_loc))           DEALLOCATE(hl_loc)
        IF(ALLOCATED(intgrl_hl))        DEALLOCATE(intgrl_hl)
        IF(ALLOCATED(hl_all))           DEALLOCATE(hl_all)

        IF(ALLOCATED(erpolar))          DEALLOCATE(erpolar)
        IF(ALLOCATED(el_loc_smth))      DEALLOCATE(el_loc_smth)
        IF(ALLOCATED(el_loc))           DEALLOCATE(el_loc)
        IF(ALLOCATED(intgrl_el))        DEALLOCATE(intgrl_el)
        IF(ALLOCATED(el_all))           DEALLOCATE(el_all)

        IF (ALLOCATED(z_radar_mod_nmovh)) DEALLOCATE(z_radar_mod_nmovh)
        IF (ALLOCATED(z_ext_mod_nmovh))   DEALLOCATE(z_ext_mod_nmovh)
        IF (ALLOCATED(z_ext_mod_nmovh_tot))   DEALLOCATE(z_ext_mod_nmovh_tot)          

      END IF ! output_my_radar = .true.

      IF ( num_compute > 1 ) THEN

        ! .. In this case, the memory has been allocated to the pointer
        !    itself by gatherv_values(). Therefore deallocate it.
        IF (ASSOCIATED(radwind_mod_all_smth))    DEALLOCATE(radwind_mod_all_smth)
        IF (ASSOCIATED(z_radar_mod_all_smth))    DEALLOCATE(z_radar_mod_all_smth)
        IF (ASSOCIATED(z_ext_mod_all_smth))      DEALLOCATE(z_ext_mod_all_smth) 
        IF (ASSOCIATED(radpos_all_smth))         DEALLOCATE(radpos_all_smth)
        IF (ASSOCIATED(hl_loc_all_smth))         DEALLOCATE(hl_loc_all_smth)
        IF (ASSOCIATED(el_loc_all_smth))         DEALLOCATE(el_loc_all_smth)

      ELSE

        ! .. In this case, the pointers simply point to another
        !    pointers, to whom the memory has been allocated. Therefore,
        !    simply break the connection by NULLIFYING. The memory
        !    of the original pointers will be deallocated at the end
        !    of organize_radar().
        IF (ASSOCIATED(radwind_mod_all_smth))    NULLIFY(radwind_mod_all_smth)
        IF (ASSOCIATED(z_radar_mod_all_smth))    NULLIFY(z_radar_mod_all_smth)
        IF (ASSOCIATED(z_ext_mod_all_smth))      NULLIFY(z_ext_mod_all_smth) 
        IF (ASSOCIATED(radpos_all_smth))         NULLIFY(radpos_all_smth)
        IF (ASSOCIATED(hl_loc_all_smth))         NULLIFY(hl_loc_all_smth)
        IF (ASSOCIATED(el_loc_all_smth))         NULLIFY(el_loc_all_smth)

      END IF

      IF (ltime) CALL get_timings (i_radar_out, ntstep, dt, izerror)

    END DO chunkloop ! loop over (num_compute packages of) stations

    !----------------------------------------------------------------
    ! .. Distribute the info, for which stations the feedback files
    !    have been created by any of the processors:

    IF (num_compute > 1 .AND. lreadmeta_from_netcdf) THEN

      lsendbuf(:) = .FALSE.
      DO ista=1,nradsta
        lsendbuf(ista) = rs_meta(ista)%lfdbkfile_exist
      END DO

      CALL global_values (lsendbuf(1:nradsta), nradsta, 'OR', imp_logical, icomm_cart,    &
                          -1_iintegers, yzerrmsg, mpierror)
      DO ista=1,nradsta
        rs_meta(ista)%lfdbkfile_exist = lsendbuf(ista)
      END DO

    END IF

    !----------------------------------------------------------------
    ! .. Distribute the info, for which stations the geometry files
    !    have been written by any of the processors:

    IF (num_compute > 1 .AND. lout_geom .AND. .NOT.lonline .AND. .NOT.geom_all_written) THEN

      CALL global_values (geom_written(1:nradsta), nradsta, 'OR', imp_logical, icomm_cart,    &
                          -1_iintegers, yzerrmsg, mpierror)

    END IF

    geom_all_written = ALL(geom_written(1:nradsta))

    !----------------------------------------------------------------

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE output_radar_smth

  SUBROUTINE elim_shielded(f, naz, nra, nel, shieldedval)

    !------------------------------------------------------------------------------
    !
    ! Description: Set values in field f to a value of "shieldedval" 
    !              outwards in range, beginning from first 
    !              shielded value (=988.88) encountered along the ray.
    !
    ! The field f (az_ind, ra_ind, el_ind) is modified in place.
    !
    !------------------------------------------------------------------------------

    IMPLICIT NONE

    REAL(kind=ireals), INTENT(inout), DIMENSION(:,:,:) :: f
    INTEGER(kind=iintegers), INTENT(in) :: naz, nra, nel
    REAL(kind=ireals), INTENT(in)       :: shieldedval   ! missing value for shielded rangebins

    INTEGER(kind=iintegers)  :: i, j, k
    LOGICAL                  :: flag(naz,nel)
    
!CDIR COLLAPSE
    flag = .FALSE.

    DO j=1, nra
      DO k=1, nel
        DO i=1, naz
          IF (.NOT. flag(i,k)) THEN
            IF (f(i,j,k) < -980.0_ireals .AND. f(i,j,k) > -990.0_ireals) THEN
              f(i,j,k) = shieldedval
              flag(i,k) = .TRUE.
            END IF
          ELSE
            f(i,j,k) = shieldedval
          END IF
        END DO
      END DO
    END DO

  END SUBROUTINE elim_shielded

#ifdef NETCDF

  SUBROUTINE output_radar_dwd_obs ( ista, time_mod, vr_mod, zr_mod, hr_mod )

    !------------------------------------------------------------------------------
    !
    ! Description: Reads the radar obs data of station ista from NetCDF files
    !              (one file per data type - vr, qv, z, qz - for the entire time frame)
    !              and writes the data to disc. Currently this is done in 
    !              ascii files (or bin files on the NEC),
    !              later it will be done also to NetCDF feedback files.
    !
    !              Before writing, the radar data are sorted into a 3D array
    !              according to range, azimut and elevation indices,
    !              data(range,azi,ele),
    !              range runs from 1 ... Nrange ( r = range * ra_inc )
    !              azi   runs from 1 ... Naz    ( az = az_start + (azi-1)*az_inc )
    !              ele   runs from 1 ... Nele   ( as defined in el_arr(ele) meta data )
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    REAL(kind=ireals), INTENT(IN)       :: time_mod     ! seconds since model start
    INTEGER(kind=iintegers), INTENT(IN) :: ista         ! index of radar station
    REAL(kind=ireals), INTENT(IN), &                    ! simulated radar fields for feedback files
         DIMENSION( rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel ) :: &
                                           vr_mod, zr_mod, hr_mod

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) :: yzroutine
    CHARACTER (LEN=80) :: yzerrmsg 

    INTEGER (KIND = iintegers)   :: i, iobs, nobs_obs, tmppos_obs

    INTEGER (KIND = iintegers), ALLOCATABLE :: &
         m_obs(:),  & ! azimuthal indices for all radar points of a radar station in observations
         n_obs(:),  & ! radial    indices for all radar points of a radar station in observations
         o_obs(:)     ! elevation indices for all radar points of a radar station in observations

    REAL(kind=ireals),          ALLOCATABLE :: vrpolar_obs(:,:,:)  , zrpolar_obs(:,:,:)  , &
                                               vrpolar_obs_q(:,:,:), zrpolar_obs_q(:,:,:)

    CHARACTER(len=100) :: fileprefix

    LOGICAL            :: zlradwind_ok, zlzradar_ok, zlrefend, zlastpr, zlwrite_veridata

#ifdef NUDGING
    CHARACTER (LEN=300)          :: yerrstring 
    INTEGER (KIND = iintegers)   :: fdbk_err, nexce_rep, nexce_bdy
    REAL(kind=ireals),          ALLOCATABLE ::   &
         rdata_obs(:,:,:) , rquali_obs(:,:,:)  , &
         rdata_mod(:,:,:)                      , &
         rheight  (:,:,:) , rpress    (:,:,:), &
         zazivec(:), zrvec(:)
#endif

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE output_radar_dwd_obs
    !------------------------------------------------------------------------------


    yzroutine(:) = ' '
    yzroutine = 'output_radar_dwd_obs'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !.. Read DWD radar data from station number "ista" at time "time_mod":
    CALL read_dwd_rad(ista, time_mod, 'read')

    ! .. nob_obs from read_dwd_rad:
    nobs_obs = MAXVAL(rs_data(ista)%nobs_obs)

    ! .. check which observations (and quality flags) are available for output:
    zlradwind_ok = ( rs_meta(ista)%lradwind_avail .AND. rs_meta(ista)%lradwind_q_avail ) .AND. loutradwind
    zlzradar_ok  = ( rs_meta(ista)%lzradar_avail  .AND. rs_meta(ista)%lzradar_q_avail  ) .AND. loutdbz

    
    ! .. If radwind obs or reflectivity obs are available, get indices for 3D sorting:
    !---------------------------------------------------------------------------------
    IF ( zlradwind_ok .OR. zlzradar_ok ) THEN

      ALLOCATE( vrpolar_obs(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel),   &
                vrpolar_obs_q(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel), &
                zrpolar_obs(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel),   &
                zrpolar_obs_q(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel) )
      !.. Initialize with standard missing value:
!CDIR BEGIN COLLAPSE
      vrpolar_obs = -999.99_ireals
      vrpolar_obs_q = -999.99_ireals
      zrpolar_obs = -999.99_ireals
      zrpolar_obs_q = -999.99_ireals
!CDIR END

      ALLOCATE( m_obs(nobs_obs), n_obs(nobs_obs), o_obs(nobs_obs) )

      IF ( lequal_azi_alldatasets ) THEN
!CDIR BEGIN COLLAPSE
        m_obs = -1_iintegers
        n_obs = -1_iintegers
        o_obs = -1_iintegers
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, nobs_obs
          tmppos_obs = rs_data(ista)%ind_intp_obs(iobs)
          IF (tmppos_obs > -900_iintegers) THEN
            ! .. existing datum in NetCDF file (the data itself might still be missing values):
            m_obs(iobs)  = MOD( tmppos_obs-1, rs_meta(ista)%naz ) + 1
            n_obs(iobs)  = MOD( INT(REAL(tmppos_obs-1,ireals) / &
                 REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
            o_obs(iobs)  = INT(REAL(tmppos_obs-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
                 *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          ENDIF
        END DO

      END IF

    END IF


    ! .. If radwind obs are available, sort them into regular 3D data set and output:
    !--------------------------------------------------------------------------------
    IF ( zlradwind_ok ) THEN

      IF ( .NOT.lequal_azi_alldatasets ) THEN

!CDIR BEGIN COLLAPSE
        m_obs = -1_iintegers
        n_obs = -1_iintegers
        o_obs = -1_iintegers
!CDIR END
!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, rs_data(ista)%nobs_obs(1)
          tmppos_obs = rs_data(ista)%ind_intp_obs_vr(iobs)
          IF (tmppos_obs > -900_iintegers) THEN
            ! .. existing datum in NetCDF file (the data itself might still be missing values):
            m_obs(iobs)  = MOD( tmppos_obs-1, rs_meta(ista)%naz ) + 1
            n_obs(iobs)  = MOD( INT(REAL(tmppos_obs-1,ireals) / &
                 REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
            o_obs(iobs)  = INT(REAL(tmppos_obs-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
                 *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          ENDIF
        END DO

      END IF

      !.. Sort the collected radar points into the 3D field according
      !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs_obs(1)
        IF ( rs_data(ista)%ind_intp_obs_vr(iobs) > -900_iintegers .AND. &
             rs_data(ista)%radwind_obs(iobs) /= missing_vr ) THEN
          vrpolar_obs( m_obs(iobs),&
               n_obs(iobs),&
               o_obs(iobs) ) = rs_data(ista)%radwind_obs(iobs)
        END IF
      END DO
      

      IF ( .NOT.lequal_azi_alldatasets ) THEN

!CDIR BEGIN COLLAPSE
        m_obs = -1_iintegers
        n_obs = -1_iintegers
        o_obs = -1_iintegers
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, rs_data(ista)%nobs_obs(2)
          tmppos_obs = rs_data(ista)%ind_intp_obs_qv(iobs)
          IF (tmppos_obs > -900_iintegers) THEN
            ! .. existing datum in NetCDF file (the data itself might still be missing values):
            m_obs(iobs)  = MOD( tmppos_obs-1, rs_meta(ista)%naz ) + 1
            n_obs(iobs)  = MOD( INT(REAL(tmppos_obs-1,ireals) / &
                 REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
            o_obs(iobs)  = INT(REAL(tmppos_obs-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
                 *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          ENDIF
        END DO
      END IF

      !.. Sort the collected radar points into the 3D field according
      !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, rs_data(ista)%nobs_obs(2)
          IF ( rs_data(ista)%ind_intp_obs_qv(iobs) > -900_iintegers .AND. &
               rs_data(ista)%radwind_obs_q(iobs) /= missing_qv ) THEN
            vrpolar_obs_q( m_obs(iobs),&
                 n_obs(iobs),&
                 o_obs(iobs) ) = rs_data(ista)%radwind_obs_q(iobs)
          END IF
        END DO


      !.. Output the sorted polar data set into a standard file format: 
      !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
      !   - simple ASCII on all other systems
      fileprefix(:) = ' '
      WRITE (fileprefix, '("vrobs_id-",i6.6)') rs_meta(ista)%station_id
      CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
           vrpolar_obs, TRIM(ADJUSTL(fileprefix)), 'Observed radial velocity, no aliasing', 'm/s', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.TRUE.)

      fileprefix(:) = ' '
      WRITE (fileprefix, '("qvobs_id-",i6.6)') rs_meta(ista)%station_id
      CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
           vrpolar_obs_q, TRIM(ADJUSTL(fileprefix)), 'Quality of observed radial velocity, no aliasing', '-', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.TRUE.)

      CALL control_output(radwindobsoutputunit(ista), time_mod, rs_meta(ista), "V_r [m/s]", &
           vrpolar_obs, (vrpolar_obs > -900.0_ireals), -999.99_ireals, nobs_obs)

    END IF  ! zlradwind_ok


    ! .. If reflectivity obs are available, sort them into regular 3D data set and output:
    !-------------------------------------------------------------------------------------
    IF ( zlzradar_ok ) THEN

      IF ( .NOT.lequal_azi_alldatasets ) THEN

!CDIR BEGIN COLLAPSE
        m_obs = -1_iintegers
        n_obs = -1_iintegers
        o_obs = -1_iintegers
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, rs_data(ista)%nobs_obs(3)
          tmppos_obs = rs_data(ista)%ind_intp_obs_z(iobs)
          IF (tmppos_obs > -900_iintegers) THEN
            ! .. existing datum in NetCDF file (the data itself might still be missing values):
            m_obs(iobs)  = MOD( tmppos_obs-1, rs_meta(ista)%naz ) + 1
            n_obs(iobs)  = MOD( INT(REAL(tmppos_obs-1,ireals) / &
                 REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
            o_obs(iobs)  = INT(REAL(tmppos_obs-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
                 *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          ENDIF
        END DO

      END IF

      !.. Sort the collected radar points into the 3D field according
      !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs_obs(3)
        IF ( rs_data(ista)%ind_intp_obs_z(iobs) > -900_iintegers .AND. &
             rs_data(ista)%z_radar_obs(iobs) /= missing_z ) THEN
          ! .. Observed reflectivity is already in logarithmic dBZ units:
          zrpolar_obs( m_obs(iobs),&
               n_obs(iobs),&
               o_obs(iobs) ) = rs_data(ista)%z_radar_obs(iobs)
        END IF
      END DO
        

      IF ( .NOT.lequal_azi_alldatasets ) THEN

!CDIR BEGIN COLLAPSE
        m_obs = -1_iintegers
        n_obs = -1_iintegers
        o_obs = -1_iintegers
!CDIR END

!CDIR NODEP,VOVERTAKE,VOB
        DO iobs = 1, rs_data(ista)%nobs_obs(4)
          tmppos_obs = rs_data(ista)%ind_intp_obs_qz(iobs)
          IF (tmppos_obs > -900_iintegers) THEN
            ! .. existing datum in NetCDF file (the data itself might still be missing values):
            m_obs(iobs)  = MOD( tmppos_obs-1, rs_meta(ista)%naz ) + 1
            n_obs(iobs)  = MOD( INT(REAL(tmppos_obs-1,ireals) / &
                 REAL(rs_meta(ista)%naz,ireals),iintegers), rs_meta(ista)%nra ) + 1
            o_obs(iobs)  = INT(REAL(tmppos_obs-1,ireals) / (REAL(rs_meta(ista)%naz,ireals) &
                 *REAL(rs_meta(ista)%nra,ireals)),iintegers) + 1
          ENDIF
        END DO
        
      END IF

      !.. Sort the collected radar points into the 3D field according
      !   to sorted range, azimut and elevation:
!CDIR NODEP,VOVERTAKE,VOB
      DO iobs = 1, rs_data(ista)%nobs_obs(4)
        IF ( rs_data(ista)%ind_intp_obs_qz(iobs) > -900_iintegers .AND. &
             rs_data(ista)%z_radar_obs_q(iobs) /= missing_qz ) THEN
          ! .. Observed reflectivity is already in logarithmic dBZ units:
          zrpolar_obs_q( m_obs(iobs),&
               n_obs(iobs),&
               o_obs(iobs) ) = rs_data(ista)%z_radar_obs_q(iobs)
        END IF
      END DO
        

      ! Set correct 0-value (-99.99) for zrpolar (missing values have been set above (-999.99)):
!CDIR BEGIN COLLAPSE
      WHERE (zrpolar_obs >= -900.0_ireals .AND. zrpolar_obs < -90_ireals)
        zrpolar_obs = -99.99_ireals
      END WHERE
!CDIR END

      !.. Output the sorted polar data set into a standard file format: 
      !   - binary on the SX9, convert to simple ASCII with program "bin2ascii_convrates3d" from Ulrich Blahak
      !   - simple ASCII on all other systems
      fileprefix(:) = ' '
      WRITE (fileprefix, '("zrobs_id-",i6.6)') rs_meta(ista)%station_id
      CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
           zrpolar_obs, TRIM(ADJUSTL(fileprefix)), 'Observed radar reflectivity', 'dBz', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.TRUE.)
      
      fileprefix(:) = ' '
      WRITE (fileprefix, '("qzobs_id-",i6.6)') rs_meta(ista)%station_id
      CALL output3d_ascii_radar(rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
           zrpolar_obs_q, TRIM(ADJUSTL(fileprefix)), 'Observed radar reflectivity', 'dBz', 'polar', &
                 rmeta=rs_meta(ista), refltype=dbz_meta(ista)%itype_refl, is_aliased=.TRUE.)
      
      CALL control_output(radreflobsoutputunit(ista), time_mod, rs_meta(ista), "Z [dBZ]", &
           zrpolar_obs, (zrpolar_obs > -900.0_ireals), -999.99_ireals, nobs_obs)
      
    END IF  ! zlzradar_ok


#ifdef NUDGING

    ! .. Output of NetCDF feedback file (vr and z are written to the same file!):
    !----------------------------------------------------------------------------

    IF ( lfdbk_output .AND. ( zlradwind_ok .OR. zlzradar_ok ) ) THEN

      ! .. preparations, coordinate vectors and temporary storage fiels in order (range, azi, ele):

      zlrefend = .FALSE. ! eigentlich: (lnudge) .AND. (nverend == nstop)

      ! .. zlastpr has to be .true. if we are at the last output time step:
      zlastpr  = ( ABS(time_mod - rs_meta(ista)%obs_times(rs_meta(ista)%nobs_times)) <= 0.5 * dt )

      zlwrite_veridata = .TRUE.   ! write also the simulated data to feedback file
 
      ALLOCATE ( &
           zazivec (rs_meta(ista)%naz), &
           zrvec   (rs_meta(ista)%nra)  &
           )

      DO i=1, rs_meta(ista)%naz
        zazivec(i) = rs_meta(ista)%az_start + (i-1)*rs_meta(ista)%az_inc
        zazivec(i) = MODULO(zazivec(i),360.0_ireals)
      END DO
      DO i=1, rs_meta(ista)%nra
        zrvec(i) = i * rs_meta(ista)%ra_inc
      END DO

 !!$ Caution: data fields in order (azi, range, ele), not (range, azi, ele)!
      ALLOCATE ( &
!!$           rdata_obs (rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel) ,&
!!$           rquali_obs(rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel) ,&
!!$           rdata_mod (rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel) ,&
!!$           rheight   (rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel) ,&
           rpress    (rs_meta(ista)%naz,rs_meta(ista)%nra,rs_meta(ista)%nel)  &
           )
      
      ! .. radar bin heights and pressures:

!!$      rheight    = RESHAPE (hr_mod,        shape=SHAPE(rheight),    order=(/2,1,3/))
      
      ! .. estimate of the pressure at the bin heights
      !     (for now: simple ICAO standard atmosphere, later: something more
      !      accurate, e.g., esimate based on mean surface pressure in comb. with
      !      temperature gradients from the ICAO- atmosphere)
!!$      rpress = 1013.25e2 * (1.0 - 0.0065*MIN(rheight,11000.0_ireals)/293.16) ** &
!!$                 (9.816/(287.05*0.0065))
      rpress = 1013.25e2 * (1.0 - 0.0065*MIN(hr_mod,11000.0_ireals)/293.16) ** &
                 (9.816/(287.05*0.0065))

      IF ( zlradwind_ok ) THEN

!!$        rdata_obs  = RESHAPE (vrpolar_obs,   shape=SHAPE(rdata_obs),  order=(/2,1,3/))
!!$        rquali_obs = RESHAPE (vrpolar_obs_q, shape=SHAPE(rquali_obs), order=(/2,1,3/))
!!$        rdata_mod  = RESHAPE (vr_mod,        shape=SHAPE(rdata_mod),  order=(/2,1,3/))

        yerrstring(:) = ' '
        fdbk_err = 0

        CALL obs_write_cdf_feedobs ( ista, 'vr', time_mod/60.0, &
!!$             rdata_obs, rquali_obs, &
!!$             rdata_mod, rheight, rpress, &
             vrpolar_obs, vrpolar_obs_q, &
             vr_mod, hr_mod, rpress, &
             zazivec, zrvec, rs_meta(ista)%el_arr(1:rs_meta(ista)%nel), &
             rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
             (zlastpr .AND. .NOT.loutdbz), zlrefend, zlwrite_veridata,                &
             ydate_ini, hversta, hverend,                 &
             ie_tot, je_tot, ke_tot, pollat, pollon,      &
             dlat, dlon, startlat_tot, startlon_tot,      &
             iepsmem, nvers,                     &
             TRIM(yncglob_institution), TRIM(yncglob_source), &
             nexce_rep, nexce_bdy, fdbk_err, yerrstring, &
             obs_is_aliased = .TRUE., mod_is_aliased = .FALSE.)
        
        IF (fdbk_err /= 0) THEN
          WRITE (*,'(a)') 'ERROR in '//TRIM(yzroutine)//' writing vr: '//TRIM(yerrstring)
        END IF

      END IF

      IF ( zlzradar_ok ) THEN

!!$        rdata_obs  = RESHAPE (zrpolar_obs,   shape=SHAPE(rdata_obs),  order=(/2,1,3/))
!!$        rquali_obs = RESHAPE (zrpolar_obs_q, shape=SHAPE(rquali_obs), order=(/2,1,3/))
!!$        rdata_mod  = RESHAPE (zr_mod,        shape=SHAPE(rdata_mod),  order=(/2,1,3/))

        yerrstring(:) = ' '
        fdbk_err = 0

        CALL obs_write_cdf_feedobs ( ista, 'z', time_mod/60.0, &
!!$             rdata_obs, rquali_obs, &
!!$             rdata_mod, rheight, rpress, &
             zrpolar_obs, zrpolar_obs_q, &
             zr_mod, hr_mod, rpress, &
             zazivec, zrvec, rs_meta(ista)%el_arr(1:rs_meta(ista)%nel), &
             rs_meta(ista)%naz, rs_meta(ista)%nra, rs_meta(ista)%nel, &
             zlastpr, zlrefend, zlwrite_veridata,                &
             ydate_ini, hversta, hverend,                 &
             ie_tot, je_tot, ke_tot, pollat, pollon,      &
             dlat, dlon, startlat_tot, startlon_tot,      &
             iepsmem, nvers,                     &
             TRIM(yncglob_institution), TRIM(yncglob_source), &
             nexce_rep, nexce_bdy, fdbk_err, yerrstring )
        
        IF (fdbk_err /= 0) THEN
          WRITE (*,'(a)') 'ERROR in '//TRIM(yzroutine)//' writing z: '//TRIM(yerrstring)
        END IF
        
      END IF

      DEALLOCATE (             &
!!$           rdata_obs,  &
!!$           rquali_obs, &
!!$           rdata_mod,  &
!!$           rheight,    &
           rpress      &
!!$           zazivec, zrvec &
           )
       
    END IF
#endif
    
    ! .. Cleanup:
    !------------
    IF ( zlradwind_ok .OR. zlzradar_ok ) THEN
      DEALLOCATE( vrpolar_obs, vrpolar_obs_q, zrpolar_obs, zrpolar_obs_q )
      DEALLOCATE( m_obs, n_obs, o_obs )
    END IF
    CALL read_dwd_rad(ista, time_mod, 'cleanup')
    
    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id        

  END SUBROUTINE output_radar_dwd_obs

#endif

  !==============================================================================
  !+ Module procedure in src_radar for the coordinate transformation of radar
  !  radar coordinates to geographical coordinates for constant beam propagation
  !------------------------------------------------------------------------------

  SUBROUTINE rad2geo_const (latsta,lonsta,altsta,naz,nra,nel,ra,az,el,lat,lon,h)

    !------------------------------------------------------------------------------
    !
    ! Description: Coordinate transformation of radar coordinates
    !              (range, azimuth and elevation) to 
    !              geographical coordinates (lat, lon and height asl)
    !
    ! Method:      Assumption: 4/3 earth model
    !              Formulas with reference to  Appendices B and D of Dissertation 
    !              of Uli Blahak
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    ! Parameter list:
    REAL (KIND=ireals), INTENT (IN)      ::        &
         latsta,  & ! geographical latitude of radar station
         lonsta,  & ! geographical longitude of radar station
         altsta     ! altitude of radar station asl (m)

    INTEGER (KIND=iintegers), INTENT (IN) ::       &
         nra,naz,nel! number of ranges, azimuths and elevations (array dimensions)

    REAL (KIND=ireals), INTENT (IN)      ::        &
         ra(nra), & ! array of ranges
         az(naz), & ! array of azimuths
         el(nel)    ! array of elevations

    REAL (KIND=ireals), INTENT (OUT)     ::        &
         lat(naz,nra,nel),& ! geographical latitude
         lon(naz,nra,nel),& ! geographical longitude
         h(nra,nel)         ! height above mean sea level
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers) :: ira,iaz,iel
    REAL    (KIND=ireals)    :: h1,s1,d1,d2,d3,re


    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE rad2geo_const
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'rad2geo_const'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    re = 4.0_ireals/3.0_ireals*(r_earth + altsta)

    !if (my_cart_id == 0) then
    !   write(my_cart_id+700,'(2(A7),3(A10,"(",A3,")"),3A12') 'latsta','lonsta','az','m','ra','n','el','o','lon','lat','alt'
    !end if

    DO iel = 1,nel
      DO ira = 1,nra

        ! calculate height of radar beam above surface (formula B.8)
        h1 = SQRT(re**2 + ra(ira)**2 + 2*re*ra(ira)*SIN(el(iel)*degrad)) - re
        ! calculate length of circle at height of radar station (formula B.9)
        s1 = re*ASIN(ra(ira)*COS(el(iel)*degrad)/(re+h1))
        ! calculate dummy variable 
        d1 = s1/(r_earth+altsta)

        ! calculate height above mean sea level (only dependent on range and elevation!)
        ! (formula B.14)
        h(ira,iel) = altsta + h1

        DO iaz = 1,naz

          ! compute geographical latitude (dependent on range, azimuth and elevation)
          ! (formula D.4)
          d2 = SIN(latsta*degrad)*COS(d1) + COS(latsta*degrad)*SIN(d1)*COS(az(iaz)*degrad)
          ! restrict argument of asin to [-1,1]
          d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)
          lat(iaz,ira,iel) = ASIN(d2)

          ! compute geographical longitude (dependent on range, azimuth and elevation)
          ! (formula D.5)
          d3 =(COS(d1)-SIN(latsta*degrad)*SIN(lat(iaz,ira,iel)))/(COS(latsta*degrad)*COS(lat(iaz,ira,iel)))
          ! restrict argument of acos to [-1,1]
          d3 = MIN(MAX(d3,-1.0_ireals),1.0_ireals)
          lon(iaz,ira,iel) = lonsta*degrad + SIGN(1.0_ireals,(pi - az(iaz)*degrad)) * ACOS(d3)


          !if (my_cart_id == 0) then
          !   write(my_cart_id+700,'(2(F7.2),3(F10.2,"(",I3,")"),3F12.5)') latsta, lonsta, az(iaz),iaz, &
          !         ra(ira),ira,el(iel),iel,lon(iaz,ira,iel)*raddeg, lat(iaz,ira,iel)*raddeg,h(ira,iel)
          !end if

        END DO
      END DO
    END DO

    lat = lat * raddeg
    lon = lon * raddeg

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE rad2geo_const


  ! ZY >> Updated for the vectorized version
  !==============================================================================
  !+ Module procedure in src_radar for the coordinate transformation of radar
  !  radar coordinates to geographical coordinates for constant beam propagation
  !------------------------------------------------------------------------------

  SUBROUTINE rad2geo_const_vec (latsta,lonsta,altsta,naz,nra,nel,ra,az,el,lat,lon,h)

    !------------------------------------------------------------------------------
    !
    ! Description: Coordinate transformation of radar coordinates
    !              (range, azimuth and elevation) to 
    !              geographical coordinates (lat, lon and height asl)
    !
    ! Method:      Assumption: 4/3 earth model
    !              Formulas with reference to  Appendices B and D of Dissertation 
    !              of Uli Blahak
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    ! Parameter list:
    REAL (KIND=ireals), INTENT (IN)      ::        &
         latsta,  & ! geographical latitude of radar station
         lonsta,  & ! geographical longitude of radar station
         altsta     ! altitude of radar station asl (m)

    INTEGER (KIND=iintegers), INTENT (IN)::        &
         nra,naz,nel! number of ranges, azimuths and elevations (array dimensions)

    REAL (KIND=ireals), INTENT (IN)      ::        &
         ra(nra), & ! array of ranges
         az(naz), & ! array of azimuths
         el(nel)    ! array of elevations

    REAL (KIND=ireals), INTENT (OUT)     ::        &
         lat(naz*nra*nel),& ! geographical latitude
         lon(naz*nra*nel),& ! geographical longitude
         h(naz*nra*nel)     ! height above mean sea level
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers) :: ira,iaz,iel,irp
    REAL    (KIND=ireals)    :: h1,s1,d1,d2,d3,re


    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE rad2geo_const_vec
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'rad2geo_const_vec'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    re = 4.0_ireals/3.0_ireals*(r_earth + altsta)

    !if (my_cart_id == 0) then
    !   write(my_cart_id+700,'(2(A7),3(A10,"(",A3,")"),3A12') 'latsta','lonsta','az','m','ra','n','el','o','lon','lat','alt'
    !end if

    DO iel = 1,nel
      DO ira = 1,nra
        DO iaz = 1,naz
          ! ZY >> use new index irp to replace m,n,o indices
          ! Determine the index of the radar point, based on az,ra,el
          irp = iaz + (ira - 1)*naz  + (iel - 1)*naz*nra
          ! ZY <<

          ! ZY >> Vectorized Version
          ! calculate height of radar beam above surface (formula B.8)
          h1 = SQRT(re**2 + ra(ira)**2 + 2*re*ra(ira)*SIN(el(iel)*degrad)) - re
          ! calculate length of circle at height of radar station (formula B.9)
          s1 = re*ASIN(ra(ira)*COS(el(iel)*degrad)/(re+h1))
          ! calculate dummy variable 
          d1 = s1/(r_earth+altsta)

          ! calculate height above mean sea level (only dependent on range and elevation!)
          ! (formula B.14)

          h(irp) =  altsta + h1

          ! compute geographical latitude (dependent on range, azimuth and elevation)
          ! (formula D.4)
          d2 = SIN(latsta*degrad)*COS(d1) + COS(latsta*degrad)*SIN(d1)*COS(az(iaz)*degrad)
          ! restrict argument of asin to [-1,1]
          d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)
          lat(irp) = ASIN(d2)

          ! compute geographical longitude (dependent on range, azimuth and elevation)
          ! (formula D.5)
          d3 =(COS(d1)-SIN(latsta*degrad)*SIN(lat(irp)))/(COS(latsta*degrad)*COS(lat(irp)))
          ! restrict argument of acos to [-1,1]
          d3 = MIN(MAX(d3,-1.0_ireals),1.0_ireals)
          lon(irp) = lonsta*degrad + SIGN(1.0_ireals,(pi - az(iaz)*degrad)) * ACOS(d3)
          ! ZY <<

          !if (my_cart_id == 0) then
          !   write(my_cart_id+700,'(2(F7.2),3(F10.2,"(",I3,")"),3F12.5)') latsta, lonsta, az(iaz),iaz, &
          !         ra(ira),ira,el(iel),iel,lon(iaz,ira,iel)*raddeg, lat(iaz,ira,iel)*raddeg,h(ira,iel)
          !end if

        END DO
      END DO
    END DO

    lat = lat * raddeg
    lon = lon * raddeg

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE rad2geo_const_vec

  ! ZY << Updated for the vectorized version


  ! ZY >> rad2geo_const_smth with spatial averaging added

  SUBROUTINE rad2geo_const_smth(ista_for_smthpoints,&
       latsta,lonsta,altsta,naz,nra,nel,nv,nh,ra,az,el,lat,lon,h)

    !------------------------------------------------------------------------------
    !
    ! Description: Coordinate transformation of radar coordinates
    !              (range, azimuth and elevation) to 
    !              geographical coordinates (lat, lon and height asl)
    !
    ! Method:      Assumption: 4/3 earth model
    !              Formulas with reference to  Appendices B and D of Dissertation 
    !              of Uli Blahak
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    ! Parameter list:
    REAL (KIND=ireals), INTENT (IN)      ::        &
         latsta,  & ! geographical latitude of radar station
         lonsta,  & ! geographical longitude of radar station
         altsta     ! altitude of radar station asl (m)

    INTEGER (KIND=iintegers), INTENT (IN) :: &
         nra,naz,nel, & ! number of ranges, azimuths and elevations (array dimensions)
         nv,nh,       & ! number of smoothing points in vertiacal and horizontal directions 
         ista_for_smthpoints  ! station index for feeding the functions which
                              ! determine the smoothing points

    REAL (KIND=ireals), INTENT (IN)      ::        &
         ra(nra), & ! array of ranges
         az(naz), & ! array of azimuths
         el(nel)    ! array of elevations

    REAL (KIND=ireals), INTENT (INOUT)     ::        &
         lat(naz*nra*nel*nv*nh),& ! geographical latitude
         lon(naz*nra*nel*nv*nh),& ! geographical longitude
         h(naz*nra*nel*nv*nh)         ! height above mean sea level
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers) :: ira,iaz,iel,irp,iv,ih
    REAL    (KIND=ireals)    :: h1,s1,d1,d2,d3,re
    REAL    (KIND=ireals)    ::           &
         el_tmp , & ! elevation of smoothing point
         az_tmp     ! azimuth of smoothing point

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE rad2geo_const_smth
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine = 'rad2geo_const_smth'

    re = 4.0_ireals/3.0_ireals*(r_earth + altsta)

    !if (my_cart_id == 0) then
    !   write(my_cart_id+700,'(2(A7),3(A10,"(",A3,")"),3A12') 'latsta','lonsta','az','m','ra','n','el','o','lon','lat','alt'
    !end if
    DO ih = 1,nh
      DO iv = 1,nv
        DO iel = 1,nel
          DO ira = 1,nra
            DO iaz = 1,naz

              ! Determine the index of the radar point, based on az,ra,el
              irp = iaz + (ira - 1)*naz  + (iel - 1)*naz*nra + (iv - 1)*nel*naz*nra + (ih - 1)*nv*nel*naz*nra

!!$ inlined code from smth_el_horzscan
!!$              theta3_eff = rs_meta(ista)%Theta3
!!$
!!$              smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_v(iv)
!!$
!!$              el_tmp = el(iel) + smthpoint

              el_tmp = el(iel) + smth_el_horzscan(ista_for_smthpoints,iv)

              ! calculate height of radar beam above surface (formula B.8)
              h1 = SQRT(re**2 + ra(ira)**2 + 2*re*ra(ira)*SIN(el_tmp*degrad)) - re
              ! calculate length of circle at height of radar station (formula B.9)
              s1 = re*ASIN(ra(ira)*COS(el_tmp*degrad)/(re+h1))
              ! calculate dummy variable 
              d1 = s1/(r_earth+altsta)

              ! calculate height above mean sea level (only dependent on range and elevation!)
              ! (formula B.14)
              !  h(irp,iv,ih) = max(altsta + h1,0.0_ireals)
              h(irp) =altsta + h1

!!$ inlined code from smth_az_horzscan
!!$              phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
!!$                   ( COS(el(iel)*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
!!$                   ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )
!!$
!!$              smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
!!$                   rs_meta(ista)%xabscsm_h(ih)
!!$
!!$              az_tmp = az(iaz) + smthpoint

              az_tmp = az(iaz) + smth_az_horzscan(ista_for_smthpoints,ih,el(iel))

              ! compute geographical latitude (dependent on range, azimuth and elevation)
              ! (formula D.4)
              d2 = SIN(latsta*degrad)*COS(d1) + COS(latsta*degrad)*SIN(d1)*COS(az_tmp*degrad)
              ! restrict argument of asin to [-1,1]
              d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)
              lat(irp) = ASIN(d2)

              ! compute geographical longitude (dependent on range, azimuth and elevation)
              ! (formula D.5)
              d3 =(COS(d1)-SIN(latsta*degrad)*SIN(lat(irp)))/(COS(latsta*degrad)*COS(lat(irp)))
              ! restrict argument of acos to [-1,1]
              d3 = MIN(MAX(d3,-1.0_ireals),1.0_ireals)
              lon(irp) = lonsta*degrad + SIGN(1.0_ireals,(pi - az_tmp*degrad)) * ACOS(d3)

            END DO
          END DO
        END DO
      END DO
    END DO

    lat = lat * raddeg
    lon = lon * raddeg

  END SUBROUTINE rad2geo_const_smth

  ! ZY >>  rad2geo_const_smth with spatial averaging added


  SUBROUTINE grd2geo(latsta,lonsta,naz,nal,az,al,lat,lon)

    !------------------------------------------------------------------------------
    !
    ! Description: Coordinate transformation of auxiliary grids coordinates
    !              (azimuth, arc length) to geographical coordinates (lat, lon)
    !
    ! Method:      Assumption: 4/3 earth model
    !              Formulas with reference to  Appendices B and D of Dissertation 
    !              of Uli Blahak
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    ! Parameter list:
    REAL (KIND=ireals), INTENT (IN)      ::        &
         latsta,  & ! geographical latitude of radar station
         lonsta     ! geographical longitude of radar station

    INTEGER (KIND=iintegers), INTENT (IN) :: &
         naz,nal! number of azimuths, arc distances (array dimensions)

    REAL (KIND=ireals),     INTENT (IN) :: &   
         az(naz), & ! array of azimuths
         al(nal)    ! array of distance

    REAL (KIND=ireals), INTENT (OUT)     ::        &
         
         lat(naz,nal),& ! geographical latitude
         lon(naz,nal)   ! geographical longitude

    ! Local scalars:
    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers) :: iaz,ial
    REAL    (KIND=ireals)    :: d1,d2,d3


    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE  grd2geo
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine = 'grd2geo'


    DO ial = 1,nal
      DO iaz = 1,naz

        d1 =  al(ial)/(r_earth)

        d2 = SIN(latsta*degrad)*COS(d1) + COS(latsta*degrad)*SIN(d1)*COS(az(iaz)*degrad)

        d2 = MIN(MAX(d2,-1.0_ireals),1.0_ireals)

        lat(iaz,ial) = ASIN(d2)

        d3 =(COS(d1)-SIN(latsta*degrad)*SIN(lat(iaz,ial)))/(COS(latsta*degrad)*COS(lat(iaz,ial)))

        d3 = MIN(MAX(d3,-1.0_ireals),1.0_ireals)

        lon(iaz,ial) = lonsta*degrad + SIGN(1.0_ireals,(pi - az(iaz)*degrad)) * ACOS(d3)

        !if (my_cart_id == 0) then
        !   write(my_cart_id+700,'(2(F7.2),3(F10.2,"(",I3,")"),3F12.5)') latsta, lonsta, az(iaz),iaz, ra(ira),ira,el(iel),iel,lon(iaz,ira,iel)*raddeg, lat(iaz,ira,iel)*raddeg,h(ira,iel)
        !end if

      END DO
    END DO

    lat = lat * raddeg
    lon = lon * raddeg

  END SUBROUTINE grd2geo


  SUBROUTINE calc_vert_weight(alt,hhl,ke,wi,wj,kout,wk)

    !------------------------------------------------------------------------------
    !
    ! Description: Calculation of vertical interpolation weight and level index
    !              above the radar point for the interpolation of the model grids
    !              to the radar points. This routine assumes that all input radar
    !              points are horizontally within the model domain.
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    !------------------------------------------------------------------------------
    ! Parameter list:
    INTEGER (KIND=iintegers), INTENT (IN)     ::        &
         ke               ! vertical dimension of model levels

    REAL (KIND=ireals), INTENT (IN)           ::        &
         alt,           & ! height a.s.l of radar point
         hhl(2,2,ke+1), & ! model level heights of the 4 grid points surrounding
                          ! the radar point
         wi,            & ! interpolation weight in i direction
         wj               ! interpolation weight in j direction

    INTEGER (KIND=iintegers), INTENT (OUT)    ::        &
         kout             ! lowest level index above radar point
                          ! -1 if radar point below topography
                          ! ke if radar point above topo and below first model full level

    REAL (KIND=ireals), INTENT (OUT)          ::        &
         wk               ! vertical interpolation weight
                          ! -1.0 if radar point below topography
                          !  0.0 if radar point above topo and below first model full level

    ! Local scalars:
    INTEGER (KIND=iintegers) :: k
    REAL    (KIND=ireals)    :: hfl_up,hfl_low,hsurf_avg

    ! Local arrays:
    REAL    (KIND=ireals)    :: hfl(2,2,ke) ! full level heights of the 4 grid points
    ! surrounding the radar point
    !- End of header
    !==============================================================================


    !initialize vertical interpolation weight and level index
    wk = -1.0_ireals
    kout = -1

    ! find vertical index below height of radar point

    hfl(:,:,ke) = 0.5*(hhl(:,:,ke) + hhl(:,:,ke+1))

    hfl_up = (hfl(1,1,ke)*(1.0_ireals-wi)+hfl(2,1,ke)*wi)*(1.0_ireals - wj) + &
         (hfl(1,2,ke)*(1.0_ireals-wi)+hfl(2,2,ke)*wi)*wj               

    ! if radar point is below surface return undefined
    hsurf_avg = (hhl(1,1,ke+1)*(1.0_ireals-wi)+hhl(2,1,ke+1)*wi)*(1.0_ireals - wj) + &
         (hhl(1,2,ke+1)*(1.0_ireals-wi)+hhl(2,2,ke+1)*wi)*wj               
    IF (alt < hsurf_avg) RETURN

    ! if radar point is below lowest full level
    IF (alt < hfl_up) THEN
      wk = 0.0_ireals
      kout = ke
      RETURN 
    END IF

    ! loop over levels, start at the surface and proceed upwards
    DO k = ke,1,-1

      hfl(:,:,k) = 0.5*(hhl(:,:,k) + hhl(:,:,k+1))

      hfl_low = hfl_up
      hfl_up  = (hfl(1,1,k)*(1.0_ireals-wi)+hfl(2,1,k)*wi)*(1.0_ireals - wj) + &
           (hfl(1,2,k)*(1.0_ireals-wi)+hfl(2,2,k)*wi)*wj               

      !write(my_cart_id+700,'("k = ",I2," hfl_up = ",F7.0," hfl_low = ",F7.0)') k,hfl_up,hfl_low

      IF (hfl_up > alt) THEN
        ! radar point found:
        wk = (alt-hfl_up)/(hfl_low-hfl_up)
        kout = k
        ! UB>> changed from "return" to "exit"
        EXIT
      END IF

    END DO


  END SUBROUTINE calc_vert_weight


  ! ZY >> Updated for the vectorized version

  SUBROUTINE calc_vert_weight_vec(np,alt,iin,jin,wi,wj,kout,wk)

    !------------------------------------------------------------------------------
    !
    ! Description: Calculation of vertical interpolation weight and level index
    !              above the radar point for the interpolation of the model grids
    !              to the radar points. This routine assumes that all input radar
    !              points are horizontally within the model domain.
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    !------------------------------------------------------------------------------
    ! Parameter list:

    CHARACTER (LEN=32) yzroutine


    INTEGER (KIND=iintegers), INTENT (IN)     ::        &
         np                ,&             
         iin(np)           ,&
         jin(np)            
    REAL (KIND=ireals), INTENT (IN)           ::        &
         alt(np)           ,& ! height a.s.l of radar point
         wi(np)            ,& ! interpolation weight in i direction
         wj(np)               ! interpolation weight in j direction

    INTEGER (KIND=iintegers), INTENT (OUT)    ::        &
         kout(np)             ! lowest level index above radar point
                              ! -1 if radar point below topography
                              ! ke if radar point above topo and below first model full level

    REAL (KIND=ireals), INTENT (OUT)          ::        &
         wk(np)               ! vertical interpolation weight
                              ! -1.0 if radar point below topography
                              !  0.0 if radar point above topo and below first model full level

    INTEGER (KIND=iintegers) :: i,io,j,jo,k,irp,flag(np) ! use flag to check if the radar point has already been done
    REAL    (KIND=ireals)    :: hfl_low,hsurf_avg

    ! Local arrays:
!!$    REAL    (KIND=ireals)    :: hfl(np,2,2,ke),hfl_up(np,ke) ! full level heights of the 4 grid points
    REAL    (KIND=ireals)    :: hfl11,hfl21,hfl12,hfl22,hfl_up(np) ! full level heights of the 4 grid points
    ! surrounding the radar point
    !- End of header
    !==============================================================================

    yzroutine(:) = ' '
    yzroutine = 'calc_vert_weight_vec'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !initialize vertical interpolation weight and level index
    wk = -1.0_ireals
    kout = -1
    flag = 0
    ! ZY >> Vectorized Version

    ! Check if the radar point is below topography.
    ! If yes, then flag = 1 (wk,kout = default value); Elseif below the first main level, then flag = 1, wk = 0, kout = ke.
    DO irp = 1, np

      i = iin(irp)
      io= MIN(i+1,ie)
      j = jin(irp)
      jo= MIN(j+1,je)

!!$      hfl(irp,1,1,ke) = 0.5*(hhl(i,j,ke)+ hhl(i,j,ke+1))
!!$      hfl(irp,2,1,ke) = 0.5*(hhl(io,j,ke)+ hhl(io,j,ke+1))
!!$      hfl(irp,1,2,ke) = 0.5*(hhl(i,jo,ke)+ hhl(i,jo,ke+1))
!!$      hfl(irp,2,2,ke) = 0.5*(hhl(io,jo,ke)+ hhl(io,jo,ke+1))
!!$
!!$      hfl_up(irp) = (hfl(irp,1,1,ke)*(1.0_ireals-wi(irp))+hfl(irp,2,1,ke)*wi(irp))*(1.0_ireals - wj(irp)) + &
!!$           (hfl(irp,1,2,ke)*(1.0_ireals-wi(irp))+hfl(irp,2,2,ke)*wi(irp))*wj(irp)

      hfl11 = 0.5*(hhl(i,j,ke)  + hhl(i,j,ke+1))
      hfl21 = 0.5*(hhl(io,j,ke) + hhl(io,j,ke+1))
      hfl12 = 0.5*(hhl(i,jo,ke) + hhl(i,jo,ke+1))
      hfl22 = 0.5*(hhl(io,jo,ke)+ hhl(io,jo,ke+1))

      hfl_up(irp) = (hfl11*(1.0_ireals-wi(irp))+hfl21*wi(irp))*(1.0_ireals - wj(irp)) + &
           (hfl12*(1.0_ireals-wi(irp))+hfl22*wi(irp))*wj(irp)

      hsurf_avg = (hhl(i,j,ke+1)*(1.0_ireals-wi(irp))+               &
           hhl(io,j,ke+1)*wi(irp))*(1.0_ireals - wj(irp)) + &
           (hhl(i,jo,ke+1)*(1.0_ireals-wi(irp))+hhl(io,jo,ke+1)*wi(irp))*wj(irp)

      IF (alt(irp) < hsurf_avg) THEN

        flag(irp) = 1

      ELSEIF (hfl_up(irp) > alt(irp)) THEN

        wk(irp) = 0.0_ireals
        ! ZY >> kout(irp) = -1
        kout(irp) = ke
        ! ZY <<
        flag(irp) = 1

      ENDIF

    ENDDO

    ! Loop over k from second lowest level to the top
    ! Determine the k indice above the radar point
    DO k = ke-1,1,-1

      DO irp =1, np

        IF (flag(irp) == 0) THEN

!!$          hfl_low = hfl_up(irp,k+1)
          hfl_low = hfl_up(irp)

          i = iin(irp)
          io= MIN(i+1,ie)
          j = jin(irp)
          jo= MIN(j+1,je)

!!$          hfl(irp,1,1,k) = 0.5*(hhl(i,j,k)+ hhl(i,j,k+1))
!!$          hfl(irp,2,1,k) = 0.5*(hhl(io,j,k)+ hhl(io,j,k+1))
!!$          hfl(irp,1,2,k) = 0.5*(hhl(i,jo,k)+ hhl(i,jo,k+1))
!!$          hfl(irp,2,2,k) = 0.5*(hhl(io,jo,k)+ hhl(io,jo,k+1))
!!$
!!$          hfl_up(irp) = (hfl(irp,1,1,k)*(1.0_ireals-wi(irp))+hfl(irp,2,1,k)*wi(irp))*(1.0_ireals - wj(irp)) + &
!!$               (hfl(irp,1,2,k)*(1.0_ireals-wi(irp))+hfl(irp,2,2,k)*wi(irp))*wj(irp) 

          hfl11 = 0.5*(hhl(i,j,k)  + hhl(i,j,k+1))
          hfl21 = 0.5*(hhl(io,j,k) + hhl(io,j,k+1))
          hfl12 = 0.5*(hhl(i,jo,k) + hhl(i,jo,k+1))
          hfl22 = 0.5*(hhl(io,jo,k)+ hhl(io,jo,k+1))

          hfl_up(irp) = (hfl11*(1.0_ireals-wi(irp))+hfl21*wi(irp))*(1.0_ireals - wj(irp)) + &
               (hfl12*(1.0_ireals-wi(irp))+hfl22*wi(irp))*wj(irp) 

          IF (hfl_up(irp) > alt(irp)) THEN

            ! radar point found:
            wk(irp) = (alt(irp)-hfl_up(irp))/(hfl_low-hfl_up(irp))

            kout(irp) = k

            flag(irp) = 1

          ENDIF

        ENDIF

      ENDDO

    ENDDO

    ! ZY <<

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_vert_weight_vec

  ! ZY << Updated for the vectorized version


  ! ZY >> Updated for the dynamical version

  SUBROUTINE calc_vert_weight_online(np,alt,hfl,azarr,naz_loc,istart_az,iend_az,nal,nhl,iaz,ial,weight,kout,wk)

    !------------------------------------------------------------------------------
    !
    ! Description: Calculation of vertical interpolation weight and level index
    !              above the radar point for the interpolation of the auxiliary grids
    !              to the radar points. 
    !
    !------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    !------------------------------------------------------------------------------
    ! Parameter list:

    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers), INTENT (IN)     ::        &
         np,istart_az,iend_az,naz_loc,nal,nhl  , &  ! np = no. of radar points, naz_loc = size of azarr
         azarr(naz_loc)                ,&           ! azimut index range of this processor in the aux. grid
         iaz(np)                       ,&  
         ial(np)

    INTEGER (KIND = iintegers)                :: istart(0:num_compute-1),iend(0:num_compute-1),i

    REAL (KIND=ireals), INTENT (IN)           ::        &
         alt(np)               ,& ! 
         weight(np)            ,& ! interpolation weight in i direction
         hfl(istart_az:iend_az,nal,nhl)         ! height a.s.l of radar point

    INTEGER (KIND=iintegers), INTENT (OUT)     ::       &
         kout(np)             ! lowest level index above radar point
                              ! -1 if radar point below topography

    REAL (KIND=ireals), INTENT (OUT)     ::             &
         wk(np)               ! vertical interpolation weight
                              ! -1.0 if radar point below topography

    INTEGER (KIND=iintegers) :: m,mo,n,no,k,irp,flag(np) ! use flag to check if the radar point has already been done

    REAL    (KIND=ireals)    :: hfl_low

    ! Local arrays:
    REAL    (KIND=ireals)    :: hfl_up(np) ! full level heights of the 4 grid points
    ! surrounding the radar point
    !- End of header
    !==============================================================================

    yzroutine(:) = ' '
    yzroutine = 'calc_vert_weight_online'

    ! IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !initialize vertical interpolation weight and level index
    wk = -1.0_ireals
    kout = -1
    flag = 0
    ! ZY >> Vectorized Version

   ! Check if the radar point is below topography.
   ! If yes, then flag = 1 (wk,kout = default value); Elseif below the first main level, then flag = 1, wk = 0, kout = ke.

    DO irp = 1, np

      m = azarr(iaz(irp))
      mo= MIN(m+1,iend_az)
      n = ial(irp)
      no= MIN(n+1,nal)

!!$      IF ( hfl(azarr(iaz(irp)),ial(irp),ke)     > -900.0_ireals .AND. &
!!$           hfl(azarr(iaz(irp)),ial(irp)+1,ke)   > -900.0_ireals .AND. &
!!$           hfl(azarr(iaz(irp)),ial(irp),ke-1)   > -900.0_ireals .AND. &
!!$           hfl(azarr(iaz(irp)),ial(irp)+1,ke-1) > -900.0_ireals       &
!!$           ) THEN

      IF ( hfl(m,n,ke)     > -900.0_ireals .AND. &
           hfl(m,no,ke)   > -900.0_ireals .AND. &
           hfl(m,n,ke-1)   > -900.0_ireals .AND. &
           hfl(m,no,ke-1) > -900.0_ireals       &
           ) THEN
          
!!$        
!!$        hfl_low = hfl(azarr(iaz(irp)),ial(irp),ke) * (1.0_ireals-weight(irp)) + &
!!$             hfl(azarr(iaz(irp)),ial(irp)+1,ke) * weight(irp)
!!$
!!$        hfl_up(irp,ke-1) = hfl(azarr(iaz(irp)),ial(irp),ke-1) * (1.0_ireals-weight(irp)) + &
!!$             hfl(azarr(iaz(irp)),ial(irp)+1,ke-1) * weight(irp)

        hfl_low = hfl(m,n,ke) * (1.0_ireals-weight(irp)) + hfl(m,no,ke) * weight(irp)

        hfl_up(irp) = hfl(m,n,ke-1) * (1.0_ireals-weight(irp)) + hfl(m,no,ke-1) * weight(irp)


!!$ UB>> ???      IF (alt(irp) < hfl_low .OR. alt(irp) < 0.0 .OR. hfl_low < 0.0 .OR. hfl_up(irp,ke) < 0.0) THEN
        IF (alt(irp) < hfl_low .OR. alt(irp) < -900.0_ireals ) THEN

          flag(irp) = 1

        ELSEIF (hfl_up(irp) >= alt(irp)) THEN

          wk(irp) = (alt(irp)-hfl_up(irp))/(hfl_low-hfl_up(irp))

          kout(irp) = ke - 1

          flag(irp) = 1

        ENDIF

      ELSE

        hfl_up(irp) = -999.99_ireals

      ENDIF

    ENDDO

    ! Loop over k from second lowest level to the top
    ! Determine the k indice above the radar point
    DO k = ke-2,1,-1

      DO irp =1, np

        IF (flag(irp) == 0) THEN

!!$          hfl_low = hfl_up(irp,k+1)
          hfl_low = hfl_up(irp)

          m = azarr(iaz(irp))
          mo= MIN(m+1,iend_az)
          n = ial(irp)
          no= MIN(n+1,nal)


!!$          IF ( hfl(azarr(iaz(irp)),ial(irp),k)     > -900.0_ireals .AND. &
!!$               hfl(azarr(iaz(irp)),ial(irp)+1,k)   > -900.0_ireals       &
!!$               ) THEN

          IF ( hfl(m,n,k)     > -900.0_ireals .AND. &
               hfl(m,no,k)   > -900.0_ireals       &
               ) THEN

!!$
!!$            hfl_up(irp,k) = hfl(azarr(iaz(irp)),ial(irp),k) * (1.0_ireals-weight(irp)) + &
!!$                 hfl(azarr(iaz(irp)),ial(irp)+1,k) * weight(irp)

            hfl_up(irp) = hfl(m,n,k) * (1.0_ireals-weight(irp)) +  hfl(m,no,k) * weight(irp)

!!$          IF (alt(irp) < 0.0 .OR. hfl_low < 0.0 .OR. hfl_up(irp,k) < 0.0) THEN
!!$
!!$            flag(irp) = 1
!!$
!!$          ELSEIF (hfl_up(irp,k) > alt(irp)) THEN
            IF (alt(irp) < -900.0_ireals) THEN

              flag(irp) = 1

            ELSEIF ( hfl_low >= -900.0_ireals .AND. &
                     hfl_low <= alt(irp) .AND. alt(irp) < hfl_up(irp) ) THEN

              wk(irp) = (alt(irp)-hfl_up(irp))/(hfl_low-hfl_up(irp))

              kout(irp) = k

              flag(irp) = 1

            END IF

          ELSE

            hfl_up(irp) = -999.99_ireals

          ENDIF
            
        ENDIF ! flag(irp) == 0

      ENDDO

    ENDDO

    ! IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_vert_weight_online

  ! ZY << Updated for the vectorized version


  ! ZY >> Updated for the dynamical version for spatial smoothing

  SUBROUTINE calc_vert_weight_onsmth(np,alt,hfl,istart_az,iend_az,nal,nhl,iaz,ial,wa,wl,kout,wk)

    !-----------------------------------------------------------------------------------
    !
    ! Description: Calculation of vertical interpolation weight and level index
    !              above the smoothing point for the interpolation of the auxiliary grids
    !              to the smoothing points. All input fields and computation are on the
    !              auxiliary azimutal grid.
    !
    !-----------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    !------------------------------------------------------------------------------
    ! Parameter list:

    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers), INTENT (IN)     ::        &
         np,istart_az,iend_az,nal,nhl,                            &             
         iaz(np),                                       &  
         ial(np)

    INTEGER (KIND = iintegers)   :: i

    REAL (KIND=ireals), INTENT (IN)           ::        &
         alt(np)               ,& ! 
         wa(np)                ,& ! interpolation weight in i direction
         wl(np)                ,&
         hfl(istart_az:iend_az,nal,nhl)         ! height a.s.l of radar point

    INTEGER (KIND=iintegers), INTENT (OUT)     ::       &
         kout(np)             ! lowest level index above radar point
    ! -1 if radar point below topography

    REAL (KIND=ireals), INTENT (OUT)     ::             &
         wk(np)               ! vertical interpolation weight
    ! -1.0 if radar point below topography

    INTEGER (KIND=iintegers) :: k,m,mo,n,no,irp,flag(np) ! use flag to check if the radar point has already been done

    INTEGER (KIND=iintegers), ALLOCATABLE :: azarr_idx(:) 

    REAL    (KIND=ireals)    :: w_a,w_l

    REAL    (KIND=ireals)    :: hfl_low,hfl_low11,hfl_low21,hfl_low12,hfl_low22

    ! Local arrays:
    REAL    (KIND=ireals)    :: hfl_up(np),hfl_up11,hfl_up21,hfl_up12,hfl_up22 ! full level heights of the 4 grid points
    ! surrounding the radar point
    !- End of header
    !==============================================================================

    yzroutine(:) = ' '
    yzroutine = 'calc_vert_weight_onsmth'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !initialize vertical interpolation weight and level index
    wk = -1.0_ireals
    kout = -1
    flag = 0
    ! ZY >> Vectorized Version

    ! Check if the radar point is below topography.
    ! If yes, then flag = 1 (wk,kout = default value); Elseif below the first main level, then flag = 1, wk = 0, kout = ke.

    DO irp = 1, np

      m = iaz(irp)
      mo= MIN(m+1,iend_az)
      n = ial(irp)
      no= MIN(n+1,nal)

      hfl_low11 = hfl(m,n,ke)
      hfl_low21 = hfl(mo,n,ke)
      hfl_low12 = hfl(m,no,ke)
      hfl_low22 = hfl(mo,no,ke)
      
      hfl_up11 = hfl(m,n,ke-1)
      hfl_up21 = hfl(mo,n,ke-1)
      hfl_up12 = hfl(m,no,ke-1)
      hfl_up22 = hfl(mo,no,ke-1)

      ! Select only azimut-slice-grid intervals which are fully in the model domain:
      IF ( hfl_low11 >= -900.0_ireals  .AND. &
           hfl_low12 >= -900.0_ireals  .AND. &
           hfl_low21 >= -900.0_ireals  .AND. &
           hfl_low22 >= -900.0_ireals  .AND. &
           hfl_up11  >= -900.0_ireals  .AND. &
           hfl_up12  >= -900.0_ireals  .AND. &
           hfl_up21  >= -900.0_ireals  .AND. &
           hfl_up22  >= -900.0_ireals        &
           ) THEN

        w_a = wa(irp)
        w_l = wl(irp)

!!$        IF (hfl_low11 < -900.0_ireals .AND. hfl_low21 >= -900.0_ireals) THEN
!!$          hfl_low11 = hfl_low21
!!$        ELSEIF (hfl_low11 >= -900.0_ireals .AND. hfl_low21 < -900.0_ireals) THEN
!!$          hfl_low21 = hfl_low11
!!$        ELSEIF (hfl_low11 < -900.0_ireals .AND. hfl_low21 < -900.0_ireals) THEN
!!$          w_l = 1.0
!!$        ELSE
!!$          CONTINUE
!!$        ENDIF
        
!!$        IF (hfl_low12 < -900.0_ireals .AND. hfl_low22 >= -900.0_ireals) THEN
!!$          hfl_low12 = hfl_low22
!!$        ELSEIF (hfl_low12 >= -900.0_ireals .AND. hfl_low22 < -900.0_ireals) THEN
!!$          hfl_low22 = hfl_low12
!!$        ELSEIF (hfl_low12 < -900.0_ireals .AND. hfl_low22 < -900.0_ireals) THEN
!!$          w_l = 0.0
!!$        ELSE
!!$          CONTINUE
!!$        ENDIF

        hfl_low = (hfl_low11*(1.0_ireals-w_a)+hfl_low21*w_a)*(1.0_ireals-w_l) + &
             (hfl_low12*(1.0_ireals-w_a)+hfl_low22*w_a)*w_l

!!$        w_a = wa(irp)
!!$        w_l = wl(irp)
!!$
!!$        IF (hfl_up11 < -900.0_ireals .AND. hfl_up21 >= -900.0_ireals) THEN
!!$          hfl_up11 = hfl_up21
!!$        ELSEIF (hfl_up11 >= -900.0_ireals .AND. hfl_up21 < -900.0_ireals) THEN
!!$          hfl_up21 = hfl_up11
!!$        ELSEIF (hfl_up11 < -900.0_ireals .AND. hfl_up21 < -900.0_ireals) THEN
!!$          w_l = 1.0
!!$        ELSE
!!$          CONTINUE
!!$        ENDIF
!!$        
!!$        IF (hfl_up12 < -900.0_ireals .AND. hfl_up22 >= -900.0_ireals) THEN
!!$          hfl_up12 = hfl_up22
!!$        ELSEIF (hfl_up12 >= -900.0_ireals .AND. hfl_up22 < -900.0_ireals) THEN
!!$          hfl_up22 = hfl_up12
!!$        ELSEIF (hfl_up12 < -900.0_ireals .AND. hfl_up22 < -900.0_ireals) THEN
!!$          w_l = 0.0
!!$        ELSE
!!$          CONTINUE
!!$        ENDIF
        
        hfl_up(irp) = (hfl_up11*(1.0_ireals-w_a)+hfl_up21*w_a)*(1.0_ireals-w_l) + &
             (hfl_up21*(1.0_ireals-w_a)+hfl_up22*w_a)*w_l


!!$      hfl_low = (hfl(iaz(irp),ial(irp),ke)*(1.0_ireals-wa(irp))+             &
!!$           hfl(iaz(irp)+1,ial(irp),ke)*wa(irp))*(1.0_ireals-wl(irp)) + &
!!$           (hfl(iaz(irp),ial(irp)+1,ke)*(1.0_ireals-wa(irp))+           &
!!$           hfl(iaz(irp)+1,ial(irp)+1,ke)*wa(irp))*wl(irp)
!!$
!!$      hfl_up(irp,ke) = (hfl(iaz(irp),ial(irp),ke-1)*(1.0_ireals-wa(irp)) +            &
!!$           hfl(iaz(irp)+1,ial(irp),ke-1)*wa(irp))*(1.0_ireals-wl(irp)) + &
!!$           (hfl(iaz(irp),ial(irp)+1,ke-1)*(1.0_ireals-wa(irp)) +          &
!!$           hfl(iaz(irp)+1,ial(irp)+1,ke-1)*wa(irp))*wl(irp)    

!!$ UB>>      IF (alt(irp) < hfl_low .or. alt(irp) < 0.0 .or. hfl_low < 0.0 .OR. hfl_up(irp,ke) < 0.0) THEN
        IF (alt(irp) < hfl_low .OR. alt(irp) < -900.0_ireals) THEN

          flag(irp) = 1
          
        ELSEIF(hfl_up(irp) >= alt(irp)) THEN
          
          wk(irp) = (alt(irp)-hfl_up(irp))/(hfl_low-hfl_up(irp))
          
          kout(irp) = ke - 1
          
          flag(irp) = 1
          
        ENDIF
        
      ELSE

        ! Do not set flag = 1, because the search should not end here!
        hfl_up(irp) = -999.99_ireals

      END IF

    ENDDO

    ! Loop over k from second lowest level to the top
    ! Determine the k indice above the radar point
!!$ UB>>    DO k = ke-1,2,-1
    DO k = ke-2,1,-1

      DO irp =1, np

        IF (flag(irp) == 0) THEN

!!$          hfl_low = hfl_up(irp,k+1)
          hfl_low = hfl_up(irp)

          m = iaz(irp)
          mo= MIN(m+1,iend_az)
          n = ial(irp)
          no= MIN(n+1,nal)

          hfl_up11 = hfl(m,n,k)
          hfl_up21 = hfl(mo,n,k)
          hfl_up12 = hfl(m,no,k)
          hfl_up22 = hfl(mo,no,k)

          IF ( hfl_up11 >= -900.0_ireals .AND. &
               hfl_up21 >= -900.0_ireals .AND. &
               hfl_up12 >= -900.0_ireals .AND. &
               hfl_up22 >= -900.0_ireals &
               ) THEN

            w_a = wa(irp)
            w_l = wl(irp)

!!$            IF (hfl_up11 < -900.0_ireals .AND. hfl_up21 >= -900.0_ireals) THEN
!!$              hfl_up11 = hfl_up21
!!$            ELSEIF (hfl_up11 >= -900.0_ireals .AND. hfl_up21 < -900.0_ireals) THEN
!!$              hfl_up21 = hfl_up11
!!$            ELSEIF (hfl_up11 < -900.0_ireals .AND. hfl_up21 < -900.0_ireals) THEN
!!$              w_l = 1.0
!!$            ELSE
!!$              CONTINUE
!!$            ENDIF
!!$
!!$            IF (hfl_up12 < -900.0_ireals .AND. hfl_up22 >= -900.0_ireals) THEN
!!$              hfl_up12 = hfl_up22
!!$            ELSEIF (hfl_up12 >= -900.0_ireals .AND. hfl_up22 < -900.0_ireals) THEN
!!$              hfl_up22 = hfl_up12
!!$            ELSEIF (hfl_up12 < -900.0_ireals .AND. hfl_up22 < -900.0_ireals) THEN
!!$              w_l = 0.0
!!$            ELSE
!!$              CONTINUE
!!$            ENDIF

            hfl_up(irp) = (hfl_up11*(1.0_ireals-w_a)+hfl_up21*w_a)*(1.0_ireals-w_l) + &
                 (hfl_up21*(1.0_ireals-w_a)+hfl_up22*w_a)*w_l

!!$          hfl_up(irp,k) = (hfl(iaz(irp),ial(irp),k-1)*(1.0_ireals-wa(irp)) +            &
!!$               hfl(iaz(irp)+1,ial(irp),k-1)*wa(irp))*(1.0_ireals-wl(irp)) + &
!!$               (hfl(iaz(irp),ial(irp)+1,k-1)*(1.0_ireals-wa(irp)) +          &
!!$               hfl(iaz(irp)+1,ial(irp)+1,k-1)*wa(irp))*wl(irp)

!!$ UB>>          IF (alt(irp) < 0.0 .OR. hfl_low < 0.0 .OR. hfl_up(irp,k) < 0.0) THEN
!!$              
!!$              flag(irp) = 1
!!$            
!!$            ELSEIF (hfl_up(irp,k) > alt(irp)) THEN
            IF (alt(irp) < -900.0_ireals) THEN
              ! This branch should not be necessary (has been 
              ! treated alread in the first loop), but for safety ...

              flag(irp) = 1
              
            ELSEIF ( hfl_low >= -900.0_ireals .AND. &
                     hfl_low <= alt(irp) .AND. alt(irp) < hfl_up(irp) ) THEN
              
              wk(irp) = (alt(irp)-hfl_up(irp))/(hfl_low-hfl_up(irp))
              
              kout(irp) = k
              
              flag(irp) = 1
              
            ENDIF ! hfl_up(irp,k) > alt(irp)

          ELSE

            hfl_up(irp) = -999.99_ireals

          ENDIF

        ENDIF ! flag(irp) == 0

      ENDDO

    ENDDO

    ! ZY <<

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE calc_vert_weight_onsmth



  SUBROUTINE calc_height_rk4(nst,nae,nra,hl1,dhdr1,rfridx,ra_inc,flag,hl2,dhdr2)

!!$   CALL calc_height_rk4(nstep,nae,rs_meta(ista)nra,alt_stavec,SIN(rs_meta(ista)%el_arr),rfridx_stavec,rfridxgrad_stavec, &
!!$                               rs_meta(ista)%ra_inc,flag(:,0),hl(:,ira),dhdr(:,ira))
    !-----------------------------------------------------------------------------------
    !
    ! Description: Calculation of vertical interpolation weight and level index
    !              above the smoothing point for the interpolation of the auxiliary grids
    !              to the smoothing points
    !-----------------------------------------------------------------------------------
    ! 
    ! Subroutine / Function arguments
    !------------------------------------------------------------------------------
    ! Parameter list:

    CHARACTER (LEN=32) yzroutine

    INTEGER (KIND=iintegers), INTENT (IN)     :: nst,nae,nra    

    INTEGER (KIND=iintegers), INTENT (IN)     :: flag(nae)

    INTEGER (KIND = iintegers)   :: ist,iae

    REAL (KIND=ireals), INTENT (IN)           :: ra_inc

    REAL (KIND=ireals), INTENT (IN)           ::             &
         hl1(nae)               ,& ! 
         dhdr1(nae)             ,& ! 
         rfridx(nae)            
      !   rfridxgrad(nae)         

    REAL (KIND=ireals)           :: k1(nae,2),k2(nae,2),k3(nae,2),k4(nae,2),f(nae,2),hltmp(nae),dhdrtmp(nae)

    REAL (KIND=ireals)           :: ra_st 

    REAL (KIND=ireals), INTENT (OUT)          ::             &
         hl2(nae)               ,& ! 
         dhdr2(nae)         

    !- End of header
    !==============================================================================

    yzroutine(:) = ' '
    yzroutine = 'calc_height_rk4'

    k1 = -999.99_ireals
    k2 = -999.99_ireals
    k3 = -999.99_ireals
    k4 = -999.99_ireals

    f  = -999.99_ireals

    hltmp   = hl1
    dhdrtmp = dhdr1

    hl2     = -999.99_ireals              
    dhdr2   = -999.99_ireals

    ra_st   = ra_inc/nst

    DO ist = 1, nst

      DO iae = 1, nae

        IF (flag(iae) > 0_iintegers) THEN

          k1(iae,1) = dhdrtmp(iae)
          k1(iae,2) = (1 - dhdrtmp(iae)**2)* &
               (rfridx(iae) + 1/(r_earth + hltmp(iae)))

          k2(iae,1) = dhdrtmp(iae) + 0.5*k1(iae,2)*ra_st 
          k2(iae,2) = (1 - (dhdrtmp(iae)+0.5*k1(iae,2)*ra_st)**2)* &
               (rfridx(iae) + 1/(r_earth + hltmp(iae) + 0.5*k1(iae,1)*ra_st))

          k3(iae,1) = dhdrtmp(iae) + 0.5*k2(iae,2)*ra_st 
          k3(iae,2) = (1 - (dhdrtmp(iae)+0.5*k2(iae,2)*ra_st)**2)* &
               (rfridx(iae) + 1/(r_earth + hltmp(iae) + 0.5*k2(iae,1)*ra_st))

          k4(iae,1) = dhdrtmp(iae) + k3(iae,2)*ra_st
          k4(iae,2) = (1 - (dhdrtmp(iae)+k3(iae,2)*ra_st)**2)* &
               (rfridx(iae) + 1/(r_earth + hltmp(iae) + k3(iae,1)*ra_st))

          f(iae,1) = 1.0/6.0*k1(iae,1) + 1.0/3.0*k2(iae,1) + 1.0/3.0*k3(iae,1) + 1.0/6.0*k4(iae,1)
          f(iae,2) = 1.0/6.0*k1(iae,2) + 1.0/3.0*k2(iae,2) + 1.0/3.0*k3(iae,2) + 1.0/6.0*k4(iae,2)

          hltmp(iae)   = hltmp(iae) + ra_st*f(iae,1)
          dhdrtmp(iae) = dhdrtmp(iae) + ra_st*f(iae,2)

        ENDIF

      ENDDO

    ENDDO

    hl2     = hltmp
    ! dhdr2 = dhdrtmp
    DO iae = 1, nae

      IF (flag(iae) > 0_iintegers) THEN
        dhdr2(iae) = MIN(MAX(dhdrtmp(iae),-1.0_ireals),1.0_ireals)
      ENDIF

    ENDDO

  END SUBROUTINE calc_height_rk4


  SUBROUTINE para_range(n1,n2,nprocs,nbl_az,istart,iend)

    !------------------------------------------------------------------------------
    ! Description: This subroutine calculates range of data for each processor 
    !              
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32) yzroutine
    CHARACTER (LEN=80) yzerrmsg 

    INTEGER (KIND = iintegers), INTENT(IN)       :: n1,n2,nprocs,nbl_az
    INTEGER (KIND = iintegers), INTENT(OUT)      :: istart(0:nprocs-1),iend(0:nprocs-1)
    INTEGER (KIND = iintegers)                   :: iwork1,iwork2,irank
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE para_range
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'para_range'

    ! IF (ldebug_radsim) WRITE (*,*)  TRIM(yzroutine), ' on proc ', my_cart_id

    iwork1 = (n2 - n1 + 1)/nprocs
    iwork2 = MOD(n2 - n1 + 1,nprocs)

    DO irank = 0, nprocs-1

      istart(irank) = irank*iwork1 + n1 + MIN(irank,iwork2)
      iend(irank)   = istart(irank) + iwork1 - 1
      IF (iwork2 > irank) THEN 
        iend(irank) = iend(irank) + 1
      ENDIF

      ! UB>> Append 2*nbl_az overlap at the upper bound of the azimut index range:
      !      (however, physically nbl_az azimut intervals are append both the lower and upper bound)
      iend(irank) = iend(irank) + 2*nbl_az

    ENDDO

    ! IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE para_range


  !-------------------------------------------------------------------------
  ! .. Local elevation angle according to the 4/3 earth model, depending on:
  !
  !    r = radar range in m
  !    hmsl = height of ray over MSL in m
  !    elsta = elevation of the antenna in degrees
  !    altsta = station height over MSL in m
  !    ae = earth radius in m
  !
  ! ( Approxim. for r << re: eloc = elsta + s1/re = elsta + s1ore,  Notation from below )

  FUNCTION el_loc_43 (r, elsta, altsta) RESULT (eloc)


    IMPLICIT NONE

    !.. Input/Output parameters:

    REAL(KIND=ireals), INTENT(IN) :: r, elsta, altsta
    REAL(KIND=ireals)             :: eloc
    
    !.. Local variables:

    REAL(KIND=ireals)             :: re, h1, sinelsta, sins1ore, s1ore, &
                                     nomi, denom, coss1ore, coss1orepel

    !------------------------------
    ! "Effective" 4/3 earth radius:
    re = 4.0_ireals/3.0_ireals * (r_earth + altsta)
    
    !------------------
    ! helper variables:

    ! calculate height of radar beam above surface (formula B.8)
    h1 = SQRT(re*re + r*r + 2.0*re*r*SIN(elsta*degrad)) - re

    ! calculate the great circle distance at height of radar station (formula B.9)
    sins1ore = r * COS(elsta*degrad) / (re+h1)
    s1ore = ASIN( sins1ore )
    coss1ore = COS(s1ore)
    coss1orepel = COS(s1ore+elsta*degrad)
    sinelsta = SIN(elsta*degrad)

    nomi = sins1ore*coss1ore + sins1ore*sins1ore*TAN(s1ore+elsta*degrad) + &
           coss1ore*coss1orepel*sinelsta + sins1ore*SIN(s1ore+elsta*degrad)*sinelsta

    denom = coss1orepel * SQRT( coss1orepel*coss1orepel + sins1ore*sins1ore + &
            2.0*sins1ore*coss1orepel*sinelsta )

    eloc = raddeg * ATAN( (nomi*(r_earth+altsta)) / (denom*(r_earth+altsta+h1)) )

  END FUNCTION el_loc_43


  
  !-----------------------------------------------------------------------------------------------
  ! Output of a 3D polar radar data set as a 3D-ASCII-file or 3D Fortran binary file on the NEC SX:
  !
  ! ATTENTION: The index order for writing is now j,i,k! Formerly it was i,j,k!
 
  SUBROUTINE output3d_ascii_radar(ni, nj, nk, zfield, &
       fieldname, fieldcomment, fieldunit, ylevtyp, rmeta, is_aliased, refltype)

    IMPLICIT NONE

    !.. Input/Output parameters:

    INTEGER(KIND=iintegers), INTENT(in) :: ni, nj, nk
    REAL(KIND=ireals), INTENT(in) :: zfield(ni,nj,nk)
    TYPE(radar_meta_type), INTENT(in), OPTIONAL :: rmeta
    LOGICAL, OPTIONAL, INTENT(in) :: is_aliased
    INTEGER(kind=iintegers), OPTIONAL, INTENT(in) :: refltype
    CHARACTER(len=*), INTENT(in) :: fieldname, fieldcomment, fieldunit, ylevtyp

    !.. Local variables:

    CHARACTER(len=250) :: ausdateiname
    INTEGER(kind=iintegers) :: i, j, k, ios, funit

    INTEGER (KIND=iintegers)              ::    &
         mfor_s,    & ! Forecast range (seconds)
         mfor_m,    & ! Forecast range (minutes)
         mfor_h,    & ! Forecast range (hours)
         mfor_d,    & ! Forecast range (days)
         mfor_y       ! Forecast range (years)
    REAL (KIND=ireals) :: zforrange
    CHARACTER (LEN= 8)                    ::    &
         yforrange      ! Forecast range as character
    CHARACTER (len=600) :: header1, header2, aliasstr, configstr

    CHARACTER (len=3) :: cnk

    REAL*4, ALLOCATABLE :: zfield_glob_32bit(:,:)
    REAL*4 :: d32bit = 0.0
    CHARACTER*1 :: dimen
    CHARACTER*5 :: cnrbuf

    ! .. switch to deactive ASCII-output (makes sense for testing purposes, e.g.,
    !    to mask out the time needed for file writing)
    IF (.NOT.lascii_output) RETURN

    ! 1) Dateiname fuer das Output-file konstruieren:
    ausdateiname = REPEAT(' ',LEN(ausdateiname))

    zforrange = FLOAT (ntstep)*dt
    mfor_d    =  INT ( zforrange/86400.0_ireals, iintegers)
    mfor_h    =  INT ((zforrange                                            &
         - FLOAT (mfor_d)*86400.0_ireals)/3600.0_ireals, iintegers)
    mfor_m    =  INT ((zforrange                                            &
         - FLOAT (mfor_d)*86400.0_ireals                           &
         - FLOAT (mfor_h)* 3600.0_ireals)/  60.0_ireals, iintegers)
    mfor_s    = NINT ( zforrange                                            &
         - FLOAT (mfor_d)*86400.0_ireals                           &
         - FLOAT (mfor_h)* 3600.0_ireals                           &
         - FLOAT (mfor_m)*   60.0_ireals, iintegers)
    WRITE (yforrange,'(4(I2.2))') mfor_d, mfor_h, mfor_m, mfor_s

    ausdateiname = TRIM(root%ydir)//'/'//TRIM(ADJUSTL(fieldname))//'_'//TRIM(ydate_ini)//'_'//yforrange//'_'//ylevtyp

    WRITE (*,*) ausdateiname

    CALL get_free_unit (funit)
    IF (funit == -1) THEN
      CALL model_abort (my_world_id, 10071, &
           'ERROR: problem in output3d_ascii_gen(): no free file unit available! Abort!', &
           'output3d_ascii_radar, opening output file')
    END IF

    ! Prepare the header information depending on the presence of radar meta structure
    !   rmeta:
    header1(:) = ' '
    header2(:) = ' '
    configstr(:) = ' '
    IF (PRESENT(rmeta)) THEN
      ! if metadata structure rmeta is present, write some extra
      !   radar metadata into the file header:
      WRITE (configstr, '(a,"=",a,1x,a,"=",L1,"(",i2.2,"x",i2.2,")",6(1x,a,"=",L1),'//&
           '2(1x,a,"=",f0.8),1(1x,a,"=",f0.1),3(1x,a,"=",f0.3))')&
           'station_name', TRIM(rmeta%station_name), &
           'lsmooth', lsmooth, rmeta%ngpsm_v, rmeta%ngpsm_h, &
           'lonline', lonline, &
           'lsode', lsode, &
           'lextdbz', lextdbz, &
           'llookup_mie', llookup_mie, &
           'lweightdbz', lweightdbz, &
           'lfall', lfall, &
           'radar_lon',rmeta%lon, &
           'radar_lat',  rmeta%lat, &
           'radar_alt_msl', rmeta%alt_msl, &
           'ra_inc', rmeta%ra_inc, &
           'az_start', rmeta%az_start, &
           'az_inc', rmeta%az_inc

      IF (PRESENT(refltype)) THEN
        WRITE (configstr, '(a,1x,a,"=",i1)') &
             TRIM(configstr), 'itype_refl', refltype
      END IF
      IF (PRESENT(is_aliased)) THEN
        WRITE (configstr, '(a,1x,a,"=",f0.3,1x,a,"=",L1)') &
             TRIM(configstr), 'vnyq', rmeta%ext_nyq, 'is_aliased', is_aliased
      END IF
      WRITE (header1, '(a,1x,a)') &
           '# '//TRIM(ADJUSTL(fieldcomment))//' ['//TRIM(ADJUSTL(fieldunit))//']', &
           TRIM(configstr)
      WRITE (cnk(1:3), '(i3)') nk
      WRITE (header2, '("|",'//TRIM(cnk)//'(1x,f0.2))') &
           (rmeta%el_arr(i), i=1,nk)
    ELSE
      ! no extra information in header:
      WRITE (header1, '(a)') &
           '# '//TRIM(ADJUSTL(fieldcomment))//' ['//TRIM(ADJUSTL(fieldunit))//']'
    END IF


#ifdef __SX__

    OPEN(unit=funit, file=TRIM(ausdateiname)//'.bin', status='replace', &
         form='unformatted', iostat=ios)
    IF (ios /= 0) THEN
      CALL model_abort (my_world_id, 10072, &
           'ERROR: problem in output3d_ascii_gen(): error opening '//TRIM(ausdateiname)//'.bin', &
           'output3d_ascii_radar, opening output file')
    ENDIF

    cnrbuf(:) = ' '
    WRITE (cnrbuf,'(i5.5)') LEN_TRIM(header1)
    WRITE (funit) cnrbuf
    WRITE (funit) TRIM(header1)

    
    IF (LEN_TRIM(header2) > 0) THEN
      dimen = ACHAR(3+100)
      WRITE (funit) dimen
!!$    WRITE (funit) ni, nj, nk
      WRITE (cnrbuf,'(i5.5)') LEN_TRIM(header2)
      WRITE (funit) cnrbuf
      WRITE (funit) nj, ni, nk
      WRITE (funit) TRIM(header2)
    ELSE
      dimen = ACHAR(3)
      WRITE (funit) dimen
!!$    WRITE (funit) ni, nj, nk
      WRITE (funit) nj, ni, nk
    END IF


#else

    OPEN(unit=funit, file=TRIM(ausdateiname)//'.dat', status='replace', iostat=ios)
    IF (ios /= 0) THEN
      CALL model_abort (my_world_id, 10072, &
           'ERROR: problem in output3d_ascii_gen(): error opening '//TRIM(ausdateiname)//'.dat', &
           'output3d_ascii_radar, opening output file')
    ENDIF

    WRITE (funit, '(a)') TRIM(header1)
    IF (LEN_TRIM(header2) > 0) THEN
      WRITE (funit, '(i4,1x,i4,1x,i4,1x,a)') nj, ni, nk, TRIM(header2)
    ELSE
      WRITE (funit, '(i4,1x,i4,1x,i4)') nj, ni, nk
    END IF

#endif


#ifdef __SX__
!!$    ALLOCATE(zfield_glob_32bit(ni,nj))
    ALLOCATE(zfield_glob_32bit(nj,ni))
    zfield_glob_32bit = 0.0        
#endif

    DO k=1,nk
#ifdef __SX__
!!$      zfield_glob_32bit = REAL(zfield(:,:,k), kind=KIND(d32bit))
      zfield_glob_32bit = TRANSPOSE(REAL(zfield(:,:,k), kind=KIND(d32bit)))
      WRITE (funit) zfield_glob_32bit
#else
!!$      DO j=1,nj
!!$        DO i=1,ni
      DO i=1,ni
        DO j=1,nj
          IF (ABS(zfield(i,j,k)) >= 1e-30_ireals) THEN
            WRITE (funit, '(es12.5)') zfield(i,j,k)
          ELSE
            WRITE (funit, '(i1)') 0_iintegers
          END IF
        END DO
      END DO
#endif
    END DO
#ifdef __SX__
    DEALLOCATE(zfield_glob_32bit)
#endif

    CLOSE (funit)
    CALL release_unit(funit)

  END SUBROUTINE output3d_ascii_radar

  !------------------------------------------------------------------------------

  ! rlat, rlon     in radians
  ! pollat, pollon in degrees

  SUBROUTINE uvrot2uv_corr (urot, vrot, rlat, rlon, pollat, pollon, u, v)

    !------------------------------------------------------------------------------
    !
    ! Description:
    !   This routine converts the wind components u and v from the rotated system
    !   to the real geographical system.
    !
    ! Method:
    !   Transformation formulas for converting between these two systems.
    !
    !------------------------------------------------------------------------------

    ! Parameter list:
    REAL (KIND=ireals), INTENT (IN)          ::    &
         urot, vrot,     & ! wind components in the rotated grid
         rlat, rlon,     & ! latitude and longitude in the true geographical system [radians]
         pollat, pollon    ! latitude and longitude of the north pole of the        [degrees]
    ! rotated grid

    REAL (KIND=ireals), INTENT (OUT)         ::    &
         u, v              ! wind components in the true geographical system

    ! Local variables

    REAL (KIND=ireals)                       ::    &
         zsinpol, zcospol, zlonp, zlat, zarg1, zarg2, znorm

    !------------------------------------------------------------------------------
    ! Begin subroutine uvrot2uv
    !------------------------------------------------------------------------------

    ! Converting from degree to radians
    zsinpol = SIN(pollat * degrad)
    zcospol = COS(pollat * degrad)
    zlonp   = (pollon*degrad-rlon)
    zlat    =                rlat

    zarg1   = zcospol*SIN(zlonp)
    zarg2   = zsinpol*COS(zlat) - zcospol*SIN(zlat)*COS(zlonp)
    znorm   = 1.0/SQRT(zarg1**2 + zarg2**2)

    ! Convert the u- and v-components
    u       =   urot*zarg2*znorm + vrot*zarg1*znorm
    v       = - urot*zarg1*znorm + vrot*zarg2*znorm

  END SUBROUTINE uvrot2uv_corr
  ! UB<<


  ! ZY >> Subroutine to compute Gauss points in interval [-1,1] added

  SUBROUTINE  gauleg(ngp, xabsc, weig)

    INTEGER (KIND=iintegers) :: i,j,m 
    REAL (KIND = ireals)     ::  p1, p2, p3, pp, z, z1
    INTEGER (KIND=iintegers), INTENT(IN) :: ngp            ! # of Gauss Points
    REAL (KIND = ireals),     INTENT(OUT):: xabsc(ngp), weig(ngp)
  
    m = (ngp + 1) / 2
    !* Roots are symmetric in the interval - so only need to find half of them  */

    DO i = 1, m				! Loop over the desired roots */

      z = COS( pi * (i-0.25_ireals) / (ngp+0.5_ireals) )
      !*   Starting with the above approximation to the ith root,
      !*          we enter the main loop of refinement by NEWTON'S method   */
      LOOP: DO

        ! 100 p1 = 1.0_ireals
        p1 = 1.0_ireals
        p2 = 0.0_ireals
        !*  Loop up the recurrence relation to get the Legendre
        !*  polynomial evaluated at z                 */

        DO j = 1, ngp
          p3 = p2
          p2 = p1
          p1 = ((2.0_ireals*j-1.0_ireals) * z * p2 - (j-1.0_ireals)*p3) / j
        ENDDO

        !* p1 is now the desired Legendre polynomial. We next compute pp,
        !* its derivative, by a standard relation involving also p2, the
        !* polynomial of one lower order.      */
        pp = ngp*(z*p1-p2)/(z*z-1.0d0)
        z1 = z
        z = z1 - p1/pp             ! Newton's Method  */

        IF (dabs(z-z1) .GT. 0.000000000000001_ireals) CYCLE LOOP
        EXIT LOOP

      END DO LOOP

      xabsc(i) =  - z                    	! Roots will be bewteen -1.0 & 1.0 */
      xabsc(ngp+1-i) =  + z                	! and symmetric about the origin  */
      weig(i) = 2.0_ireals/((1.0_ireals-z*z)*pp*pp) ! Compute the weight and its       */
      weig(ngp+1-i) = weig(i)               ! symmetric counterpart         */

    END DO     ! i loop

  END SUBROUTINE gauleg

  ! ZY << Subroutine to compute Gauss points in interval [-1,1] added


  ! ZY >> the function of antenna's radiation pattern (single beam, not effective beam pattern!)

  FUNCTION pf(ista,az0,el0,az,el) RESULT(pfvalue)

    INTEGER (KIND = iintegers)       :: ista
    REAL    (KIND = ireals)          :: az0, az, el0, el, pfvalue

    pfvalue = EXP(-8.0_ireals*LOG(2.0_ireals)*(((el-el0)/rs_meta(ista)%Theta3)**2 + &
         ((az-az0)/rs_meta(ista)%Phi3)**2))

  END FUNCTION pf

  !=========================================================================
  !
  ! .. Effective twoway beam function of an azimutally scanning radar 
  !    after the parameterization of Blahak (2008), JAOTECH.
  !
  ! RESULT:  Value of the beam function for a specific sub-ray at
  !          azimut al and elevation el relative to the radar coordinate system.
  !
  ! INPUTS:  ista    : index of radar station
  !          az0     : azimut of beam center    [degrees]
  !          el0     : elevation of beam center [degrees]
  !          az      : azimut of the respective sub-ray [degrees]
  !          al      : elevation of the respective sub-ray [degrees]
  !
  !=========================================================================

  FUNCTION f4_eff_horzscan(ista,az0,el0,az,el) RESULT(f4eff)

    INTEGER (KIND = iintegers)       :: ista
    REAL    (KIND = ireals)          :: az0, el0, az, el, f4eff, phi3_eff

    phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
         ( COS(el0*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
         ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )

    f4eff = EXP(-8.0_ireals*LOG(2.0_ireals) * ( &
                   ( (az - az0)*COS(el*degrad) / phi3_eff             )**2 + &
                   ( (el - el0)                / rs_meta(ista)%Theta3 )**2 ) )

  END FUNCTION f4_eff_horzscan

  FUNCTION phi3_eff_horzscan(ista,el0) RESULT(phi3_eff)

    INTEGER (KIND = iintegers)       :: ista
    REAL    (KIND = ireals)          :: el0, phi3_eff

    phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
         ( COS(el0*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
         ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )

  END FUNCTION phi3_eff_horzscan

  FUNCTION theta3_eff_horzscan(ista) RESULT(theta3_eff)

    INTEGER (KIND = iintegers)       :: ista
    REAL    (KIND = ireals)          :: theta3_eff

    theta3_eff = rs_meta(ista)%Theta3

  END FUNCTION theta3_eff_horzscan

  !=========================================================================
  !
  ! Functions for calculating the smoothing points relative to the beam center.
  ! The smoothing points are computed in a way that the azimut and elevation
  ! intervals span over the local effective beam widths times a pre-defined 
  ! factor, formulated relative to the radar system.
  ! 
  ! The smoothing points depend on the elevation of the beam center and on
  ! the beamwidth and azimutal averaging interval of the radar.
  ! 
  ! See Blahak (2008), JAOTECH
  !
  ! INPUTS:  iv/ih   : vertical/horizontal index of smoothing point within 
  !                    smoothing kernel, corresponding to the weights from gauleg()
  !                    (Gauss-Legendre quadrature)
  !          el0     : elevation of beam center [degrees]
  !          ista    : index of radar station
  !          
  !=========================================================================

  FUNCTION smth_az_horzscan(ista,ih,el0) RESULT(smthpoint)

    INTEGER (KIND = iintegers)       :: ista, ih
    REAL    (KIND = ireals)          :: az0, el0, phi3_eff, smthpoint

    phi3_eff = rs_meta(ista)%alpha3_eff_0 + &
         ( COS(el0*degrad) - 1.0 ) * rs_meta(ista)%dalpha * &
         ( 1.0 - EXP(-1.5*rs_meta(ista)%dalpha/rs_meta(ista)%Phi3 ) )

    smthpoint = 0.5 * phi3_eff * rs_meta(ista)%smth_interv_fact * &
         rs_meta(ista)%xabscsm_h(ih)

  END FUNCTION smth_az_horzscan

  FUNCTION smth_el_horzscan(ista,iv) RESULT(smthpoint)

    INTEGER (KIND = iintegers)       :: ista, iv
    REAL    (KIND = ireals)          :: theta3_eff, smthpoint

    theta3_eff = rs_meta(ista)%Theta3

    smthpoint = 0.5 * theta3_eff * rs_meta(ista)%smth_interv_fact * &
         rs_meta(ista)%xabscsm_v(iv)

  END FUNCTION smth_el_horzscan


  !=========================================================================
  !
  ! Subroutine for control output in files YURADWIND, YURADREFL, ...
  !
  ! Purpose: Output a statistics of 3D polar data field "feld_name" of the
  ! radar described by the meta data structure rad_meta.
  ! The field must be given a short name (<= 8 characters) "feldname".
  ! When searching for the max and min of the field, the search
  ! is limited to positions masked to .true. in the logical 3D field "mask_polar",
  ! which needs to have the same dimensions as "feld_polar". If
  ! all mask_polar is .false., no max / min can be found and the
  ! statistics line will contain the value in "default_missing" instead.
  !
  ! NOTE: ONLY CALL ON ONE PROCESSOR AT A TIME!
  !
  !=========================================================================

  SUBROUTINE control_output(outunit, time_mod, rad_meta, feldname, feld_polar, mask_polar, &
       default_missing, nobs)


    TYPE(radar_meta_type),   INTENT(in)  :: rad_meta
    INTEGER(kind=iintegers), INTENT(in)  :: outunit       , & ! unit number of the (opened) output text file
                                            nobs              ! number of valid observations
    REAL(kind=ireals),       INTENT(in)  :: time_mod          ! time in seconds since model start
!!$    REAL(kind=ireals),       INTENT(in)  :: feld_polar(rad_meta%nra,rad_meta%naz,rad_meta%nel), default_missing
!!$    LOGICAL,                 INTENT(in)  :: mask_polar(rad_meta%nra,rad_meta%naz,rad_meta%nel)      
    REAL(kind=ireals),       INTENT(in)  :: feld_polar(rad_meta%naz,rad_meta%nra,rad_meta%nel), default_missing
    LOGICAL,                 INTENT(in)  :: mask_polar(rad_meta%naz,rad_meta%nra,rad_meta%nel)      
    CHARACTER(len=*),        INTENT(in)  :: feldname

    INTEGER(kind=iintegers)              :: i, imaxloc(3), iminloc(3)
    CHARACTER(len=30)                    :: format_out

    WRITE(outunit,*)
    WRITE(outunit,*)
    WRITE(outunit,'(a)') REPEAT('=', 60)    
    WRITE(outunit,'("time     = ",I12," seconds")')     NINT(time_mod)
    WRITE(outunit,'(a)') REPEAT('=', 60)    
    WRITE(outunit,*)
    WRITE(outunit,'("stat_id  = ",I10)')      rad_meta%station_id
    WRITE(outunit,'("lon      = ",F10.4)')    rad_meta%lon
    WRITE(outunit,'("lat      = ",F10.4)')    rad_meta%lat
    WRITE(outunit,'("alt_agl_mod  = ",F10.2," (from namelist)")')  &
                                               rad_meta%alt_agl_mod
    WRITE(outunit,'("alt_msl  = ",F10.2," (actually used for computations)")') &
                                              rad_meta%alt_msl
    WRITE(outunit,'("mod_msl  = ",F10.2," (model orography height at radar station)")') &
                                              rad_meta%msl_mod
    IF (lsmooth) THEN
      WRITE(outunit,'("Phi3     = ",F10.2)')    rad_meta%Phi3
      WRITE(outunit,'("Theta3   = ",F10.2)')    rad_meta%Theta3
      WRITE(outunit,'("dalpha   = ",F10.2)')    rad_meta%dalpha
      WRITE(outunit,'("alpha3_eff_0 = ",F10.3)') rad_meta%alpha3_eff_0
      WRITE(outunit,'("ngpsm_h  = ",I10)')    rad_meta%ngpsm_h
      WRITE(outunit,'("ngpsm_v  = ",I10)')    rad_meta%ngpsm_v
      format_out(:) = ' '
      WRITE(format_out,'("(A,",I3.3,"(x,F8.4,"" |""))")') rad_meta%ngpsm_h
      WRITE(outunit,TRIM(format_out)) 'xabscsm_h = ', &
           (rad_meta%xabscsm_h(i),i=1,rad_meta%ngpsm_h)
      WRITE(outunit,TRIM(format_out)) 'weigsm_h = ', &
           (rad_meta%weigsm_h(i),i=1,rad_meta%ngpsm_h)
      format_out(:) = ' '
      WRITE(format_out,'("(A,",I3.3,"(x,F8.4,"" |""))")') rad_meta%ngpsm_v
      WRITE(outunit,TRIM(format_out)) 'xabscsm_v = ', &
           (rad_meta%xabscsm_v(i),i=1,rad_meta%ngpsm_v)
      WRITE(outunit,TRIM(format_out)) 'weigsm_v = ', &
           (rad_meta%weigsm_v(i),i=1,rad_meta%ngpsm_v)
    END IF
    WRITE(outunit,'("az_start = ",F10.2)')    rad_meta%az_start
    WRITE(outunit,'("daz      = ",F10.2)')    rad_meta%az_inc
    WRITE(outunit,'("naz      = ",I10)')      rad_meta%naz
    WRITE(outunit,'("dra      = ",F10.2)')    rad_meta%ra_inc
    WRITE(outunit,'("nra      = ",I10)')      rad_meta%nra
    WRITE(outunit,'("nel      = ",I10)')      rad_meta%nel
    WRITE(outunit,*)
    format_out(:) = ' '
    WRITE(format_out,'("(A,",I3.3,"(x,F6.2))")') rad_meta%nel
    WRITE(outunit,TRIM(format_out)) 'ele = ', (rad_meta%el_arr(i),i=1,rad_meta%nel)
    WRITE(outunit,'("nobs     = ",I10)') nobs

    ! A line in YURADWIND with max, min and mean field:

    imaxloc = MAXLOC(array=feld_polar, mask=mask_polar)
    iminloc = MINLOC(array=feld_polar, mask=mask_polar)
    WRITE(outunit,'(A20,3A12,5x,A20,3A12)') "MAX "//TRIM(feldname),"ra_max","az_max","el_max", &
         "MIN "//TRIM(feldname),"ra_min","az_min","el_min"
    IF (ALL(imaxloc > 0)) THEN
      WRITE(outunit,'(es20.5,3i12,5x,es20.5,3i12)')  &
           feld_polar(imaxloc(1),imaxloc(2),imaxloc(3)), &
!!$           imaxloc(1), &
!!$           imaxloc(2), &
           imaxloc(2), &
           imaxloc(1), &
           imaxloc(3), &
           feld_polar(iminloc(1),iminloc(2),iminloc(3)), &
!!$           iminloc(1), &
!!$           iminloc(2), &
           iminloc(2), &
           iminloc(1), &
           iminloc(3)
    ELSE
      WRITE(outunit,'(es20.5,3i12,5x,es20.5,3i12)')  &
           default_missing, &
           -1, &
           -1, &
           -1, &
           default_missing, &
           -1, &
           -1, &
           -1
    END IF

  END SUBROUTINE control_output

  !=========================================================================
  !
  ! Subroutine for input of the namelist RADARSIM_PARAMS
  !
  !=========================================================================

  SUBROUTINE input_radarnamelist

    IMPLICIT NONE

    !------------------------------------------------------------------------------
    !
    ! Description: Opens and reads the namelist on proc 0, distributes the
    !              values/structs to all other nodes, does some
    !              cross-checks and computes some derived parameters within the
    !              structs rs_meta(ista) and dbz_meta(ista).
    !
    ! Method:
    !
    ! Input files: Namelist-file INPUT_RADARSIM, containing namelist RADARSIM_PARAMS
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in/out):


    !------------------------------------------------------------------------------
    !

    !------------------------------------------------------------------------------
    ! .. Defaults for namelist parameters:

    TYPE(radar_meta_type)           :: rs_meta_d(1), rs_meta_ncdf(nradsta_max)
    TYPE(dbzcalc_params)            :: dbz_meta_d(1)
    INTEGER(kind=iintegers)         :: nradsta_d
    INTEGER(kind=iintegers)         :: itype_refl_glob_d  ! global setting for itype_refl
    LOGICAL               :: ldebug_radsim_d,  & ! turn on/off debug mode
                             lascii_output_d,  & ! enable output of ASCII files
                             lfdbk_output_d,   & ! enable output of NetCDF feedback files
                             lout_geom_d,      & ! enable output of radar bin heights and local elevations
                             loutradwind_d,    & ! enable calculation and output of 
                                                 !   radial wind for each radar
                             loutdbz_d,        & ! enable calculation and output of 
                                                 !   reflectivity for each radar
                             lextdbz_d,        & ! enable calculation and consideration of 
                                                 !   extinction of reflectivity for each radar
                             llookup_mie_d,    & ! enable the use of lookup tables for Mie-scattering
                             lweightdbz_d,     & ! enable to take the (attenuated) 
                                                 !   reflectivity as weight into account 
                                                 !   while caculating the radial wind for 
                                                 !   each radar
                             lfall_d,          & ! enable to take the falling velocity of
                                                 !   hydrometeors into account while 
                                                 !   caculating the radial wind for each radar
                             lonline_d,        & ! enable to change the strategy for 
                                                 !   computing of radio propagation path: static 4/3-earth ("offline") or
                                                 !   dynamic ("online") depending on actual refractive index of air
                             lsode_d,          & ! Mehode of SODE 
                             lsmooth_d,        & ! enable spatial smoothing (weighted spatial 
                                                 !   mean over measuring volume increasing with distance) 
                             lreadmeta_from_netcdf_d, & ! read meta data from netCDF files
                             lcheck_inputrecords_d, &   ! check input records in netCDF files and set them individually
                                                        ! for each input data type file
                             lequal_azi_alldatasets_d

    CHARACTER(len=250)              :: ydirradarin_d

    !------------------------------------------------------------------------------
    ! .. Local variables:

    CHARACTER (LEN=10)              :: cnobs
    CHARACTER (LEN=32)              :: yzroutine
    CHARACTER(len=300)              :: errstring
    CHARACTER(len=300)              :: nlradarsimfile, io_errmsg
    LOGICAL                         :: nlfile_exists, opened_nuspecif, found
 
    TYPE(radar_meta_type)           :: rs_meta_buf(1)
    TYPE(dbzcalc_params)            :: dbz_meta_buf(1)
    INTEGER(kind=iintegers)         :: i, ii, iend, ista,  &
                                       iz_err, nuin, nibuf, nlbuf, &
                                       ierr, err_meta(nradsta_max), err_miss(nradsta_max)
    INTEGER (KIND = iintegers)      :: iu, io, ju, jo
    REAL    (KIND = ireals)         :: rlon_r, rlat_r, hsurf_r(1), wi, wj, &
                                       rlon_min, rlon_max, rlat_min, rlat_max

    !------------------------------------------------------------------------------
    ! .. Definition of namelist:

    NAMELIST /RADARSIM_PARAMS/ ldebug_radsim, loutradwind, itype_refl_glob, &
                               loutdbz, lextdbz, llookup_mie, lout_geom, &
                               lweightdbz, lfall, lonline, lsode, lsmooth, lreadmeta_from_netcdf, &
                               lcheck_inputrecords, lascii_output, lfdbk_output, &
                               nradsta, rs_meta, dbz_meta, ydirradarin, lequal_azi_alldatasets

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'input_radarnamelist'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    ! name of the namelist file to read below:
    nlradarsimfile(:) = ' '
!!$    nlradarsimfile = 'INPUT_RADARSIM'  ! this will be the official name later
    nlradarsimfile = 'INPUT_IO'     ! this is now for testing


    !-------------------------------------------------------------------------------
    ! Section 1:  Set defaults for the namelist parameters
    !-------------------------------------------------------------------------------

    ldebug_radsim_d = .FALSE.
    lout_geom_d     = .FALSE.
    loutradwind_d   = .TRUE.
    loutdbz_d       = .TRUE.
    lextdbz_d       = .FALSE.  ! only effective if dbz_meta(ista)%itype_refl = 1
    llookup_mie_d   = .TRUE.
    lweightdbz_d    = .FALSE.
    lfall_d         = .FALSE.
    lonline_d       = .FALSE.
    lsode_d         = .FALSE.
    lsmooth_d       = .FALSE.

    lreadmeta_from_netcdf_d     = .FALSE.
      lcheck_inputrecords_d     = .FALSE.  ! sub-switch
      lequal_azi_alldatasets_d  = .TRUE.   ! sub-switch
    lascii_output_d = .TRUE.
    lfdbk_output_d  = .FALSE.

    nradsta_d = 1

    ydirradarin_d = ' '

    ! .. Parameters in struct rs_meta for radar station parameters:

    ! .. Take default values from prototype:
    rs_meta_d(1) = rs_meta_dwd_proto      !  for German radars
!!&    rs_meta_d(1) = rs_meta_swiss_proto    !  for Swiss radars

    ! .. Parameters in struct dbz_meta for reflectivity calculations:
    !      Initialize default-values structure dbz_meta_d with global defaults
    !      from dbz_namlst_d:
    dbz_meta_d(1) = dbz_namlst_d

    dbz_meta_d(1)%station_id = rs_meta_d(1)%station_id
    ! will later be overwritten in dbz_meta(ista) from the values in rs_meta(ista):
    dbz_meta_d(1)%lambda_radar = rs_meta_d(1)%lambda

    itype_refl_glob_d = -99

    !-------------------------------------------------------------------------------
    ! Section 2: initialize namelist variables with default values:
    !-------------------------------------------------------------------------------

    nradsta        = nradsta_d
    itype_refl_glob = itype_refl_glob_d

    ldebug_radsim = ldebug_radsim_d
    lout_geom     = lout_geom_d
    loutradwind   = loutradwind_d
    loutdbz       = loutdbz_d
    lextdbz       = lextdbz_d
    lweightdbz    = lweightdbz_d
    llookup_mie   = llookup_mie_d
    lfall         = lfall_d
    lonline       = lonline_d
    lsode         = lsode_d
    lsmooth       = lsmooth_d
    lreadmeta_from_netcdf = lreadmeta_from_netcdf_d
    lcheck_inputrecords   = lcheck_inputrecords_d
    lequal_azi_alldatasets = lequal_azi_alldatasets_d
    lascii_output = lascii_output_d
    lfdbk_output  = lfdbk_output_d

    ! .. initialize structures with default values:

    DO ista = 1, nradsta_max     
      rs_meta(ista) = rs_meta_d(1)
      dbz_meta(ista) = dbz_meta_d(1)
    END DO

    !-------------------------------------------------------------------------------
    ! Section 3: read the namelist on proc 0 twice.
    !            The first pass is to determine itype_refl_glob,
    !            which is then used as background value for dbz_meta%itype_refl
    !            in the second pass.
    !-------------------------------------------------------------------------------
    !-------------------------------------------------------------------------------

    IF (my_cart_id == 0) THEN

      INQUIRE ( file=TRIM(ADJUSTL(nlradarsimfile)) , exist=nlfile_exists )

      IF ( .NOT.nlfile_exists ) THEN

        WRITE (*,*) 'THE NAMELIST FILE '//TRIM(ADJUSTL(nlradarsimfile))// &
             ' FOR THE RADAR SIMULATOR DOES NOT EXIST!'
        iz_err = 23456

      ELSE   ! nlfile_exists

#ifndef HAS_IOMSG
        iz_err  = 0
        CALL get_free_unit(nuin)
        OPEN(nuin , FILE=TRIM(ADJUSTL(nlradarsimfile)), FORM='FORMATTED', STATUS='OLD',  &
             IOSTAT=iz_err)
        IF(iz_err /= 0) THEN
          WRITE(*,*) ' ERROR    *** Error while opening file '// &
               TRIM(ADJUSTL(nlradarsimfile))//' *** '
          iz_err = -3
        ELSE
          READ (nuin, radarsim_params, IOSTAT=iz_err)
          IF (iz_err > 0) THEN
            WRITE(*,*) ' ERROR    *** Error while reading NAMELIST /RADARSIM_PARAMS/, probably wrong values ***'
            iz_err = -2
          ELSE IF (iz_err < 0) THEN
            WRITE(*,*) ' ERROR    *** Premature EOF encountered while reading NAMELIST /RADARSIM_PARAMS/ ***'
           iz_err = -1
          ENDIF
          CLOSE(nuin)
          CALL release_unit(nuin)
        ENDIF
#else
        iz_err  = 0
        io_errmsg(:) = ' '
        CALL get_free_unit(nuin)
        OPEN(nuin , FILE=TRIM(ADJUSTL(nlradarsimfile)), FORM='FORMATTED', STATUS='OLD',  &
             IOSTAT=iz_err, IOMSG=io_errmsg)
        IF(iz_err /= 0) THEN
          WRITE(*,*) ' ERROR    *** Error while opening file '// &
               TRIM(ADJUSTL(nlradarsimfile))//'*** '
          WRITE(*,*) TRIM(io_errmsg)
          iz_err = -3
        ELSE
          READ (nuin, radarsim_params, IOSTAT=iz_err, IOMSG=io_errmsg)
          IF (iz_err > 0) THEN
            WRITE(*,*) ' ERROR    *** Error while reading NAMELIST /RADARSIM_PARAMS/, probably wrong values ***'
            WRITE(*,*) TRIM(io_errmsg)
            iz_err = -2
          ELSE IF (iz_err < 0) THEN
            WRITE(*,*) ' ERROR    *** Premature EOF encountered while reading NAMELIST /RADARSIM_PARAMS/ ***'
            WRITE(*,*) TRIM(io_errmsg)
           iz_err = -1
          ENDIF
          CLOSE(nuin)
          CALL release_unit(nuin)
        ENDIF
#endif
        
      END IF

      !-------------------------------------------------------------------------------
      !- Section 4a: Check values for errors and consistency
      !-------------------------------------------------------------------------------

      IF  (iz_err /= 0) THEN

        errstring(:) = ' '
        WRITE (errstring,'(a)') 'Error during opening/reading file INPUT_RADARSIM'
        CALL model_abort (my_world_id, 10077, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')

      END IF

      !-------------------------------------------------------------------------------
      ! .. Set dbz_meta(ista)itype_refl = itype_refl_glob for all stations
      !    if itype_refl_glob has been specified in the namelist:
      !-------------------------------------------------------------------------------

      IF (itype_refl_glob >= 1 .AND. itype_refl_glob <= 4) THEN
        DO ista = 1, nradsta_max     
          dbz_meta(ista)%itype_refl = itype_refl_glob
        END DO
      ELSE IF (itype_refl_glob /= itype_refl_glob_d) THEN
        errstring(:) = ' '
        WRITE (errstring,'(a)') 'Wrong value for itype_refl_glob in INPUT_RADARSIM.' // &
             ' Must be >= 1 and <= 4 or -99!'
        CALL model_abort (my_world_id, 10077, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')
      END IF

    END IF  ! if (my_cart_id == 0)


    !-------------------------------------------------------------------------------
    !- Section 5: Communication Part 1:
    !             Distribute global namelist flags to all other nodes
    !-------------------------------------------------------------------------------
    
    IF (num_compute > 1) THEN

       ! distribute number of radar stations
      IF (my_cart_id == 0) THEN

        nibuf = 0
        nibuf = nibuf + 1 ;   intbuf(nibuf)  = nradsta
        nibuf = nibuf + 1 ;   intbuf(nibuf)  = itype_refl_glob
        
        nlbuf = 0
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = ldebug_radsim
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lout_geom
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = loutradwind
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = loutdbz
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lextdbz
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = llookup_mie
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lweightdbz
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lfall
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lonline
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lsode
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lsmooth
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lreadmeta_from_netcdf
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lcheck_inputrecords
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lequal_azi_alldatasets
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lascii_output
        nlbuf = nlbuf + 1 ;   logbuf(nlbuf)  = lfdbk_output
      END IF

      ! First, distribute the buffer sizes:
      CALL distribute_values (nibuf, 1, 0, imp_integers,     icomm_cart, ierr)
      CALL distribute_values (nlbuf, 1, 0, imp_integers,     icomm_cart, ierr)

      ! Then distribute the actual buffers:
      CALL distribute_values (intbuf,  nibuf, 0, imp_integers, icomm_cart, ierr)
      CALL distribute_values (logbuf,  nlbuf, 0, imp_logical , icomm_cart, ierr)

      IF (my_cart_id /= 0) THEN

        nibuf = 0
        nibuf = nibuf + 1 ;   nradsta        = intbuf(nibuf)
        nibuf = nibuf + 1 ;   itype_refl_glob = intbuf(nibuf)

        nlbuf = 0
        nlbuf = nlbuf + 1 ;   ldebug_radsim  = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lout_geom      = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   loutradwind    = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   loutdbz        = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lextdbz        = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   llookup_mie    = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lweightdbz     = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lfall          = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lonline        = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lsode          = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lsmooth        = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lreadmeta_from_netcdf = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lcheck_inputrecords   = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lequal_azi_alldatasets=logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lascii_output  = logbuf(nlbuf)
        nlbuf = nlbuf + 1 ;   lfdbk_output   = logbuf(nlbuf)

      END IF

      ! distribute the path for the input radar data:
      CALL distribute_values (ydirradarin(1  :100), 100, 0, imp_character, icomm_cart, ierr)
      CALL distribute_values (ydirradarin(101:200), 100, 0, imp_character, icomm_cart, ierr)
      CALL distribute_values (ydirradarin(201:250),  50, 0, imp_character, icomm_cart, ierr)

    END IF


#ifndef NETCDF

    !--------------------------------------------------------------
    ! .. abort if #ifndef NETCDF and lreadmeta_from_netcdf = .true.

    IF (lreadmeta_from_netcdf) THEN
      errstring(:) = ' '
      WRITE (errstring,'(a)') ' namelist lreadmeta_from_netcdf = .true. not possible ' &
           //'because preprocessor switch -DNETCDF not set!'             
      CALL model_abort (my_world_id, 10074, &
           'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
           'src_radar.f90, input_radarnamelist()')
    END IF

#else


    IF (lreadmeta_from_netcdf) THEN

      !-----------------------------------------------------
      ! .. Read meta data from NetCDF files and collect them
      !    on PE 0.

      ! .. Make full meta data lists for DWD radar network:
      !      rs_meta_dwd(1:nradsta_dwd),    dbz_meta_dwd(1:nradsta_dwd)
      !    This is used later for:
      !    - merging with the input namelist "rs_meta" (second highest priority)
      !    - merging with the meta data from the NetCDF files "rs_meta_ncdf" (highest priority)
      ! NOTE: not all metadata are contained in the NetCDF files!
      CALL get_meta_network_dwd ( rs_meta_dwd, dbz_meta_dwd )

      ! .. initialize structure "rs_meta_ncdf"
      !    for storage of the meta data from the NetCDF files
      !    with the prototype defaults for DWD radars:
      rs_meta_ncdf(:) = rs_meta_dwd_proto

      IF (itype_refl_glob >= 1 .AND. itype_refl_glob <= 4) THEN
        ! .. overwrite itype_refl for each station with namelist parameter itype_refl_glob:
        dbz_meta_dwd(:)%itype_refl = itype_refl_glob
      END IF

      ! .. Partially overwrite these with meta data from NetCDF-files 
      !    from DWD radar network, store the merged meta data
      !    in "rs_meta_ncdf" and sort according to the station number
      !    from the NetCDF file name:
      !
      ! NOTE: "nradsta" will be set to the number of radar files,
      !       not to the value from the namelist!
      
      CALL read_meta_info_dwd ( rs_meta_dwd , rs_meta_ncdf , err_meta , err_miss )

      ! .. If mandatory files (one for each vr/qv/z/qz) are missing for a station,
      !    abort model run. This abort might later be removed in operational mode,
      !    in which case the respective station(s) are discarded from the radar simulation.
      !    A WARNING about this has already been issued from within read_meta_info_dwd().
      DO ista = 1, nradsta_max
        IF (err_miss(ista) /= 0) THEN
          errstring(:) = ' '
          IF (err_meta(ista) == 1) THEN
            WRITE (errstring,'(a,i3,a)') 'Some of the mandatory NetCDF files for radar data ' &
                 //'is/are missing for station no. ',ista,'!'
          END IF
          CALL model_abort (my_world_id, 10089, &
               'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
               'src_radar.f90, input_radarnamelist()')
        END IF
      END DO
      
      ! .. If some other errors occur for one or all stations,
      !    abort model run. This abort might later be removed in operational mode
      !    for some of the errors (2,3,4,5), in which case the respective station(s) 
      !    should be eliminated from the rs_meta_ncdf structure and nradsta should
      !    be decreased accordingly.
      !    Some WARNINGS/ERRORS about this have already been issued from within read_meta_info_dwd().
      DO ista = 1, nradsta
        IF (err_meta(ista) /= 0) THEN
          errstring(:) = ' '
          IF (err_meta(ista) == 1) THEN
            WRITE (errstring,'(a)') 'No NetCDF files for station metadata reading ' &
                 //'could be found!'
          ELSE IF (err_meta(ista) == 2) THEN
            WRITE (errstring,'(a)') 'One of the necessary files for vr and qv ' &
                 //'could not be opened for a radar station!'
          ELSE IF (err_meta(ista) == 3) THEN
            WRITE (errstring,'(a)') 'One of the necessary files for z and qz ' &
                 //'could not be opened for a radar station!'
          ELSE IF (err_meta(ista) == 4) THEN
            WRITE (errstring,'(a,i6,a)') 'Station metadata not in rs_meta_dwd for ' &
                 //'radar station ID ',rs_meta_ncdf(ista)%station_id,' !'             
          ELSE IF (err_meta(ista) == 5) THEN
            WRITE (errstring,'(a)') 'No radar data records in ' &
                 //'NetCDF file for radar station ID ',rs_meta_ncdf(ista)%station_id,' !'
          ELSE IF (err_meta(ista) == 6) THEN
            WRITE (errstring,'(a,i6,a)') 'Nominal and actual elevations from NetCDF files ' &
                 //'not matching for radar station ID ',rs_meta_ncdf(ista)%station_id,' !'             
          END IF
          CALL model_abort (my_world_id, 10091, &
               'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
               'src_radar.f90, input_radarnamelist()')
        END IF
      END DO
      

      IF (my_cart_id == 0) THEN

        ! .. Merge meta information for grid point dbz calculation:
        DO ista = 1, nradsta
          found = .FALSE.
          DO i = 1, nradsta_dwd
            IF (dbz_meta_dwd(i)%station_id == rs_meta_ncdf(ista)%station_id) THEN
              dbz_meta(ista) = dbz_meta_dwd(i)
              found = .TRUE.
              EXIT
            END IF
          END DO
          IF (.NOT.found) THEN
            errstring(:) = ' '
            WRITE (errstring,'(a,i7,a)') 'DBZ metadata not in dbz_meta_dwd for ' &
                 //'radar station ID ',rs_meta_ncdf(ista)%station_id,' !'             
            CALL model_abort (my_world_id, 10091, &
                 'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
                 'src_radar.f90, input_radarnamelist()')
          END IF
        END DO

        !-----------------------------------------------------------------------------
        ! .. Check if the el_arr_obs from NetCDF matches the el_arr from the
        !    namelist. Otherwise, model_abort!

        DO i = 1, rs_meta_ncdf(ista)%nel
          IF ( ABS(rs_meta_ncdf(ista)%el_arr(i)-rs_meta_ncdf(ista)%el_arr_obs(i)) > 0.05_ireals ) THEN
            errstring(:) = ' '
            WRITE (errstring,'(a,i7,a)') 'Namelist error: rs_meta%el_arr_obs for station ID ', &
                 rs_meta_ncdf(ista)%station_id,' is not equal to nominal values in rs_meta_dwd%el_arr!'
            CALL model_abort (my_world_id, 10181, &
                 'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
                 'src_radar.f90, input_radarnamelist()')
          END IF
        END DO


        !-----------------------------------------------------------------------------
        ! .. Re-define rs_meta with rs_meta_ncdf:
        rs_meta = rs_meta_ncdf
        
      END IF   ! my_cart_id == 0

    END IF     ! lreadmeta_from_netcdf

#endif


    IF (my_cart_id == 0) THEN

      !-------------------------------------------------------------------------------
      ! .. check nradsta:
      IF (nradsta > nradsta_max) THEN
        errstring(:) = ' '
        WRITE (errstring,'(a)') 'nradsta > nradsta_max !'
        CALL model_abort (my_world_id, 10075, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')
      END IF
      
      !-------------------------------------------------------------------------------
      ! .. check rs_meta(ista)%nobstimes:
      DO ista = 1,nradsta
        
        IF (rs_meta(ista)%nobs_times > nobstimes_max) THEN
          errstring(:) = ' '
          WRITE (errstring,'(a,i3,a)') 'Namelist error: ' &
               //'rs_meta%nobstimes > nobstimes_max for station ',ista,'!'
          CALL model_abort (my_world_id, 10076, &
               'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
               'src_radar.f90, input_radarnamelist()')
        END IF
        
      END DO
      
      !-------------------------------------------------------------------------------
      ! .. check if station IDs are all unique:
      DO ista = 1,nradsta
        DO i = 1,nradsta
          
          IF (i /= ista) THEN
            
            IF ( rs_meta(ista)%station_id == rs_meta(i)%station_id ) THEN
              errstring(:) = ' '
              WRITE (errstring,'(a,i3,a)') 'Namelist error: rs_meta%station_id for station ',ista,' is not unique!'
              CALL model_abort (my_world_id, 10179, &
                   'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
                   'src_radar.f90, input_radarnamelist()')
            END IF
            
          END IF
          
        END DO
      END DO
      

      !-------------------------------------------------------------------------------
      !- Section 4b: Calculate some necessary parameters
      !-------------------------------------------------------------------------------

      !-------------------------------------------------------------------------------
      ! .. fill observation times (and, if needed, obs_startrec, obs_endrec) for all radar stations
      DO ista = 1,nradsta

        IF ( ALL(rs_meta(ista)%obs_times < 0.0_ireals) .AND. .NOT.lreadmeta_from_netcdf ) THEN

          ! .. rs_meta(ista)%dt_obs is the relevant parameter here:

          IF (rs_meta(ista)%nobs_times < 0_iintegers) THEN

            rs_meta(ista)%nobs_times = INT(nstop*dt/rs_meta(ista)%dt_obs)+1

            IF (rs_meta(ista)%nobs_times > nobstimes_max) THEN
              errstring(:) = ' '
              WRITE (errstring,'(a,i3,a)') 'Namelist error: rs_meta(ista)%dt_obs ',&
                   'too small so that rs_meta%nobstimes > nobstimes_max for station ',&
                   ista,'!'
              CALL model_abort (my_world_id, 10078, &
                   'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
                 'src_radar.f90, input_radarnamelist()')
            END IF
          END IF

          DO i = 1,rs_meta(ista)%nobs_times
            rs_meta(ista)%obs_times(i)  = (i-1) * rs_meta(ista)%dt_obs
          END DO

        ELSE
          
          ! .. Obs times >= 0.0 have been specified in rs_meta(ista)%obs_times
          !    and automatically take precedence over the specification 
          !    via dt_obs and nobs_times, without doing anything here.
          !    However, we sort the obs times to the beginning of
          !    the vector and set nobstimes properly:
          !      (for the case of lreadmeta_from_netcdf=.true., we also
          !       reorder obs_cdate and obs_startrec, obs_endrec correspondingly)

          rs_meta_buf(1)%obs_times   = rs_meta(ista)%obs_times
          rs_meta_buf(1)%obs_cdate   = rs_meta(ista)%obs_cdate
          rs_meta_buf(1)%obs_startrec = rs_meta(ista)%obs_startrec
          rs_meta_buf(1)%obs_endrec  = rs_meta(ista)%obs_endrec
          rs_meta_buf(1)%nobs_times  = rs_meta(ista)%nobs_times

          rs_meta(ista)%obs_times    = -999.99_ireals
          rs_meta(ista)%obs_cdate    = 'YYYYMMDDHHMMSS'
          rs_meta(ista)%obs_startrec = -999_iintegers
          rs_meta(ista)%obs_endrec   = -999_iintegers

          rs_meta(ista)%nobs_times   = 0
 
          iend = 1
          DO i = 1, nobstimes_max

            IF (rs_meta_buf(1)%obs_times(i) >= 0.0_ireals .AND. &
                 rs_meta_buf(1)%obs_times(i) <= nstop*dt) THEN

              rs_meta(ista)%nobs_times = rs_meta(ista)%nobs_times + 1

              rs_meta(ista)%obs_times(rs_meta(ista)%nobs_times) = &
                   rs_meta_buf(1)%obs_times(i)
              rs_meta(ista)%obs_cdate(rs_meta(ista)%nobs_times) = &
                   rs_meta_buf(1)%obs_cdate(i)

              DO ii = 1, ndatakind
                rs_meta(ista)%obs_startrec(rs_meta(ista)%nobs_times,ii) = &
                     rs_meta_buf(1)%obs_startrec(i,ii)
                rs_meta(ista)%obs_endrec(rs_meta(ista)%nobs_times,ii) = &
                     rs_meta_buf(1)%obs_endrec(i,ii)
              END DO

              iend = i + 1

            END IF

          END DO

        END IF

        !-----------------------------------------------------------------------------
        ! .. Check if there are obs_times within the time of the model run,
        !    otherwise issue a warning:
        IF ( rs_meta(ista)%nobs_times > 0 ) THEN
          IF ( .NOT. ANY( rs_meta(ista)%obs_times(1:rs_meta(ista)%nobs_times) >= 0.0_ireals &
                    .AND. rs_meta(ista)%obs_times(1:rs_meta(ista)%nobs_times) <= nstop * dt ) ) THEN
            WRITE (*,'(a,i3)') '  WARNING input_radarnamelist: no obs_times '// &
                 'within model run for radar station ',ista
          END IF
        ELSE
            WRITE (*,'(a,i3)') '  WARNING input_radarnamelist: no obs_times '// &
                 'within model run for radar station ',ista
        END IF

        !-----------------------------------------------------------------------------
        ! .. Overtake the radar wavelength from rs_meta - structure to 
        !    dbz_meta - structure:
        dbz_meta(ista)%lambda_radar = rs_meta(ista)%lambda
        
        !-----------------------------------------------------------------------------
        ! .. Compute rs_meta(ista)%alpha3_eff_0 from interpolated table-lookup
        !      (values from Blahak, 2008, JAOTECH)
        rs_meta(ista)%alpha3_eff_0 = get_alpha3_eff_0 ( &
             rs_meta(ista)%dalpha / rs_meta(ista)%Phi3 )

      END DO

    END IF  ! my_cart_id == 0

    !-------------------------------------------------------------------------------
    !- Section 5: Part 2: 
    !             Distribute station meta data to all other nodes
    !-------------------------------------------------------------------------------
    
    IF (num_compute > 1) THEN

      ! loop over all radar stations
      DO ista = 1, nradsta

        ! distribute the rs_meta structure and the dbz_meta structure:

!!$        IF (my_cart_id == 0) THEN
!!$          rs_meta_buf(1)  = rs_meta(ista)
!!$          dbz_meta_buf(1) = dbz_meta(ista)
!!$        ENDIF
!!$
!!$        CALL mpi_bcast (rs_meta_buf,1,mpi_radar_meta_typ,0,icomm_cart,ierr)
!!$        CALL mpi_bcast (dbz_meta_buf,1,mpi_dbzcalc_params_typ,0,icomm_cart,ierr)
!!$
!!$        IF (my_cart_id /= 0) THEN
!!$          rs_meta(ista)     = rs_meta_buf(1)
!!$          dbz_meta(ista)    = dbz_meta_buf(1)
!!$        ENDIF

        CALL mpi_bcast (rs_meta(ista), 1, mpi_radar_meta_typ,     0,icomm_cart,ierr)
        CALL mpi_bcast (dbz_meta(ista),1, mpi_dbzcalc_params_typ, 0,icomm_cart,ierr)

      END DO

    END IF

    !-------------------------------------------------------------------------------
    !- Section 6: Do some checks which can only be done after the
    !             distribution of the namelist parameters to all nodes
    !-------------------------------------------------------------------------------
    
    !-------------------------------------------------------------------------------
    ! .. Check station coordinates, get orography height at the station and
    !    check station height against orography:

    rlon_min = startlon_tot + (nboundlines-0.5)*dlon
    rlon_max = startlon_tot + (ie_tot-nboundlines-0.5)*dlon
    rlat_min = startlat_tot + (nboundlines-0.5)*dlat
    rlat_max = startlat_tot + (je_tot-nboundlines-0.5)*dlat

    DO ista = 1,nradsta

      ! calculate rotated longitude and latitude of radar position:
      rlon_r = rla2rlarot(rs_meta(ista)%lat,rs_meta(ista)%lon,pollat,pollon,polgam)
      rlat_r = phi2phirot(rs_meta(ista)%lat,rs_meta(ista)%lon,pollat,pollon)
      
      ! Check if radar station is outside model domain:
      IF ( rlon_r < rlon_min .OR. rlon_r > rlon_max .OR. &
           rlat_r < rlat_min .OR. rlat_r > rlat_max ) THEN
        
        errstring(:) = ' '
        WRITE (errstring,'(a,i3,a,2(es12.5,a,2es14.5,a))') 'Radar Nr. ', ista, &
             ' position is outside of model domain, lon_rad = ', &
             rlon_r, ' ( domain min/max ', rlon_min, rlon_max, ' )  lat_rad = ', &
             rlat_r, ' ( domain min/max ', rlat_min, rlat_max, ' ) '
        CALL model_abort (my_world_id, 10373, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')
        
      END IF

      ! Global index for the nearest model grid point of the radar station
      !   for meta information:
      rs_meta(ista)%i_nearest_mod = NINT((rlon_r-startlon_tot) / dlon) + 1
      rs_meta(ista)%j_nearest_mod = NINT((rlat_r-startlat_tot) / dlat) + 1

      ! Interpolate the orography height at the radar station and broadcast to all PEs:

      ! Local index of lower left and upper right grid points for hsurf-interpolation:
      iu = FLOOR((rlon_r-startlon) / dlon) + 1
      io = iu + 1
      ju = FLOOR((rlat_r-startlat) / dlat) + 1
      jo = ju + 1

      hsurf_r(1) = -9999.99

      IF ( iu >= 1 .AND. io <= ie .AND. &
           ju >= 1 .AND. jo <= je ) THEN

        ! The radar station is in this processors sub-domain
        ! and the interpolated surface height of its position
        ! can be distributed to all other nodes:

        wi =  MODULO(rlon_r-startlon, dlon) / dlon
        wj =  MODULO(rlat_r-startlat, dlat) / dlat

        hsurf_r(1) = (hhl(iu,ju,ke+1)*(1.0-wi) + hhl(io,ju,ke+1)*wi) * (1.0-wj) + &
                     (hhl(iu,jo,ke+1)*(1.0-wi) + hhl(io,jo,ke+1)*wi) *    wj

        WRITE (*,*) 'MESSAGE from '//TRIM(yzroutine)// &
             ': position of radar station ',ista,' has been found on proc ', my_cart_id, hsurf_r(1)
        
      END IF

      ! Distribute hsurf_r by means of a mpi_reduce "MAX" - operation. By using this
      ! trick, the situation is correctly handled that a radar station is
      ! positionend in the boundary zone of a processor region and hsurf_r
      ! has been computed above on more than 1 processor:

      errstring(:) = ' '
      CALL global_values(hsurf_r, 1, "MAX", imp_reals, icomm_cart, -1, errstring, ierr)

      IF (hsurf_r(1) < -9000_ireals) THEN
        errstring(:) = ' '
        WRITE (errstring,'(a,i3,a,a)') 'Radar Nr. ', ista, &
             ' orography height at the station site could not be determined.', &
             ' That is strange!'
        CALL model_abort (my_world_id, 10374, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')
      END IF

      
      !-------------------------------------------------------------------------------
      ! .. Set rs_meta(ista)%alt_msl according to namelist settings,
      !    rs_meta(ista)%alt_msl takes precedence over rs_meta(ista)%alt_agl_mod:
    
      !   - rs_meta(ista)%alt_agl_mod :  height AGL above the model orography
      !   - rs_meta(ista)%alt_msl     :  height above MSL
      !
      ! IF only rs_meta(ista)%alt_agl_mod or nothing is given in the namelist and
      !  rs_meta(ista)%alt_msl < -9000.0 (default), then the radar height
      !  rs_meta(ista)%alt_msl will be set to hsurf(iradar,jradar) + rs_meta(ista)%alt_agl_mod.
      !
      ! IF rs_meta(ista)%alt_msl >= -9000.0, this value will be used
      !  directly and takes precedence over the other, because all relevant subroutines
      !  of the radar simulator work with rs_meta(ista)%alt_msl.

      rs_meta(ista)%msl_mod = hsurf_r(1)

      IF ( rs_meta(ista)%alt_msl < -9000.0_ireals ) THEN

        rs_meta(ista)%alt_msl = rs_meta(ista)%msl_mod + rs_meta(ista)%alt_agl_mod

      ELSE

        ! unset rs_meta(ista)%alt_agl_mod to show explicitly that this
        ! value is not used in the simulator:

        rs_meta(ista)%alt_agl_mod = -999.99

!!! alternative: rs_meta(ista)%alt_msl = rs_meta(ista)%alt_msl + rs_meta(ista)%alt_agl_mod

      END IF

      !-------------------------------------------------------------------------------
      ! .. Check station height:
    
      IF ( rs_meta(ista)%alt_msl <= hsurf_r(1) ) THEN
        
        errstring(:) = ' '
        WRITE (errstring,'(a,i3,a,4(a,es12.5))') 'Radar Nr. ', ista, &
             ' station height is equal or below model orography, ', &
             ' h_rad MSL = ', rs_meta(ista)%alt_msl, &
             ' hsurf     = ', hsurf_r(1), &
             ' lon_rad   = ', rlon_r, ' lat_rad = ', rlat_r
        CALL model_abort (my_world_id, 10375, &
             'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
             'src_radar.f90, input_radarnamelist()')
        
      END IF
      

    END DO  ! loop over nradsta

   
    !-------------------------------------------------------------------------------
    ! - Section 7: Write diagnostic output on PE 0
    !-------------------------------------------------------------------------------
    
    IF (my_cart_id == 0) THEN

      WRITE(*,*)
      WRITE(*,*) "=================================================================="
      WRITE(*,*) "Information on Radar Simulator"
      WRITE(*,*) "=================================================================="
      WRITE(*,'(a,T30,"=",L8)') '  lfdbk_output', lfdbk_output
      WRITE(*,'(a,T30,"=",L8)') '  lascii_output', lascii_output
      WRITE(*,'(a,T30,"=",L8)') '  lout_geom', lout_geom
      WRITE(*,'(a,T30,"=",L8)') '  loutradwind', loutradwind
      WRITE(*,'(a,T30,"=",L8)') '  loutdbz', loutdbz
      WRITE(*,'(a,T30,"=",L8)') '  lextdbz ', lextdbz
      WRITE(*,'(a,T30,"=",L8)') '  llookup_mie ', llookup_mie
      WRITE(*,'(a,T30,"=",i8)') '  itype_refl_glob', itype_refl_glob
      WRITE(*,'(a,T30,"=",L8)') '  lweightdbz ', lweightdbz
      WRITE(*,'(a,T30,"=",L8)') '  lfall ', lfall
      WRITE(*,'(a,T30,"=",L8)') '  lonline ', lonline
      WRITE(*,'(a,T30,"=",L8)') '  lsode ', lsode
      WRITE(*,'(a,T30,"=",L8)') '  lsmooth', lsmooth
      WRITE(*,'(a,T30,"=",L8)') '  lreadmeta_from_netcdf', lreadmeta_from_netcdf
      WRITE(*,'(a,T30,"=",L8)') '  lcheck_inputrecords',   lcheck_inputrecords
      WRITE(*,'(a,T30,"=",i8)') '  nradsta', nradsta 
      WRITE(*,*)
      WRITE(*,*) "=================================================================="
      WRITE(*,*) "Information on Radar Stations"
      WRITE(*,*) "=================================================================="
      DO ista = 1, nradsta
        WRITE(*,*) "Radar station ",rs_meta(ista)%station_id,"   ista = ",ista
        WRITE(*,'(" lat: ",F7.3,2X,"lon: ",F7.3,2X,"alt_agl_mod: ",F9.3,'//&
             '2X,"alt_msl: ",F9.3,"msl_mod: ",F9.3)') &
             rs_meta(ista)%lat,rs_meta(ista)%lon,rs_meta(ista)%alt_agl_mod, &
             rs_meta(ista)%alt_msl,rs_meta(ista)%msl_mod
        WRITE(*,'(" range bins (number/increment): ",I4,"/",F8.2,/,'//&
             '" azimuths (number/increment/start): ",I4,"/",F6.2,"/",F6.2)') &
             rs_meta(ista)%nra, rs_meta(ista)%ra_inc, &
             rs_meta(ista)%naz, rs_meta(ista)%az_inc, rs_meta(ista)%az_start
        IF (lsmooth) THEN
          WRITE(*,'("  Phi3: ",f6.2,/,"  Theta3: ",f6.2,/,"  dalpha: ",f6.2,' &
               //'/,"  alpha3_eff_0: ",f7.3)') &
               rs_meta(ista)%Phi3, rs_meta(ista)%Theta3, rs_meta(ista)%dalpha, &
               rs_meta(ista)%alpha3_eff_0
        ENDIF
        WRITE(*,*) "elevations: "
        WRITE(*,*) (rs_meta(ista)%el_arr(i),i=1,rs_meta(ista)%nel)
        WRITE(*,*) "observation times:   no. obs. times = ", rs_meta(ista)%nobs_times
        cnobs(:) = ' '
        IF (rs_meta(ista)%nobs_times > 10) THEN
          WRITE(cnobs,'(i10)') 10_iintegers
          WRITE(*,'('//TRIM(ADJUSTL(cnobs))//'(f8.1," |")," ...")') &
               (rs_meta(ista)%obs_times(i),i=1,10)
        ELSE IF (rs_meta(ista)%nobs_times > 0) THEN
          WRITE(cnobs,'(i10)') rs_meta(ista)%nobs_times
          WRITE(*,'('//TRIM(ADJUSTL(cnobs))//'(f8.1," |"))') &
               (rs_meta(ista)%obs_times(i),i=1,rs_meta(ista)%nobs_times)
        END IF
        WRITE(*,*) "--------------------------------------------------"
      END DO
      
    END IF

    !-------------------------------------------------------------------------------
    ! - Section 8: Write namelist parameters and their defaults to file unit nuspecif:
    !-------------------------------------------------------------------------------

    IF ( my_cart_id == 0 ) THEN

      INQUIRE (unit=nuspecif, opened=opened_nuspecif)
      IF (.NOT.opened_nuspecif) THEN
        INQUIRE (file=TRIM(yuspecif), exist=nlfile_exists)
        IF (nlfile_exists) THEN
          OPEN (nuspecif, file=TRIM(yuspecif), form='formatted', status='old', &
               position='append', iostat=ierr)
        ELSE
          OPEN (nuspecif, file=TRIM(yuspecif), form='formatted', status='new', &
               iostat=ierr)         
        END IF
        IF (ierr /= 0) THEN
          errstring(:) = ' '
          WRITE (errstring,'(a)') 'Error during opening/reading file '//TRIM(yuspecif)
          CALL model_abort (my_world_id, 10085, &
               'ERROR: problem in input_radarnamelist(): '//TRIM(ADJUSTL(errstring)), &
               'src_radar.f90, input_radarnamelist()')
        END IF
      END IF

      WRITE (nuspecif, '(A2)')  '  '
      WRITE (nuspecif, '(A)') '0    NAMELIST: radarsim_params'
      WRITE (nuspecif, '(A)') '     -------------------------'
      WRITE (nuspecif, '(A2)')  '  '
      WRITE (nuspecif, '(A)')  'Variables for radar simulator'
      WRITE (nuspecif, '(T8,A,T40,A,T55,A,T70,A)') 'Variable', 'Actual Value',   &
           'Default Value', 'Format'
      WRITE (nuspecif, '(T8,A,T40,I12,T55,I12,T70,A)')                       &
           'nradsta', nradsta, nradsta_d, ' I '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'ldebug_radsim', ldebug_radsim, ldebug_radsim_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lascii_output', lascii_output, lascii_output_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lfdbk_output', lfdbk_output, lfdbk_output_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lout_geom', lout_geom, lout_geom_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'loutradwind', loutradwind, loutradwind_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'loutdbz', loutdbz, loutdbz_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lextdbz', lextdbz, lextdbz_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'llookup_mie', llookup_mie, llookup_mie_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,I12,T55,I12,T70,A)')                       &
           'itype_refl_glob', itype_refl_glob, itype_refl_glob_d, ' I '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lweightdbz', lweightdbz, lweightdbz_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lfall', lfall, lfall_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lonline', lonline, lonline_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lsode', lsode, lsode_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lsmooth', lsmooth, lsmooth_d     , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lreadmeta_from_netcdf', lreadmeta_from_netcdf, lreadmeta_from_netcdf_d , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lcheck_inputrecords', lcheck_inputrecords, lcheck_inputrecords_d , ' L '
      WRITE (nuspecif, '(T8,A,T40,L12,T55,L12,T70,A)')                       &
           'lequal_azi_alldatasets', lequal_azi_alldatasets, lequal_azi_alldatasets_d , ' L '
      DO ista = 1, nradsta
        WRITE (nuspecif, '(T2,a,i3,a)') 'Meta data of radar station ',ista, ' :'
        CALL ctrl_output_ista_nuspecif(nuspecif, ista, rs_meta(ista), rs_meta_d(1), &
             dbz_meta(ista), dbz_meta_d(1))
      END DO

      IF (.NOT.opened_nuspecif) THEN
        CLOSE (nuspecif, status='keep')
      END IF

    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE input_radarnamelist

  !==============================================================================
  !+ Module procedure in src_radar for determining the half width of the
  !  effective beam weighting function
  !------------------------------------------------------------------------------

  FUNCTION get_alpha3_eff_0 (daophi3) RESULT(alpha3_eff_0)

    !------------------------------------------------------------------------------
    !
    ! Description: Computation of the half width parameter of the
    !              effective beam weigthing function of a scanning radar.
    !
    ! Method: Linear table interpolation; table vectors from Blahak (2008, JAOTECH).
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):
    
    IMPLICIT NONE

    REAL(kind=ireals), INTENT(in)   ::   daophi3
    REAL(kind=ireals)               ::   alpha3_eff_0

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    INTEGER(kind=iintegers)         ::   ierr
    REAL(kind=ireals)               ::   xinter(1), finter(1)

    REAL(kind=ireals), PARAMETER :: danvec(21) = &
         (/ 0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, &
            1.0, 1.1, 1.2, 1.3, 1.4, 1.5, 2.0, 2.5, 3.0, 4.0, 5.0 /)

    REAL(kind=ireals), PARAMETER :: alvec(21)  = (/ &
         1.000, 1.015, 1.031, 1.063, 1.096,   &
         1.129, 1.180, 1.245, 1.322, 1.393,   &
         1.461, 1.554, 1.645, 1.733, 1.832,   &
         1.934, 2.433, 2.913, 3.432, 4.424,   &
         5.423 /)

    xinter(1) = daophi3

    ! .. Linear table interpolation with constant extrapolation
    !    of out-of-range values
    CALL linear_interpol(danvec, alvec, 21_iintegers, &
         xinter, finter, 1_iintegers, ierr)

    alpha3_eff_0 = finter(1)

  END FUNCTION get_alpha3_eff_0

  !==============================================================================
  !+ Module procedure in src_radar for control output of the radar namelist
  !  parameters in the structures rs_meta(ista) and dbz_meta(ista) to a file
  !  (normally to  "YUSPECIF")
  !------------------------------------------------------------------------------

  SUBROUTINE ctrl_output_ista_nuspecif(funit, ista, rs_m, rs_m_d, dbz_m, dbz_m_d)
 
    !------------------------------------------------------------------------------
    !
    ! Description: Control output of the radar namelist
    !              parameters in the structures rs_meta(ista) and dbz_meta(ista) to a file
    !              (normally to  "YUSPECIF")
    !
    ! Method: Wrinting to file with unit "funit". File has to be opened before
    !         calling this subroutine!
    !
    ! Input files:
    !
    ! Output files:
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    IMPLICIT NONE

    INTEGER(kind=iintegers), INTENT(in) :: funit, ista
    TYPE(radar_meta_type), INTENT(in)   :: rs_m, rs_m_d
    TYPE(dbzcalc_params), INTENT(in)    :: dbz_m, dbz_m_d

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    CHARACTER (LEN=32)                  :: yzroutine
    INTEGER(kind=iintegers)             :: i, ii

    !---------------------------------------------------------------------------------
    ! .. Parameters for struct radar_meta_type:

    yzroutine(:) = ' '
    yzroutine = 'ctrl_output_ista_nuspecif'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T46,A,T61,A,T76,A)')                     &
         ista, 'station_name',  rs_m%station_name, rs_m_d%station_name, ' C*3 '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'station_id', rs_m%station_id, rs_m_d%station_id, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'lambda', rs_m%lambda, rs_m_d%lambda, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.6,T55,f12.6,T70,A)')              &
         ista, 'lat', rs_m%lat, rs_m_d%lat, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.6,T55,f12.6,T70,A)')              &
         ista, 'lon', rs_m%lon, rs_m_d%lon, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.1,T55,f12.1,T70,A)')              &
         ista, 'alt_agl_mod', rs_m%alt_agl_mod, rs_m_d%alt_agl_mod, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'alt_msl', rs_m%alt_msl, rs_m_d%alt_msl, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'msl_mod', rs_m%msl_mod, rs_m_d%msl_mod, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'i_nearest_mod', rs_m%i_nearest_mod, rs_m_d%i_nearest_mod, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'j_nearest_mod', rs_m%j_nearest_mod, rs_m_d%j_nearest_mod, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'nobs_times', rs_m%nobs_times, rs_m_d%nobs_times, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.1,T55,f12.1,T70,A)')              &
         ista, 'dt_obs', rs_m%dt_obs, rs_m_d%dt_obs, ' R '
    DO i = 1, rs_m%nobs_times
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.1,T55,f12.1,T70,A)')       &
           ista, 'obs_times(',i,')', rs_m%obs_times(i), rs_m_d%obs_times(i), ' R '
    END DO
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'nel', rs_m%nel, rs_m_d%nel, ' I '
    DO i = 1, MAX(rs_m%nel,rs_m_d%nel)
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.3,T55,f12.3,T70,A)')       &
           ista, 'el_arr(',i,')', rs_m%el_arr(i), rs_m_d%el_arr(i), ' R '
    END DO
    IF (lreadmeta_from_netcdf) THEN
      DO i = 1, MAX(rs_m%nel,rs_m_d%nel)
        WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.3,T55,f12.3,T70,A)')     &
             ista, 'el_arr_obs(',i,')', rs_m%el_arr_obs(i), rs_m_d%el_arr(i), ' R '
      END DO
    END IF
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'az_start', rs_m%az_start, rs_m_d%az_start, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'naz', rs_m%naz, rs_m_d%naz, ' I '
    IF (lreadmeta_from_netcdf) THEN
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                &
           ista, 'naz_ncdf (vr)', rs_m%naz_ncdf(1), rs_m_d%naz_ncdf(1), ' I '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                &
           ista, 'naz_ncdf (qv)', rs_m%naz_ncdf(2), rs_m_d%naz_ncdf(2), ' I '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                &
           ista, 'naz_ncdf ( z)', rs_m%naz_ncdf(3), rs_m_d%naz_ncdf(3), ' I '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                &
           ista, 'naz_ncdf (qz)', rs_m%naz_ncdf(4), rs_m_d%naz_ncdf(4), ' I '
    END IF
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'az_inc', rs_m%az_inc, rs_m_d%az_inc, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'nra', rs_m%nra, rs_m_d%nra, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'ra_inc', rs_m%ra_inc, rs_m_d%ra_inc, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'Phi3', rs_m%Phi3, rs_m_d%Phi3, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'Theta3', rs_m%Theta3, rs_m_d%Theta3, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'dalpha', rs_m%dalpha, rs_m_d%dalpha, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'alpha3_eff_0', rs_m%alpha3_eff_0, rs_m_d%alpha3_eff_0, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'smth_interv_fact', rs_m%smth_interv_fact, rs_m_d%smth_interv_fact, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'ext_nyq', rs_m%ext_nyq, rs_m_d%ext_nyq, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'high_nyq', rs_m%high_nyq, rs_m_d%high_nyq, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'prf', rs_m%prf, rs_m_d%prf, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'dualprf_ratio', rs_m%dualprf_ratio, rs_m_d%dualprf_ratio, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'rngate_len', rs_m%rngate_len, rs_m_d%rngate_len, ' R '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'num_gates', rs_m%num_gates, rs_m_d%num_gates, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'num_pulses', rs_m%num_pulses, rs_m_d%num_pulses, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'ngpsm_h', rs_m%ngpsm_h, rs_m_d%ngpsm_h, ' I '
    WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'ngpsm_v', rs_m%ngpsm_v, rs_m_d%ngpsm_v, ' I '
    DO i = 1, rs_m%ngpsm_h
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.5,T55,f12.5,T70,A)')       &
           ista, 'xabscsm_h(',i,')', rs_m%xabscsm_h(i), rs_m_d%xabscsm_h(i), ' R '
    END DO
    DO i = 1, rs_m%ngpsm_v
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.5,T55,f12.5,T70,A)')       &
           ista, 'xabscsm_v(',i,')', rs_m%xabscsm_v(i), rs_m_d%xabscsm_v(i), ' R '
    END DO
    DO i = 1, rs_m%ngpsm_h
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.5,T55,f12.5,T70,A)')       &
           ista, 'weigsm_h(',i,')', rs_m%weigsm_h(i), rs_m_d%weigsm_h(i), ' R '
    END DO
    DO i = 1, rs_m%ngpsm_v
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,f12.5,T55,f12.5,T70,A)')       &
           ista, 'weigsm_v(',i,')', rs_m%weigsm_v(i), rs_m_d%weigsm_v(i), ' R '
    END DO
    IF (lreadmeta_from_netcdf) THEN
      DO i = 1, rs_m%nobs_times
        WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,A14,T55,A14,T70,A)')         &
             ista, 'obs_cdate(',i,')', rs_m%obs_cdate(i), rs_m_d%obs_cdate(i), ' C*14 '
      END DO
      DO i = 1, rs_m%nobs_times
        WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,'//TRIM(cndatakind)//'I10)') &
             ista, 'obs_startrec(',i,',1:'//TRIM(cndatakind)//')', rs_m%obs_startrec(i,1:ndatakind)
        WRITE (funit, '(T8,"rs_m(",i3,")%",A,i3,A,T40,'//TRIM(cndatakind)//'I10)') &
             ista, 'obs_endrec  (',i,',1:'//TRIM(cndatakind)//')', rs_m%obs_endrec(i,1:ndatakind)
      END DO
      DO ii=1,ndatakind
        WRITE (funit, '(T8,"rs_m(",i3,")%",A,"(",i1,")",T40,I12,T55,I12,T70,A)')   &
             ista, 'nrep_ncdf', ii, rs_m%nrep_ncdf(ii), rs_m_d%nrep_ncdf(ii), ' I '
      END DO
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,A)')                                &
           ista, 'ncdffile_vr', TRIM(ADJUSTL(rs_m%ncdffile_vr))
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,L12,T70,A)')                        &
           ista, 'lradwind_avail', rs_m%lradwind_avail, ' L '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,A)')                                &
           ista, 'ncdffile_qv', TRIM(ADJUSTL(rs_m%ncdffile_qv))
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,L12,T70,A)')                        &
           ista, 'lradwind_q_avail', rs_m%lradwind_q_avail, ' L '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,A)')                                &
           ista, 'ncdffile_z ', TRIM(ADJUSTL(rs_m%ncdffile_z ))
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,L12,T70,A)')                        &
           ista, 'lzradar_avail', rs_m%lzradar_avail, ' L '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,A)')                                &
           ista, 'ncdffile_qz', TRIM(ADJUSTL(rs_m%ncdffile_qz))
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,L12,T70,A)')                        &
           ista, 'lzradar_q_avail', rs_m%lzradar_q_avail, ' L '
      WRITE (funit, '(T8,"rs_m(",i3,")%",A,T40,A)')                                &
           ista, 'fdkbfile', TRIM(ADJUSTL(rs_m%fdbkfile))
    END IF


    !---------------------------------------------------------------------------------
    ! .. Parameters for struct dbzcalc_params:

    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'station_id', dbz_m%station_id, dbz_m_d%station_id, ' I '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'lambda_radar', dbz_m%lambda_radar, dbz_m_d%lambda_radar, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista, 'itype_refl', dbz_m%itype_refl, dbz_m_d%itype_refl, ' I '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,I12,T55,I12,T70,A)')                  &
         ista,  'igraupel_type',  dbz_m%igraupel_type, dbz_m_d%igraupel_type, ' I '     
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'Tmeltbegin_s', dbz_m%Tmeltbegin_s, dbz_m_d%Tmeltbegin_s, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'meltdegTmin_s', dbz_m%meltdegTmin_s, dbz_m_d%meltdegTmin_s, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'Tmeltbegin_g', dbz_m%Tmeltbegin_g, dbz_m_d%Tmeltbegin_g, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'meltdegTmin_g', dbz_m%meltdegTmin_g, dbz_m_d%meltdegTmin_g, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'Tmeltbegin_h', dbz_m%Tmeltbegin_h, dbz_m_d%Tmeltbegin_h, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T40,f12.3,T55,f12.3,T70,A)')              &
         ista, 'meltdegTmin_h', dbz_m%meltdegTmin_h, dbz_m_d%meltdegTmin_h, ' R '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_drysnow_mie',  dbz_m%ctype_drysnow_mie, dbz_m_d%ctype_drysnow_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wetsnow_mie',  dbz_m%ctype_wetsnow_mie, dbz_m_d%ctype_wetsnow_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_drygraupel_mie',  dbz_m%ctype_drygraupel_mie, dbz_m_d%ctype_drygraupel_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wetgraupel_mie',  dbz_m%ctype_wetgraupel_mie, dbz_m_d%ctype_wetgraupel_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_dryhail_mie',  dbz_m%ctype_dryhail_mie, dbz_m_d%ctype_dryhail_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wethail_mie',  dbz_m%ctype_wethail_mie, dbz_m_d%ctype_wethail_mie, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_drysnow_ray',  dbz_m%ctype_drysnow_ray, dbz_m_d%ctype_drysnow_ray, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wetsnow_ray',  dbz_m%ctype_wetsnow_ray, dbz_m_d%ctype_wetsnow_ray, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_drygraupel_ray', dbz_m%ctype_drygraupel_ray, dbz_m_d%ctype_drygraupel_ray, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wetgraupel_ray', dbz_m%ctype_wetgraupel_ray, dbz_m_d%ctype_wetgraupel_ray, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_dryhail_ray', dbz_m%ctype_dryhail_ray, dbz_m_d%ctype_dryhail_ray, ' C*12 '
    WRITE (funit, '(T8,"dbz_m(",i3,")%",A,T46,A,T61,A,T76,A)')                      &
         ista, 'ctype_wethail_ray', dbz_m%ctype_wethail_ray, dbz_m_d%ctype_wethail_ray, ' C*12 '

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE ctrl_output_ista_nuspecif

  !==============================================================================
  !+ Module procedure in src_radar for defining a prototype meta data structure
  !  for DWD radars as a basis for later refinement for each station.
  !------------------------------------------------------------------------------

  FUNCTION get_meta_proto_dwd () RESULT(m)
    IMPLICIT NONE
    TYPE(radar_meta_type) :: m
    CHARACTER(len=250)    :: errstring
    REAL(kind=ireals)     :: zlat, zlon

    IF (ldebug_radsim) WRITE (*,*) 'get_meta_proto_dwd on proc ', my_cart_id

    ! .. Prototype parameters in TYPE(radar_meta_type) for DWD radar station parameters:
    !
    m%station_name  = "XXX"                    ! Short name of station
    m%station_id          = 999999_iintegers
    m%lambda      = 0.055_ireals
    m%lat         = startlat_tot + (INT(je_tot/2.0)+1)*dlat
    m%lon         = startlon_tot + (INT(ie_tot/2.0)+1)*dlon
    ! convert to geographic coordinates:
    zlat = phirot2phi(m%lat,m%lon,pollat,pollon,polgam)
    zlon = rlarot2rla(m%lat,m%lon,pollat,pollon,polgam)
    m%lat = zlat
    m%lon = zlon
    ! Height AGL. Will not be used for actual computations,
    ! but takes effect if m%alt_msl < -9000.0, in that it
    ! will be added to the model orography height at the
    ! radar station and written to m%alt_msl.
    m%alt_agl_mod = 50.0_ireals
    m%alt_msl     = -9999.99_ireals  ! will be actually used for all computations; 
                                     ! < 9000.0 means that it will be determined from 
                                     ! m%alt_agl_mod + model orography height at the 
                                     ! radar station coordinates
    m%msl_mod     = -9999.99_ireals  ! oro height MSL at station (m). Dummy value, will be determined automatically
    m%i_nearest_mod = -9999_iintegers   ! i-Index of nearest neighbour grid point to radar station (also dummy)
    m%j_nearest_mod = -9999_iintegers   ! j-Index of nearest neighbour grid point to radar station (also dummy)
    m%nel            = 18_iintegers     ! actually used nel
    m%nel_default(:) = -9999_iintegers  ! nel of some default scanstrategies; come into play
    m%nel_default(1) = 18_iintegers     ! if metadata are read from DWD netcdf radar files
    m%nel_default(2) = 10_iintegers
    m%nobs_times  = -999_iintegers
    m%dt_obs      = 900.0_ireals
    m%obs_times(1:nobstimes_max) = -999.9_ireals
    m%el_arr   (1:nel_max)  = 0.0_ireals
    IF (m%nel > nel_max) THEN
      errstring(:) = ' '
      WRITE (errstring,'(a,a,i6)') 'DWD radar metadata default', &
           ' has more elevations than allowed by nel_max = ', nel_max
      CALL model_abort (my_world_id, 10073, &
           'ERROR: problem in get_meta_proto_dwd(): '//TRIM(ADJUSTL(errstring)), &
           'src_radar.f90, get_meta_proto_dwd()')
    END IF
    m%el_arr(1:m%nel)  = &
         (/0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, &
         9.5,11.0,13.0,15.0,17.0,19.0,23.0,29.0,37.0/)  ! nominal elevations (from old DWD radars...)

    ! default sets of nominal elevations; come into play if metadata are read from radar files:
    m%el_arr_default(:,nscanstrategies_max) = 0.0_ireals
    m%el_arr_default(1:m%nel_default(1),1)  = &
         (/0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, &
         9.5,11.0,13.0,15.0,17.0,19.0,23.0,29.0,37.0/)  ! nominal elevations (from old DWD radars...)
    m%el_arr_default(1:m%nel_default(2),2)  = &
         (/0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 8.0, 12.0, 17.0, 25.0/)  ! nominal elevations (from new DWD radars...)

!    m%el_arr(1:m%nel)  = &
!         (/0.1, 0.2, 0.3, 0.4, 0.5, 2.5, 3.5/)  ! nominal elevations (from DWD radars...)

    m%el_arr_obs  = m%el_arr                     ! if elev. are read from obs-files, 
                                                 ! these are the values read from obs files
                                                 ! and used for cross-checking with m%el_arr_default
    m%az_start    = 0.0_ireals
    m%naz         = 360_iintegers
    m%naz_ncdf(:) = 360_iintegers  ! dummy obs file azi dimension, will be read from obs files
    m%az_inc      = 1.0_ireals
!!$    m%ra_start    = 1000.0_ireals
    m%nra         = 124_iintegers   ! max. number of range bins occuring in a volume scan
    m%ra_inc      = 1000.0_ireals
    m%Theta3      = 1.0_ireals  ! vertical 3-dB-oneway beam width (deg)
    m%Phi3        = 1.0_ireals  ! horizontal 3-dB-oneway  beam width (deg)
    m%dalpha      = 1.0_ireals  ! azimutal averaging interval for calculation of one averaged pulse
                                           ! (averaging over the number of statistically independent pulses)
    m%alpha3_eff_0 = 1.461_ireals  ! dummy value for the effective horizontal 3-dB-oneway beam width at elevation = 0.0.
                                   ! Depends on the ratio (dalpha/phi3) - has to be exaclty determined later!
                                   ! The provisional value 1.461 is valid for dalpha/phi3 = 1.0
    m%smth_interv_fact = 1.29_ireals  ! Factor to determine the azimutal and elevational integration range
                                      !   for the smoothing over the beam function. The ranges are computed by multiplying this
                                      !   factor to the effective 3-dB-oneway beamwidths.
                                      !   ( a value of 1.29 leads to the 90-%-weight-range of the beam function)
    m%ngpsm_v     = 1_iintegers  ! number of vertical smoothing points for Gauss-Legendre quadrature
    m%ngpsm_h     = 1_iintegers  ! number of horizontal smoothing points for Gauss-Legendre quadrature
    m%xabscsm_v   = 0.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%xabscsm_h   = 0.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%weigsm_v    = 1.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%weigsm_h    = 1.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%high_nyq    = 32.5_ireals                ! Nyquist frequency
    m%ext_nyq     = 32.5_ireals                ! Nyquist frequency incl. techniques like Dual-PRF
    m%prf         = 1000.0_ireals  ! Low PRF (???)
    m%dualprf_ratio = 4.0_ireals / 3.0_ireals  ! Dual PRF Ratio
    m%rngate_len  = 125.0_ireals               ! Range gate length
    m%obs_cdate(1:nobstimes_max) = "YYYYMMDDHHMMSS"       ! array of observation times as string
    m%obs_startrec(1:nobstimes_max,:) = -999_iintegers    ! array of observation start records
    m%obs_endrec(1:nobstimes_max,:)   = -999_iintegers    ! array of observation end records
    m%nrep_ncdf   = -1_iintegers
    m%num_gates   = 0_iintegers
    m%num_pulses  = 0_iintegers
    m%ncdffile_vr(:)  = 'nofile_vr'  ! name of NetCDF input file for vr
    m%ncdffile_qv(:)  = 'nofile_qv'  ! name of NetCDF input file for qv
    m%ncdffile_z (:)  = 'nofile_z '  ! name of NetCDF input file for z
    m%ncdffile_qz(:)  = 'nofile_qz'  ! name of NetCDF input file for qz
    m%fdbkfile(:)     = 'nofile_fdbk'  ! name of NetCDF feedback file for vr
    m%lradwind_avail    = .FALSE.  ! Flags for success or failure
    m%lradwind_q_avail  = .FALSE.  ! of data reading from NetCDF
    m%lzradar_avail     = .FALSE.
    m%lzradar_q_avail   = .FALSE.
    m%lfdbkfile_exist    = .FALSE.  ! Flag for existence of feedback file 
    
    IF (ldebug_radsim) WRITE (*,*)  'done with get_meta_proto_dwd on proc ', my_cart_id

  END FUNCTION get_meta_proto_dwd

  !==============================================================================
  !+ Module procedure in src_radar for defining a prototype meta data structure
  !  for MeteoSwiss radars as a basis for later refinement for each station.
  !------------------------------------------------------------------------------

  FUNCTION get_meta_proto_swiss () RESULT(m)
    IMPLICIT NONE
    TYPE(radar_meta_type) :: m
    CHARACTER(len=250)    :: errstring
    REAL(kind=ireals)     :: zlat, zlon

    IF (ldebug_radsim) WRITE (*,*) 'get_meta_proto_swiss on proc ', my_cart_id

    ! .. Prototype parameters in TYPE(radar_meta_type) for DWD radar station parameters:
    !
    m%station_name  = "XXX"                    ! Short name of station
    m%station_id          = 999999_iintegers
    m%lambda      = 0.055_ireals
    m%lat         = startlat_tot + (INT(je_tot/2.0)+1)*dlat
    m%lon         = startlon_tot + (INT(ie_tot/2.0)+1)*dlon
    ! convert to geographic coordinates:
    zlat = phirot2phi(m%lat,m%lon,pollat,pollon,polgam)
    zlon = rlarot2rla(m%lat,m%lon,pollat,pollon,polgam)
    m%lat = zlat
    m%lon = zlon
    ! Height AGL. Will not be used for actual computations,
    ! but takes effect if m%alt_msl < -9000.0, in that it
    ! will be added to the model orography height at the
    ! radar station and written to m%alt_msl.
    m%alt_agl_mod = 50.0_ireals
    m%alt_msl     = -9999.99_ireals  ! will be actually used for all computations; 
                                     ! < 9000.0 means that it will be determined from 
                                     ! m%alt_agl_mod + model orography height at the 
                                     ! radar station coordinates
    m%msl_mod     = -9999.99_ireals  ! oro height MSL at station (m). Dummy value, will be determined automatically
    m%i_nearest_mod    = -9999_iintegers  ! i-Index of nearest neighbour grid point to radar station (also dummy)
    m%j_nearest_mod    = -9999_iintegers  ! j-Index of nearest neighbour grid point to radar station (also dummy)
    m%nel         = 20_iintegers     ! actually used nel
    m%nel_default(:) = -9999_iintegers  ! nel of some default scanstrategies; come into play
    m%nel_default(1) = 20_iintegers     ! if metadata are read from DWD netcdf radar files
    m%nobs_times  = -999_iintegers
    m%dt_obs      = 300.0_ireals
    m%obs_times(1:nobstimes_max) = -999.9_ireals
    m%el_arr   (1:nel_max)       = 0.0_ireals
    IF (m%nel > nel_max) THEN
      errstring(:) = ' '
      WRITE (errstring,'(a,a,i6)') 'Swiss radar metadata default', &
           ' has more elevations than allowed by nel_max = ', nel_max
      CALL model_abort (my_world_id, 10073, &
           'ERROR: problem in get_meta_proto_swiss(): '//TRIM(ADJUSTL(errstring)), &
           'src_radar.f90, get_meta_proto_swiss()')
    END IF
    m%el_arr(1:m%nel)  = &
         (/-0.3, 0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, &
         9.5,11.0,13.0,15.5,18.3,21.6,25.3,29.6,34.5,40.0/)  ! nominal elevations (from Swiss radars...)

    ! default sets of nominal elevations; come into play if metadata are read from radar files:
    m%el_arr_default(:,nscanstrategies_max) = 0.0_ireals
    m%el_arr_default(1:m%nel_default(1),1)  = &
         (/-0.3, 0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 8.5, &
         9.5,11.0,13.0,15.5,18.3,21.6,25.3,29.6,34.5,40.0/)  ! nominal elevations (from Swiss radars...)
 
    m%el_arr_obs  = m%el_arr                       ! if elev. are read from obs-files, 
                                                   ! these are the values read from obs files
                                                   ! and used for cross-checking with m%el_arr_default

    m%az_start    = 0.5_ireals
    m%naz         = 360_iintegers
    m%naz_ncdf(:) = 360_iintegers  ! dummy obs file azi dimension, will be read from obs files
    m%az_inc      = 1.0_ireals
!!$    m%ra_start    = 1000.0_ireals
    m%nra         = 230_iintegers     ! max. number of range bins occuring in a volume scan
    m%ra_inc      = 1000.0_ireals
    m%Theta3      = 1.0_ireals  ! vertical 3-dB-oneway beam width (deg)
    m%Phi3        = 1.0_ireals  ! horizontal 3-dB-oneway  beam width (deg)
    m%dalpha      = 1.0_ireals  ! azimutal averaging interval for calculation of one averaged pulse
                                           ! (averaging over the number of statistically independent pulses)
    m%alpha3_eff_0 = 1.461_ireals  ! dummy value for the effective horizontal 3-dB-oneway beam width at elevation = 0.0.
                                   ! Depends on the ratio (dalpha/phi3) - has to be exaclty determined later!
                                   ! The provisional value 1.461 is valid for dalpha/phi3 = 1.0
    m%smth_interv_fact = 1.29_ireals  ! Factor to determine the azimutal and elevational integration range
                                      !   for the smoothing over the beam function. The ranges are computed by multiplying this
                                      !   factor to the effective 3-dB-oneway beamwidths.
                                      !   ( a value of 1.29 leads to the 90-%-weight-range of the beam function)
    m%ngpsm_v     = 3_iintegers  ! number of vertical smoothing points for Gauss-Legendre quadrature
    m%ngpsm_h     = 2_iintegers  ! number of horizontal smoothing points for Gauss-Legendre quadrature
    m%xabscsm_v   = 0.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%xabscsm_h   = 0.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%weigsm_v    = 1.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%weigsm_h    = 1.0_ireals   ! initial dummy value, will be overwritten later and should be omitted in namelist!
    m%high_nyq    = 11.5_ireals                ! Nyquist frequency
    m%ext_nyq     = 11.5_ireals                ! Nyquist frequency incl. techniques like Dual-PRF
    m%prf         = 600.0_ireals  ! Low PRF
    m%dualprf_ratio = 1.0_ireals  ! Dual PRF Ratio
    m%rngate_len  = 83.3333333_ireals          ! Range gate length
    m%obs_cdate(1:nobstimes_max) = "YYYYMMDDHHMMSS"       ! array of observation times as string
    m%obs_startrec(1:nobstimes_max,:) = -999_iintegers    ! array of observation start records
    m%obs_endrec(1:nobstimes_max,:)   = -999_iintegers    ! array of observation end records
    m%nrep_ncdf   = -1_iintegers
    m%num_gates   = 12_iintegers
    m%num_pulses  = 32_iintegers
    m%ncdffile_vr(:)  = 'nofile_vr'  ! name of NetCDF input file for vr
    m%ncdffile_qv(:)  = 'nofile_qv'  ! name of NetCDF input file for qv
    m%ncdffile_z (:)  = 'nofile_z '  ! name of NetCDF input file for z
    m%ncdffile_qz(:)  = 'nofile_qz'  ! name of NetCDF input file for qz
    m%fdbkfile(:)     = 'nofile_fdbk'  ! name of NetCDF feedback file for vr
    m%lradwind_avail    = .FALSE.  ! Flags for success or failure
    m%lradwind_q_avail  = .FALSE.  ! of data reading from NetCDF
    m%lzradar_avail     = .FALSE.
    m%lzradar_q_avail   = .FALSE.
    m%lfdbkfile_exist    = .FALSE.  ! Flag for existence of feedback file 

    IF (ldebug_radsim) WRITE (*,*)  'done with get_meta_proto_swiss on proc ', my_cart_id

  END FUNCTION get_meta_proto_swiss

  !==============================================================================
  !+ Module procedure in src_radar for defining the meta data structures
  !  for each radar of the German (DWD) network.
  !------------------------------------------------------------------------------

  SUBROUTINE get_meta_network_dwd ( m , dbzparams)
    IMPLICIT NONE
    TYPE(radar_meta_type) :: m(nradsta_dwd)
    TYPE(dbzcalc_params)  :: dbzparams(nradsta_dwd)

    !========================================================
    ! .. start from the protoype:
    !========================================================

    m(:)         = get_meta_proto_dwd ()
    dbzparams(:) = dbz_namlst_d

    !========================================================
    ! INDIVIDUAL SETTINGS FOR EACH RADAR STATION:
    !========================================================
    !
    ! STATION 1: m(1) and dbzparams(1): BOO Boosted
    !
    m(1)%station_name        = 'BOO'
    m(1)%station_id          = 10132
    m(1)%lambda = 0.055
    m(1)%lat = 54.00417
    m(1)%lon = 10.04667
    m(1)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(1)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(1)%alt_msl     = 124.0,
    !
    dbzparams(1)%station_id          = 10132
    !
    !========================================================
    !
    ! STATION 2: m(2) and dbzparams(2): DRS Dresden
    !
    m(2)%station_name        = 'DRS'
    m(2)%station_id          = 10488
    m(2)%lambda = 0.055
    m(2)%lat = 51.12456
    m(2)%lon = 13.76867
    m(2)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(2)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(2)%alt_msl     = 262.0,
    !
    dbzparams(2)%station_id          = 10488
    !
    !========================================================
    !
    ! STATION 3: m(3) and dbzparams(3): EIS Eisberg
    !
    m(3)%station_name        = 'EIS'
    m(3)%station_id          = 10780
    m(3)%lambda = 0.055
    m(3)%lat = 49.54061
    m(3)%lon = 12.40311
    m(3)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(3)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(3)%alt_msl     = 800.0,
    !
    dbzparams(3)%station_id          = 10780
    !
    !========================================================
    !
    ! STATION 4: m(4) and dbzparams(4): EMD Emden
    !
    m(4)%station_name        = 'EMD'
    m(4)%station_id          = 10204
    m(4)%lambda = 0.055
    m(4)%lat = 53.33872
    m(4)%lon = 7.02369
    m(4)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(4)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(4)%alt_msl     = 58.0,
    !
    dbzparams(4)%station_id          = 10204

    !========================================================
    !
    ! STATION 5: m(5) and dbzparams(5): ESS Essen
    !
    m(5)%station_name        = 'ESS'
    m(5)%station_id          = 10410
    m(5)%lambda = 0.055
    m(5)%lat = 51.40564
    m(5)%lon = 6.96708
    m(5)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(5)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(5)%alt_msl     = 185.0,
    !
    dbzparams(5)%station_id          = 10410
    !
    !========================================================
    !
    ! STATION 6: m(6) and dbzparams(6): FBG Feldberg
    !
    m(6)%station_name        = 'FBG'
    m(6)%station_id          = 10908
    m(6)%lambda = 0.055
    m(6)%lat = 47.87356
    m(6)%lon = 8.00386
    m(6)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(6)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(6)%alt_msl     = 1517.0,
    !
    dbzparams(6)%station_id          = 10908
    !
    !========================================================
    !
    ! STATION 7: m(7) and dbzparams(7): FLD Flechtdorf
    !
    m(7)%station_name        = 'FLD'
    m(7)%station_id          = 10440
    m(7)%lambda = 0.055
    m(7)%lat = 51.31119
    m(7)%lon = 8.80203
    m(7)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(7)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(7)%alt_msl     = 623.0,
    !
    dbzparams(7)%station_id          = 10440
    !
    !========================================================
    !
    ! STATION 8: m(8) and dbzparams(8): HAN Hannover
    !
    m(8)%station_name        = 'HAN'
    m(8)%station_id          = 10338
    m(8)%lambda = 0.055
    m(8)%lat = 52.46006
    m(8)%lon = 9.69449
    m(8)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(8)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(8)%alt_msl     = 81.0,
    !
    dbzparams(8)%station_id          = 10338
    !
    !========================================================
    !
    ! STATION 9: m(9) and dbzparams(9): NEU Neuhaus
    !
    m(9)%station_name        = 'NEU'
    m(9)%station_id          = 10557
    m(9)%lambda = 0.055
    m(9)%lat = 50.50006
    m(9)%lon = 11.13500
    m(9)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(9)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(9)%alt_msl     = 879.0,
    !
    dbzparams(9)%station_id          = 10557
    !
    !========================================================
    !
    ! STATION 10: m(10) and dbzparams(10): NHB Neuheilenbach
    !
    m(10)%station_name        = 'NHB'
    m(10)%station_id          = 10605
    m(10)%lambda = 0.055
    m(10)%lat = 50.10972
    m(10)%lon = 6.54805
    m(10)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(10)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(10)%alt_msl     = 585.0,
    !
    dbzparams(10)%station_id          = 10605
    !
    !========================================================
    !
    ! STATION 11: m(11) and dbzparams(11): OFT Offenthal
    !
    m(11)%station_name        = 'OFT'
    m(11)%station_id          = 10629
    m(11)%lambda = 0.055
    m(11)%lat = 49.98478
    m(11)%lon = 8.71294
    m(11)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(11)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(11)%alt_msl     = 246.0,
    !
    dbzparams(11)%station_id          = 10629
    !
    !========================================================
    !
    ! STATION 12: m(12) and dbzparams(12): PRO Proetzel
    !
    m(12)%station_name        = 'PRO'
    m(12)%station_id          = 10392
    m(12)%lambda = 0.055
    m(12)%lat = 52.64861
    m(12)%lon = 13.85778
    m(12)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(12)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(12)%alt_msl     = 189.0,
    !
    dbzparams(12)%station_id          = 10392
    !
    !========================================================
    !
    ! STATION 13: m(13) and dbzparams(13): MEM Memmingen
    !
    m(13)%station_name        = 'MEM'
    m(13)%station_id          = 10950
    m(13)%lambda = 0.055
    m(13)%lat = 48.04214
    m(13)%lon = 10.21922
    m(13)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(13)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(13)%alt_msl     = 720.0,
    !
    dbzparams(13)%station_id          = 10950
    !
    !========================================================
    !
    ! STATION 14: m(14) and dbzparams(14): ROS Rostock
    !
    m(14)%station_name        = 'ROS'
    m(14)%station_id          = 10169
    m(14)%lambda = 0.055
    m(14)%lat = 54.17575
    m(14)%lon = 12.05797
    m(14)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(14)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(14)%alt_msl     = 36.0,
    !
    dbzparams(14)%station_id          = 10169
    !
    !========================================================
    !
    ! STATION 15: m(15) and dbzparams(15): SNA Schnaupping
    !
    m(15)%station_name        = 'SNA'
    m(15)%station_id          = 10873
    m(15)%lambda = 0.055
    m(15)%lat = 48.17470
    m(15)%lon = 12.10179
    m(15)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(15)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(15)%alt_msl     = 724.0,
    !
    dbzparams(15)%station_id          = 10873
    !
    !========================================================
    !
    ! STATION 16: m(16) and dbzparams(16): TUR Tuerkheim
    !
    m(16)%station_name        = 'TUR'
    m(16)%station_id          = 10832
    m(16)%lambda = 0.055
    m(16)%lat = 48.58528
    m(16)%lon = 9.78278
    m(16)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(16)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(16)%alt_msl     = 764.0,
    !
    dbzparams(16)%station_id          = 10832
    !
    !========================================================
    !
    ! STATION 17: m(17) and dbzparams(17): UMD Ummendorf
    !
    m(17)%station_name        = 'UMD'
    m(17)%station_id          = 10356
    m(17)%lambda = 0.055
    m(17)%lat = 52.16011
    m(17)%lon = 11.17606
    m(17)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(17)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(17)%alt_msl     = 183.0,
    !
    dbzparams(17)%station_id          = 10356
    !
    !========================================================
    !
    ! STATION 18: m(18) and dbzparams(18): BLN Berlin Tempelhof
    !
    m(18)%station_name        = 'BLN'
    m(18)%station_id          = 10384
    m(18)%lambda = 0.055
    m(18)%lat = 52.47792
    m(18)%lon = 13.38694
    m(18)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(18)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(18)%alt_msl     = 80.0,
    !
    dbzparams(18)%station_id          = 10384
    !
    !========================================================
    !
    ! STATION 19: m(19) and dbzparams(19): ASE Essen
    !
    m(19)%station_name        = 'ASE'
    m(19)%station_id          = 10412
    m(19)%lambda = 0.055
    m(19)%lat = 51.40514
    m(19)%lon = 6.96381
    m(19)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(19)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(19)%alt_msl     = 188.0,
    !
    dbzparams(19)%station_id          = 10412
    !
    !========================================================
    !
    ! STATION 20: m(20) and dbzparams(20): HAM Hamburg
    !
    m(20)%station_name        = 'HAM'
    m(20)%station_id          = 10147
    m(20)%lambda = 0.055
    m(20)%lat = 53.62125
    m(20)%lon = 9.9965
    m(20)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(20)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(20)%alt_msl     = 46.0,
    !
    dbzparams(20)%station_id          = 10147
    !
    !========================================================
    !
    ! STATION 21: m(21) and dbzparams(21): FRI Frankfurt Flughafen
    !
    m(21)%station_name        = 'FRI'
    m(21)%station_id          = 10630
    m(21)%lambda = 0.055
    m(21)%lat = 50.02244
    m(21)%lon = 8.55853
    m(21)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(21)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(21)%alt_msl     = 145.0,
    !
    dbzparams(21)%station_id          = 10630
    !
    !========================================================
    !
    ! STATION 22: m(22) and dbzparams(22): MUC Muenchen Fuerholzen
    !
    m(22)%station_name        = 'MUC'
    m(22)%station_id          = 10871
    m(22)%lambda = 0.055
    m(22)%lat = 48.33639
    m(22)%lon = 11.61172
    m(22)%alt_agl_mod = 50.0     ! only effective if alt_msl < -9000
    m(22)%alt_msl     = -9999.99 ! value < -9000 indicates that alt_agl_mod should be used instead
!    m(22)%alt_msl     = 511.0,
    !
    dbzparams(22)%station_id          = 10871
    !


  END SUBROUTINE get_meta_network_dwd

  !==============================================================================
  !+ Module procedure in src_radar for reading radar meta data from netCDF files
  !  called by init_radar if lreadmeta_from_netcdf = .TRUE.
  !------------------------------------------------------------------------------

#ifdef NETCDF

  SUBROUTINE read_meta_info_dwd ( rs_meta_dwd_network , rs_meta_ncdf ,  err_ista , miss_err)

    !------------------------------------------------------------------------------
    !
    ! Description: Reads meta information from NetCDF files of German radar stations
    !              and collects them on the root node (PE 0).
    !
    !              It expects 1 file per station and per data type (vr, qv, z, qz), 
    !              containing all the radar data of the respective type
    !              for the desired time period, ordered by time (1. priority) and 
    !              elevation (2. priority). The files for the different
    !              stations are numbered from 1, ..., "nradsta" (number of stations),
    !              and this number and ordering of stations is overtaken, so that the
    !              number of present files for different stations determine,
    !              how many radars are simulated by the radar simulator.
    !              
    !              Not all the needed meta information is in the files, so this
    !              routine expects a list of meta informations for
    !              all the German radars as a first guess, contained in the
    !              input structure field "rs_meta_dwd_network".
    !
    !              The routine goes through one of the NetCDF files 
    !              for each station to identify the station ID and copies 
    !              the respective background parameter list (matched by the station ID)
    !              from "rs_meta_dwd_network" to the output list "rs_meta_ncdf(ista)"
    !              where ista is the station index read from the NetCDF file name.
    !              After this "background initialization", some meta data are
    !              read from the NetCDF file and overwrite the initialized values.
    !              
    !
    ! This routine is parallelized and has to be called on every node!
    !
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! In, InOut, Outgoing:

    TYPE(radar_meta_type),    INTENT(inout)  :: rs_meta_dwd_network(nradsta_dwd) ! prototype meta data for the German network
    TYPE(radar_meta_type),    INTENT(inout)  :: rs_meta_ncdf(nradsta_max)        ! output meta structure, merged info from prototype and NetCDF files
    INTEGER (KIND=iintegers), INTENT(out)    :: err_ista(nradsta_max)    
    INTEGER (KIND=iintegers), INTENT(out)    :: miss_err(nradsta_max)    

    ! Local scalars:
    CHARACTER (LEN=32)         :: yzroutine
    CHARACTER (LEN=80)         :: yzerrmsg
    LOGICAL,SAVE               :: lfirst=.TRUE.
    INTEGER (KIND = iintegers) :: iaz,ira,i,j,ir,nel,nobs_times,ierr,nrealbuf
    ! NetCDF variable id for
    INTEGER (KIND = iintegers)            :: varid_yssosn ! short name of station
    INTEGER (KIND = iintegers)            :: varid_mii    ! WMO-block-number
    INTEGER (KIND = iintegers)            :: varid_niii   ! WMO-station number
    INTEGER (KIND = iintegers)            :: varid_mlah   ! latitude
    INTEGER (KIND = iintegers)            :: varid_mloh   ! longitude
    INTEGER (KIND = iintegers)            :: varid_mhp    ! height of station
    INTEGER (KIND = iintegers)            :: varid_rgoff  ! offset of radial (021203)
    INTEGER (KIND = iintegers)            :: varid_azoff  ! offset of azimuths (021204)
    INTEGER (KIND = iintegers)            :: varid_rngbs  ! range bin size (021201)
    INTEGER (KIND = iintegers)            :: varid_azres  ! azimutal resolution (021202)
    INTEGER (KIND = iintegers)            :: varid_manel  ! antenna elevation
    INTEGER (KIND = iintegers)            :: varid_time   ! reference time
    INTEGER (KIND = iintegers)            :: varid_date   ! reference date
    INTEGER (KIND = iintegers)            :: varid_enyq   ! extended NYQUIST Velocity (021236)
    INTEGER (KIND = iintegers)            :: varid_hnyq   ! high NYQUIST Velocity (021237)
    INTEGER (KIND = iintegers)            :: varid_dprf   ! DualPRF Ratio (002194)
    INTEGER (KIND = iintegers)            :: varid_mrglen ! RANGE-GATE LENGTH
    INTEGER (KIND = iintegers)            :: varid_mngave ! NUMBER OF GATES AVERAGED
    INTEGER (KIND = iintegers)            :: varid_mnipul ! NUMBER OF INTEGRATED PULSES
    INTEGER (KIND = iintegers)            :: varid_mjjj
    INTEGER (KIND = iintegers)            :: varid_mmm
    INTEGER (KIND = iintegers)            :: varid_myy
    INTEGER (KIND = iintegers)            :: varid_mgg
    INTEGER (KIND = iintegers)            :: varid_ngg
    INTEGER (KIND = iintegers)            :: varid_nsecm
    INTEGER (KIND = iintegers)            :: mii,niii,mhp,azres,rngbs,ireport, irepel
    INTEGER (KIND = iintegers)            :: len_report,len_azimut,len_range,len_ele
    INTEGER (KIND = iintegers)            :: status, RecordDimID,AziDim,RBDim,EleDim
    INTEGER (KIND = iintegers)            :: mngave, mnipul
    REAl    (KIND = ireals   )            :: mlah,mloh,enyq,hnyq,dprf,mrglen,azoff, rgoff
    REAL    (KIND = ireals   ),ALLOCATABLE:: elev(:), manel(:), sec_ob(:)
    INTEGER (KIND = iintegers),ALLOCATABLE:: records(:), endrecs(:), date(:), time(:)
    INTEGER (KIND=iintegers), ALLOCATABLE :: nc_mjjj(:), nc_mmm(:), nc_myy(:)  , &
         nc_mgg(:),  nc_ngg(:), nc_nsecm(:)
    INTEGER (KIND = iintegers)            :: otime,timecheck,nsta,ncount,iscstr_def,iscanstrat
    CHARACTER (LEN=3)                     :: yssosn, cisc
    CHARACTER (LEN=14), ALLOCATABLE       :: cdate(:)

    INTEGER  (KIND=iintegers)             ::  &
         ianyy   ,& ! year     / of the date and time
         ianmm   ,& ! month   /  of the current
         iandd   ,& ! day    <   observation
         ianhh   ,& ! hour    \  resp. of the initial
         ianmin  ,& ! minute   \ model date and time
!!$ UB>>
         iansec  ,& ! second    \ model date and time
!!$ UB<<
         imindif          ,& ! time difference [min] between these two times
!!$ UB>>
         isecdif          ,& ! time difference [min] between these two times
!!$ UB<<
         ierrf(2,6)          ! error status for time difference routine

    INTEGER (KIND = iintegers)  :: ii, ista, ista_par, ipe_rad, fids(ndatakind), fid, &
                                   station_id, mpierr, mpistat, ista_end, znel_def(nscanstrategies_max)
    LOGICAL                     :: fileexist(nradsta_max), station_found, fileexist_ista(ndatakind)
    CHARACTER (len=250), DIMENSION(nradsta_max) :: &
         zyncdffile_vr, zyncdffile_qv, zyncdffile_z, zyncdffile_qz

    CHARACTER(len=300)  :: errstring

#ifdef NUDGING
    ! .. For get_utc_date():
!!$    CHARACTER (LEN=10)  :: zyakdat1  ! actual date in the form   yyyymmddhh
!!$    CHARACTER (LEN=22)  :: zyakdat2  ! actual date, form:   wd   dd.mm.yy  hh UTC
    CHARACTER (LEN=14)  :: zyakdat1  ! actual date in the form   yyyymmddhhmmss
    CHARACTER (LEN=28)  :: zyakdat2  ! actual date, form:   wd   dd.mm.yy  hh mm ss UTC
    CHARACTER (LEN=12)  :: zyveri_ref_datim
    REAl (KIND=ireals)       :: zhr
    LOGICAL                  :: zlrefend
    INTEGER (KIND=iintegers) :: nzday  ,& ! Julian day
                                nrefmin,& ! verification reference date: minutes since ydate_ini
                                zitype_calendar, &
                                ziveri_ref_time, &
                                ziveri_ref_date
#endif

    !==============================================================================
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE read_meta_info_dwd
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'read_meta_info_dwd'

    IF (lfirst) THEN

      IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

      lfirst = .FALSE.

      err_ista = 0_iintegers
      miss_err = 0_iintegers


      ! Return if nothing has to be done by the radar operator:
      !--------------------------------------------------

      IF ( .NOT.(loutradwind .OR. loutdbz) ) THEN
        RETURN
      END IF


      ! Generate file names of input files:
      ! first assume that nradsta_max
      ! radar station files exist:
      !--------------------------------------------------

      DO ista = 1, nradsta_max
        zyncdffile_vr(ista)(:) = ' '
        WRITE(zyncdffile_vr(ista),'(a,i2.2)') &
             TRIM(ydirradarin)//'/cdfin_'//TRIM(datakind(1))//'_', ista
        zyncdffile_qv(ista)(:) = ' '
        WRITE(zyncdffile_qv(ista),'(a,i2.2)') &
             TRIM(ydirradarin)//'/cdfin_'//TRIM(datakind(2))//'_', ista
        zyncdffile_z(ista)(:)  = ' '
        WRITE(zyncdffile_z(ista) ,'(a,i2.2)') &
             TRIM(ydirradarin)//'/cdfin_'//TRIM(datakind(3))//'_', ista
        zyncdffile_qz(ista)(:) = ' '
        WRITE(zyncdffile_qz(ista),'(a,i2.2)') &
             TRIM(ydirradarin)//'/cdfin_'//TRIM(datakind(4))//'_', ista
      END DO


      IF (my_cart_id == 0) THEN

        fileexist(:) = .FALSE.
        ista = 0
        check_loop: DO ii = 1, nradsta_max

          ! Check for existence of necessary radar files:
          !------------------------------------------------------------

          IF (loutradwind) THEN
            INQUIRE(FILE=TRIM(zyncdffile_vr(ii)), EXIST=fileexist_ista(1))
            INQUIRE(FILE=TRIM(zyncdffile_qv(ii)), EXIST=fileexist_ista(2))
            IF (.NOT.fileexist_ista(1) .AND. .NOT.fileexist_ista(2)) THEN
              WRITE(*,'(i5,1x,3a)') my_cart_id, 'WARNING: NetCDF file ', TRIM(zyncdffile_vr(ii)), &
                   ' could not be found, but that might be ok!'
            ELSE IF (fileexist_ista(1) .NEQV. fileexist_ista(2)) THEN
              WRITE(*,'(i5,1x,a,i2.2,a)') my_cart_id, 'WARNING: One of the necessary NetCDF files for '// &
                   'station no. ', ii, ' is missing! Needed are vr and qv, station discarded!'
              miss_err(ii) = 1
            END IF
          END IF
          IF (loutdbz) THEN
            INQUIRE(FILE=TRIM(zyncdffile_z(ii)) , EXIST=fileexist_ista(3))
            INQUIRE(FILE=TRIM(zyncdffile_qz(ii)), EXIST=fileexist_ista(4))
            IF (.NOT.fileexist_ista(3) .AND. .NOT.fileexist_ista(4)) THEN
              WRITE(*,'(i5,1x,3a)') my_cart_id, 'WARNING: NetCDF file ', TRIM(zyncdffile_z(ii)), &
                   ' could not be found, but that might be ok!'
            ELSE IF (fileexist_ista(3) .NEQV. fileexist_ista(4)) THEN
              WRITE(*,'(i5,1x,a,i2.2,a)') my_cart_id, 'WARNING: One of the necessary NetCDF files for '// &
                   'station no. ', ii, ' is missing! Needed are z and qz, station discarded!'
              miss_err(ii) = 2
            END IF
          END IF

          ! Then set flag "fileexist" to true for those stations which
          !   have the required radar data files:
          !------------------------------------------------------------

          IF ( (loutradwind .AND. fileexist_ista(1) .AND. fileexist_ista(2) ) .OR. &
               (loutdbz     .AND. fileexist_ista(3) .AND. fileexist_ista(4) ) ) THEN
            fileexist(ii) = .TRUE.
            ista = ista + 1
          END IF

        END DO check_loop

        nradsta = ista

      END IF

      !------------------------------------------------------------
      !.. overwrite nradsta with true number of radar stations with
      !   available obs and distribute the information over the processors,
      !   so that it is available in the read_loop below, which
      !   is parallelized.

      IF (num_compute > 1) THEN

        CALL distribute_values (nradsta, 1, 0, imp_integers, icomm_cart, mpierr)
        CALL distribute_values (fileexist, nradsta_max, 0, imp_logical, icomm_cart, mpierr)

      END IF

      IF (nradsta < 1) THEN
        err_ista = 1
        IF (my_cart_id == 0) THEN
          WRITE(*,'(2a)') TRIM(yzroutine) // ' ERROR: No complete sets of NetCDF radar station files ' &
               //'could be found in directory ', TRIM(ydirradarin)
        END IF
        RETURN
      END IF

      ! .. Put filenames of data files in the meta structure on all PEs:
      ista = 0
      DO ii = 1, nradsta_max
        IF (fileexist(ii)) THEN
          ista = ista + 1
          rs_meta_ncdf(ista)%ncdffile_vr = TRIM(zyncdffile_vr(ii))
          rs_meta_ncdf(ista)%ncdffile_qv = TRIM(zyncdffile_qv(ii))
          rs_meta_ncdf(ista)%ncdffile_qz = TRIM(zyncdffile_qz(ii))
          rs_meta_ncdf(ista)%ncdffile_z  = TRIM(zyncdffile_z (ii))          
        END IF
      END DO

      !------------------------------------------------------------
      ! .. Parallel read of the meta data in a round-robin fashion:
      !      Loop over num_compute-sized chunks of radar stations

      DO ista_par = 1, nradsta, num_compute

        ista_end = MIN(ista_par+num_compute-1, nradsta)

        read_loop: DO ista = ista_par, ista_end

          ! determine the number of the PE for output of the radar with no. ista:
          ipe_rad = MOD(ista-1, num_compute)


          IF (my_cart_id == ipe_rad) THEN


            !-------------------------------------------------------
            !   Open NetCDF files for reading of station meta data:
            CALL netcdf_open_dwd(rs_meta_ncdf(ista), fids)


            ! First priority: Radial Wind File:
            ! ---------------------------------

            fid = 0
            IF ( loutradwind ) THEN
              IF ( fids(1) == 0 .OR. fids(2) == 0 ) THEN
                WRITE(*,'(i5,1x,a)') my_cart_id, &
                     TRIM(yzroutine) // ' ERROR: NetCDF radwind and/or radwind_q files for a station '// &
                     'could not be opened for meta data reading!'
                err_ista(ista) = 2
                CALL netcdf_close_dwd ( fids )
                ! Das hier muss hier ein Sprung aus dem IF-Zweig sein!
                CYCLE read_loop         
              ELSE
                fid = 1
              END IF
            END IF

            ! Second priority: Reflectivity File:
            ! -----------------------------------

            IF (fid == 0) THEN
              IF ( loutdbz ) THEN
                IF ( fids(3) == 0 .OR. fids(4) == 0 ) THEN
                  WRITE(*,'(i5,1x,a)') my_cart_id, &
                       TRIM(yzroutine) // ' ERROR: NetCDF reflect and/or reflect_q files for a station '// &
                       'could not be opened for meta data reading!'
                  err_ista(ista) = 3
                  CALL netcdf_close_dwd ( fids )
                  ! Das hier muss hier ein Sprung aus dem IF-Zweig sein!
                  CYCLE read_loop
                ELSE
                  fid = 3
                END IF
              END IF
            END IF

            !---------------------------------------------------
            !     Get information on dimensions and radar variables
            !---------------------------------------------------

            status = nf90_inquire(fids(fid), unlimitedDimId = RecordDimID)
            status = nf90_inquire_dimension(fids(fid), RecordDimID,len = len_report) !Number of reports
            status = nf90_inq_dimid(fids(fid), "Loop_000_maxlen", AziDim)
            status = nf90_inquire_dimension(fids(fid), AziDim, len = len_azimut) ! Number of azimuth
            status = nf90_inq_dimid(fids(fid), "Loop_001_maxlen", RBDim)
            status = nf90_inquire_dimension(fids(fid), RBDim, len = len_range)   ! Number of range bins
            status = nf90_inq_dimid(fids(fid), "section1_length", EleDim)
            status = nf90_inquire_dimension(fids(fid), EleDim, len = len_ele)   ! Max. number of elevations (can be wrong, so do not use!)

            status = nf90_inq_varid (fids(fid), 'YSSOSN', varid_yssosn)
            status = nf90_inq_varid (fids(fid), 'MII',   varid_mii)
            status = nf90_inq_varid (fids(fid), 'NIII',  varid_niii)
            status = nf90_inq_varid (fids(fid), 'MLAH',  varid_mlah)
            status = nf90_inq_varid (fids(fid), 'MLOH',  varid_mloh)
            status = nf90_inq_varid (fids(fid), 'MHP' ,  varid_mhp)
            status = nf90_inq_varid (fids(fid), '021201',varid_rngbs)
            status = nf90_inq_varid (fids(fid), '021202',varid_azres)
            status = nf90_inq_varid (fids(fid), '021203',varid_rgoff)
            status = nf90_inq_varid (fids(fid), '021204',varid_azoff)
            status = nf90_inq_varid (fids(fid), '021236',varid_enyq)    !extended Nyquist Velocity
            status = nf90_inq_varid (fids(fid), '021237',varid_hnyq)    !high Nyquist Velocity
            status = nf90_inq_varid (fids(fid), '002194',varid_dprf)    !DualPRF ratio
            status = nf90_inq_varid (fids(fid), 'MRGLEN',varid_mrglen)  !RANGE-GATE LENGTH
            status = nf90_inq_varid (fids(fid), 'MNGAVE',varid_mngave)  !NUMBER OF GATES AVERAGED
            status = nf90_inq_varid (fids(fid), 'MNIPUL',varid_mnipul)  !NUMBER OF INTEGRATED PULSES
            status = nf90_inq_varid (fids(fid), 'MJJJ',  varid_mjjj)    !Year
            status = nf90_inq_varid (fids(fid), 'MMM',   varid_mmm)     !Month
            status = nf90_inq_varid (fids(fid), 'MYY',   varid_myy)     !Day
            status = nf90_inq_varid (fids(fid), 'MGG',   varid_mgg)     !Hour
            status = nf90_inq_varid (fids(fid), 'NGG',   varid_ngg)     !Minute
            status = nf90_inq_varid (fids(fid), 'NSECM', varid_nsecm)   !Second within a minute

            status = nf90_get_var (fids(fid), varid_yssosn, yssosn, start=(/1/)) ! short name of station
            status = nf90_get_var (fids(fid), varid_mii,  mii,  start=(/1/)) ! Station ID country
            status = nf90_get_var (fids(fid), varid_niii, niii, start=(/1/)) ! Local station ID
            status = nf90_get_var (fids(fid), varid_mlah, mlah, start=(/1/)) ! Latitude of station
            status = nf90_get_var (fids(fid), varid_mloh, mloh, start=(/1/)) ! Longitude of station
            status = nf90_get_var (fids(fid), varid_mhp,  mhp,  start=(/1/)) ! Altitude of station
            status = nf90_get_var (fids(fid), varid_azres,azres,start=(/1/)) ! Azimuthal resolution
            status = nf90_get_var (fids(fid), varid_rngbs,rngbs,start=(/1/)) ! Range bin resolution in m
            status = nf90_get_var (fids(fid), varid_azoff,azoff,start=(/1/)) ! Azimuthal resolution
            status = nf90_get_var (fids(fid), varid_rgoff,rgoff,start=(/1/)) ! Range bin resolution in m
            status = nf90_get_var (fids(fid), varid_enyq, enyq, start=(/1/)) ! extended Nyquist Velocity
            status = nf90_get_var (fids(fid), varid_hnyq, hnyq, start=(/1/)) ! high Nyquist Velocity
            status = nf90_get_var (fids(fid), varid_dprf, dprf, start=(/1/)) ! DualPRF ratio
            status = nf90_get_var (fids(fid), varid_mrglen, mrglen, start=(/1/)) ! RANGE-GATE LENGTH
            status = nf90_get_var (fids(fid), varid_mngave, mngave, start=(/1/)) ! NUMBER OF GATES AVERAGED
            status = nf90_get_var (fids(fid), varid_mnipul, mnipul, start=(/1/)) ! NUMBER OF INTEGRATED PULSES

            ! preset meta data array "rs_meta_ncdf(ista)" for each radar station
            ! with the base values from the list "rs_meta_dwd_network":
            station_id = mii*1000+niii
            station_found = .FALSE.
            DO ii = 1, nradsta_dwd
              IF ( station_id == rs_meta_dwd_network(ii)%station_id ) THEN
                ! .. Save NetCDF file names back to base-structure before copying
                !    the whole base structure to rs_meta_ncdf-structure:
                rs_meta_dwd_network(ii)%ncdffile_vr = rs_meta_ncdf(ista)%ncdffile_vr
                rs_meta_dwd_network(ii)%ncdffile_qv = rs_meta_ncdf(ista)%ncdffile_qv
                rs_meta_dwd_network(ii)%ncdffile_z  = rs_meta_ncdf(ista)%ncdffile_z
                rs_meta_dwd_network(ii)%ncdffile_qz = rs_meta_ncdf(ista)%ncdffile_qz
                ! .. Copy the base values into rs_meta_ncdf(ista).
                rs_meta_ncdf(ista) = rs_meta_dwd_network(ii)
                station_found = .TRUE.
                EXIT
              END IF
            END DO

            IF (.NOT.station_found) THEN
              err_ista(ista) = 4
              WRITE (*,'(i5,1x,a,i7,a)') my_cart_id, &
                   TRIM(yzroutine) // ' ERROR: radar station ', station_id, &
                   ' not found in base list rs_meta_dwd_network!'
              CYCLE read_loop
            END IF

            ! .. Now partially override with the meta data from the file:
            rs_meta_ncdf(ista)%station_id  = station_id
            rs_meta_ncdf(ista)%station_name  = yssosn
            rs_meta_ncdf(ista)%lat         = mlah
            rs_meta_ncdf(ista)%lon         = mloh
            rs_meta_ncdf(ista)%alt_msl     = mhp
            rs_meta_ncdf(ista)%naz_ncdf(:) = len_azimut
            rs_meta_ncdf(ista)%az_inc      = azres
            rs_meta_ncdf(ista)%nra         = len_range    ! max. number of range bins occuring in a volume scan
            rs_meta_ncdf(ista)%ra_inc      = rngbs
            rs_meta_ncdf(ista)%nrep_ncdf(fid)   = len_report
!!$        rs_meta_ncdf(ista)%ra_start    = rgoff
            rs_meta_ncdf(ista)%az_start    = azoff
            rs_meta_ncdf(ista)%ext_nyq     = enyq
            rs_meta_ncdf(ista)%high_nyq    = hnyq
            rs_meta_ncdf(ista)%dualprf_ratio = dprf
            rs_meta_ncdf(ista)%rngate_len  = mrglen
            rs_meta_ncdf(ista)%num_gates   = mngave
            rs_meta_ncdf(ista)%num_pulses  = mnipul

            status = nf90_inq_varid (fids(fid), 'TIME', varid_time)
            status = nf90_inq_varid (fids(fid), 'DATE', varid_date)
            status = nf90_inq_varid (fids(fid), 'MANEL', varid_manel)

            IF ( len_report < 1 ) THEN
              WRITE (*,'(i5,1x,a,i7,a)') my_cart_id, &
                   TRIM(yzroutine) // ' ERROR: NetCDF file for ' // &
                   TRIM(datakind(fid)) // ' for radar station ', station_id, &
                   ' do not contain any data records!'
              err_ista(ista) = 5
              CYCLE read_loop
            END IF

            ireport=1
            irepel=1

            ALLOCATE(records (len_report), &
                 endrecs (len_report), &
                 sec_ob  (len_report), &
                 elev    (len_report), &
                 time    (len_report), &
                 date    (len_report), &
                 cdate   (len_report), &
                 manel   (len_report), &
                 nc_mjjj (len_report), &
                 nc_mmm  (len_report), &
                 nc_myy  (len_report), &
                 nc_mgg  (len_report), &
                 nc_ngg  (len_report), &
                 nc_nsecm(len_report)   )

            ! Bestimme Anzahl an unabhaengigen Beobachtungszeitpunkten passend zum Modell (Sekunden seit Modellstart)

            nsta   = 1
            ncount = len_report
            status = nf90_get_var (fids(fid), varid_time , time    ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_date , date    ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_manel, manel   ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_mjjj , nc_mjjj ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_mmm  , nc_mmm  ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_myy  , nc_myy  ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_mgg  , nc_mgg  ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_ngg  , nc_ngg  ,(/nsta/), (/ncount/))
            status = nf90_get_var (fids(fid), varid_nsecm, nc_nsecm,(/nsta/), (/ncount/))

            IF (nc_mjjj(1) < 100) THEN
              nc_mjjj (1) = 2000 + nc_mjjj(1)
              IF (nc_mjjj(1) > 2059)  nc_mjjj (1) = nc_mjjj(1) - 100
            END IF

!!$        WRITE (cdate(1),'(i4.4,5i2.2)') & 
!!$             nc_mjjj(1), nc_mmm(1), nc_myy(1), nc_mgg(1), nc_ngg(1), nc_nsecm(1)
!!$! nsecm is not 0 (as in the nominal time) but the true seconds part of the end time of
!!$!       the scan, so disregard nsecm and take time-field (= "hhmm00") instead:
            WRITE (cdate(ireport),'(i4.4,2i2.2,i6.6)') &
                 nc_mjjj(1), nc_mmm(1), nc_myy(1), time(1)

            CALL diff_seconds ( zydate_ini_mod, cdate(1), isecdif, ierrf )

            records(1) = 1
            endrecs(1) = 1
            elev(1)    = manel(1)
            otime      = nc_myy(1)*1000000 + time(1)
            sec_ob(1)  = isecdif

            DO i = 2, len_report

              timecheck  = nc_myy(i)*1000000 + time(i)

              IF ( timecheck /= otime ) THEN

                ireport = ireport + 1

                IF (nc_mjjj(i) < 100) THEN
                  nc_mjjj (i) = 2000 + nc_mjjj(i)
                  IF (nc_mjjj(i) > 2059)  nc_mjjj (i) = nc_mjjj(i) - 100
                END IF

!!$            WRITE (cdate(ireport),'(i4.4,5i2.2)') &
!!$                 nc_mjjj(i), nc_mmm(i), nc_myy(i), nc_mgg(i), nc_ngg(i), nc_nsecm(i)
!!$! nsecm is not 0 (as in the nominal time) but the true seconds part of the end time of
!!$!       the scan, so disregard nsecm and take time-field (= "hhmm00") instead:
                WRITE (cdate(ireport),'(i4.4,2i2.2,i6.6)') &
                     nc_mjjj(i), nc_mmm(i), nc_myy(i), time(i)

                CALL diff_seconds ( zydate_ini_mod, cdate(ireport), isecdif, ierrf )

                records(ireport)      = i
                sec_ob(ireport)       = isecdif ! Difference to model start time!!!

                otime                 = timecheck

              ELSE

                endrecs(ireport)      = i

              END IF

              !.. Find and eliminate duplicated elevations for rs_meta_ncdf(ista)%el_arr
              !   and sort elevations in ascending direction:
              DO ir = 1, irepel
                IF (manel(i) == elev(ir)) EXIT
                IF (manel(i) < elev(ir)) THEN
                  ! manel(i) is smaller than the largest elevation so far,
                  ! so put it inbetween the correct neighouring elevs:
                  irepel   = irepel + 1
                  elev(ir+1:irepel) = elev(ir:irepel-1)
                  elev(ir) = manel(i)
                  EXIT
                END IF
                IF (ir == irepel) THEN
                  ! if we reach this point at the end of the loop,
                  ! no equal or larger elevation has been found so far,
                  ! so this is a new elevation to put at the end of the elev-vector:
                  irepel   = irepel + 1
                  elev(irepel) = manel(i)
                END IF
              END DO

            END DO

            ! determine which of the default scan strategies matches the
            ! radar data in the netcdf files:
            iscanstrat = -9999_iintegers
            DO ir = 1, nscanstrategies_max
              IF (rs_meta_ncdf(ista)%nel_default(ir) == irepel) THEN
                iscanstrat = ir
                EXIT
              END IF
            END DO

            IF (iscanstrat < 0) THEN
              err_ista(ista) = 6
              iscstr_def = 0
              DO ir = 1, nscanstrategies_max
                IF (rs_meta_ncdf(ista)%nel_default(ir) > 0) THEN
                  iscstr_def = iscstr_def + 1
                  znel_def(iscstr_def) = rs_meta_ncdf(ista)%nel_default(ir)
                END IF
              END DO
              cisc(:) = ''
              WRITE(cisc, '(i3)') iscstr_def
              WRITE (*,'(a,i3,a,'//TRIM(ADJUSTL(cisc))//'(i3,x),a,i7)') &
                   TRIM(yzroutine)//' WARNING: number of elevations found in NetCDF file for ' // &
                   TRIM(datakind(fid)) // ' (', irepel , &
                   ') not equal to any possible nominal value (',rs_meta_ncdf(ista)%nel_default(1:iscstr_def), &
                   ') for station ID ', rs_meta_ncdf(ista)%station_id
            END IF

            !.. round nominal elevations to next multiple of 0.05 degrees:
!!$        DO ir = 1, irepel
!!$          elev(ir) = NINT(elev(ir)/0.05) * 0.05
!!$        END DO

            rs_meta_ncdf(ista)%nobs_times                         = ireport 
            rs_meta_ncdf(ista)%nel                                = irepel
            rs_meta_ncdf(ista)%el_arr(1:rs_meta_ncdf(ista)%nel)   = &
                 rs_meta_ncdf(ista)%el_arr_default(1:rs_meta_ncdf(ista)%nel, iscanstrat)

            rs_meta_ncdf(ista)%obs_startrec(1:rs_meta_ncdf(ista)%nobs_times,fid) = &
                 records(1:rs_meta_ncdf(ista)%nobs_times)

            rs_meta_ncdf(ista)%obs_endrec(1:rs_meta_ncdf(ista)%nobs_times,fid) = &
                 endrecs(1:rs_meta_ncdf(ista)%nobs_times)

            rs_meta_ncdf(ista)%obs_times(1:rs_meta_ncdf(ista)%nobs_times)   = &
                 REAL(sec_ob(1:rs_meta_ncdf(ista)%nobs_times), kind=ireals)

            rs_meta_ncdf(ista)%obs_cdate(1:rs_meta_ncdf(ista)%nobs_times)   = &
                 cdate(1:rs_meta_ncdf(ista)%nobs_times)

            rs_meta_ncdf(ista)%el_arr_obs(1:rs_meta_ncdf(ista)%nel)         = &
                 elev(1:rs_meta_ncdf(ista)%nel)


            DEALLOCATE(records, endrecs, sec_ob, elev,  &
                 time, date, cdate,      &
                 manel, nc_mjjj, nc_mmm, &
                 nc_myy, nc_mgg, nc_ngg, &
                 nc_nsecm )


            !---------------------------------------------------------------------
            ! .. Check, match and store the corresponding obs_startrec, obs_endrec 
            !    of the other files against the first file. If records for some times
            !    are missing in other files, eliminate this obs_time from the
            !    list by setting it to a value < 0.0. Those obs times will be
            !    filtered out later in the program:

            IF (lcheck_inputrecords) THEN

              ! .. Do a thorough checking and matching:

              DO ii = 1, ndatakind
                IF (ii /= fid .AND. fids(ii) /= 0) THEN

                  status = nf90_inquire(fids(ii), unlimitedDimId = RecordDimID)
                  status = nf90_inquire_dimension(fids(ii), RecordDimID,len = len_report) !Number of reports
                  status = nf90_inq_dimid(fids(ii), "Loop_000_maxlen", AziDim)
                  status = nf90_inquire_dimension(fids(ii), AziDim, len = len_azimut) ! Number of azimuth

                  rs_meta_ncdf(ista)%nrep_ncdf(ii)   = len_report
                  rs_meta_ncdf(ista)%naz_ncdf(ii)    = len_azimut

                  status = nf90_inq_varid (fids(ii), 'TIME',  varid_time )
                  status = nf90_inq_varid (fids(ii), 'MJJJ',  varid_mjjj )     !Year
                  status = nf90_inq_varid (fids(ii), 'MMM',   varid_mmm  )     !Month
                  status = nf90_inq_varid (fids(ii), 'MYY',   varid_myy  )     !Day

                  ALLOCATE( time    (len_report), &
                       cdate   (len_report), &
                       nc_mjjj (len_report), &
                       nc_mmm  (len_report), &
                       nc_myy  (len_report)  )

                  nsta   = 1
                  ncount = len_report
                  status = nf90_get_var (fids(ii), varid_time , time    ,(/nsta/), (/ncount/))
                  status = nf90_get_var (fids(ii), varid_mjjj , nc_mjjj ,(/nsta/), (/ncount/))
                  status = nf90_get_var (fids(ii), varid_mmm  , nc_mmm  ,(/nsta/), (/ncount/))
                  status = nf90_get_var (fids(ii), varid_myy  , nc_myy  ,(/nsta/), (/ncount/))

                  rs_meta_ncdf(ista)%obs_startrec(:,ii) = -999
                  DO i = 1, len_report

                    IF (nc_mjjj(i) < 100) THEN
                      nc_mjjj (i) = 2000 + nc_mjjj(i)
                      IF (nc_mjjj(i) > 2059)  nc_mjjj (i) = nc_mjjj(i) - 100
                    END IF

                    WRITE (cdate(i),'(i4.4,2i2.2,i6.6)') &
                         nc_mjjj(i), nc_mmm(i), nc_myy(i), time(i)

                    DO j = 1, rs_meta_ncdf(ista)%nobs_times

                      IF ( cdate(i) == rs_meta_ncdf(ista)%obs_cdate(j) ) THEN

                        IF ( rs_meta_ncdf(ista)%obs_startrec(j,ii) < -900 ) THEN
                          rs_meta_ncdf(ista)%obs_startrec(j,ii) = i
                        END IF
                        
                        rs_meta_ncdf(ista)%obs_endrec(j,ii) = i

                      END IF

                    END DO

                  END DO

                  ! .. If a certain obs_time could not be found in this file, eliminate
                  !    it from the list of obs_times by setting it to a value < 0.0:
                  DO j = 1, rs_meta_ncdf(ista)%nobs_times
                    
                    IF ( rs_meta_ncdf(ista)%obs_startrec(j,ii) < -900 ) THEN
                      
                      WRITE (*,'(i5,1x,a,i7,a)') my_cart_id, &
                           TRIM(yzroutine) // ' WARNING: Obs time ' // &
                           rs_meta_ncdf(ista)%obs_cdate(j) // &
                           ' for radar station ', station_id, &
                           ' missing in NetCDF file for ' // TRIM(datakind(ii)) // ' ! Discarded!'
                      
                      rs_meta_ncdf(ista)%obs_times(j) = -999.99_ireals

                    END IF
                    
                  END DO

                  DEALLOCATE (time, cdate, nc_mjjj, nc_mmm, nc_myy)

                END IF
              END DO

            ELSE

              ! .. Just assume that records in all files are the same:

              DO ii = 1, ndatakind
                IF (ii /= fid .AND. fids(ii) /= 0) THEN
                  rs_meta_ncdf(ista)%obs_startrec(:,ii) = rs_meta_ncdf(ista)%obs_startrec(:,fid)
                  rs_meta_ncdf(ista)%obs_endrec  (:,ii) = rs_meta_ncdf(ista)%obs_endrec(:,fid)
                  rs_meta_ncdf(ista)%nrep_ncdf(ii)      = rs_meta_ncdf(ista)%nrep_ncdf(fid)
                END IF
              END DO

            END IF

            ! close netCDF files:       
            CALL netcdf_close_dwd ( fids )


!!!!!$ Doing the communication by an extra loop below seems to be slightly faster.
!!$            ! .. if you are not PE 0, send to PE 0:
!!$            IF (num_compute > 1 .AND.  my_cart_id /= 0) THEN
!!$              CALL mpi_send ( rs_meta_ncdf(ista), 1, mpi_radar_meta_typ, &
!!$                              0, 2+ista, icomm_cart, mpierr )
!!$            END IF
!!$
!!$          ELSE ! my_cart_id /= ipe_rad
!!$
!!$            ! .. you are not ipe_rad and if PE 0, receive from other PE:
!!$            IF (num_compute > 1 .AND. my_cart_id == 0) THEN
!!$              CALL mpi_recv ( rs_meta_ncdf(ista), 1, mpi_radar_meta_typ, &
!!$                              ipe_rad, 2+ista, icomm_cart, mpistat, mpierr )
!!$            END IF

          END IF ! my_cart_id == ipe_rad

        END DO read_loop   ! loop over one num_compute-chunk over ista


!!!!!$ Doing the communication by an extra loop below seems to be slightly faster.
        IF (num_compute > 1) THEN

          dist_loop: DO ista = ista_par, ista_end

            ! determine the number of the PE for output of the radar with no. ista:
            ipe_rad = MOD(ista-1, num_compute)

            IF (my_cart_id == ipe_rad .AND. my_cart_id /= 0) THEN
              CALL mpi_send ( rs_meta_ncdf(ista), 1, mpi_radar_meta_typ, &
                              0, 2+ista, icomm_cart, mpierr )
            END IF

            IF (my_cart_id /= ipe_rad .AND. my_cart_id == 0) THEN
              CALL mpi_recv ( rs_meta_ncdf(ista), 1, mpi_radar_meta_typ, &
                              ipe_rad, 2+ista, icomm_cart, mpistat, mpierr )
            END IF


          END DO dist_loop

        END IF

        ! .. A communication synchronisation might be necessary here:
        IF (num_compute > 1) THEN
          CALL mpi_barrier (icomm_cart, mpierr)
        END IF

      END DO   ! loop over num_compute-chunks of 1...nradsta


      ! Distribute error-status:
      errstring(:) = ' '
      CALL global_values(err_ista, nradsta, "MAX", imp_integers, icomm_cart, 0, errstring, mpierr)


#ifdef NUDGING

    IF (lfdbk_output) THEN

      !-----------------------------------------------------------------------
      ! .. Create names of feedback files:
      
      zlrefend = .FALSE. ! eigentlich: (lnudge) .AND. (nverend == nstop)
      
      ! difference between model initial time and verification reference time:
      !   (reference time = number of minutes from ydate_ini)
      IF (      zlrefend)  nrefmin  =  NINT( hverend * 60.0_ireals )
      IF (.NOT. zlrefend)  nrefmin  =  0
      
      zitype_calendar = 0
      
!CS   ! the following computation of 'iveri_ref_time' is ok
      ! only as long as 'ydate_ini' is at full hours

      ! .. Calculate the verification reference date in format YYYYMMDDhhmm:
      CALL get_utc_date ( nrefmin, ydate_ini, 60.0_ireals, zitype_calendar, zyakdat1       &
           , zyakdat2, nzday, zhr)
      
      
      READ( zyakdat1(1:8) ,'(I8)' )  ziveri_ref_date
!!$      READ( zyakdat1(9:10),'(I2)' )  ziveri_ref_time
!!$      ziveri_ref_time  =  ziveri_ref_time *100 + MOD( nrefmin , 60 )
      READ( zyakdat1(9:12),'(I4)' )  ziveri_ref_time
      WRITE( zyveri_ref_datim,'(I8.8,I4.4)' )  ziveri_ref_date, ziveri_ref_time


      DO ista = 1, nradsta

        ! .. Name of feedback file incl. reference date:
        rs_meta_ncdf(ista)%fdbkfile(:) = ' '
        WRITE ( rs_meta_ncdf(ista)%fdbkfile, '(a,i6.6,a,I8.8,I4.4,a)') &
             TRIM(root%ydir) // '/' // 'fof_radar_id-', &
             rs_meta_ncdf(ista)%station_id, '_' ,ziveri_ref_date, ziveri_ref_time, '00.nc'

        ! .. Initialize existence flag with .false., so that
        !    the file is newly created and an erroneously pre-existing
        !    file of the same name will be deleted:
        rs_meta_ncdf(ista)%lfdbkfile_exist = .FALSE.

      END DO

      !----------------------------------
    ENDIF

#endif

      IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

    END IF


  END SUBROUTINE read_meta_info_dwd
  

  !==============================================================================
  !+ Module procedure in src_radar for the reading of radar data from NetCDF
  !------------------------------------------------------------------------------


  SUBROUTINE netcdf_open_dwd(rsm, fids)

    !------------------------------------------------------------------------------
    !
    ! Description: opens input data files for one radar station
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! INCOMING:
    TYPE(radar_meta_type), INTENT(IN)      :: rsm

    ! OUTGOING:
    INTEGER (KIND = iintegers),INTENT(out) :: fids(ndatakind)  ! file IDs
                                                               ! Index 1 = vr
                                                               ! Index 2 = qv
                                                               ! Index 3 = z
                                                               ! Index 4 = qz

    ! Local scalars:
    CHARACTER (LEN=32)         :: yzroutine
    CHARACTER (LEN=80)         :: yzerrmsg
    INTEGER (KIND = iintegers) :: status
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE init_radar
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'netcdf_open_dwd'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id


    fids = 0

    IF (loutradwind) THEN

      ! Open Radial Wind Files
      ! ----------------------

      IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine)//': opening '//TRIM(rsm%ncdffile_vr)//' ...'

      status = nf90_open (TRIM(rsm%ncdffile_vr), NF90_NOWRITE, fids(1))

      IF (status /= nf90_noerr) THEN
        WRITE(*,'(i5,1x,3a)') my_cart_id, 'ERROR: NetCDF file ', TRIM(rsm%ncdffile_vr), &
             ' could not be opened!'
        fids(1) = 0
      END IF

      ! Open Quality Files for Radial Wind
      ! ----------------------------------

      IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine)//': opening '//TRIM(rsm%ncdffile_qv)//' ...'

      status = nf90_open (TRIM(rsm%ncdffile_qv), NF90_NOWRITE, fids(2))

      IF (status /= nf90_noerr) THEN
        WRITE(*,'(i5,1x,3a)') my_cart_id, 'ERROR: NetCDF file ', TRIM(rsm%ncdffile_qv), &
             ' could not be opened'
        fids(2) = 0
      END IF

    END IF ! loutradwind


    IF (loutdbz) THEN


      ! Open Reflectivity File
      ! ----------------------

      IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine)//': opening '//TRIM(rsm%ncdffile_z)//' ...'

      status = nf90_open (TRIM(rsm%ncdffile_z), NF90_NOWRITE, fids(3))

      IF (status /= nf90_noerr) THEN
        WRITE(*,'(i5,1x,3a)') my_cart_id, 'ERROR: NetCDF file ', TRIM(rsm%ncdffile_z), &
             'could not be opened!'
        fids(3) = 0
      END IF

      ! Open Quality Files for Reflectivity File
      ! ----------------------

      IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine)//': opening '//TRIM(rsm%ncdffile_qz)//' ...'

      status = nf90_open (TRIM(rsm%ncdffile_qz), NF90_NOWRITE, fids(4))
      
      IF (status /= nf90_noerr) THEN
        WRITE(*,'(i5,1x,3a)') my_cart_id, 'ERROR: NetCDF file ', TRIM(rsm%ncdffile_qz), &
             'could not be opened!'
        fids(4) = 0
      END IF

    END IF ! loutdbz

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE netcdf_open_dwd

  !==============================================================================
  !+ Module procedure in src_radar for the reading of radar data from NetCDF
  !------------------------------------------------------------------------------

  SUBROUTINE netcdf_close_dwd ( fids )

    !------------------------------------------------------------------------------
    !
    ! Description: closes input data files for one radar station
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    !------------------------------------------------------------------------------
    !
    ! INCOMING:
    INTEGER (KIND = iintegers),INTENT(in) :: fids(ndatakind)  ! file IDs
                                                              ! Index 1 = vr
                                                              ! Index 2 = qv
                                                              ! Index 3 = z
                                                              ! Index 4 = qz

    ! Local scalars:
    CHARACTER (LEN=32)         :: yzroutine
    INTEGER (KIND = iintegers) :: status
    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE init_radar
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'netcdf_close_dwd'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    IF (loutradwind) THEN
      IF (fids(1) /= 0 ) THEN
        status = nf90_close(fids(1))
        IF (status /= nf90_noerr) WRITE (*,*) "Error in closing radwind obs file"
      ENDIF
      IF (fids(2) /= 0 ) THEN
        status = nf90_close(fids(2))
        IF (status /= nf90_noerr) WRITE (*,*) "Error in closing radwind quali file"
      ENDIF
    END IF

    IF (loutdbz) THEN
      IF (fids(3) /= 0 ) THEN
        status = nf90_close(fids(3))
        IF (status /= nf90_noerr) WRITE (*,*) "Error in closing reflectivity obs file"
      ENDIF
      IF (fids(4) /= 0 ) THEN
        status = nf90_close(fids(4))
        IF (status /= nf90_noerr) WRITE (*,*) "Error in closing reflectivity qualy file"
      ENDIF
    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE netcdf_close_dwd

  !==============================================================================
  !+ Module procedure in src_radar for the reading of radar data from NetCDF
  !------------------------------------------------------------------------------

  SUBROUTINE read_field_obs_dwd(ista, fid, idata, itime, ncdf_shortname, &
       datap, zind_intp_obs, ldata_avail, missing_data)

    !------------------------------------------------------------------------------
    !
    ! Description: This subroutine reads observed data for each
    !              radar station for each time in a generic fashion.
    !
    ! Method: The NetCDF file id "fid" has to point to an open file.
    !         "datap" has to be a pointer to a 1D data vector in 
    !         the rs_data(ista) structure, which points to the desired
    !         input field. "ncdf_shortname" denotes the NetCDF shortname
    !         of the input field as determined from ncdump.
    !         "ldata_avail" is a flag indicating failure or success of reading.
    !         "missing_data" is the correct missing value for the data.
    !
    ! IS CALLED FROM "READ_DWD_RAD".
    !
    ! Caveat: At the moment, this subroutine has some side-effects through
    !         some global variables / data vectors, which are only correctly
    !         integrated if this subroutine is called from "read_dwd_rad"!
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with INTENT(in):

    INTEGER (KIND=iintegers),INTENT(IN)    :: &
         ista     , & ! Station nr.
         fid      , & ! NetCDF file ID
         idata    , & ! data type index: 1=vr, 2=qv, 3=z, 4=qz
         itime        ! time index, from 1 ... rs_meta(ista)%nobs_times

    CHARACTER (len=*), INTENT(in) :: ncdf_shortname ! NetCDF short name of radar data field

    !.. INTENT(out):
    REAL (KIND=ireals), POINTER      :: datap(:) ! storage vector for the data
    INTEGER (KIND=iintegers), POINTER      :: zind_intp_obs(:) ! storage vector for the data index
    LOGICAL, intent(out)             :: ldata_avail   ! flag for success of reading
    REAL (KIND=ireals), intent(out)  :: missing_data  ! correct missing value for the data

    !------------------------------------------------------------------------------
    !
    ! Local scalars:
    CHARACTER (LEN=32)                   :: yzroutine
    CHARACTER (LEN=80)                   :: yzerrmsg

    ! NetCDF variable id for
    INTEGER (KIND=iintegers)           :: varid_mabaz  ! azimuth mabaz
    INTEGER (KIND=iintegers)           :: varid_mabaz0 ! azimuth mabaz0
    INTEGER (KIND=iintegers)           :: varid_manel  ! elevation manel
    INTEGER (KIND=iintegers)           :: varid_manel0 ! elevation manel
    INTEGER (KIND=iintegers)           :: varid_data   ! radar field shortname
    INTEGER (KIND=iintegers)           :: varid_time   ! observation time
    INTEGER (KIND=iintegers)           :: varid_rbins  ! number of range bins of individual report

    INTEGER (KIND=iintegers)           :: m,n,o,status,status1,status2
    REAL    (KIND=ireals)              :: mdmvr, missing_az
    REAL    (KIND=ireals),ALLOCATABLE  :: manel0(:,:),mabaz0(:,:),manel(:),mabaz(:)
                                            
    INTEGER (KIND=iintegers),ALLOCATABLE :: time(:),rbins(:),azind(:,:),eleind(:)
    INTEGER (KIND=iintegers)             :: nobs
    INTEGER (KIND=iintegers)             :: ierr,nsta(3),ncount(3),nrep, nobs_max, &
                                            start_rec, end_rec, tol, zcheck(4)

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    !------------------------------------------------------------------------------
    ! Section 1: Initializations
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'read_field_obs_dwd'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !    Check index idata:
    IF (idata < 1 .OR. idata > ndatakind) THEN
      WRITE (*,'(a,/,a,i2,a)') TRIM(yzroutine)//': ERROR reading data (shortname = '// &
           ncdf_shortname//') from a NetCDF file:', &
           '  idata = ', idata, ' is not between 1 and '//cndatakind//'!'
      ldata_avail = .FALSE.
      IF (ASSOCIATED(datap)) DEALLOCATE(datap)
      NULLIFY(datap)
      RETURN
    END IF

    !    Get the NetCDF start- and end record numbers from the meta-data-structure for 
    !    the data type with index idata (1,2,3,or 4):
    start_rec = rs_meta(ista)%obs_startrec(itime,idata)
    end_rec   = rs_meta(ista)%obs_endrec(itime,idata)

    !    Define three dimensional start and count arrays
    nrep      = end_rec - start_rec + 1
    nsta(1:3) = (/1,1,start_rec/)
    ncount(1:3) = (/rs_meta(ista)%nra,rs_meta(ista)%naz_ncdf(idata),nrep/)

    !    Define max. number of possible observations:
    nobs_max = rs_meta(ista)%naz_ncdf(idata) * rs_meta(ista)%nel * rs_meta(ista)%nra


    ! .. Set %check - fields for checking of equivalence of
    !    available azimuts and elevations for different data sets
    !    from the same station from the same time:

    IF (ALLOCATED(time))    DEALLOCATE(time,manel,rbins,mabaz)
    ALLOCATE( time (start_rec:end_rec) , &
              manel(start_rec:end_rec) , &
              mabaz(start_rec:end_rec) , &
              rbins(start_rec:end_rec) )

    time(:) = -99_iintegers
    manel(:) = missing_obs
    mabaz(:) = missing_obs    
    rbins(:) = 0_iintegers

    status = nf90_inq_varid (fid, 'TIME'  , varid_time)          ! Reference time
    status = nf90_get_var (fid, varid_time, time, (/start_rec/), (/nrep/))
    status = nf90_inq_varid (fid, 'MANEL' , varid_manel)         ! Elevation nominal
    status = nf90_get_var (fid, varid_manel,manel,(/start_rec/), (/nrep/))
    status = nf90_inq_varid (fid, 'MABAZ' , varid_mabaz)         ! Azimuth start
    status = nf90_get_var (fid, varid_mabaz,mabaz,(/start_rec/), (/nrep/))
    status = nf90_inq_varid (fid, '030194', varid_rbins)
    status = nf90_get_var (fid, varid_rbins, rbins, (/start_rec/), (/nrep/))


    IF (.NOT.lequal_azi_alldatasets .OR. MAXVAL(rs_data(ista)%check) == -99_iintegers) THEN

      ! .. Either the %check - fields have not been initialized so far, i.e., first call
      !    for the actual time, or lequal_azi_alldatasets = .false., i.e., which means
      !    that the following is called for every dataset and we do not assume
      !    that azimuts are exactly equal for all datasets.

      IF (ALLOCATED(mabaz0))           DEALLOCATE(mabaz0,manel0,azind,eleind)
      ALLOCATE( mabaz0(rs_meta(ista)%naz_ncdf(idata),start_rec:end_rec) , &
           manel0(rs_meta(ista)%naz_ncdf(idata),start_rec:end_rec) , &
           azind (rs_meta(ista)%naz_ncdf(idata),start_rec:end_rec) , & 
           eleind(start_rec:end_rec)                           )

      status = nf90_inq_varid (fid, 'MABAZ0', varid_mabaz0)        ! Azimuth
      status = nf90_get_att (fid, varid_mabaz0, "_FillValue", missing_az)
      mabaz0 = missing_az
      status = nf90_get_var (fid, varid_mabaz0, mabaz0, (/nsta(2),start_rec/), (/ncount(2),nrep/))
      status = nf90_inq_varid (fid, 'MANEL0', varid_manel0)       ! Elevation
      status = nf90_get_var (fid, varid_manel0, manel0, (/nsta(2),start_rec/), (/ncount(2),nrep/))
      rs_data(ista)%check(1) = SUM(time(start_rec:end_rec))
      rs_data(ista)%check(2) = SUM(NINT(manel(start_rec:end_rec)*100.))
      rs_data(ista)%check(3) = SUM(NINT(mabaz(start_rec:end_rec)*100.))
      rs_data(ista)%check(4) = SUM(rbins(start_rec:end_rec))

      ! .. Get azimut- and elevation- indices for sorting of the radar data into a regular
      !    3D data set with nominal range, azimut and elevation:

      ! .. Azimut: assign azimut index by rounding to the next regular azimut value
      ! .. Elevation: assign index from next regular elevation in rs_meta(ista)%el_arr(:)
      ! .. mabaz0 is the end of the azimut interval in sweep direction, so, in the following
      !    subroutine, add/subtract half of az_inc (dep. on antenna rotation direction) to
      !    center it on the center of the azimut interval

      CALL get_posind_rounded_fullrev (mabaz0(:,:), manel0(:,:), &
           rs_meta(ista)%naz_ncdf(idata), nrep, missing_az, &
           rs_meta(ista)%az_start, rs_meta(ista)%az_inc, &
           rs_meta(ista)%el_arr  , rs_meta(ista)%nel,    &
           azind(:,:), eleind(:) , rs_meta(ista)%naz)

      ! .. Allocate and calculate the vector for storing the running index from
      !    which the indices for range, azimut and elevation can be restored:
      IF (ASSOCIATED(zind_intp_obs)) DEALLOCATE(zind_intp_obs)
      NULLIFY(zind_intp_obs)

      IF (lequal_azi_alldatasets) THEN
        IF (ASSOCIATED(rs_data(ista)%ind_intp_obs)) DEALLOCATE(rs_data(ista)%ind_intp_obs)
        NULLIFY(rs_data(ista)%ind_intp_obs)
        ALLOCATE(rs_data(ista)%ind_intp_obs(nobs_max))
        rs_data(ista)%ind_intp_obs = -999_iintegers
        zind_intp_obs => rs_data(ista)%ind_intp_obs
      ELSE
        ALLOCATE(zind_intp_obs(nobs_max))
        zind_intp_obs = -999_iintegers      
      END IF

      nobs  = 0_iintegers
      DO o = start_rec,end_rec           ! Loop over Reports (one elevation per record)
        DO m = 1,rs_meta(ista)%naz_ncdf(idata)  ! Loop over Azimut
!CDIR NODEP
          DO n = 1,rs_meta(ista)%nra     ! Loop over Range
            nobs = nobs + 1
            IF ( azind(m,o) > -900_iintegers .AND. eleind(o) > -900_iintegers .AND. n <= rbins(o) ) THEN
              zind_intp_obs(nobs) = azind(m,o) + (n-1)*rs_meta(ista)%naz &
                   + (eleind(o)-1)*rs_meta(ista)%nra*rs_meta(ista)%naz
            ELSE
!!$              rs_data(ista)%ind_intp_obs(nobs) = -9999_iintegers
              zind_intp_obs(nobs) = -9999_iintegers
            END IF
          END DO
        END DO
      END DO

      IF (lequal_azi_alldatasets) THEN
        rs_data(ista)%nobs_obs(:)         = nobs
      ELSE
        rs_data(ista)%nobs_obs(idata)     = nobs
      END IF

      DEALLOCATE(mabaz0,manel0,azind,eleind)

    ELSE

      ! .. Follow up call for aditional data set, therefore compare 
      !    azimuts and elevations of this data set with %check:

      ! .. Some azimut- and/or elevation values in different data type files might deviate
      !    by 0.01 degree (rounding error???), so we need a little tolerance
      !    in elevation- and azimut checking:

      tol = nrep*1  ! tolerance in the sum of azimuts/elevations = nrep * 0.01 (nrep*1 because of factor 100 below!)

      zcheck(1) = SUM(time(start_rec:end_rec))
      zcheck(2) = SUM(NINT(manel(start_rec:end_rec)*100.))
      zcheck(3) = SUM(NINT(mabaz(start_rec:end_rec)*100.))
      zcheck(4) = SUM(rbins(start_rec:end_rec))

      IF ( rs_data(ista)%check(1)   /= zcheck(1)         .OR. &
           ABS( rs_data(ista)%check(2)-zcheck(2) ) > tol .OR. &
           ABS( rs_data(ista)%check(3)-zcheck(3) ) > tol .OR. &
           rs_data(ista)%check(4)   /= zcheck(4)              &
           ) THEN

        WRITE(*,'(a,i4,i8,4(/,a,2i12))') &
             TRIM(yzroutine)//': Error: Data set inconsistent '// &
             'from same radar and time: station: ',ista,rs_meta(ista)%station_id, &
             '  time checksum: ', zcheck(1), rs_data(ista)%check(1) , &
             '  elev checksum: ', zcheck(2), rs_data(ista)%check(2) , &
             '  azim checksum: ', zcheck(3), rs_data(ista)%check(3) , &
             '  rbin checksum: ', zcheck(4), rs_data(ista)%check(4)
        
        ldata_avail = .FALSE.
        IF (ASSOCIATED(datap)) DEALLOCATE(datap)
        NULLIFY(datap)
        DEALLOCATE(time,manel,rbins,mabaz)
        RETURN

      END IF

    END IF

    DEALLOCATE(time,manel,rbins,mabaz)

    ! allocate memory for the data:
    IF (ASSOCIATED(datap)) DEALLOCATE(datap)
    NULLIFY(datap)
    ALLOCATE(datap(nobs_max))

    ! get the data:
    status1 = nf90_inq_varid (fid, ncdf_shortname, varid_data)
    status2 = nf90_get_att   (fid, varid_data, "_FillValue", missing_data) 
    status = nf90_get_var   (fid, varid_data, datap, nsta, ncount)

    IF (status == nf90_noerr) THEN

      ldata_avail = .TRUE.

    ELSE

      WRITE (*,'(a,6i6,/,i12,3i6)') TRIM(yzroutine)//': ERROR reading data (shortname = '// &
           ncdf_shortname//') from a NetCDF file!', &
           fid, varid_data, status, status1, status2, nf90_noerr, &
           start_rec, rs_meta(ista)%nra, rs_meta(ista)%naz_ncdf(idata), nrep

      ldata_avail = .FALSE.
      IF (ASSOCIATED(datap)) DEALLOCATE(datap)
      NULLIFY(datap)

    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE read_field_obs_dwd
  
  !==============================================================================

  !==============================================================================

  SUBROUTINE read_dwd_rad ( ista, time_mod, action )

    !------------------------------------------------------------------------------
    !
    ! Description: Read the radar data in DWD NetCDF-Format for
    !              the station with number "ista" and for model time
    !              "time_mod" (seconds since model start.
    !
    ! Method: - Open netcdf-files for vr, qv, z, qz
    !         - allocate necessary data vector components in rs_data-structure
    !         - read the data into this structure
    !         - round first azimut value to nearest multiple of dazi
    !
    ! MISSING: Interpolation to regular azimut grid!
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER (kind=iintegers), INTENT(in) :: ista
    REAL (KIND = ireals), INTENT(IN)     :: time_mod       ! seconds since model start
    CHARACTER(len=*), INTENT(in)         :: action

    !------------------------------------------------------------------------------
    !
    ! Local scalars:

    CHARACTER (LEN=32)                   :: yzroutine
    INTEGER (KIND = iintegers)           :: n, start_rec, end_rec, irep, status
    INTEGER (KIND = iintegers)           :: fids(4)  ! file IDs
                                                     ! Index 1 = vr
                                                     ! Index 2 = qv
                                                     ! Index 3 = z
                                                     ! Index 4 = qz

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'read_dwd_rad'


    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine),' ',action, ' on proc ', my_cart_id

    IF (action == 'read') THEN

      ! .. Initialize data present flags, data pointers and nobs_obs:
      rs_meta(ista)%lradwind_avail   = .FALSE.
      rs_meta(ista)%lradwind_q_avail = .FALSE.
      rs_meta(ista)%lzradar_avail    = .FALSE.
      rs_meta(ista)%lzradar_q_avail  = .FALSE.

      ! .. for safety:
      rs_data(ista)%nobs_obs(:)   = 0_iintegers
      
      ! .. for safety:
      IF (ASSOCIATED (rs_data(ista)%radwind_obs)) DEALLOCATE(rs_data(ista)%radwind_obs)
      IF (ASSOCIATED (rs_data(ista)%radwind_obs_q)) DEALLOCATE(rs_data(ista)%radwind_obs_q)
      IF (ASSOCIATED (rs_data(ista)%z_radar_obs)) DEALLOCATE(rs_data(ista)%z_radar_obs)
      IF (ASSOCIATED (rs_data(ista)%z_radar_obs_q)) DEALLOCATE(rs_data(ista)%z_radar_obs_q)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs)) DEALLOCATE(rs_data(ista)%ind_intp_obs)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_vr)) DEALLOCATE(rs_data(ista)%ind_intp_obs_vr)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_qv)) DEALLOCATE(rs_data(ista)%ind_intp_obs_qv)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_z)) DEALLOCATE(rs_data(ista)%ind_intp_obs_z)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_qz)) DEALLOCATE(rs_data(ista)%ind_intp_obs_qz)
      NULLIFY(rs_data(ista)%radwind_obs)
      NULLIFY(rs_data(ista)%radwind_obs_q)
      NULLIFY(rs_data(ista)%z_radar_obs)
      NULLIFY(rs_data(ista)%z_radar_obs_q)
      NULLIFY(rs_data(ista)%ind_intp_obs)
      NULLIFY(rs_data(ista)%ind_intp_obs_vr)
      NULLIFY(rs_data(ista)%ind_intp_obs_qv)
      NULLIFY(rs_data(ista)%ind_intp_obs_z)
      NULLIFY(rs_data(ista)%ind_intp_obs_qz)


      ! .. search for the index of time_mod in the obs_times:
      irep = -999_iintegers
      DO n = 1, rs_meta(ista)%nobs_times
        IF ((rs_meta(ista)%obs_times(n) - 0.5*dt < time_mod .AND. &
             time_mod <= rs_meta(ista)%obs_times(n) + 0.5*dt)) THEN
          irep = n
          EXIT
        END IF
      END DO

      IF (irep == -999_iintegers) THEN

        WRITE (*,'(a,f12.1,a)') TRIM(yzroutine)//': Read nothing, because no radar obs data found ' // &
                    'for model time ', time_mod, ' s !'

      ELSE

        ! .. Data found for the particular timestep, so read them:
      
        ! Open the radar station files:
        CALL netcdf_open_dwd (rs_meta(ista), fids)

        !.. allocate field for cross-checking whether the 4 data
        !   sets to be read in below are from the same
        !   scan:
        rs_data(ista)%check(:) = -99_iintegers
        
        ! .. Reading of data:
        !      ( read_field_obs_dwd () will allocate rs_data(ista)%ind_intp_obs(nobs_max) )
        IF (loutradwind) THEN
          IF (fids(1) /= 0 ) THEN
            ! .. will allocate rs_data(ista)%radwind_obs(nobs_max) and, if needed,
            !    alternatively rs_data(ista)%ind_intp_obs) or rs_data(ista)%ind_intp_obs_vr(nobs_max)
            CALL read_field_obs_dwd (ista,fids(1),1,irep, &
                 'MDMVR',rs_data(ista)%radwind_obs, rs_data(ista)%ind_intp_obs_vr, &
                 rs_meta(ista)%lradwind_avail,&
                 missing_vr)
          ENDIF
          IF (fids(2) /= 0 ) THEN
            ! .. will allocate rs_data(ista)%radwind_obs_q(nobs_max) and, if needed,
            !    alternatively rs_data(ista)%ind_intp_obs) or rs_data(ista)%ind_intp_obs_qv(nobs_max)
            CALL read_field_obs_dwd (ista,fids(2),2,irep, &
                 '021218',rs_data(ista)%radwind_obs_q,  rs_data(ista)%ind_intp_obs_qv, &
                 rs_meta(ista)%lradwind_q_avail,&
                 missing_qv)
         ENDIF
        END IF
        IF (loutdbz) THEN
          IF (fids(3) /= 0 ) THEN
            ! .. will allocate rs_data(ista)%z_radar_obs(nobs_max) and, if needed,
            !    alternatively rs_data(ista)%ind_intp_obs) or rs_data(ista)%ind_intp_obs_z(nobs_max)
            CALL read_field_obs_dwd (ista,fids(3),3,irep, &
                 'MHORRE0',rs_data(ista)%z_radar_obs, rs_data(ista)%ind_intp_obs_z, &
                 rs_meta(ista)%lzradar_avail,&
                 missing_z)
          ENDIF
          IF (fids(4) /= 0 ) THEN
            ! .. will allocate rs_data(ista)%z_radar_obs_q(nobs_max) and, if needed,
            !    alternatively rs_data(ista)%ind_intp_obs) or rs_data(ista)%ind_intp_obs_qz(nobs_max)
            CALL read_field_obs_dwd (ista,fids(4),4,irep, &
                 '021218',rs_data(ista)%z_radar_obs_q, rs_data(ista)%ind_intp_obs_qz, &
                 rs_meta(ista)%lzradar_q_avail,&
                 missing_qz)
          ENDIF
        END IF
        

        CALL netcdf_close_dwd ( fids )

      END IF
      
    ELSE IF (action == 'cleanup') THEN
      
      IF (ASSOCIATED (rs_data(ista)%radwind_obs)) DEALLOCATE(rs_data(ista)%radwind_obs)
      IF (ASSOCIATED (rs_data(ista)%radwind_obs_q)) DEALLOCATE(rs_data(ista)%radwind_obs_q)
      IF (ASSOCIATED (rs_data(ista)%z_radar_obs)) DEALLOCATE(rs_data(ista)%z_radar_obs)
      IF (ASSOCIATED (rs_data(ista)%z_radar_obs_q)) DEALLOCATE(rs_data(ista)%z_radar_obs_q)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs)) DEALLOCATE(rs_data(ista)%ind_intp_obs)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_vr)) DEALLOCATE(rs_data(ista)%ind_intp_obs_vr)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_qv)) DEALLOCATE(rs_data(ista)%ind_intp_obs_qv)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_z)) DEALLOCATE(rs_data(ista)%ind_intp_obs_z)
      IF (ASSOCIATED (rs_data(ista)%ind_intp_obs_qz)) DEALLOCATE(rs_data(ista)%ind_intp_obs_qz)
      NULLIFY(rs_data(ista)%radwind_obs)
      NULLIFY(rs_data(ista)%radwind_obs_q)
      NULLIFY(rs_data(ista)%z_radar_obs)
      NULLIFY(rs_data(ista)%z_radar_obs_q)
      NULLIFY(rs_data(ista)%ind_intp_obs)
      NULLIFY(rs_data(ista)%ind_intp_obs_vr)
      NULLIFY(rs_data(ista)%ind_intp_obs_qv)
      NULLIFY(rs_data(ista)%ind_intp_obs_z)
      NULLIFY(rs_data(ista)%ind_intp_obs_qz)

    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine),' ',action,' on proc ', my_cart_id

  END SUBROUTINE read_dwd_rad

  SUBROUTINE get_posind_rounded_fullrev (az_volscan, el_volscan, naz_ncdf, nele_ncdf,  &
                                missing_az, az_start, az_inc, &
                                el_arr, nele,    &
                                azind, eleind, naz)
  
    !------------------------------------------------------------------------------
    !
    ! Description: For azimut- and elevation-data of a DWD volume scan,
    !              determine the usable data sector (constant elevation,
    !              continuous valid azimut range). Then, compute the 
    !              "regular" azimut- and elevation indices valid for
    !              approximating the "true" ones by a regular azimut- grid
    !              which spans one full antenna revolution (360 degrees)
    !              with a constant increment of "az_inc".
    !
    ! Method:
    !
    !   Round "middle" azimut value of the sweeps to nearest multiple of az_inc and successively
    !   increment/decrement the azimut index by 1 from neighbour to neighbour.
    !   The direction of antenna rotation is correctly taken into account.
    !
    !   We take into account the fact that the azimut values given in
    !   the radar data files denotes the end of the azimutal pulse averaging interval
    !   in the direction of antenna rotation. This is achieved by "cheating" with
    !   the nominal az_start, in that it is increased/decreased by 0.5*az_inc in the
    !   antenna rotation direction ("az_start_mod" below).
    !
    !   As a result, the subroutine returns regular azimut indices i in a nearest-neighbour
    !   sense for each ray of the sweep.
    !   From i, the nominal azimut value can be computed by:
    !
    !   az(i) = az_start + (i-1)*az_inc   ,  i = 1 ... naz (full antenna revolution)
    !
    !      where    naz = NINT(360 / az_inc)
    !
    ! Outputs:
    !
    !   - naz : number of nominal azimuts for full antenna revolution
    !   - azind(1:naz_ncdf, 1:nele_ncdf): nominal azimut index (equals "i" above)
    !                                     for each radar bin in each elevation sweep
    !   - eleind(1:nele_ncdf): nominal elevation index for each elevation
    !
    !   - "missing" azimuts and elevations in the data file are flagged by azind(i) = -999
    !
    !
    ! POSSIBLE IMPROVEMENT: Interpolation to regular azimut grid!
    !
    !------------------------------------------------------------------------------
    !
    ! Subroutine / Function arguments
    ! Scalar arguments with intent(in):

    INTEGER (kind=iintegers), INTENT(in) ::  naz_ncdf, nele_ncdf  ! field dimensions azim, elev
    INTEGER (kind=iintegers), INTENT(in) ::  nele                 ! vector length of nominal elevations el_arr 

    REAL (kind=ireals), INTENT(in) :: az_volscan(naz_ncdf,nele_ncdf) ! array of azimuts for each ray of a volume scan     [deg]
    REAL (kind=ireals), INTENT(in) :: el_volscan(naz_ncdf,nele_ncdf) ! array of elevations for each ray of a volume scan  [deg]
    REAL (kind=ireals), INTENT(in)       ::  az_start, az_inc     ! nominal azimut start and increment [deg]
    REAL (kind=ireals), INTENT(in)       ::  el_arr(nele)         ! nominal elevation vector           [deg]
    REAL (kind=ireals), INTENT(in)       ::  missing_az           ! missing value in azimut array      [deg]

    ! .. INTENT(OUT):
    INTEGER (kind=iintegers), INTENT(out) ::  naz                 ! number of nominal azimuts for full antenna revolution
    INTEGER (kind=iintegers), INTENT(out) ::  azind(naz_ncdf,nele_ncdf) ! nominal azimut index of each ray
    INTEGER (kind=iintegers), INTENT(out) ::  eleind(nele_ncdf)   ! nominal elevation index of each elevation


    !------------------------------------------------------------------------------
    !
    ! .. Local variables:

    CHARACTER (LEN=32)                   :: yzroutine
    INTEGER (kind=iintegers) :: i, o, zazmin, zazmax, znaz_ncdf, rotsign, znaz, &
                                zazind_start, azmin_el, azmax_el, azmid
    REAL (kind=ireals)       :: reldiffazi(10), elemean, az_start_mod, &
                                azi_offset, azinomdiff(naz_ncdf)
    REAL (kind=ireals), PARAMETER :: eps   = 1e-20_ireals
    REAL (kind=ireals), PARAMETER :: eps01 = 0.15_ireals

    !- End of header
    !==============================================================================

    !------------------------------------------------------------------------------
    !- Begin SUBROUTINE
    !------------------------------------------------------------------------------

    yzroutine(:) = ' '
    yzroutine = 'get_posind_rounded_fullrev'

    IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id

    !.. number of azimuts for full antenna revolution:
    naz = NINT(360.0_ireals / az_inc)

    !.. Initializations with missing values:
    azind  = -999_iintegers
    eleind = -999_iintegers

    !.. Determine the regular azimuts and their nominal indices for each elevation
    !   along with the nominal elevation index of the elevation:
    eleloop: DO o = 1, nele_ncdf

      !.. Clip the azimut range to its non-missing range (search from the back):
      DO i = naz_ncdf, 1, -1
        IF (az_volscan(i,o) /= missing_az) THEN
          znaz_ncdf = i
          EXIT
        END IF
      END DO     

      !.. Antenna rotation direction +1 or -1, determined from the first few azimuts:
      zazmax = MIN(10_iintegers,znaz_ncdf-1)
      reldiffazi = 0.0_ireals
      reldiffazi(1:zazmax) = az_volscan(2:zazmax+1,o) - az_volscan(1:zazmax,o)
      reldiffazi(1:zazmax) = reldiffazi(1:zazmax) / ( ABS(reldiffazi(1:zazmax)) + eps )
      rotsign = NINT(SIGN(1.0_ireals, SUM(reldiffazi)), iintegers)

      !.. The azimut values in the radar files denote the end of the azimut averaging interval
      !   in antenna rotation direction. To ensure that the below determined 
      !   nearest regular azimuts represent the center of the averaging intervals,
      !   cheat here by shifting the "regular" az_start accordingly by 0.5*az_inc:
      az_start_mod = az_start + rotsign*az_inc*0.5

      !.. Determine mean elevation of sweep from mid section of azimut interval
      !   (should be nearly constant over the sweep):
      zazmin = MAX( NINT(znaz_ncdf*0.5,iintegers)-5, 1_iintegers) ! Mid azi of ele sweep - 5
      zazmax = MIN( zazmin + 10, znaz_ncdf)                       ! Mid azi of ele sweep + 5
      elemean = SUM(el_volscan(zazmin:zazmax,o)) / (zazmax-zazmin+1.0)
      

      !.. Determine equivalence with one of the nominal elevations and if yes,
      !   store the corresponding elevation index in eleind(o):
!CDIR NODEP
      DO i = 1, nele
        IF ( ABS(elemean-el_arr(i)) <= eps01 ) THEN
          eleind(o) = i
          EXIT
        END IF
      END DO

      IF ( eleind(o) == -999_iintegers ) THEN
        WRITE (*,'(a,i5,1x,f0.4)') 'WARNING: '//TRIM(yzroutine)//': an elevation from a' // &
             'NetCDF file does not have a correct nominal elevation angle! eleind, elemean = ', o, elemean
      END IF

      !.. Find the azimut part with constant elevation by searching from both sides
      !   of the azimut sector towards its center. This assumes that only
      !   the margins of the azimutal sweep deviate:
      azmin_el = -999_iintegers
      azmax_el = -999_iintegers
      DO i = 1, znaz_ncdf
        IF ( ABS(el_volscan(i,o)-elemean) <= eps01 ) THEN
          azmin_el = i
          EXIT          
        END IF
      END DO
      DO i = znaz_ncdf, 1, -1
        IF ( ABS(el_volscan(i,o)-elemean) <= eps01 ) THEN
          azmax_el = i
          EXIT          
        END IF
      END DO

      IF (azmin_el == -999 .OR. azmax_el == -999) THEN
        WRITE (*,'(a,2i5,1x,f0.4)') 'ERROR: '//TRIM(yzroutine)//': a sweep from a NetCDF file' // &
             ' does not have azimuts at constant elevation!  naz, eleind, elemean = ', znaz_ncdf, o, elemean
        CYCLE eleloop 
      END IF

      !.. number of azimuts with constant elevation:
      znaz = azmax_el - azmin_el + 1

      IF ( znaz < 20 ) THEN
        WRITE (*,'(a,3i5)') 'WARNING: '//TRIM(yzroutine)//': a sweep from a NetCDF file' // &
             ' has less than 20 azimuts at constant elevation! ',azmin_el,azmax_el,o
      ELSE IF ( znaz < naz ) THEN
        WRITE (*,'(a,3i5)') 'WARNING: '//TRIM(yzroutine)//': a sweep from a NetCDF file' // &
             ' does not cover one complete antenna revolution! ',azmin_el,azmax_el,o
      END IF

      !.. Rounding of the nominal azimut index of the middle regular azimut
      !   and incrementing the indices for the next azimuts, starting from the
      !   first regular azimut. This assumes that
      !   the azimuts of the sweep are continuous. The direction of
      !   antenna rotation is correctly taken into account, so that
      !   the nominal azimut index is increasing with increasing azimut:

      azmid = NINT(0.5*(azmin_el+azmax_el))

!!$      zazind_start = NINT( ( az_volscan(azmid,o)-(azmid-azmin_el)*az_inc - &
!!$                             MODULO(az_start_mod,360.0_ireals) ) / az_inc ) + 1
      zazind_start = NINT( MODULO(az_volscan(azmid,o)-(azmid-azmin_el)*az_inc - &
                                  az_start_mod, 360.0_ireals ) / az_inc ) + 1
      DO i = azmin_el, MIN(azmax_el, azmin_el+naz-1)
        azind(i,o) = MODULO( zazind_start+rotsign*i-azmin_el - 1, naz) + 1
      END DO

      !.. Check azimuts against nominal values, taking into account a rounding shift of
      !   the azimut determined from the mid point of the sweep:

      azi_offset = az_volscan(azmid,o) - ( az_start_mod + ( azind(azmid,o) - 1 ) * az_inc )

      IF ( azi_offset >= 360.0-2*az_inc ) THEN
        azi_offset = azi_offset - 360.0
      ELSE IF (azi_offset <= -360.0+2*az_inc) THEN
        azi_offset = azi_offset + 360.0
      END IF

!CDIR NODEP
      DO i = 1, MIN(znaz,naz)

        azinomdiff(i) = MODULO(az_start_mod + (azind(azmin_el+i-1,o)-1)*az_inc, 360.0_ireals) - &
                        az_volscan(azmin_el+i-1,o) + azi_offset

        IF ( azinomdiff(i) >= 360.0-az_inc ) THEN
          azinomdiff(i) = azinomdiff(i) - 360.0
        ELSE IF (azinomdiff(i) <= -360.0+az_inc) THEN
          azinomdiff(i) = azinomdiff(i) + 360.0
        END IF
        azinomdiff(i) = ABS(azinomdiff(i))

      END DO

      IF ( MAXVAL(azinomdiff(1:MIN(znaz,naz))) > 0.15*ABS(az_inc) ) THEN
        WRITE (*,'(a,i5)') 'WARNING: '//TRIM(yzroutine)//': not all azimuts from NetCDF file' // &
             ' agree with their nominal value!  eleind = ',o
        DO i=1, MIN(znaz,naz)
          IF (azinomdiff(i) > 0.15*ABS(az_inc)) THEN
            WRITE (*,'(a,i4,4f10.4)') '  az_i = ', i, azinomdiff(i), az_volscan(azmin_el+i-1,o), &
                 az_volscan(azmin_el,o), azi_offset
          END IF
        END DO
      END IF

    END DO eleloop

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  END SUBROUTINE get_posind_rounded_fullrev

#endif

  !==============================================================================
  !==============================================================================
  !
  ! SUBROUTINES FOR GRID POINT REFLECTIVITY/EXTINCTION CALCULATION
  ! FOMERLY IN SRC_OUTPUT.F90
  !
  !==============================================================================
  !
  ! calculation of radar reflectivity with radar_mie_lm.f90
  !
  ! Pre-requisites:
  ! - inclusion of module radar_mie_lm from Ulrich Blahak into the COSMO-Code
  ! - to ensure that DBZ is calculated only once during one timestep:
  !   - set flag zlcalc_dbz = .true. before the output-namelist-loop 
  !     ("write_loop" in organze_output)
  !   - allocate dbzstore(ie,je,ke) before the output-namelist-loop
  !   - deallocate dbzstore after the output-namelist-loop
  !
  ! Calculation is only done when it is necessary, i.e.,
  ! only once during one timestep, even if DBZ, DBZ_850 and DZB_CMAX
  ! are specified as output variables. However, if more than one
  ! output namelist is present, it might be that the parameters
  ! specifying the type of DBZ calculation are different among
  ! those namelists, and in that case, calculation has to be done
  ! more than once during one timestep.
  !
  !==============================================================================

  ! Uses subroutines from vectorized version radar_mie_lm_vec.f90:
  SUBROUTINE calc_dbz_vec (itl, namlist_in, z_radar, z_radar_850, z_radar_cmax, z_ext)

    USE data_io,            ONLY :  &
       dbzcalc_params

    !------------------------------------------------------------------------------

    USE pp_utilities, ONLY :  radar_lm_ray

    !------------------------------------------------------------------------------

    USE radar_mie_lm_vec, ONLY :  &
         radar_lm_mie_vec, &
         radar_lm_rayleigh_vec, &
         radar_lm_rayleigh_oguchi_vec
  
    !------------------------------------------------------------------------------

#ifdef TWOMOMSEIFERT
    USE pp_utilities, ONLY :  radar_sb_ray

    !------------------------------------------------------------------------------

    USE radar_mie_lm_vec, ONLY :  &
         radar_sb_mie_vec,  &
         radar_sb_rayleigh_vec,  &
         radar_sb_rayleigh_oguchi_vec
#endif

    !------------------------------------------------------------------------------

   IMPLICIT NONE

    INTEGER(kind=iintegers), INTENT(IN)      :: itl
    TYPE(dbzcalc_params),    INTENT(IN)      :: namlist_in

    REAL(kind=ireals), OPTIONAL, INTENT(OUT) :: & 
         z_radar(ie,je,ke), z_radar_850(ie,je), z_radar_cmax(ie,je), &
         z_ext(ie,je,ke)

    ! Helper strings for comparison of actual struct namlist with 
    ! that of the last call to calc_dbz_vec, namlist_dbzcalc_vec_store:
    CHARACTER(len=1200) :: cnamnew, cnamold

    ! How to diagnose the N0 of snow PSD for itype_gscp<100:
    INTEGER(kind=iintegers), PARAMETER      :: isnow_n0temp = 2

    TYPE(dbzcalc_params)                    :: namlist

    ! Flags and variables to determine if radar reflectivity calculation is necessary in this
    ! timestep or if it has been already calculated and we can use a SAVE storage array:
    INTEGER(kind=iintegers),         SAVE  :: ntstep_lastcall = -HUGE(1_iintegers)
    LOGICAL,                         SAVE  :: zlnew_timestep = .TRUE.
    REAL (KIND=ireals), ALLOCATABLE, SAVE  :: dbzvecstore(:,:,:)
    REAL (KIND=ireals), ALLOCATABLE, SAVE  :: dbzextstore(:,:,:)
!!$    TYPE(dbzcalc_params),            SAVE  :: namlist_dbzcalc_vec_store = dbz_namlst_d
    TYPE(dbzcalc_params),            SAVE  :: namlist_dbzcalc_vec_store
    CHARACTER (LEN=32)                     :: yzroutine
    CHARACTER (LEN=300)                    :: errstring, dateiname
    LOGICAL                                :: zlcalc_dbz_vec, zl_same_on_all_pes(1), zlcheck(num_compute)
    INTEGER (KIND=iintegers)               :: mpierr, funit, izdebug
    LOGICAL,                         SAVE  :: fileexist = .false.

    yzroutine(:) = ' '
    yzroutine = 'calc_dbz_vec'

    IF (ldebug_radsim) THEN
      WRITE (*,*)  TRIM(yzroutine)//' on proc ', my_cart_id
      izdebug = 6
    ELSE
      izdebug = 0
    END IF

    !.. Initializations for the beginning and each new timestep:
    IF (.NOT. ALLOCATED(dbzvecstore) .OR. ntstep /= ntstep_lastcall) THEN

      ! Initialize flag for dbz calculation and allocate storage array:
      zlnew_timestep = .TRUE.

      IF (.NOT.ALLOCATED(dbzvecstore)) ALLOCATE(dbzvecstore(ie,je,ke))
      dbzvecstore = -999.99_ireals
      IF (.NOT.ALLOCATED(dbzextstore)) ALLOCATE(dbzextstore(ie,je,ke))
      dbzextstore = 0.0_ireals

      namlist_dbzcalc_vec_store = dbz_namlst_d

      ! change struct namlist_dbzcalc_vec_store a little bit, 
      ! that it is not equal to that of the last timestep:
      namlist_dbzcalc_vec_store%ctype_wetsnow_mie = 'gagagagagaga'

      ntstep_lastcall = ntstep
    END IF

    cnamnew(:) = ' '
    cnamold(:) = ' '

    ! write namelists to the helper strings, disregard station_id:
    namlist = namlist_in
    namlist%station_id = dbz_namlst_d%station_id
    WRITE(cnamnew,*) namlist
    WRITE(cnamold,*) namlist_dbzcalc_vec_store

    ! store namlist of the actual call for the next call:
    namlist_dbzcalc_vec_store = namlist


    IF ( .NOT.lgsp ) THEN

      IF (my_cart_id == 0) WRITE (*,*) '  DBZ is not calculated because of lgsp = .false.'    

    ELSE

      ! .. Criterion for re-calculation of DBZ or copying the values from storage array:
      zlcalc_dbz_vec = ( zlnew_timestep .OR. TRIM(cnamnew) /= TRIM(cnamold) )

      IF (ldebug_radsim) THEN

        ! .. Debug output of dbzparams-namelists (one file for each PE):
        dateiname(:) = ' '
        WRITE(dateiname,'("calc_dbz_vec_err_pe-",i3.3,".txt")') my_cart_id

        CALL get_free_unit(funit)

        IF (fileexist) THEN
          OPEN(funit , FILE=TRIM(dateiname), FORM='FORMATTED', STATUS='OLD', &
                       action='WRITE', position='APPEND')
        ELSE
          OPEN(funit , FILE=TRIM(dateiname), FORM='FORMATTED', STATUS='REPLACE', &
                       action='WRITE')
          fileexist = .TRUE.
        END IF
          
        WRITE (funit,'(a)') 'New: '//TRIM(cnamnew)
        WRITE (funit,'(a)') 'Old: '//TRIM(cnamold)
          
        CLOSE(funit)
        CALL release_unit(funit)

        IF (num_compute > 1) THEN

          ! check if we have the same settings on all processors. If not, the program might
          ! hang up, since there is an MPI-exchange of temperature in the reflectivity calculations
          ! for namlist%itype_refl <= 3 below:

          zl_same_on_all_pes(1) = zlcalc_dbz_vec

          CALL MPI_GATHER (zl_same_on_all_pes, 1, imp_logical,      &
                           zlcheck,            1, imp_logical,      &
                           0, icomm_cart, mpierr)

          IF (my_cart_id == 0) THEN
          
            IF ( .NOT.ALL( zlcheck(2:num_compute) .EQV. zlcheck(1) ) ) THEN
              
              errstring(:) = ' '
              WRITE (errstring,'(a,a,i6)') 'Not the same settings on all PEs for DBZ re-calculation!'
              CALL model_abort (my_world_id, 20573, &
                   'ERROR in '//TRIM(yzroutine)//': '//TRIM(ADJUSTL(errstring)), &
                   'src_radar.f90, '//TRIM(yzroutine))
              
            END IF

          END IF

        END IF

      END IF  ! ldebug_radsim


      IF ( zlcalc_dbz_vec ) THEN

        SELECT CASE (namlist%itype_refl)
        CASE(1)
          IF (my_cart_id == 0) WRITE (*,*) '  Calculating DBZ with Mie-Scattering functions, vectorized'
          IF (itype_gscp < 100) THEN
            IF (my_cart_id == 0 .AND. llookup_mie) WRITE (*,*) '  *** Using lookup tables for Mie-Scattering functions *** '
            CALL radar_lm_mie_vec( itl, klv850, my_cart_id, namlist%lambda_radar, &
                 itype_gscp, isnow_n0temp, namlist%igraupel_type, &
                 namlist%ctype_drysnow_mie, namlist%ctype_wetsnow_mie, namlist%ctype_drygraupel_mie, &
                 namlist%ctype_wetgraupel_mie, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 llookup_mie, &
                 z_radar = dbzvecstore(:,:,:), z_ext = dbzextstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#ifdef TWOMOMSEIFERT
          ELSE
            CALL radar_sb_mie_vec( itl, klv850, my_cart_id, namlist%lambda_radar, namlist%igraupel_type, &
                 namlist%ctype_drysnow_mie, namlist%ctype_wetsnow_mie, namlist%ctype_drygraupel_mie, &
                 namlist%ctype_wetgraupel_mie, namlist%ctype_dryhail_mie, namlist%ctype_wethail_mie, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 namlist%Tmeltbegin_h, namlist%meltdegTmin_h, &
                 z_radar = dbzvecstore(:,:,:), z_ext = dbzextstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#endif
          END IF
        case(2)
          IF (my_cart_id == 0) WRITE (*,*) '  Calculating DBZ with Rayleigh approximation, vectorized'
          IF (itype_gscp < 100) THEN
            CALL radar_lm_rayleigh_vec( itl, klv850, my_cart_id, namlist%lambda_radar, &
                 itype_gscp, isnow_n0temp, &
                 namlist%ctype_drysnow_ray, namlist%ctype_wetsnow_ray, namlist%ctype_drygraupel_ray, &
                 namlist%ctype_wetgraupel_ray, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 z_radar = dbzvecstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#ifdef TWOMOMSEIFERT
          ELSE
            CALL radar_sb_rayleigh_vec( itl, klv850, my_cart_id, namlist%lambda_radar, &
                 namlist%ctype_drysnow_ray, namlist%ctype_wetsnow_ray, namlist%ctype_drygraupel_ray, &
                 namlist%ctype_wetgraupel_ray, namlist%ctype_dryhail_ray, namlist%ctype_wethail_ray, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 namlist%Tmeltbegin_h, namlist%meltdegTmin_h, &
                 z_radar = dbzvecstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#endif
          END IF
          dbzextstore(:,:,:) = 0.0
        CASE(3)
          IF (my_cart_id == 0) WRITE (*,*) '  Calculating DBZ ', &
               'with Rayleigh approximation and Oguchi refractive index, vectorized'
          IF (itype_gscp < 100) THEN
            CALL radar_lm_rayleigh_oguchi_vec( itl, klv850, my_cart_id, namlist%lambda_radar, &
                 itype_gscp, isnow_n0temp, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 z_radar = dbzvecstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#ifdef TWOMOMSEIFERT
          ELSE
            CALL radar_sb_rayleigh_oguchi_vec( itl, klv850, my_cart_id, namlist%lambda_radar, &
                 namlist%Tmeltbegin_s, namlist%meltdegTmin_s, &
                 namlist%Tmeltbegin_g, namlist%meltdegTmin_g, &
                 namlist%Tmeltbegin_h, namlist%meltdegTmin_h, &
                 z_radar = dbzvecstore(:,:,:), &
                 linc_boundlines=.TRUE. )
#endif
          END IF
          dbzextstore(:,:,:) = 0.0
        CASE(4)
          IF (my_cart_id == 0) WRITE (*,*) '  Calculating DBZ ', &
               'with Rayleigh approximation from pp_utilities.f90'
          IF (itype_gscp == 3) THEN
!!$ UB: added t0_melt to the argument list, because this is required starting from V4.25:
            CALL radar_lm_ray (ie,je,ke, pi, rho_w, rho_ice, K_w, K_ice, t0_melt,     &
                 klv850, my_cart_id, itype_gscp, izdebug, t(:,:,:,itl), &
                 qc(:,:,:,itl)*rho, qr(:,:,:,itl)*rho,   &
                 qi(:,:,:,itl)*rho, qs(:,:,:,itl)*rho, z_radar = dbzvecstore(:,:,:))
          ELSEIF (itype_gscp == 4) THEN
!!$ UB: added t0_melt to the argument list, because this is required starting from V4.25:
            CALL radar_lm_ray (ie,je,ke, pi, rho_w, rho_ice, K_w, K_ice, t0_melt,     &
                 klv850, my_cart_id, itype_gscp, izdebug, t(:,:,:,itl), &
                 qc(:,:,:,itl)*rho, qr(:,:,:,itl)*rho,   &
                 qi(:,:,:,itl)*rho, qs(:,:,:,itl)*rho, q_grau  = qg(:,:,:,itl)*rho,         &
                 z_radar = dbzvecstore(:,:,:) )
#ifdef TWOMOMSEIFERT
          ELSEIF (itype_gscp >= 100) THEN
            CALL radar_sb_ray (ie, je, ke, pi,                               &
                 klv850, my_cart_id, t(:,:,:,itl),                      &
                 qc(:,:,:,itl)*rho, qr(:,:,:,itl)*rho,                          &
                 qi(:,:,:,itl)*rho, qs(:,:,:,itl)*rho, qg(:,:,:,itl)*rho, qh(:,:,:,itl)*rho,      &
                 qnc(:,:,:,itl)*rho, qnr(:,:,:,itl)*rho,                        &
                 qni(:,:,:,itl)*rho, qns(:,:,:,itl)*rho, qng(:,:,:,itl)*rho, qnh(:,:,:,itl)*rho,  &
                 z_radar = dbzvecstore(:,:,:) )
#endif
          ENDIF
          dbzextstore(:,:,:) = 0.0
        CASE default
          IF (my_cart_id == 0) THEN
            WRITE (*,*) '  SRC_OUTPUT: Unknown type of radar reflectivity calculation: ',namlist%itype_refl
          END IF
          dbzvecstore(:,:,:) = -999.99_ireals
          dbzextstore(:,:,:) = 0.0_ireals
        END SELECT

        !.. Bei zukuenftigen Aufrufen (z.B. fuer dbz_850 und dbz_cmax) waehrend dieses Zeitschrittes nicht mehr berechnen, 
        !   sondern dann von vornherein dbzvecstore benutzen.
        zlnew_timestep = .FALSE.

      ELSE    ! ... IF (zlcalc_dbz_vec)

        IF (my_cart_id == 0) THEN

          SELECT CASE (namlist%itype_refl)
          CASE(1)
            WRITE (*,*) '  Taking previous DBZ with Mie-Scattering functions'
          CASE(2)
            WRITE (*,*) '  Taking previous DBZ with Rayleigh approximation functions'
          CASE(3)
            WRITE (*,*) '  Taking previous DBZ with Rayleigh/Oguchi approximation'
          CASE(4)
            WRITE (*,*) '  Taking previous DBZ with Rayleigh approximation from pp_utilities.f90'
          CASE default
            WRITE (*,*) '  SRC_OUTPUT: Unknown type of radar reflectivity calculation: ',namlist%itype_refl
          END SELECT

        END IF

      END IF  ! ... IF (zlcalc_dbz_vec)

    END IF    ! ... IF ( .NOT.lgsp )

    IF (PRESENT(z_radar)) THEN
      z_radar(:,:,:) = dbzvecstore(:,:,:)
    END IF

    IF ( PRESENT(z_radar_850) ) THEN
      z_radar_850(:,:) = dbzvecstore(:,:,klv850)
    ENDIF

    IF ( PRESENT(z_radar_cmax) ) THEN
      z_radar_cmax(:,:) = MAXVAL(dbzvecstore,3)
    ENDIF

    IF (PRESENT(z_ext)) THEN
      z_ext = dbzextstore
    END IF

    IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

    RETURN
  END SUBROUTINE calc_dbz_vec


#ifdef NUDGING

!!$ Caution: data fields in order (azi, range, ele), not (range, azi, ele)!

SUBROUTINE obs_write_cdf_feedobs ( ista, cvarname, time_mod, &
     rdata_obs, rquali_obs, &
     rdata_mod, rheight, rpress, &
     azivec, rvec, elevec, naz, nra, nele, &
     lastpr, lrefend, lwrite_veridata,                &
     zydate_ini, hversta, hverend,                 &
     zie_tot, zje_tot, zke_tot, zpollat, zpollon,      &
     zdlat, zdlon, zstartlat_tot, zstartlon_tot,      &
     iveri_ens_member, nvers,                     &
     yglatt_institution, yglatt_source, &
     nexce_rep, nexce_bdy, jerr, yerr, &
     obs_is_aliased, mod_is_aliased)


  !-------------------------------------------------------------------------------
  !
  ! Description:
  !   This module procedure of module "obs_write_cdf_feedobs" writes out the
  !   radar observations, the quality flags from the radar input files,
  !   as well as the values obtained by applying the observation operator
  !   to the model values.
  !
  ! Method:
  !   If the program is run in parallel mode, this subroutine
  !   is called for one radar station, one output timestep and one obstype (vr and z)
  !   at a time and writes one feedback file per station containing all output timesteps
  !   and obstypes.
  !   This is achieved by repeatedly opening, appending, and closing
  !   the output file during each output timestep.
  !   The size of the feedback file equals the maximum possible number of data
  !   which is determined by the number of nominal ranges, azimuts and elevations of the
  !   radar station and the number of output timesteps.
  !
  ! NOTE: Only those radar bins are actually written to the file, where both observations
  !       and simulated data are not flagged as invalid or missing (-999.99).
  !       Therefore, the files may actually contain less data (and less headers, if
  !       entire records are flagged missing) than the pre-allocated
  !       filesize would allow.
  !
  ! Current Code Owner: DWD, Ulrich Blahak
  !  phone:  +49  69  8062 2393
  !  fax:    +49  69  8062 3721
  !  email:  ulrich.blahak@dwd.de
  !
  ! Code Description:
  ! Language: Fortran 90.
  ! Software Standards: "European Standards for Writing and
  ! Documenting Exchangeable Fortran 90 Code".
  !===============================================================================

  !===============================================================================
  !
  ! Local USE statements:
  !
  !===============================================================================

  USE mo_fdbk, ONLY : &
       t_fdbk, &
       setup_fdbk, &
       create_fdbk, &
       print_fdbk, &
       add_verification, &
       close_fdbk, &
       cleanup_fdbk, &
       open_fdbk_read, &
       open_fdbk_write, &
       read_fdbk_meta => read_meta

  USE mo_fdbk_cosmo, ONLY : &
       t_acc_header, t_acc_body, t_acc_radar, t_account, &
       write_report_radar_1, write_report_radar_2

  USE mo_fdbk_tables, ONLY  : &
       VN_REFL, VN_RADVEL, VN_HEIGHT, ST_ACTIVE, FL_NONE, OT_RADAR, &
       VT_FIRSTGUESS, VT_ANALYSIS, VT_FORECAST, RC_VOR, RC_ASS


  ! .. values for missing data (rmdi) and checking on missing data (rmdich)
!!$  (available in a future COSMO version)
!!$  USE data_obs_lib_cosmo, ONLY : &
!!$       rmdi, rmdich
!!$  USE data_obs_record, only : &
!!$       imdi
!!$ if available from above modules, remove the local definitions of rmdi, rmdich and imdi
!!$ below !!!

  USE mo_netcdf_param,  ONLY:  &
       NF_INT,  nf_put_att_int , nf_noerr, &
       NF_GLOBAL, nf_enddef, nf_redef

  !===============================================================================
  !
  ! Declarations:
  !
  !===============================================================================

  IMPLICIT NONE

  !===============================================================================

  ! Subroutine arguments:
  ! --------------------

  INTEGER (KIND=iintegers) , INTENT (IN)  :: &
       ista                ,& ! station nr. in the rs_meta(ista) - meta data structure
       naz                 ,& ! number of azimut bins in rdata (regular 3D data set)
       nra                 ,& ! number of range bins in rdata (regular 3D data set)
       nele                   ! number of elevations in rdata (regular 3D data set)

  CHARACTER (LEN= * )      , INTENT (IN)  :: &
       cvarname               ! Tag for type of output field: 'vr' or 'z'

  REAL    (KIND=ireals)    , INTENT (IN)  :: &
       time_mod                   ,& ! Time in minutes since model start
       rdata_obs (naz, nra, nele) ,& ! Obs. radar data to be written to feedback file (3D)
       rquali_obs(naz, nra, nele) ,& ! Quality flag of radar data, directly taken from radar obs file (3D)
       rdata_mod (naz, nra, nele) ,& ! Sim. radar data to be written to feedback file (3D)
       rheight   (naz, nra, nele) ,& ! Height of bin [m MSL] (from simulations)
       rpress    (naz, nra, nele) ,& ! Pressure at height of bin [Pa] (from simulations)
       azivec    (naz      ) ,& ! Vector of regular azimuts
       rvec      (     nra      ) ,& ! Vector of regular range bins
       elevec    (          nele)    ! Vector of regular elevations

  LOGICAL                  , INTENT (IN)  :: &
       lwrite_veridata ,& ! Write also verification data (= sim. radar data), not only obs
       lastpr      ,& ! last time, sth is written to ncfeedobs in this model run
       lrefend        ! .t.: verification reference time set to end of model run
                      !      (for NUDGE runs only; for FORECAST (LETKF) or
                      !       NUDGECAST, veri_ref_time = start of model run)

  LOGICAL        , INTENT (IN), OPTIONAL  :: &
       obs_is_aliased ,& ! flag if obs vr is aliased or not (raw data are normally aliased)
       mod_is_aliased    ! flag if simul. vr is aliased or not

!!$  CHARACTER (LEN=10)       , INTENT (IN)  :: &
  CHARACTER (LEN=14)       , INTENT (IN)  :: &
       zydate_ini      ! reference date (e.g. start of the model run) [yyyymmddhh]
  !                                  (year, month, day, hour)

  REAL    (KIND=ireals)    , INTENT (IN)  :: &
       hversta     ,& ! start of verification period in 'model integration hours'
       hverend        ! end of verification period in 'model integration hours'

  ! following variables are only used for supplementary info in nc file header

  INTEGER (KIND=iintegers) , INTENT (IN)  :: &
       zie_tot      ,& ! number of grid points in zonal direction
       zje_tot      ,& ! number of grid points in meridional direction
       zke_tot         ! number of grid points in vertical direction

  REAL    (KIND=ireals)    , INTENT (IN)  :: &
       zpollat      ,& ! latitude  of the rotated north pole (in degrees, N>0)
       zpollon      ,& ! longitude of the rotated north pole (in degrees, E>0)
       zdlat        ,& ! grid point distance in meridional direction (in degrees)
       zdlon        ,& ! grid point distance in zonal      direction (in degrees)
       zstartlat_tot,& ! rotated latitude   \  of the lower left grid point of the
       zstartlon_tot   ! rotated longitude  /  total domain (in degrees, N,E>0)

  INTEGER (KIND=iintegers) , INTENT (IN)  :: &
       iveri_ens_member  ,& ! ensemble member ( -1: deterministic)
       nvers                ! exp. id + 16384*(class of model run)

  CHARACTER (LEN= * )      , INTENT (IN)  :: &
                                ! NetCDF global attributes:
       yglatt_institution,& ! originating center name
       yglatt_source        ! program name and version
  !   yglatt_title      ,& ! title string for the output
  !   yglatt_references    ! URL, report etc.

  INTEGER (KIND=iintegers) , INTENT (INOUT)  :: &
       nexce_rep   ,& ! number of reports exceeding FOF size
       nexce_bdy   ,& ! number of obs     exceeding FOF size
       jerr           ! error status variable

  ! it is assumed here that LEN >= 72 !
  CHARACTER (LEN= * )      , INTENT (INOUT)  :: &
       yerr           ! error message

  ! Local parameters:
  ! ----------------

!!$ the following missing value indicators will be available in 
!!$ the future from modules "data_obs_lib_cosmo" and "data_obs_record"
  INTEGER (KIND=iintegers) , PARAMETER  :: &
       imdi   =  2147483647    ! missing data indicator for ODR integers (2^31 -1)

  REAL    (KIND=ireals)    , PARAMETER  :: &
       rmdi   = -1.E31_ireals  ,& ! commonly used missing data indicator 
       rmdich = -1.E30_ireals     ! commonly used check value for missing data (> rmdi)
!!$!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


  INTEGER (KIND = iintegers) , PARAMETER  :: &
       itype_calendar = 0    ! for specifying the calendar used in 'get_utc_date'

  REAL    (KIND = ireals)    , PARAMETER  :: &
       c1000r  =     0.001_ireals   ,& !
       c60     =    60.0_ireals     ,& !
       c0      =     0.0_ireals     ,& !
       epsy    =    1e-8_ireals

  TYPE (t_fdbk), SAVE  :: fb(nradsta_max)        ! feedback meta file structure for each station 
!!$  !TYPE (t_account), ALLOCATABLE :: report(:)  ! reports written to feedback file
!!$  TYPE (t_acc_header) :: rep_header(naz*nele)  ! report headers written to feedback file
!!$  TYPE (t_acc_body)   :: rep_body(naz*nele,nra)! report bodys written to feedback file
!!$  INTEGER             :: rep_len(naz*nele)     ! len of report body
!!$  INTEGER             :: rep_offset(naz*nele)  ! offset of report body
  TYPE (t_acc_header) :: rep_header(nele)  ! report headers written to feedback file
  TYPE (t_acc_body)   :: rep_body(naz*nra,nele)! report bodys written to feedback file
!!$  TYPE (t_acc_radar)  :: spec_radar(naz,nele)! specific for radar rays
  TYPE (t_acc_radar)  :: spec_radar(nele*naz)! specific for radar rays
  INTEGER             :: rep_len(nele)     ! len of report body
  INTEGER             :: rep_offset(nele)  ! offset of report body
  INTEGER             :: spec_offset(nele)  ! offset of report body

  ! Local scalars:
  ! -------------

  INTEGER (KIND=iintegers)  :: &
       ivarno,         & ! Type of data, VN_REFL od. VN_RADVEL
       zspec_r_flags     ! Specification flags of data: 
                         !   itype_refl,lextdbz,lsmooth,lonline,lsode,lfall,obs_is_aliased,mod_is_aliased 

  INTEGER (KIND = iintegers) ::  i, j, k, thin_i, thin_j, ij, &
       irep, icl, iradar ,& ! loop indices (reports, characters, "radar specific" dimension)
!!$    iobs   , ilev  ,& ! loop indices (over observations / levels)
       kk             ,& ! counter or loop index over observations for feedobs file
       nfcast         ,& ! number of forecast runs to compare with observations
       nrefmin        ,& ! diff. betw. verif. ref. time and model initial time
       nzday          ,& ! Julian day
!!$    ilenpath       ,& ! length of path of feedobs file
       kerr            ! error status variable
!!$    insert         ,& ! statement function to insert any bit pattern
!!$    invar          ,& ! word to be unpacked / to be partly replaced
!!$    inval  , ibit  ,& ! bit pattern / bit position to be inserted
!!$    ibits          ,& ! statement function to unpack any bit pattern
!!$    ibp            ,& ! bit position of bit struct. to be unpacked /replaced
!!$    icovr          ,& ! no. of bit occ. by the bit structure
!!$    ireplace       ,& ! statement function to replace any bit pattern
!!$    ipos           ,& ! bit position    of the bit structure to be replaced
!!$    iboc           ,& ! no. of bit occ. by the bit structure to be replaced
!!$    irepl          ,& ! word containing the replacing bit structure
!!$    ipsr              ! bit position of the replacing bit structure

  INTEGER (KIND = iintegers) ::  &
       len_body       ,& ! number of body elements in report used in feedback file
       nw_rep         ,& ! number of reports to be put into FOF
       n_body,         & ! number of bodys to be put into FOF
       n_spec            ! number of rays to be put into FOF

  REAL    (KIND = ireals)    ::  &
       zhr,  &             ! hour
       zsubcategory, &
       ze_o

  INTEGER                    ::  ihdr_pos, ibdy_pos, inw_rep, in_body, &
       iveri_exp_id       ,& ! experiment identity number of the model verif. run
       iveri_run_class    ,& ! class (main / ass.) of the model verification run
       iveri_run_type     ,& ! run type (fcst./f.g./ana.) of the verification run
       iveri_ref_date     ,& ! reference date
       iveri_ref_time     ,& ! reference time
       iveri_start        ,& ! start of verification rel. to reference time
       iveri_end          ,& ! end   of verification rel. to reference time
       iveri_forecast_time,& ! forecast time (hhhmm)
       iiveri_ens_member  ,& ! ensemble member ( -1: deterministic)
       idomain (3)        ,& ! model domain size, input for 'create_fdbk'
       imax_rep           ,& ! max. # reports in NetCDF feedobs file, type integer
       imax_radar         ,& ! max. # obs in NetCDF feedobs file, type integer
       imax_rays          ,& ! max. # rays in NetCDF feedobs file, type integer
       imax_body          ,& ! max. # obs in NetCDF feedobs file, type integer
       varid              ,& ! netcdf variable identifier, for 'add_verification'
       imiss                 ! missing data indicator for integers (2^31-1)

  INTEGER                    ::  num_observables  ! max. # of type of radar observables in body

  INTEGER                    ::  thin_naz, thin_nra, thin_az_step, thin_ra_step, imaxloc(1)

  REAL                       ::  &
       resolution  (2)    ,& ! model resolution (lat, lon)
       pole        (2)    ,& ! pole (lat, lon) of rotated grid
       lower_left  (2)    ,& ! lower left  corner of model domain (lat, lon)
       upper_right (2)    ,& ! upper right corner of model domain (lat, lon)
       rmich                 ! check value for missing real data   (-1.E30)

  CHARACTER (LEN=12)  :: yveri_ref_datim      ! yyyymmddhhmm reference time
  CHARACTER (LEN=12)  :: yveri_initial_date   ! yyyymmddhhmm initial time
  CHARACTER (LEN=45)  :: yveri_descript       ! description of model verif. run
  CHARACTER (LEN=64)  :: yversion             ! model version number
!!$  CHARACTER (LEN=10)  :: zyakdat1  ! actual date in the form   yyyymmddhh
!!$  CHARACTER (LEN=22)  :: zyakdat2  ! actual date, form:   wd   dd.mm.yy  hh UTC
  CHARACTER (LEN=14)  :: zyakdat1  ! actual date in the form   yyyymmddhhmmss
  CHARACTER (LEN=28)  :: zyakdat2  ! actual date, form:   wd   dd.mm.yy  hh mm ss UTC

  INTEGER (KIND = iintegers) , SAVE   :: &
       n_veri               ! number of verifications, always 1 in COSMO model

  LOGICAL :: &
       zobs_is_aliased ,& ! flag if obs vr is aliased or not (raw data are normally aliased)
       zmod_is_aliased    ! flag if simul. vr is aliased or not

  ! Local arrays:
  ! ------------

  INTEGER, ALLOCATABLE  :: &
       lenv(:), rind(:), kkv(:), jerrv(:), i_ind(:), j_ind(:), k_ind(:)

  CHARACTER (LEN=32)         :: yzroutine
  CHARACTER (LEN=80)         :: yzerrmsg

  !------------ End of header ----------------------------------------------------


  !-------------------------------------------------------------------------------
  ! Begin Subroutine obs_write_cdf_feedobs
  !-------------------------------------------------------------------------------

  !-------------------------------------------------------------------------------
  !  Section 0: Initialisations
  !-------------------------------------------------------------------------------


  yzroutine(:) = ' '
  yzroutine = 'obs_write_cdf_feedobs'

  IF (ldebug_radsim) WRITE (*,*) TRIM(yzroutine), ' on proc ', my_cart_id



  jerr       = 0
  yerr(:)    = ' '
  kerr       = 0
  zhr        = INT( hversta + epsy )
  nexce_rep  = 0
  nexce_bdy  = 0

  IF (lwrite_veridata) THEN
    nfcast = 1   ! will be written to "n_veri" lateron
  ELSE
    nfcast = 0
  END IF

  ! difference between model initial time and verification reference time
  !   (reference time = number of minutes from ydate_ini)
  IF (      lrefend)  nrefmin  =  NINT( hverend *c60 )
  IF (.NOT. lrefend)  nrefmin  =  0



  IF (TRIM(cvarname) == 'vr') THEN
    ivarno = VN_RADVEL
    zsubcategory = 1
    ze_o       = 0.2 ! m; Beob. Fehler 0.5 dB, 0.2 m/s (wird nachher noch getuned)
  ELSE IF (TRIM(cvarname) == 'z') THEN
    ivarno = VN_REFL
    zsubcategory = 0
    ze_o       = 0.5 ! dB; Beob. Fehler 0.5 dB, 0.2 m/s (wird nachher noch getuned)
  ELSE
    ivarno = -9       ! Dummy
    zsubcategory = -9 ! Dummy
    ze_o       = 0.0  ! Dummy
    WRITE ( yerr , '(a)') &
         TRIM(yzroutine)//' ERROR: cvarname = '//TRIM(cvarname)//'is not supported!'
    jerr = 1
    CALL undwech ()
    RETURN
  END IF

  !-------------------------------------------------------------------------------
  !  Section 1:  Create the netCDF feedback file 
  !-------------------------------------------------------------------------------

  !CS   ! the following computation of 'iveri_ref_time' is ok
  ! only as long as 'ydate_ini' is at full hours

  ! .. Calculate the verification reference date in format YYYYMMDDhhmm:
  CALL get_utc_date ( nrefmin, zydate_ini, 60.0_ireals, itype_calendar, &
       zyakdat1, zyakdat2, nzday, zhr)


  READ( zyakdat1(1:8) ,'(I8)' )  iveri_ref_date
!!$  READ( zyakdat1(9:10),'(I2)' )  iveri_ref_time
!!$  iveri_ref_time  =  iveri_ref_time *100 + MOD( nrefmin , 60 )
  READ( zyakdat1(9:12),'(I4)' )  iveri_ref_time
  WRITE( yveri_ref_datim,'(I8.8,I4.4)' )  iveri_ref_date, iveri_ref_time

  iveri_end    =  NINT( hverend *c60 )  -  nrefmin
  iveri_start  =  NINT( hversta *c60 )  -  nrefmin
  IF (hversta > epsy)  iveri_start  =  MAX( iveri_start , 1-nrefmin )


  !-------------------------------------------------------------------------------
  ! .. Some maximum data dimensions:

  ! .. set to 1 for no thinning:
  thin_az_step = 5
  thin_ra_step = 5

  thin_naz = INT(REAL(naz-1,ireals)/REAL(thin_az_step,ireals),iintegers) + 1
  thin_nra = INT(REAL(nra-1,ireals)/REAL(thin_ra_step,ireals),iintegers) + 1
  

  ! .. max. number of observables per feedback file body
  num_observables = 2  ! Z and VR
  ! .. max. number of rays per output timestep per data category (one ray = one report):
  !imax_radar = naz * nele
  imax_radar = nele
  ! .. max. possible number of reports for all output timesteps:
  imax_rep  =  imax_radar * rs_meta(ista)%nobs_times * num_observables
  ! .. max. number of body data for all timesteps (2 datasets, vr and z):
  !imax_body =  imax_rep * nra
  imax_body =  imax_rep * thin_nra * thin_naz

!  imax_rays = rs_meta(ista)%nobs_times * thin_nra * thin_naz
!  imax_rays = rs_meta(ista)%nobs_times * nele * thin_naz * num_observables
  imax_rays = imax_rep * thin_naz

  !-------------------------------------------------------------------------------
  ! .. Create feedback file if necessary:

  IF (.NOT. rs_meta(ista)%lfdbkfile_exist) THEN

    ! determine NetCDF global attributes
    ! ----------------------------------

    resolution(1)  = zdlat
    resolution(2)  = zdlon
    idomain(1)     = zie_tot
    idomain(2)     = zje_tot
    idomain(3)     = zke_tot
    pole(1)        = zpollat
    pole(2)        = zpollon 
    lower_left(1)  = zstartlat_tot                     ! / lower left corner
    lower_left(2)  = zstartlon_tot                     ! \ of model domain
    upper_right(1) = zstartlat_tot + (zje_tot-1) * zdlat ! / upper right corner
    upper_right(2) = zstartlon_tot + (zie_tot-1) * zdlon ! \ of model domain
    yversion = yglatt_source
    IF (yversion(1:5) == 'COSMO') yversion = yversion(7:LEN_TRIM(yversion)-6)


    ! determine NetCDF variables related to the verification data
    ! (i.e. to the current model run)
    ! -----------------------------------------------------------

    IF ((nvers >= 0) .AND. (nvers < 1048576)) THEN
      iveri_exp_id     =  MOD( nvers, 16384 )
      iveri_run_class  =       nvers/ 16384
    ELSE
      iveri_exp_id     =  imdi
      iveri_run_class  =  imdi
    ENDIF
    yveri_initial_date  =   yveri_ref_datim
    IF (lrefend) THEN
      iveri_forecast_time =   c0
      yveri_descript      =   'nudging assimilation        '
      iveri_run_type      =   VT_ANALYSIS
    ELSE
      iveri_forecast_time =   INT( hverend +c1000r ) * 100                     &
           + MOD( NINT( hverend *c60 ) , 60 )
      yveri_descript      =   'deterministic forecast      '
      IF (iveri_ens_member >= 1)                                               &
           WRITE( yveri_descript,'("ensemble forecast member ",I3)' )             &
           iveri_ens_member
      iveri_run_type      =   VT_ANALYSIS
      IF ((iveri_run_class == RC_ASS) .OR. (hverend < 3.01_ireals))            &
           iveri_run_type    =   VT_FIRSTGUESS
    ENDIF
    iiveri_ens_member = iveri_ens_member

    IF (ldebug_radsim) WRITE(*,'(a)') 'Creating fdbk file: '//TRIM(rs_meta(ista)%fdbkfile(1:108))

    IF ( LEN_TRIM(rs_meta(ista)% fdbkfile) > LEN(fb(ista)% nc% path) ) THEN
      WRITE( yerr ,'("ERROR '//TRIM(yzroutine)//': filename of NetCDF file too long! len = ",i6", maxlen = ",i6)' )&
           LEN_TRIM(rs_meta(ista)% fdbkfile), LEN(fb(ista)% nc% path)
      jerr = 35
      CALL undwech ()
      RETURN
    END IF

    ! create the feedback file (and initialise fdbk tables)
    ! -------------------------

    CALL setup_fdbk   ( fb(ista)%nc )
    !   ===============

    ! needs new mo_fdbk.f90 from Andreas in subdir tmp/:
    CALL create_fdbk (fb(ista)          ,&! feedback file meta data
         TRIM(rs_meta(ista)%fdbkfile)   ,&! path and filename
         'COSMO'                 ,&! model
         yversion                ,&! model version
         yglatt_institution      ,&! institution
         imax_rep                ,&! d_hdr
         imax_body               ,&! d_body  (later will use d_radar instead; then set d_body = 1)
         iveri_ref_date          ,&! reference date
         iveri_ref_time          ,&! reference time
         iveri_start             ,&! start of verification
         iveri_end               ,&! end   of verification
         resolution              ,&! resolution
         idomain                 ,&! COSMO domain size
         yveri_descript          ,&! comment (for history)
         yveri_ref_datim         ,&! time    (for history)
         pole       =pole        ,&! pole of rotated grid
         lower_left =lower_left  ,&! l.l. corner of domain
         upper_right=upper_right ,&! u.r. corner of domain
         n_radar    = imax_rays  ,&! d_radar = max of radar body
         opt        = 'RADAR') ! flag optional variables

    !   ================

    IF (nfcast >= 1)                                                           &
         
         CALL add_verification (fb(ista)  ,&! feedback file meta data
         'COSMO'             ,&! model 
         iveri_run_type      ,&! run type
         iveri_run_class     ,&! run class
         yveri_initial_date  ,&! initial date 
         iveri_forecast_time ,&! forecast time (hhhmm)
         resolution          ,&! resolution
         idomain             ,&! domain size
         yveri_descript      ,&! description
         iiveri_ens_member   ,&! ensemble member 
         iveri_exp_id        ,&! experiment id
         varid )               ! variable id
    !     ====================

    rs_meta(ista)%lfdbkfile_exist = .TRUE.

    n_veri          = nfcast  
    IF (ldebug_radsim) WRITE  (*,'(A)') 'Created fdbk file: '//TRIM(rs_meta(ista)%fdbkfile(1:108))

    CALL close_fdbk (fb(ista))

  ENDIF   ! .not. rs_meta(ista)%lfdbkfile_exist


  ! .. (Re-)Open the existing feedback file and retrieve global attributes:
  IF (ldebug_radsim) WRITE  (*,'(A)') '(Re)Open fdbk file: '//TRIM(rs_meta(ista)%fdbkfile(1:108))

  ! .. Open for read access to read the meta data structure:
  CALL open_fdbk_read ( fb(ista), TRIM(rs_meta(ista)%fdbkfile) )

  ! .. Read the more variable meta data from the file (keep the static ones from the SAVE fb(ista) above):
  CALL read_fdbk_meta  ( fb(ista) ) 
  IF (fb(ista)%nc% error /= NF_NOERR) THEN
    WRITE( yerr ,'("ERROR in read_meta, retrieving structure fb(ista), error = ",I0)' ) fb(ista)%nc% error
    jerr = fb(ista)%nc% error
    CALL undwech ()
    RETURN
  END IF

  ! .. Close file ...
  CALL close_fdbk ( fb(ista) )

  CALL print_fdbk ( fb(ista) )

  ! .. ... and open again for write access:
  CALL open_fdbk_write ( fb(ista), TRIM(rs_meta(ista)%fdbkfile) )


  IF (ldebug_radsim) WRITE  (*,'(A)') 'Feedback file opened: '//TRIM(rs_meta(ista)%fdbkfile)

  !-------------------------------------------------------------------------------
  !  Section 3:  Fill 'report' which is the input for 'write_report'
  !-------------------------------------------------------------------------------

  ! determine 'nw_rep', 'n_body' (number of new reports / observations)
  ! -------------------------------------------------------------------

  nw_rep = imax_radar

!!$! It seems to be not allowed to make record allocatable, because it has a POINTER component.
!!$! However, such derived types can be automatic arrays.
!!$!   Therefore, splitted report of type(t_account) in its components
!!$!   rep_header (type t_acc_header) und rep_body (type t_acc_body) sowie
!!!$   rep_len und rep_offset!
!!$  IF (nw_rep > 0) THEN
!!$    ALLOCATE( report( nw_rep ), STAT=jerr )
!!$    IF (jerr/=0) THEN
!!$      WRITE ( yerr ,'("ERROR in memory alloc: report(nw_rep) ",I8)') nw_rep
!!$      CALL undwech ()
!!$      RETURN
!!$    ENDIF
!!$  ENDIF

  ! initialize filling of 'report'
  ! ------------------------------


#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_begin(TRIM(yzroutine)//'_preparations')
#endif

  ALLOCATE ( lenv(nw_rep) )
  lenv(:) = 0

  DO k = 1, nele
    DO i= 1, nra, thin_ra_step
!CDIR NODEP
      DO j = 1, naz, thin_az_step

        irep = k

        IF (rdata_obs(j,i,k) >= -900.0_ireals .AND. rdata_mod(j,i,k) >= -900.0_ireals) THEN
          lenv(irep) = lenv(irep) + 1
        END IF

      END DO
    END DO
  END DO

  ALLOCATE ( rind(nw_rep) )
  rind(:) = 0

  rep_len(:) = 0
  i = 0
  DO irep=1,nw_rep
    IF (lenv(irep) > 0) THEN
      i = i + 1
      rep_len(i) = lenv(irep)
      rind(i) = irep
    END IF
  END DO
  nw_rep = i

  DEALLOCATE (lenv)

  ! update total nubmers of reports in header / body:
  ! -------------------------------------------------
  fb(ista)%n_hdr = fb(ista)%n_hdr + nw_rep

  n_body = 0
  n_spec = 0
  rep_offset(:) = fb(ista)%n_body
  spec_offset(:) = fb(ista)%n_radar
  DO irep=1, nw_rep

    rep_offset(irep) = rep_offset(irep)  + n_body
    n_body = n_body + rep_len(irep)

    spec_offset(irep) = spec_offset(irep)  + n_spec
    n_spec = n_spec + thin_naz

  END DO
  fb(ista)%n_body = fb(ista)%n_body + n_body
  fb(ista)%n_radar = fb(ista)%n_radar + n_spec


  ! fill report(irep)% header
  ! -------------------------

  ! Set radar obs and mod configuration flags:
  ! Bitwise coding for itype_refl, lextdbz, lsmooth, lonline, lsode, 
  !  lfall, obs_is_aliased, mod_is_aliased:

  IF (PRESENT(obs_is_aliased)) THEN
    zobs_is_aliased = obs_is_aliased
  ELSE
    zobs_is_aliased = .TRUE.   ! which is normally the case with raw radar data ...
  END IF
  IF (PRESENT(mod_is_aliased)) THEN
    zmod_is_aliased = mod_is_aliased
  ELSE
    zmod_is_aliased = .FALSE.
  END IF

  zspec_r_flags = (dbz_meta(ista)%itype_refl-1)     ! itype_refl=1,2,3,4 and reserve up to 16 for future use
  IF (lextdbz)         zspec_r_flags = IBSET(zspec_r_flags, 5)
  IF (lsmooth)         zspec_r_flags = IBSET(zspec_r_flags, 6)
  IF (lonline)         zspec_r_flags = IBSET(zspec_r_flags, 7)
  IF (lsode)           zspec_r_flags = IBSET(zspec_r_flags, 8)
  IF (lfall)           zspec_r_flags = IBSET(zspec_r_flags, 9)
  IF (zobs_is_aliased) zspec_r_flags = IBSET(zspec_r_flags,10)
  IF (zmod_is_aliased) zspec_r_flags = IBSET(zspec_r_flags,11)

  ! (recover flags with:)
  !
  ! itype_refl = MOD(zspec_r_flags, 2**5) + 1   OR   itype_refl = IBITS(zspec_r_flags,0,5) + 1
  ! lextdbz = BTEST(zspec_r_flags, 5)
  ! lsmooth = BTEST(zspec_r_flags, 6)
  ! lonline = BTEST(zspec_r_flags, 7)
  ! lsode   = BTEST(zspec_r_flags, 8)
  ! lfall   = BTEST(zspec_r_flags, 9)
  ! zobs_is_aliased = BTEST(zspec_r_flags, 10)
  ! zmod_is_aliased = BTEST(zspec_r_flags, 11)

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_end(TRIM(yzroutine)//'_preparations')
#endif


#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_begin(TRIM(yzroutine)//'_header')
#endif

  DO irep=1, nw_rep

    len_body = rep_len(irep) 

    rep_header(irep)% i_body        = rep_offset(irep)+1  ! offset im body
    rep_header(irep)% l_body        = len_body  ! Laenge des Eintrags im body
    rep_header(irep)% n_level       = len_body  ! Laenge des Eintrags im body

    rep_header(irep)% i_spec        = spec_offset(irep)+1  ! offset im spec
    rep_header(irep)% l_spec        = thin_naz  ! Laenge des Eintrags im spec

    rep_header(irep)% data_category = 6  ! erst mal FillValue
    rep_header(irep)% sub_category  = zsubcategory  ! 0 = reflectivity, 1 = radwind

    rep_header(irep)% center        = 78
    rep_header(irep)% sub_center    = 255
    rep_header(irep)% obstype       = OT_RADAR
    rep_header(irep)% codetype      = -1
    rep_header(irep)% lat           = rs_meta(ista)%lat
    rep_header(irep)% lon           = rs_meta(ista)%lon
    rep_header(irep)% ident         = rs_meta(ista)%station_id

    rep_header(irep)% sun_zenit     = rmdi
    rep_header(irep)% time          = NINT(time_mod) ! Obs time min relativ zur reftime (weil lrefend bei LETKF .false., steht hier einfach mal die obs_time seit modellstart in min.

    rep_header(irep)% time_nomi     = rep_header(irep)%time

    rep_header(irep)% time_dbase    = rep_header(irep)%time ! Provisional; should be time of data base entry section2_decoding_time

    rep_header(irep)% z_station     = rs_meta(ista)%alt_msl
    rep_header(irep)% z_modsurf     = rs_meta(ista)%msl_mod  ! bilinear interpolation
    rep_header(irep)% r_state       = ST_ACTIVE

    rep_header(irep)% vnyquist      = rs_meta(ista)%ext_nyq  ! Nyquist velocity incl. Dual-PRF

    rep_header(irep)% r_flags       = 0          ! ???

    rep_header(irep)% spec_r_flags  = zspec_r_flags

    rep_header(irep)% r_check       = FL_NONE

    rep_header(irep)% sta_corr      = 0  ! = 0

    rep_header(irep)% mdlsfc        = 1 ! Flag bit-weise, hier bit 1 gesetzt = 1 = Land

    rep_header(irep)% index_x       = rs_meta(ista)%i_nearest_mod ! nearest i-gridpoint to radar station
    rep_header(irep)% index_y       = rs_meta(ista)%j_nearest_mod ! nearest j-gridpoint to radar station

    rep_header(irep)% instype       = 1      ! selbst vergeben: 1 (WMO???)

    rep_header(irep)% phase         = 1      ! Volumenscan=1, Precip-Scan=2 (selbst vergeben)

  END DO ! irep

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_end(TRIM(yzroutine)//'_header')
#endif

!!$  ! .. Extra loop for data types which are problematic for vectorization:
!!$  DO irep=1, nw_rep
!!$
!!$    rep_header(irep)% statid(4:10)   = ' '
!!$    rep_header(irep)% statid(1:1)   = rs_meta(ista)%station_name(1:1)
!!$    rep_header(irep)% statid(2:2)   = rs_meta(ista)%station_name(2:2)
!!$    rep_header(irep)% statid(3:3)   = rs_meta(ista)%station_name(3:3)
!!$
!!$  END DO


  ! Allocate report(irep)% body
  ! -----------------------

  ! .. Very inefficient on the NEC !
!!$  DO irep=1, nw_rep
!!$
!!$ !!! This is problematic, because report%body is itself a structure with
!!$ !!! allocatable pointer component "veri_data", so ALLOCATE should fail here ...
!!$ !!!   removed allocatable attribute from veri_data!!!
!!$    ALLOCATE( report(irep)% body(report(irep)% header% l_body) , STAT=jerr )
!!$    IF (jerr/=0) THEN
!!$      WRITE( yerr ,'("ERROR in memory alloc: report(irep)%body(len_body) "      &
!!$           &,2I8)' ) irep, report(irep)% header% l_body
!!$      CALL undwech ()
!!$      RETURN
!!$    ENDIF
!!$    IF (report(irep)% offset + report(irep)% header% l_body > imax_body) THEN
!!$      ! this should never happen as 'max_body' is already checked further above
!!$      WRITE( yerr , '("ERROR: MAX_BODY for feedobs file too small ",3I8,I6)' )    &
!!$           report(irep)% offset, report(irep)% header% l_body, imax_body, irep
!!$      jerr = report(irep)% offset + report(irep)% header% l_body - imax_body
!!$      CALL undwech ()
!!$      RETURN
!!$    ENDIF
!!$
!!$    IF (n_veri >= 1) THEN
!!$      DO kk = 1, report(irep)% header% l_body
!!$        ALLOCATE ( report(irep)% body(kk)% veri_data(n_veri) , STAT=jerr )
!!$        IF (jerr/=0) THEN
!!$          WRITE( yerr ,'(a,I6,I8,I3)') &
!!$               'ERROR in alloc: report(irep)%body(kk)%veri_data(n_veri) ',irep, kk, n_veri
!!$          CALL undwech ()
!!$          RETURN
!!$        ENDIF
!!$      END DO
!!$    END IF
!!$
!!$  END DO  ! irep

  ! fill report(irep)% body
  ! -----------------------

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_begin(TRIM(yzroutine)//'_body')
#endif

  ALLOCATE ( kkv(nw_rep), jerrv(nw_rep), stat=jerr)
  IF (jerr/=0) THEN
    WRITE( yerr ,'(a,I0)') &
         'ERROR in alloc: kkv(nw_rep), jerrv(nw_rep), nw_rep = ', nw_rep
    CALL undwech ()
    RETURN
  ENDIF

  ALLOCATE ( i_ind(thin_naz*thin_nra), &
             j_ind(thin_naz*thin_nra), &
             k_ind(thin_naz*thin_nra), stat=jerr)
  IF (jerr/=0) THEN
    WRITE( yerr ,'(a)') &
         'ERROR in alloc: i_ind, j_ind, k_ind'
    CALL undwech ()
    RETURN
  ENDIF

  
  kkv(:) = 0
!!$  spec_radar(:,:)% nbody = 0
  spec_radar(:)% nbody = 0
  jerrv(:) = 0

  DO irep=1, nw_rep

    k = rind(irep)

    kk = 0

!!$    DO thin_j = 1, thin_naz
!!$    
!!$      j = (thin_j-1)*thin_az_step + 1
!!$
!!$      DO thin_i = 1, thin_nra
!!$
!!$        i = (thin_i-1)*thin_ra_step + 1

    DO ij = 1, thin_naz*thin_nra
    
      thin_i = MODULO(ij-1,thin_nra) + 1
      i = (thin_i-1)*thin_ra_step + 1
      thin_j = (ij-1)/thin_nra + 1
      j = (thin_j-1)*thin_az_step + 1

      IF (rdata_obs(j,i,k) >= -900.0_ireals .AND. rdata_mod(j,i,k) >= -900.0_ireals) THEN
        
        kk = kk + 1
        IF (kk > rep_header(irep)% l_body) THEN
          ! This should never happen!
          jerrv (irep) = irep
        ELSE
          i_ind(kk) = i
          j_ind(kk) = j
          k_ind(kk) = k
        END IF

      END IF

!!$      END DO


    END DO

    kkv(irep) = kk

!CDIR VOVERTAKE,VOB
    DO kk = 1, kkv(irep)

      i = i_ind(kk)
      j = j_ind(kk)
      k = k_ind(kk)

      rep_body(kk,irep)% varno      = ivarno       ! VN_REFL od. VN_RADVEL                
      rep_body(kk,irep)% obs        = rdata_obs(j,i,k)    
      rep_body(kk,irep)% bcor       = 0.0 ! bias corr = 0.0
      rep_body(kk,irep)% e_o        = ze_o ! dB; Beob. Fehler 0.5 dB, 0.2 m/s (wird nachher noch getuned)
      rep_body(kk,irep)% level      = rheight(j,i,k) ! Hoehe des Radar-bins in m MSL
      rep_body(kk,irep)% plevel     = rpress (j,i,k) ! Dazu korresp. Druck in Pa
      rep_body(kk,irep)% accuracy   = rep_body(kk,irep)% e_o ! Bei radar: stat. Fehler 0.5 dB bzw. 0.2 m/s
      rep_body(kk,irep)% level_typ  = VN_HEIGHT
      rep_body(kk,irep)% level_sig  = 0   ! dummy value
      rep_body(kk,irep)% state      = ST_ACTIVE ! erst mal ST_ACTIVE        
      rep_body(kk,irep)% flags      = 0         ! noch kein check gelaufen => 0
      rep_body(kk,irep)% check      = FL_NONE   ! welcher check hat zur rejection gefuehrt? -> 
      rep_body(kk,irep)% qual       = rquali_obs(j,i,k)
!!$            rep_body(kk,irep)% spec_index = i+(j-1)*nra+(k-1)*nra*naz  ! here: "total index"
      rep_body(kk,irep)% spec_index = i  ! here: range index (i) or "total index"
      
      ! fill rep_body(kk,irep)% veri_data  (if n_veri >= 1)
      ! --------------------------------------
      IF (n_veri >= 1) THEN
        
        ! .. WORKS ONLY FOR N_VERI = 1 !!!
        rep_body(kk,irep)% veri_data1 = rdata_mod(j,i,k)
        
      END IF

!!$ The following is not vectorized, so that the entire loop is only partially vectorized.
!!$ However, the performance is not so bad, and up to now no better way
!!$ of doing this could be found.
      thin_j = (j-1)/thin_ra_step + 1
      iradar = thin_j + (irep-1)*thin_naz
      spec_radar(iradar)% nbody  = spec_radar(iradar)% nbody + 1

    END DO

  END DO

  IF ( ANY(jerrv(:) > 0_iintegers) ) THEN
    ! this should never happen because of the way report(irep)%len and rep_header(irep)% l_body have been calculated above...
    imaxloc = MAXLOC(array=jerrv(:))
    WRITE( yerr ,'("ERROR: rep_header(irep)% l_body for feedobs file too small ",3I8,I6)' )    &
         rep_offset(imaxloc(1)), rep_header(imaxloc(1))% l_body, imax_body, imaxloc(1)
    jerr = rep_offset(imaxloc(1)) + rep_header(imaxloc(1))% l_body + imax_body
    CALL undwech ()
    RETURN
  END IF

!!$  DO thin_j = 1, thin_naz
!!$    
!!$    j = (thin_j-1)*thin_az_step + 1
!!$
!!$!CDIR NODEP    
!!$    DO irep = 1, nw_rep
!!$
!!$   !!! THIS IS THE WRONG INDEX ORDER ANYWAY. SHOULD BE spec_radar(thin_j,irep) instead!
!!$
!!$      spec_radar(irep,thin_j)% azimuth     = rs_meta(ista)%az_start + (j-1)*rs_meta(ista)%az_inc
!!$      spec_radar(irep,thin_j)% elevation   = rs_meta(ista)%el_arr(irep)
!!$      spec_radar(irep,thin_j)% range_start = rs_meta(ista)%ra_inc  ! yes, it is really the same as ra_inc!
!!$      spec_radar(irep,thin_j)% drange      = rs_meta(ista)%ra_inc
!!$      spec_radar(irep,thin_j)% nrange      = rs_meta(ista)%nra
!!$      
!!$    END DO
!!$  END DO
  
!CDIR NODEP    
  DO iradar = 1, thin_naz*nw_rep
    
    thin_j = MOD(iradar-1,thin_naz) + 1
    irep   = (iradar-1) / thin_naz  + 1
    j = (thin_j-1)*thin_az_step + 1
    k = rind(irep)

    spec_radar(iradar)% azimuth     = rs_meta(ista)%az_start + (j-1)*rs_meta(ista)%az_inc
    spec_radar(iradar)% elevation   = rs_meta(ista)%el_arr(k)
    spec_radar(iradar)% range_start = rs_meta(ista)%ra_inc  ! yes, it is really the same as ra_inc!
    spec_radar(iradar)% drange      = rs_meta(ista)%ra_inc
    spec_radar(iradar)% nrange      = rs_meta(ista)%nra
      

  END DO
  
  DEALLOCATE(rind,kkv,jerrv)
  DEALLOCATE(i_ind,j_ind,k_ind)

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_end(TRIM(yzroutine)//'_body')
#endif

  !-------------------------------------------------------------------------------
  !  Section 4:  Write all obs reports (in 'report') into NetCDF feedobs file
  !-------------------------------------------------------------------------------

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_begin(TRIM(yzroutine)//'_writenetcdf')
#endif

  IF (nw_rep > 0) THEN

    ihdr_pos  =  fb(ista)%n_hdr  - nw_rep + 1
    ibdy_pos  =  fb(ista)%n_body - n_body + 1
    inw_rep   =  nw_rep
    in_body   =  n_body
    imiss     =  imdi
    rmich     =  rmdich

    CALL write_report_radar_1 ( fb(ista), rep_header(1:nw_rep), rep_body(:,1:nw_rep), &
                            spec_radar(1:nw_rep*thin_naz), &
                            inw_rep, SIZE(rep_body,2), thin_naz, &
                            in_body, ihdr_pos, ibdy_pos, &
                            imiss, rmich, jerr, yerr, &
                            yzstatid=rs_meta(ista)%station_name(1:3))
    !   =================

    IF (jerr/=0) THEN
      yerr = 'ERROR from write_report: '//yerr
      CALL undwech ()
      RETURN
    END IF

  ENDIF  !  nw_rep

  ! print statistics
  ! ----------------------------------------------
  IF ( lastpr ) THEN
    WRITE (*,'(A,/,T10,A)')     '    NetCDF FEEDOBS FILE created: ' ,                &
               TRIM(rs_meta(ista)%fdbkfile)
    WRITE (*,'(A,I10,A,I8)') '    Total number of reports in fdbk file:'        &
                           , fb(ista)% n_hdr,  " ; max allowed : ", imax_rep
    WRITE (*,'(A,I10,A,I8)') '    Total number of bodys in fdbk file: '         &
                           , fb(ista)% n_body, " ; max allowed : ", imax_body
  END IF


  ! set some global attributes (e.g. n_hdr and n_body) to the actual values and close FOF
  ! -------------------------------------------------------------------------------------
  jerr          = nf_redef ( fb(ista)% nc% ncid )
  IF ((jerr/=0) .AND. (kerr == 0)) kerr = 51
  fb(ista)% nc% error = nf_put_att_int ( fb(ista)%nc% ncid, NF_GLOBAL, 'n_hdr',NF_INT, 1 &
       , fb(ista)% n_hdr )
  fb(ista)% nc% error = nf_put_att_int ( fb(ista)%nc% ncid, NF_GLOBAL,'n_body',NF_INT, 1 &
       , fb(ista)% n_body )
  fb(ista)% nc% error = nf_put_att_int ( fb(ista)%nc% ncid, NF_GLOBAL,'n_radar',NF_INT, 1 &
       , fb(ista)% n_radar )
  jerr          = nf_enddef ( fb(ista)% nc% ncid )
  IF ((jerr/=0) .AND. (kerr == 0)) kerr = 52
  IF (jerr/=0) THEN
    IF (kerr == 51)                                                          &
         WRITE( yerr,'("ERROR in nf_redef  in '//TRIM(yzroutine)//'")' )
    IF (kerr == 52)                                                          &
         WRITE( yerr,'("ERROR in nf_enddef in '//TRIM(yzroutine)//'")' )
    CALL undwech ()
    RETURN
  ENDIF

#if defined (FTRACE_RADAR) && defined(_FTRACE)
CALL ftrace_region_end(TRIM(yzroutine)//'_writenetcdf')
#endif

  CALL undwech ()

  IF (ldebug_radsim) WRITE (*,*)  'done with '//TRIM(yzroutine)//' on proc ', my_cart_id

  !-------------------------------------------------------------------------------
  ! End of module procedure obs_write_cdf_feedobs
  !-------------------------------------------------------------------------------

CONTAINS

  SUBROUTINE undwech
    CALL close_fdbk   ( fb(ista) )
    !   ===============
    IF (lastpr) CALL cleanup_fdbk ( fb(ista) )
    !   =================    
  END SUBROUTINE undwech


END SUBROUTINE obs_write_cdf_feedobs

#endif


END MODULE src_radar



